@@ -1,7 +1,8 @@
 #!/usr/bin/env python
+
+# Test c89 std code compliance
   
 configure_options = [
-  '--with-shared=0',
   '--with-cc=gcc -std=c89',
   '--with-fc=f77',
   '--download-mpich=1',
@@ -14,6 +15,3 @@ configure_options = [
 if __name__ == '__main__':
   import configure
   configure.petsc_configure(configure_options)
-
-# Extra options used for testing locally
-test_options = []
