@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 
-# Note: Intel 7.1 Fortran cannot work with g++ 3.3
 configure_options = [
   '--with-mpi-dir=/home/petsc/soft/linux-debian_sarge-gcc-pgf90/mpich-1.2.6',
   '--download-f-blas-lapack=1'
@@ -9,6 +8,3 @@ configure_options = [
 if __name__ == '__main__':
   import configure
   configure.petsc_configure(configure_options)
-
-# Extra options used for testing locally
-test_options = []
