@@ -1,5 +1,7 @@
 #!/usr/bin/env python
 
+# ******* Currently not tested **********
+
 configure_options = [
   '--with-mpi-include=/home/petsc/soft/linux-rh73/mpich-1.2.4/include',
   '--with-mpi-lib=[/home/petsc/soft/linux-rh73/mpich-1.2.4/lib/libmpich.a,/home/petsc/soft/linux-rh73/mpich-1.2.4/lib/libpmpich.a]',
@@ -21,6 +23,3 @@ configure_options = [
 if __name__ == '__main__':
   import configure
   configure.petsc_configure(configure_options)
-
-# Extra options used for testing locally
-test_options = []
