@@ -122,6 +122,9 @@
       PetscEnum MAT_NOT_SYMMETRIC,MAT_HERMITIAN
       PetscEnum MAT_NOT_STRUCTURALLY_SYMMETRIC,MAT_NOT_HERMITIAN
       PetscEnum MAT_SYMMETRY_ETERNAL,MAT_NOT_SYMMETRY_ETERNAL
+      PetscEnum MAT_USE_COMPRESSEDROW,MAT_DO_NOT_USE_COMPRESSEDROW
+      PetscEnum MAT_IGNORE_LOWER_TRIANGULAR,MAT_ERROR_LOWER_TRIANGULAR
+      PetscEnum MAT_GETROW_UPPERTRIANGULAR
 
       parameter (MAT_ROW_ORIENTED=1,MAT_COLUMN_ORIENTED=2)
       parameter (MAT_ROWS_SORTED=4,MAT_COLUMNS_SORTED=8)
@@ -143,6 +146,11 @@
       parameter (MAT_NOT_STRUCTURALLY_SYMMETRIC=85)
       parameter (MAT_NOT_HERMITIAN=86)
       parameter (MAT_SYMMETRY_ETERNAL=87,MAT_NOT_SYMMETRY_ETERNAL=88)
+      parameter (MAT_USE_COMPRESSEDROW=89)
+      parameter (MAT_DO_NOT_USE_COMPRESSEDROW=90)
+      parameter (MAT_IGNORE_LOWER_TRIANGULAR=91)
+      parameter (MAT_ERROR_LOWER_TRIANGULAR=92)
+      parameter (MAT_GETROW_UPPERTRIANGULAR=93)
 
 !
 !  MatDuplicateOption
