@@ -209,13 +209,13 @@ M*/
    Level: developer
 
     Example:
-      PetscPolymorphicScalar(VecAXPY,(PetscScalar _t,Vec x,Vec y),(&_T,x,y)) generates the new routine
-           PetscErrorCode VecAXPY(PetscScalar _t,Vec x,Vec y) = {PetscScalar _T = _t; return VecAXPY(&_T,x,y);}
+      PetscPolymorphicScalar(VecAXPY,(PetscScalar _val,Vec x,Vec y),(&_Val,x,y)) generates the new routine
+           PetscErrorCode VecAXPY(PetscScalar _val,Vec x,Vec y) = {PetscScalar _Val = _val; return VecAXPY(&_Val,x,y);}
 
 .seealso: PetscPolymorphicFunction(),PetscPolymorphicSubroutine()
 
 M*/
-#define PetscPolymorphicScalar(A,B,C) PETSC_STATIC_INLINE PetscErrorCode A B {PetscScalar _T = _t; return A C;}
+#define PetscPolymorphicScalar(A,B,C) PETSC_STATIC_INLINE PetscErrorCode A B {PetscScalar _Val = _val; return A C;}
 
 /*MC
       PetscPolymorphicFunction - allows defining a C++ polymorphic version of 
@@ -702,7 +702,7 @@ M*/
    PetscFree - Frees memory
 
    Input Parameter:
-.   memory - memory to free
+.   memory - memory to free (the pointer is ALWAYS set to 0 upon sucess)
 
    Synopsis:
    PetscErrorCode PetscFree(void *memory)
@@ -932,11 +932,17 @@ EXTERN PetscErrorCode PETSC_DLLEXPORT   PetscMallocSetDumpLog(void);
 
 /*
     Variable type where we stash PETSc object pointers in Fortran.
-    Assumes that sizeof(long) == sizeof(void*) which is true on 
-    all machines that we know. If this is not the case you should change
-    the long below to something appropriate
+    On most machines size(pointer) == sizeof(long) - except windows
+    where its sizeof(long long)
 */     
+
+#if (PETSC_SIZEOF_VOID_P) == (PETSC_SIZEOF_LONG)
 #define PetscFortranAddr   long
+#elif  (PETSC_SIZEOF_VOID_P) == (PETSC_SIZEOF_LONG_LONG)
+#define PetscFortranAddr   long long
+#else
+#error "Unknown size for PetscFortranAddr! Send us a bugreport at petsc-maint@mcs.anl.gov"
+#endif
 
 /*E
     PetscDataType - Used for handling different basic data types.
@@ -1133,6 +1139,7 @@ typedef PetscErrorCode (*PetscErrorCodeFunction)(void);
     Functions that can act on any PETSc object.
 */
 EXTERN PetscErrorCode PETSC_DLLEXPORT PetscObjectCreate(MPI_Comm,PetscObject*);
+EXTERN PetscErrorCode PETSC_DLLEXPORT PetscObjectCreateGeneric(MPI_Comm, PetscCookie, const char [], PetscObject *);
 EXTERN PetscErrorCode PETSC_DLLEXPORT PetscObjectDestroy(PetscObject);
 EXTERN PetscErrorCode PETSC_DLLEXPORT PetscObjectExists(PetscObject,PetscTruth*);
 EXTERN PetscErrorCode PETSC_DLLEXPORT PetscObjectGetComm(PetscObject,MPI_Comm *);
@@ -1288,9 +1295,7 @@ EXTERN PetscErrorCode PETSC_DLLEXPORT PetscMPIDump(FILE*);
 /*
     Defines the base data structures for all PETSc objects
 */
-PETSC_EXTERN_CXX_END
 #include "private/petscimpl.h"
-PETSC_EXTERN_CXX_BEGIN
 /*
      Defines PETSc profiling.
 */
@@ -1324,11 +1329,12 @@ EXTERN PetscErrorCode PETSC_DLLEXPORT  PetscFOpen(MPI_Comm,const char[],const ch
 EXTERN PetscErrorCode PETSC_DLLEXPORT  PetscFClose(MPI_Comm,FILE*);
 EXTERN PetscErrorCode PETSC_DLLEXPORT  PetscFPrintf(MPI_Comm,FILE*,const char[],...) PETSC_PRINTF_FORMAT_CHECK(3,4);
 EXTERN PetscErrorCode PETSC_DLLEXPORT  PetscPrintf(MPI_Comm,const char[],...)  PETSC_PRINTF_FORMAT_CHECK(2,3);
+EXTERN PetscErrorCode PETSC_DLLEXPORT  PetscSNPrintf(char*,size_t,const char [],...);
 
 /* These are used internally by PETSc ASCII IO routines*/
 #include <stdarg.h>
-EXTERN PetscErrorCode PETSC_DLLEXPORT  PetscVSNPrintf(char*,size_t,const char*,va_list);
-EXTERN PetscErrorCode PETSC_DLLEXPORT  PetscVFPrintf(FILE*,const char*,va_list);
+EXTERN PetscErrorCode PETSC_DLLEXPORT  PetscVSNPrintf(char*,size_t,const char[],va_list);
+EXTERN PetscErrorCode PETSC_DLLEXPORT  PetscVFPrintf(FILE*,const char[],va_list);
 
 /*MC
     PetscErrorPrintf - Prints error messages.
