@@ -1,8 +1,10 @@
 #ifndef __PETSCCTABLE_H
 #define __PETSCCTABLE_H
+#include "petsc.h"
+PETSC_EXTERN_CXX_BEGIN
 /* Contributed by - Mark Adams */
 
-typedef struct _p_PetscTable * PetscTable;
+typedef struct _n_PetscTable* PetscTable;
 typedef PetscInt* PetscTablePosition;  
 
 EXTERN PetscErrorCode PETSC_DLLEXPORT PetscTableCreate(const PetscInt,PetscTable*);
@@ -15,5 +17,5 @@ EXTERN PetscErrorCode PETSC_DLLEXPORT PetscTableFind(PetscTable,const PetscInt,P
 EXTERN PetscErrorCode PETSC_DLLEXPORT PetscTableGetHeadPosition(PetscTable,PetscTablePosition*);
 EXTERN PetscErrorCode PETSC_DLLEXPORT PetscTableGetNext(PetscTable,PetscTablePosition*,PetscInt*,PetscInt*);
 EXTERN PetscErrorCode PETSC_DLLEXPORT PetscTableRemoveAll(PetscTable);
-
+PETSC_EXTERN_CXX_END
 #endif
