@@ -48,6 +48,8 @@ struct _n_DMMG {
   Vec            w,work1,work2;         /* global vectors */
   Vec            lwork1;
 
+  PetscErrorCode (*lfj)(void);          /* function used when computing Jacobian via FD, usually da->lf */
+
   /* FAS only */
   NLF            nlf;                   /* FAS smoother object */
   VecScatter     inject;                /* inject from this level to the next coarsest */
@@ -62,6 +64,8 @@ EXTERN PetscErrorCode PETSCSNES_DLLEXPORT DMMGDestroy(DMMG*);
 EXTERN PetscErrorCode PETSCSNES_DLLEXPORT DMMGSetUp(DMMG*);
 EXTERN PetscErrorCode PETSCSNES_DLLEXPORT DMMGSetKSP(DMMG*,PetscErrorCode (*)(DMMG,Vec),PetscErrorCode (*)(DMMG,Mat,Mat));
 EXTERN PetscErrorCode PETSCSNES_DLLEXPORT DMMGSetSNES(DMMG*,PetscErrorCode (*)(SNES,Vec,Vec,void*),PetscErrorCode (*)(SNES,Vec,Mat*,Mat*,MatStructure*,void*));
+
+EXTERN PetscErrorCode PETSCSNES_DLLEXPORT DMMGSetInitialGuessLocal(DMMG*,PetscErrorCode (*)(DALocalInfo*,void*));
 EXTERN PetscErrorCode PETSCSNES_DLLEXPORT DMMGSetInitialGuess(DMMG*,PetscErrorCode (*)(DMMG,Vec));
 EXTERN PetscErrorCode PETSCSNES_DLLEXPORT DMMGInitialGuessCurrent(DMMG,Vec);
 EXTERN PetscErrorCode PETSCSNES_DLLEXPORT DMMGView(DMMG*,PetscViewer);
@@ -94,6 +98,7 @@ EXTERN PetscErrorCode PETSCSNES_DLLEXPORT DMMGSetSNESLocalib_Private(DMMG*,Petsc
 #  define DMMGSetSNESLocalib(dmmg,function,ad_function,admf_function) DMMGSetSNESLocalib_Private(dmmg,(PetscErrorCode(*)(DALocalInfo*,MatStencil*,void*,PetscScalar*,void*))function,0,0)
 #endif
 
+extern PetscErrorCode DMMGSetSNESLocalFD(DMMG*,DALocalFunction1);
 
 /*MC
    DMMGGetRHS - Returns the right hand side vector from a DMMG solve on the finest grid
@@ -373,5 +378,8 @@ M*/
 M*/
 #define DMMGGetDMMG(ctx)              (ctx)[(ctx)[0]->nlevels-1]
 
+#define PCDMMG      "pcdmmg"
+EXTERN PetscErrorCode PCDMMGSetDMMG(PC,DMMG*);
+
 PETSC_EXTERN_CXX_END
 #endif
