@@ -142,10 +142,7 @@ $   IS_COLORING_GHOSTED - includes colors for ghost points
 .seealso: DAGetColoring()
 E*/
 typedef enum {IS_COLORING_LOCAL,IS_COLORING_GHOSTED} ISColoringType;
-
-#define MPIU_COLORING_VALUE MPI_CHAR
-#define IS_COLORING_MAX     255
-typedef unsigned char ISColoringValue;
+typedef unsigned PETSC_IS_COLOR_VALUE_TYPE ISColoringValue;
 EXTERN PetscErrorCode PETSCVEC_DLLEXPORT ISAllGatherColors(MPI_Comm,PetscInt,ISColoringValue*,PetscInt*,ISColoringValue*[]);
 
 /*S
@@ -161,7 +158,7 @@ EXTERN PetscErrorCode PETSCVEC_DLLEXPORT ISAllGatherColors(MPI_Comm,PetscInt,ISC
 
 .seealso:  ISColoringCreate(), ISColoringGetIS(), ISColoringView(), ISColoringGetIS()
 S*/
-struct _p_ISColoring {
+struct _n_ISColoring {
   PetscInt        refct;
   PetscInt        n;                /* number of colors */
   IS              *is;              /* for each color indicates columns */
@@ -170,9 +167,9 @@ struct _p_ISColoring {
   PetscInt        N;                /* number of columns */
   ISColoringType  ctype;
 };
-typedef struct _p_ISColoring* ISColoring;
+typedef struct _n_ISColoring* ISColoring;
 
-EXTERN PetscErrorCode PETSCVEC_DLLEXPORT ISColoringCreate(MPI_Comm,PetscInt,const ISColoringValue[],ISColoring*);
+EXTERN PetscErrorCode PETSCVEC_DLLEXPORT ISColoringCreate(MPI_Comm,PetscInt,PetscInt,const ISColoringValue[],ISColoring*);
 EXTERN PetscErrorCode PETSCVEC_DLLEXPORT ISColoringDestroy(ISColoring);
 EXTERN PetscErrorCode PETSCVEC_DLLEXPORT ISColoringView(ISColoring,PetscViewer);
 EXTERN PetscErrorCode PETSCVEC_DLLEXPORT ISColoringGetIS(ISColoring,PetscInt*,IS*[]);
