@@ -6,32 +6,37 @@
 #define __PetscLog_H
 #include "petsc.h"  
 PETSC_EXTERN_CXX_BEGIN
-/*
-  Each PETSc object class has it's own cookie (internal integer in the 
-  data structure used for error checking). These are all defined by an offset 
-  from the lowest one, PETSC_COOKIE.
-*/
-#define PETSC_COOKIE 1211211
-extern PetscCookie PETSC_LARGEST_COOKIE;
+
 #define PETSC_EVENT  1311311
 extern PetscEvent PETSC_LARGEST_EVENT;
 
-/* Events for the Petsc standard library */
-extern PetscEvent PETSC_DLLEXPORT PETSC_Barrier;
-
 /* Global flop counter */
 extern PetscLogDouble PETSC_DLLEXPORT _TotalFlops;
 
 /* General logging of information; different from event logging */
-EXTERN PetscErrorCode PETSC_DLLEXPORT PetscLogInfo_Private(void*,const char[],...) PETSC_PRINTF_FORMAT_CHECK(2,3);
-#if defined(PETSC_USE_DEBUG)
-#define PetscLogInfo(A)      PetscLogInfo_Private A
+EXTERN PetscErrorCode PETSC_DLLEXPORT PetscInfo_Private(const char[],void*,const char[],...) PETSC_PRINTF_FORMAT_CHECK(3,4);
+#if defined(PETSC_USE_INFO)
+#define PetscInfo(A,S)                       PetscInfo_Private(__FUNCT__,A,S)
+#define PetscInfo1(A,S,a1)                   PetscInfo_Private(__FUNCT__,A,S,a1)
+#define PetscInfo2(A,S,a1,a2)                PetscInfo_Private(__FUNCT__,A,S,a1,a2)
+#define PetscInfo3(A,S,a1,a2,a3)             PetscInfo_Private(__FUNCT__,A,S,a1,a2,a3)
+#define PetscInfo4(A,S,a1,a2,a3,a4)          PetscInfo_Private(__FUNCT__,A,S,a1,a2,a3,a4)
+#define PetscInfo5(A,S,a1,a2,a3,a4,a5)       PetscInfo_Private(__FUNCT__,A,S,a1,a2,a3,a4,a5)
+#define PetscInfo6(A,S,a1,a2,a3,a4,a5,a6)    PetscInfo_Private(__FUNCT__,A,S,a1,a2,a3,a4,a5,a6)
+#define PetscInfo7(A,S,a1,a2,a3,a4,a5,a6,a7) PetscInfo_Private(__FUNCT__,A,S,a1,a2,a3,a4,a5,a6,a7)
 #else 
-#define PetscLogInfo(A)      0
+#define PetscInfo(A,S)                       0
+#define PetscInfo1(A,S,a1)                   0
+#define PetscInfo2(A,S,a1,a2)                0
+#define PetscInfo3(A,S,a1,a2,a3)             0
+#define PetscInfo4(A,S,a1,a2,a3,a4)          0
+#define PetscInfo5(A,S,a1,a2,a3,a4,a5)       0
+#define PetscInfo6(A,S,a1,a2,a3,a4,a5,a6)    0
+#define PetscInfo7(A,S,a1,a2,a3,a4,a5,a6,a7) 0
 #endif
-EXTERN PetscErrorCode PETSC_DLLEXPORT PetscLogInfoDeactivateClass(PetscCookie);
-EXTERN PetscErrorCode PETSC_DLLEXPORT PetscLogInfoActivateClass(PetscCookie);
-extern PetscTruth     PETSC_DLLEXPORT PetscLogPrintInfo;  /* if true, indicates PetscLogInfo() is turned on */
+EXTERN PetscErrorCode PETSC_DLLEXPORT PetscInfoDeactivateClass(PetscCookie);
+EXTERN PetscErrorCode PETSC_DLLEXPORT PetscInfoActivateClass(PetscCookie);
+extern PetscTruth     PETSC_DLLEXPORT PetscLogPrintInfo;  /* if true, indicates PetscInfo() is turned on */
 
 #if defined(PETSC_USE_LOG)  /* --- Logging is turned on --------------------------------*/
 
@@ -61,11 +66,11 @@ EXTERN PetscErrorCode PETSC_DLLEXPORT        PetscLogMPEDump(const char[]);
 extern PetscTruth UseMPE;
 #define PETSC_LOG_EVENT_MPE_BEGIN(e) \
   ((UseMPE && _stageLog->stageInfo[_stageLog->curStage].eventLog->eventInfo[e].active) ? \
-   MPE_Log_event(_stageLog->eventLog->eventInfo[e].mpe_id_begin,0,(char*)"") : 0)
+   MPE_Log_event(_stageLog->eventLog->eventInfo[e].mpe_id_begin,0,NULL) : 0)
 
 #define PETSC_LOG_EVENT_MPE_END(e) \
   ((UseMPE && _stageLog->stageInfo[_stageLog->curStage].eventLog->eventInfo[e].active) ? \
-   MPE_Log_event(_stageLog->eventLog->eventInfo[e].mpe_id_end,0,(char*)"") : 0)
+   MPE_Log_event(_stageLog->eventLog->eventInfo[e].mpe_id_end,0,NULL) : 0)
 
 #else 
 #define PETSC_LOG_EVENT_MPE_BEGIN(e) 0 
@@ -139,14 +144,14 @@ extern PETSC_DLLEXPORT int            PETSC_DUMMY_COUNT;
 
 /* We must make these structures available if we are to access the event
    activation flags in the PetscLogEventBegin/End() macros. If we forced a
-   function call each time, we could leave these structures in plog.h
+   function call each time, we could make these private.
 */
 /* Default log */
-typedef struct _StageLog *StageLog;
+typedef struct _n_StageLog *StageLog;
 extern PETSC_DLLEXPORT StageLog _stageLog;
 
 /* A simple stack (should replace) */
-typedef struct _IntStack *IntStack;
+typedef struct _n_IntStack *IntStack;
 
 /* The structures for logging performance */
 typedef struct _EventPerfInfo {
@@ -185,30 +190,30 @@ typedef struct _EventRegInfo {
 #endif
 } EventRegInfo;
 
-typedef struct _EventRegLog *EventRegLog;
-struct _EventRegLog {
+typedef struct _n_EventRegLog *EventRegLog;
+struct _n_EventRegLog {
   int           numEvents; /* The number of registered events */
   int           maxEvents; /* The maximum number of events */
   EventRegInfo *eventInfo; /* The registration information for each event */
 };
 
-typedef struct _EventPerfLog *EventPerfLog;
-struct _EventPerfLog {
+typedef struct _n_EventPerfLog *EventPerfLog;
+struct _n_EventPerfLog {
   int            numEvents; /* The number of logging events */
   int            maxEvents; /* The maximum number of events */
   EventPerfInfo *eventInfo; /* The performance information for each event */
 };
 
 /* The structure for logging class information */
-typedef struct _ClassRegLog *ClassRegLog;
-struct _ClassRegLog {
+typedef struct _n_ClassRegLog *ClassRegLog;
+struct _n_ClassRegLog {
   int           numClasses; /* The number of classes registered */
   int           maxClasses; /* The maximum number of classes */
   ClassRegInfo *classInfo;  /* The structure for class information (cookies are monotonicly increasing) */
 };
 
-typedef struct _ClassPerfLog *ClassPerfLog;
-struct _ClassPerfLog {
+typedef struct _n_ClassPerfLog *ClassPerfLog;
+struct _n_ClassPerfLog {
   int            numClasses; /* The number of logging classes */
   int            maxClasses; /* The maximum number of classes */
   ClassPerfInfo *classInfo;  /* The structure for class information (cookies are monotonicly increasing) */
@@ -223,7 +228,7 @@ typedef struct _StageInfo {
   ClassPerfLog  classLog; /* The class information for this stage */
 } StageInfo;
 
-struct _StageLog {
+struct _n_StageLog {
   /* Size information */
   int         numStages; /* The number of registered stages */
   int         maxStages; /* The maximum number of stages */
@@ -274,6 +279,9 @@ EXTERN PetscErrorCode PETSC_DLLEXPORT StageLogGetClassPerfLog(StageLog, int, Cla
 EXTERN PetscErrorCode PETSC_DLLEXPORT StageLogGetEventPerfLog(StageLog, int, EventPerfLog *);
 
 /*
+     These are used internally in the PETSc routines to keep a count of MPI messages and 
+   their sizes.
+
      This does not work for MPI-Uni because our include/mpiuni/mpi.h file
    uses macros to defined the MPI operations. 
 
@@ -351,6 +359,8 @@ EXTERN PetscErrorCode PETSC_DLLEXPORT StageLogGetEventPerfLog(StageLog, int, Eve
 
 #define PetscLogEventActivateClass(a)   0
 #define PetscLogEventDeactivateClass(a) 0
+#define PetscLogClassRegister(a,b)      PetscCookieRegister(a)
+#define PetscLogEventSetActiveAll(a,b)  0
 
 #define _PetscLogPLB                        0
 #define _PetscLogPLE                        0
@@ -402,12 +412,11 @@ EXTERN PetscErrorCode PETSC_DLLEXPORT PetscLogObjectState(PetscObject,const char
 #define StageLogSetVisible(stageLog, stage, visible) 0
 #define StageLogGetVisible(stageLog, stage, visible) 0
 #define StageLogGetStage(stageLog, name, stage)      0
+#define PetscLogStageGetId(a,b)                      (*(b)=0,0)
+#define PetscLogStageSetActive(a,b)                  0
 
 #endif   /* PETSC_USE_LOG */
 
-extern PETSC_DLLEXPORT PetscTruth PetscPreLoadingUsed;       /* true if we are or have done preloading */
-extern PETSC_DLLEXPORT PetscTruth PetscPreLoadingOn;         /* true if we are currently in a preloading calculation */
-
 #define PreLoadBegin(flag,name) \
 {\
   PetscTruth PreLoading = flag;\
