@@ -7,33 +7,33 @@ PETSC_EXTERN_CXX_BEGIN
 /* 
    Current PETSc version number and release date, also listed in
     Web page
-    docs/tex/manual/intro.tex,
-    docs/tex/manual/manual.tex.
-    docs/website/index.html.
+    src/docs/tex/manual/intro.tex,
+    src/docs/tex/manual/manual.tex.
+    src/docs/website/index.html.
 */
 #define PETSC_VERSION_RELEASE    1
 #define PETSC_VERSION_MAJOR      2
 #define PETSC_VERSION_MINOR      3
-#define PETSC_VERSION_SUBMINOR   1
-#define PETSC_VERSION_PATCH      11
-#define PETSC_VERSION_DATE       "February, 3, 2006"
-#define PETSC_VERSION_PATCH_DATE "Mon Mar 20 15:51:27 CST 2006"
-#define PETSC_VERSION_BK         "balay@asterix.mcs.anl.gov|ChangeSet|20060320215037|19363"
+#define PETSC_VERSION_SUBMINOR   2
+#define PETSC_VERSION_PATCH      6
+#define PETSC_VERSION_DATE       "Septenber, 1, 2006"
+#define PETSC_VERSION_PATCH_DATE "Fri Nov 10 15:19:07 CST 2006"
+#define PETSC_VERSION_HG         "3bb0895674a77d3b657513febd3155c18e037df2"
 #define PETSC_AUTHOR_INFO        "\
        The PETSc Team\n\
     petsc-maint@mcs.anl.gov\n\
  http://www.mcs.anl.gov/petsc/\n"
 
 #if (PETSC_VERSION_RELEASE == 1)
-#define PetscGetVersion(version) (sprintf(*(version),"Petsc Release Version %d.%d.%d, Patch %d, ", \
+#define PetscGetVersion(version,len) (PetscSNPrintf(*(version),len,"Petsc Release Version %d.%d.%d, Patch %d, ", \
                                          PETSC_VERSION_MAJOR,PETSC_VERSION_MINOR, PETSC_VERSION_SUBMINOR, \
                                          PETSC_VERSION_PATCH),PetscStrcat(*(version),PETSC_VERSION_PATCH_DATE), \
-                                         PetscStrcat(*(version),"\nBK revision: "),PetscStrcat(*(version),PETSC_VERSION_BK),0)
+                                         PetscStrcat(*(version)," HG revision: "),PetscStrcat(*(version),PETSC_VERSION_HG),0)
 #else
-#define PetscGetVersion(version) (sprintf(*(version),"Petsc Development Version %d.%d.%d, Patch %d, ", \
+#define PetscGetVersion(version,len) (PetscSNPrintf(*(version),len,"Petsc Development Version %d.%d.%d, Patch %d, ", \
                                          PETSC_VERSION_MAJOR,PETSC_VERSION_MINOR, PETSC_VERSION_SUBMINOR, \
                                          PETSC_VERSION_PATCH),PetscStrcat(*(version),PETSC_VERSION_PATCH_DATE), \
-                                         PetscStrcat(*(version),"\nBK revision: "),PetscStrcat(*(version),PETSC_VERSION_BK),0)
+                                         PetscStrcat(*(version)," HG revision: "),PetscStrcat(*(version),PETSC_VERSION_HG),0)
 #endif
 
 /*MC
@@ -42,11 +42,14 @@ PETSC_EXTERN_CXX_BEGIN
     Output Parameter:
 .   version - version string
 
+    Input Parameter:
+.   len - length of the string
+
     Level: developer
 
     Usage:
     char version[256];
-    PetscGetVersion(&version);
+    PetscGetVersion(&version,256);
 
     Fortran Note:
     This routine is not supported in Fortran.
