@@ -53,8 +53,11 @@
         Creates a dictionary in the current directory with a parent, and removes
         the given key. If "parent" is "None", no parent is assigned.
 '''
-import project          # This is necessary for us to create Project objects on load
-import build.buildGraph # This is necessary for us to create BuildGraph objects on load
+try:
+  import project          # This is necessary for us to create Project objects on load
+  import build.buildGraph # This is necessary for us to create BuildGraph objects on load
+except ImportError:
+  pass
 import nargs
 
 import cPickle
@@ -66,7 +69,7 @@ Arg class, which wraps the usual value.'''
   # The server will self-shutdown after this many seconds
   shutdownDelay = 60*60*5
 
-  def __init__(self, parentAddr = None, parentDirectory = None, load = 1):
+  def __init__(self, parentAddr = None, parentDirectory = None, load = 1, autoShutdown = 1):
     import atexit
     import time
     import xdrlib
@@ -89,7 +92,8 @@ Arg class, which wraps the usual value.'''
     self.writeLogLine('Greetings')
     self.connectParent(self.parentAddr, self.parentDirectory)
     if load: self.load()
-    atexit.register(self.shutdown)
+    if autoShutdown:
+      atexit.register(self.shutdown)
     self.writeLogLine('SERVER: Last access '+str(self.lastAccess))
     return
 
@@ -99,6 +103,7 @@ Arg class, which wraps the usual value.'''
     d = self.__dict__.copy()
     if 'parent'    in d: del d['parent']
     if 'saveTimer' in d: del d['saveTimer']
+    if '_setCommandLine' in d: del d['_setCommandLine']
     del d['packer']
     del d['unpacker']
     del d['logFile']
@@ -118,7 +123,13 @@ Arg class, which wraps the usual value.'''
   def setupLogFile(self, filename = 'RDict.log'):
     if not self.logFile is None:
       self.logFile.close()
-    self.logFile = file('RDict.log', 'a')
+    if os.path.isfile(filename) and os.stat(filename).st_size > 10*1024*1024:
+      if os.path.isfile(filename+'.bkp'):
+        os.remove(filename+'.bkp')
+      os.rename(filename, filename+'.bkp')
+      self.logFile = file(filename, 'w')
+    else:
+      self.logFile = file(filename, 'a')
     return
 
   def writeLogLine(self, message):
@@ -132,7 +143,7 @@ Arg class, which wraps the usual value.'''
     '''Returns the length of both the local and parent dictionaries'''
     length = dict.__len__(self)
     if not self.parent is None:
-      length += self.send()
+      length = length + self.send()
     return length
 
   def getType(self, key):
@@ -173,6 +184,7 @@ Arg class, which wraps the usual value.'''
     else:
       self.writeLogLine('__getitem__: Setting local type for '+key)
       dict.__setitem__(self, key, nargs.Arg(key))
+      self.save()
     self.writeLogLine('__getitem__: Setting local value for '+key)
     return dict.__getitem__(self, key).getValue()
 
@@ -595,6 +607,7 @@ Arg class, which wraps the usual value.'''
     '''Load the saved dictionary'''
     if not self.parentDirectory is None and os.path.samefile(os.getcwd(), self.parentDirectory):
       return
+    self.saveFilename = os.path.abspath(self.saveFilename)
     if os.path.exists(self.saveFilename):
       try:
         dbFile = file(self.saveFilename)
