@@ -123,6 +123,59 @@ class Framework(config.base.Configure, script.LanguageProcessor):
           dirs.extend(self.listDirs(os.path.join(base, dir),rest ))            
     return dirs
 
+  def getArchitecture(self):
+    import sys
+
+    auxDir = None
+    searchDirs = [os.path.join(self.root, 'packages')] + sys.path
+    for d in searchDirs:
+      if os.path.isfile(os.path.join(d, 'config.sub')):
+        auxDir      = d
+        configSub   = os.path.join(auxDir, 'config.sub')
+        configGuess = os.path.join(auxDir, 'config.guess')
+        break
+    if auxDir is None:
+      self.logPrintBox('Unable to locate config.sub in '+str(searchDirs)+'.\nYour BuildSystem installation is incomplete.\n Get BuildSystem again', 'screen')
+      return ('Unknown', 'Unknown', sys.platform)
+    try:
+      host   = config.base.Configure.executeShellCommand(self.shell+' '+configGuess, log = self.log)[0]
+      output = config.base.Configure.executeShellCommand(self.shell+' '+configSub+' '+host, log = self.log)[0]
+    except RuntimeError, e:
+      fd = open(configGuess)
+      data = fd.read()
+      fd.close()
+      if data.find('\r\n') >= 0:
+        raise RuntimeError('''It appears BuildSystem.tar.gz is uncompressed on Windows (perhaps with Winzip)
+          and files copied over to Unix/Linux. Windows introduces LF characters which are
+          inappropriate on other systems. Please use gunzip/tar on the install machine.\n''')
+      raise RuntimeError('Unable to determine host type using '+configSub+': '+str(e))
+    m = re.match(r'^(?P<cpu>[^-]*)-(?P<vendor>[^-]*)-(?P<os>.*)$', output)
+    if not m:
+      raise RuntimeError('Unable to parse output of '+configSub+': '+output)
+    return (m.group('cpu'), m.group('vendor'), m.group('os'))
+
+  def getHostCPU(self):
+    if not hasattr(self, '_host_cpu'):
+      return self.argDB['with-host-cpu']
+    return self._host_cpu
+  def setHostCPU(self, cpu):
+    self._host_cpu = cpu
+  host_cpu = property(getHostCPU, setHostCPU, doc = 'Machine CPU')
+  def getHostVendor(self):
+    if not hasattr(self, '_host_vendor'):
+      return self.argDB['with-host-vendor']
+    return self._host_vendor
+  def setHostVendor(self, vendor):
+    self._host_vendor = vendor
+  host_vendor = property(getHostVendor, setHostVendor, doc = 'Machine Vendor')
+  def getHostOS(self):
+    if not hasattr(self, '_host_os'):
+      return self.argDB['with-host-os']
+    return self._host_os
+  def setHostOS(self, os):
+    self._host_os = os
+  host_os = property(getHostOS, setHostOS, doc = 'Machine OS')
+
   def setupHelp(self, help):
     import nargs
 
@@ -141,7 +194,9 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     if list: searchdirs.append(list[-1])
     list = self.listDirs('/opt/','intel_fc_[0-9.]*/bin')
     if list: searchdirs.append(list[-1])
-    
+
+    host_cpu, host_vendor, host_os = self.getArchitecture()
+
     help.addArgument('Framework', '-configModules',       nargs.Arg(None, None, 'A list of Python modules with a Configure class'))
     help.addArgument('Framework', '-ignoreCompileOutput', nargs.ArgBool(None, 1, 'Ignore compiler output'))
     help.addArgument('Framework', '-ignoreLinkOutput',    nargs.ArgBool(None, 1, 'Ignore linker output'))
@@ -150,7 +205,11 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     help.addArgument('Framework', '-with-alternatives',   nargs.ArgBool(None, 0, 'Provide a choice among alternative package installations'))
     help.addArgument('Framework', '-search-dirs',         nargs.Arg(None, searchdirs, 'A list of directories used to search for executables'))
     help.addArgument('Framework', '-package-dirs',        nargs.Arg(None, packagedirs, 'A list of directories used to search for packages'))
+    help.addArgument('Framework', '-with-external-packages-dir=<dir>', nargs.Arg(None, None, 'Location to install downloaded packages'))
     help.addArgument('Framework', '-with-batch',          nargs.ArgBool(None, 0, 'Machine uses a batch system to submit jobs'))
+    help.addArgument('Framework', '-with-host-cpu',       nargs.Arg(None, host_cpu,    'Machine CPU'))
+    help.addArgument('Framework', '-with-host-vendor',    nargs.Arg(None, host_vendor, 'Machine vendor'))
+    help.addArgument('Framework', '-with-host-os',        nargs.Arg(None, host_os,     'Machine OS'))
     return help
 
   def getCleanup(self):
@@ -474,8 +533,9 @@ class Framework(config.base.Configure, script.LanguageProcessor):
   def substituteFile(self, inName, outName):
     '''Carry out substitution on the file "inName", creating "outName"'''
     inFile  = file(inName)
-    if not os.path.exists(os.path.dirname(outName)):
-      os.makedirs(os.path.dirname(outName))
+    if os.path.dirname(outName):
+      if not os.path.exists(os.path.dirname(outName)):
+        os.makedirs(os.path.dirname(outName))
     outFile = file(outName, 'w')
     for line in inFile.xreadlines():
       outFile.write(self.substRE.sub(self.substituteName, line))
@@ -744,6 +804,13 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     self.log.write(('='*80)+'\n')
     return
 
+  def configureExternalPackagesDir(self):
+    if 'with-external-packages-dir' in self.argDB:
+      self.externalPackagesDir = self.argDB['with-external-packages-dir']
+    else:
+      self.externalPackagesDir = None
+    return
+
   def addBatchInclude(self, includes):
     '''Add an include or a list of includes to the batch run'''
     if not isinstance(includes, list):
@@ -802,6 +869,7 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     self.setup()
     self.outputBanner()
     self.updateDependencies()
+    self.executeTest(self.configureExternalPackagesDir)
     for child in graph.DirectedGraph.topologicalSort(self.childGraph):
       if not hasattr(child, '_configured'):
         child.configure()
