@@ -39,8 +39,11 @@ class Logger(args.ArgumentProcessor):
   def __getstate__(self):
     '''We do not want to pickle the default log stream'''
     d = args.ArgumentProcessor.__getstate__(self)
-    if 'log' in d and d['log'] is Logger.defaultLog:
-      del d['log']
+    if 'log' in d:
+      if d['log'] is Logger.defaultLog:
+        del d['log']
+      else:
+        d['log'] = None
     if 'out' in d:
       if d['out'] is Logger.defaultOut:
         del d['out']
@@ -144,7 +147,7 @@ class Logger(args.ArgumentProcessor):
               curses.endwin()
             except curses.error:
               self._linewidth = -1
-          except ImportError:
+          except:
             self._linewidth = -1
           LineWidth = self._linewidth
         else:
@@ -160,7 +163,7 @@ class Logger(args.ArgumentProcessor):
        - If writeAll is true, return true
        - If debugLevel >= current level, and debugSection in current section or sections is empty, return true'''
     if not isinstance(debugLevel, int):
-      raise RuntimeError('Debug level must be an integer')
+      raise RuntimeError('Debug level must be an integer: '+str(debugLevel))
     if f is None:
       return False
     if writeAll:
@@ -198,15 +201,20 @@ class Logger(args.ArgumentProcessor):
       self.out.write('\r')
     return
 
-  def logPrintDivider(self, debugLevel = -1, debugSection = None):
-    self.logPrint('=================================================================================', debugLevel = debugLevel, debugSection = debugSection)
+  def logPrintDivider(self, debugLevel = -1, debugSection = None, single = 0):
+    if single:
+      self.logPrint('---------------------------------------------------------------------------------', debugLevel = debugLevel, debugSection = debugSection)
+    else:
+      self.logPrint('=================================================================================', debugLevel = debugLevel, debugSection = debugSection)
     return
 
   def logPrintBox(self,msg, debugLevel = -1, debugSection = 'screen', indent = 1, comm = None):
     self.logClear()
-    self.logPrint('=================================================================================', debugSection = debugSection)
-    self.logPrint('      '+msg+'\n', debugSection=debugSection)
-    self.logPrint('=================================================================================\n', debugSection = debugSection)
+    self.logPrintDivider(debugLevel = debugLevel, debugSection = debugSection)
+    [self.logPrint('      '+line, debugLevel = debugLevel, debugSection = debugSection) for line in msg.split('\n')]
+    self.logPrintDivider(debugLevel = debugLevel, debugSection = debugSection)
+    self.logPrint('', debugLevel = debugLevel, debugSection = debugSection)
+    return
 
   def logWrite(self, msg, debugLevel = -1, debugSection = None, forceScroll = 0):
     '''Write the message to the log streams'''
@@ -258,77 +266,3 @@ class Logger(args.ArgumentProcessor):
     self._root_ = root
     return
   root = property(getRoot, setRoot, doc = 'The directory containing this module')
-
-class defaultWriter:
-  def __init__(self):
-    pass
-
-  def write(self,mess):
-    sys.stdout.write(mess)
-
-  def tab(self,tab):
-    for i in range(0,tab-1):
-      sys.stdout.write(' ')
-    
-dW = defaultWriter()
-
-class LoggerOld(object):
-  debugLevel    = None
-  debugSections = None
-  debugIndent   = ' '
-
-  def __init__(self, argDB = None, log = None):
-    if LoggerOld.debugLevel is None:
-      LoggerOld.debugLevel    = argDB['debugLevel']
-    self.debugLevel        = LoggerOld.debugLevel
-    if LoggerOld.debugSections is None:
-      LoggerOld.debugSections = argDB['debugSections']
-    self.debugSections     = LoggerOld.debugSections
-    self.debugIndent       = LoggerOld.debugIndent
-    self.log               = log
-    return
-
-  def setWriter(self,writer):
-    '''Allows sending the debug message to an alternative than stdout'''
-    self.writer = writer
-    
-  def debugListStr(self, l):
-    if (self.debugLevel > 4) or (len(l) < 4):
-      return str(l)
-    else:
-      return '['+str(l[0])+'-<'+str(len(l)-2)+'>-'+str(l[-1])+']'
-
-  def debugFileSetStr(self, set):
-    import build.fileset
-    if isinstance(set, build.fileset.FileSet):
-      s = ''
-      if set.tag:
-        s += '('+set.tag+')'
-      if isinstance(set, build.fileset.RootedFileSet):
-        s += '('+set.projectUrl+')'
-        s += '('+set.projectRoot+')'
-      s += self.debugListStr(set)
-      for child in set.children:
-        s += ', '+self.debugFileSetStr(child)
-      return s
-    elif isinstance(set, list):
-      return self.debugListStr(set)
-    raise RuntimeError('Invalid fileset '+str(set))
-
-  def debugPrint(self, msg, level = 1, section = None):
-    global dW
-    import traceback
-    import sys
-
-    if not isinstance(level, int): raise RuntimeError('Debug level must be an integer')
-    indentLevel = len(traceback.extract_stack())-5
-    if not self.log is None:
-      for i in range(indentLevel):
-        self.log.write(self.debugIndent)
-      self.log.write(msg)
-      self.log.write('\n')
-    if self.debugLevel >= level:
-      if (not section) or (not self.debugSections) or (section in self.debugSections):
-        dW.tab(indentLevel)
-        dW.write(msg+'\n')
-
