@@ -35,23 +35,34 @@ class Configure(config.base.Configure):
     self.headers       = framework.require('config.headers',           self)
     self.functions     = framework.require('config.functions',         self)
     self.libraries     = framework.require('config.libraries',         self)
-    for d in ['utilities', 'packages']:
-      for utility in os.listdir(os.path.join('python', 'PETSc', d)):
-        (utilityName, ext) = os.path.splitext(utility)
-        if not utilityName.startswith('.') and not utilityName.startswith('#') and ext == '.py' and not utilityName == '__init__':
-          utilityObj              = self.framework.require('PETSc.'+d+'.'+utilityName, self)
-          utilityObj.headerPrefix = self.headerPrefix
-          setattr(self, utilityName.lower(), utilityObj)
+    if os.path.isdir(os.path.join('python', 'PETSc')):
+      for d in ['utilities', 'packages']:
+        for utility in os.listdir(os.path.join('python', 'PETSc', d)):
+          (utilityName, ext) = os.path.splitext(utility)
+          if not utilityName.startswith('.') and not utilityName.startswith('#') and ext == '.py' and not utilityName == '__init__':
+            utilityObj              = self.framework.require('PETSc.'+d+'.'+utilityName, self)
+            utilityObj.headerPrefix = self.headerPrefix
+            ##utilityObj.languageProvider = self.languages
+            setattr(self, utilityName.lower(), utilityObj)
+    self.blaslapack    = framework.require('config.packages.BlasLapack', self)
+    self.blaslapack.archProvider      = self.arch
+    self.blaslapack.precisionProvider = self.scalartypes
+    self.mpi           = framework.require('config.packages.MPI',        self)
+    self.mpi.archProvider             = self.arch
+    self.mpi.languageProvider         = self.languages
 
     self.compilers.headerPrefix = self.headerPrefix
     self.types.headerPrefix     = self.headerPrefix
     self.headers.headerPrefix   = self.headerPrefix
     self.functions.headerPrefix = self.headerPrefix
     self.libraries.headerPrefix = self.headerPrefix
+    self.blaslapack.headerPrefix = self.headerPrefix
+    self.mpi.headerPrefix        = self.headerPrefix
     headersC = map(lambda name: name+'.h', ['dos', 'endian', 'fcntl', 'float', 'io', 'limits', 'malloc', 'pwd', 'search', 'strings',
-                                            'stropts', 'unistd', 'machine/endian', 'sys/param', 'sys/procfs', 'sys/resource',
+                                            'unistd', 'machine/endian', 'sys/param', 'sys/procfs', 'sys/resource',
                                             'sys/systeminfo', 'sys/times', 'sys/utsname','string', 'stdlib',
-                                            'sys/socket','sys/wait','netinet/in','netdb','Direct','time','Ws2tcpip','sys/types','WindowsX'])
+                                            'sys/socket','sys/wait','netinet/in','netdb','Direct','time','Ws2tcpip','sys/types',
+                                            'WindowsX', 'cxxabi'])
     functions = ['access', '_access', 'clock', 'drand48', 'getcwd', '_getcwd', 'getdomainname', 'gethostname', 'getpwuid',
                  'gettimeofday', 'getwd', 'memalign', 'memmove', 'mkstemp', 'popen', 'PXFGETARG', 'rand', 'getpagesize',
                  'readlink', 'realpath',  'sigaction', 'signal', 'sigset', 'sleep', '_sleep', 'socket', 'times', 'gethostbyname',
@@ -149,14 +160,10 @@ class Configure(config.base.Configure):
     else: lang = 'CXXONLY'
     self.addMakeMacro('PETSC_LANGUAGE',lang)
 
-    if self.python.usePython:
-      self.addMakeMacro('PYTHON_INCLUDE', ' '.join([self.headers.getIncludeArgument(inc) for inc in self.python.python.include]))
-      self.addMakeMacro('PYTHON_LIB', ' '.join([self.libraries.getLibArgument(lib) for lib in self.python.python.lib]))
-    
     # real or complex
-    self.addMakeMacro('PETSC_SCALAR',self.languages.scalartype)
+    self.addMakeMacro('PETSC_SCALAR',self.scalartypes.scalartype)
     # double or float
-    self.addMakeMacro('PETSC_PRECISION',self.languages.precision)
+    self.addMakeMacro('PETSC_PRECISION',self.scalartypes.precision)
 
     if self.framework.argDB['with-batch']:
       self.addMakeMacro('PETSC_WITH_BATCH','1')
@@ -182,6 +189,7 @@ class Configure(config.base.Configure):
           i.include = [i.include]
         self.addMakeMacro(i.PACKAGE+'_INCLUDE', ' '.join([self.headers.getIncludeArgument(inc) for inc in i.include]))
     self.addMakeMacro('PACKAGES_LIBS',' '.join(['${'+package.PACKAGE+'_LIB}' for package in self.framework.packages]+[self.libraries.getLibArgument(l) for l in self.libraries.math]))
+    self.addMakeMacro('PACKAGES_INCLUDES',' '.join(['${'+p.PACKAGE+'_INCLUDE}' for p in self.framework.packages if hasattr(p,'include')]))
     
     self.addMakeMacro('INSTALL_DIR',self.installdir)
     self.addMakeMacro('top_builddir',self.installdir)                
