@@ -1,5 +1,6 @@
 from __future__ import generators
 import config.base
+import config.package
 import os
 import re
 import sys
@@ -7,50 +8,6 @@ import md5
 
 import nargs
 
-class ArgDownload(nargs.Arg):
-  '''Arguments that represent software downloads'''
-  def __init__(self, key, value = None, help = '', isTemporary = 0):
-    nargs.Arg.__init__(self, key, value, help, isTemporary)
-    return
-
-  def valueName(self, value):
-    if value == 0:
-      return 'no'
-    elif value == 1:
-      return 'yes'
-    elif value == 2:
-      return 'ifneeded'
-    return str(value)
-
-  def __str__(self):
-    if not self.isValueSet():
-      return 'Empty '+str(self.__class__)
-    elif isinstance(self.value, list):
-      return str(map(self.valueName, self.value))
-    return self.valueName(self.value)
-
-  def getEntryPrompt(self):
-    return 'Please enter download value for '+str(self.key)+': '
-
-  def setValue(self, value):
-    '''Set the value. SHOULD MAKE THIS A PROPERTY'''
-    try:
-      if   value == '0':        value = 0
-      elif value == '1':        value = 1
-      elif value == 'no':       value = 0
-      elif value == 'yes':      value = 1
-      elif value == 'false':    value = 0
-      elif value == 'true':     value = 1
-      elif value == 'ifneeded': value = 2
-      elif not isinstance(value, int):
-        value = str(value)
-    except:
-      raise TypeError('Invalid download value: '+str(value)+' for key '+str(self.key))
-    if isinstance(value, str) and not os.path.isfile(value):
-      raise ValueError('Invalid download location: '+str(value)+' for key '+str(self.key))
-    self.value = value
-    return
-
 class Package(config.base.Configure):
   def __init__(self, framework):
     config.base.Configure.__init__(self, framework)
@@ -90,7 +47,7 @@ class Package(config.base.Configure):
     self.functionsCxx     = [0, '', '']
     # include files we wish to check for
     self.includes         = []
-    # list of libraries we wish to check for (can be overwritten by providing your own generateLibraryList()
+    # list of libraries we wish to check for (can be overwritten by providing your own generateLibraryList())
     self.liblist          = [[]]
     self.extraLib         = []
     # location of libraries and includes in packages directory tree
@@ -112,10 +69,11 @@ class Package(config.base.Configure):
     self.compilers     = self.framework.require('config.compilers',self)
     self.headers       = self.framework.require('config.headers',self)
     self.libraries     = self.framework.require('config.libraries',self)
+    self.programs      = self.framework.require('config.programs', self)
     self.languages     = self.framework.require('PETSc.utilities.languages',self)
+    self.scalartypes   = self.framework.require('PETSc.utilities.scalarTypes',self)
     self.arch          = self.framework.require('PETSc.utilities.arch',self)
     self.petscdir      = self.framework.require('PETSc.utilities.petscdir',self)
-    self.programs      = self.framework.require('PETSc.utilities.programs', self)
     self.sourceControl = self.framework.require('config.sourceControl',self)
     # Need this for the with-64-bit-indices option
     self.libraryOptions = framework.require('PETSc.utilities.libraryOptions', self)
@@ -152,7 +110,7 @@ class Package(config.base.Configure):
     help.addArgument(self.PACKAGE,'-with-'+self.package+'=<bool>',nargs.ArgBool(None,self.required,'Indicate if you wish to test for '+self.name))
     help.addArgument(self.PACKAGE,'-with-'+self.package+'-dir=<dir>',nargs.ArgDir(None,None,'Indicate the root directory of the '+self.name+' installation'))
     if self.download and not self.download[0] == 'redefine':
-      help.addArgument(self.PACKAGE, '-download-'+self.package+'=<no,yes,ifneeded,filename>', ArgDownload(None, 0, 'Download and install '+self.name))
+      help.addArgument(self.PACKAGE, '-download-'+self.package+'=<no,yes,ifneeded,filename>', nargs.ArgDownload(None, 0, 'Download and install '+self.name))
     help.addArgument(self.PACKAGE,'-with-'+self.package+'-include=<dir>',nargs.ArgDir(None,None,'Indicate the directory of the '+self.name+' include files'))
     help.addArgument(self.PACKAGE,'-with-'+self.package+'-lib=<libraries: e.g. [/Users/..../libparmetis.a,...]>',nargs.ArgLibrary(None,None,'Indicate the '+self.name+' libraries'))    
     return
@@ -212,16 +170,20 @@ class Package(config.base.Configure):
       return ''
 
   def generateGuesses(self):
-    dir = self.checkDownload(1)
-    if dir:
-      for l in self.generateLibList(os.path.join(dir, self.libdir)):
-        yield('Download '+self.PACKAGE, dir,l, os.path.join(dir, self.includedir))
-      raise RuntimeError('Downloaded '+self.package+' could not be used. Please check install in '+dir+'\n')
+    d = self.checkDownload(1)
+    if d:
+      for l in self.generateLibList(os.path.join(d, self.libdir)):
+        yield('Download '+self.PACKAGE, d, l, os.path.join(d, self.includedir))
+      raise RuntimeError('Downloaded '+self.package+' could not be used. Please check install in '+d+'\n')
 
     if 'with-'+self.package+'-dir' in self.framework.argDB:     
       dir = self.framework.argDB['with-'+self.package+'-dir']
       for l in self.generateLibList(os.path.join(dir, self.libdir)):
         yield('User specified root directory '+self.PACKAGE, dir,l, os.path.join(dir,self.includedir))
+      if 'with-'+self.package+'-include' in self.framework.argDB:
+        raise RuntimeError('Do not set --with-'+self.package+'-include if you set --with-'+self.package+'-dir')
+      if 'with-'+self.package+'-lib' in self.framework.argDB:
+        raise RuntimeError('Do not set --with-'+self.package+'-lib if you set --with-'+self.package+'-dir')
       raise RuntimeError('--with-'+self.package+'-dir='+self.framework.argDB['with-'+self.package+'-dir']+' did not work')
 
     if 'with-'+self.package+'-include-dir' in self.framework.argDB:
@@ -237,11 +199,22 @@ class Package(config.base.Configure):
       raise RuntimeError('--with-'+self.package+'-lib='+str(self.framework.argDB['with-'+self.package+'-lib'])+' and \n'+\
         '--with-'+self.package+'-include='+str(self.framework.argDB['with-'+self.package+'-include'])+' did not work') 
 
+    if 'with-'+self.package+'-include' in self.framework.argDB and not 'with-'+self.package+'-lib' in self.framework.argDB:
+      raise RuntimeError('If you provide --with-'+self.package+'-include you must also supply with-'+self.package+'-lib\n')
+                         
+    if 'with-'+self.package+'-lib' in self.framework.argDB and not 'with-'+self.package+'-include' in self.framework.argDB:
+      raise RuntimeError('If you provide --with-'+self.package+'-lib you must also supply with-'+self.package+'-include\n')
+
     for d in self.getSearchDirectories():
-      for l in self.generateLibList(os.path.join(d,self.libdir)):
-        if d: includedir = os.path.join(d,self.includedir)
-        else: includedir = ''
-        yield('User specified root directory '+self.PACKAGE, d,l, includedir)
+      for l in self.generateLibList(os.path.join(d, self.libdir)):
+        if isinstance(self.includedir, list):
+          includedir = ([inc for inc in self.includedir if os.path.isabs(inc)] +
+                        [os.path.join(d, inc) for inc in self.includedir if not os.path.isabs(inc)])
+        elif d:
+          includedir = os.path.join(d, self.includedir)
+        else:
+          includedir = ''
+        yield('Package specific search directory '+self.PACKAGE, d, l, includedir)
 
     dir = self.checkDownload(2)
     if dir:
@@ -298,10 +271,10 @@ class Package(config.base.Configure):
         os.mkdir(os.path.join(packages,Dir,self.arch.arch))
     return os.path.join(packages, Dir)
 
-  def checkInclude(self, incl, hfiles, otherIncludes = []):
+  def checkInclude(self, incl, hfiles, otherIncludes = [], timeout = 600.0):
     if self.cxx:
       self.headers.pushLanguage('C++')
-    ret = self.executeTest(self.headers.checkInclude, [incl, hfiles],{'otherIncludes' : otherIncludes})
+    ret = self.executeTest(self.headers.checkInclude, [incl, hfiles],{'otherIncludes' : otherIncludes, 'timeout': timeout})
     if self.cxx:
       self.headers.popLanguage()
     return ret
@@ -321,7 +294,7 @@ class Package(config.base.Configure):
     return 1
 
   def configureLibrary(self):
-    '''Find an installation ando check if it can work with PETSc'''
+    '''Find an installation and check if it can work with PETSc'''
     self.framework.log.write('==================================================================================\n')
     self.framework.log.write('Checking for a functional '+self.name+'\n')
     foundLibrary = 0
@@ -334,7 +307,10 @@ class Package(config.base.Configure):
       if not hasattr(l,'found'):
         raise RuntimeError(l.PACKAGE+' does not have found attribute!')
       if not l.found:
-        raise RuntimeError('Did not find '+l.PACKAGE+' needed by '+self.name)
+        if self.framework.argDB['with-'+l.package] == 1:
+          raise RuntimeError('Package '+l.PACKAGE+' needed by '+self.name+' failed to configure.\nMail configure.log to petsc-maint@mcs.anl.gov.')
+        else:
+          raise RuntimeError('Did not find package '+l.PACKAGE+' needed by '+self.name+'.\nEnable the package using --with-'+l.package)
       if hasattr(l,'dlib'):    libs  += l.dlib
       if hasattr(l,'include'): incls += l.include
     if self.needsMath:
@@ -347,12 +323,13 @@ class Package(config.base.Configure):
       elif not isinstance(lib, list): lib = [lib]
       if incl == '': incl = []
       elif not isinstance(incl, list): incl = [incl]
-      incl += self.compilers.fincs
+      # keep incl at the end so that ${SUNDIALS_INCLUDE}/sundials can be done
+      incl = self.compilers.fincs + incl
       self.framework.log.write('Checking for library in '+location+': '+str(lib)+'\n')
       if self.executeTest(self.libraries.check,[lib,self.functions],{'otherLibs' : libs, 'fortranMangle' : self.functionsFortran, 'cxxMangle' : self.functionsCxx[0], 'prototype' : self.functionsCxx[1], 'call' : self.functionsCxx[2]}):
         self.lib = lib	
         self.framework.log.write('Checking for headers '+location+': '+str(incl)+'\n')
-        if (not self.includes) or self.checkInclude(incl, self.includes, incls):
+        if (not self.includes) or self.checkInclude(incl, self.includes, incls, timeout = 1800.0):
           self.include = incl
           self.found   = 1
           self.dlib    = self.lib+libs
@@ -373,7 +350,7 @@ class Package(config.base.Configure):
       self.framework.argDB['with-'+self.package] = 1
 
     if 'with-'+self.package+'-dir' in self.framework.argDB and ('with-'+self.package+'-include' in self.framework.argDB or 'with-'+self.package+'-lib' in self.framework.argDB):
-      raise RuntimeError('Use either --with-'+self.package+'-dir or --with-'+self.package+'-lib and --with-'+self.package+'-include Not both!')
+      raise RuntimeError('Specify either "--with-'+self.package+'-dir" or "--with-'+self.package+'-lib --with-'+self.package+'-include". But not both!')
 
     if 'with-'+self.package+'-dir' in self.framework.argDB or 'with-'+self.package+'-include' in self.framework.argDB or 'with-'+self.package+'-lib' in self.framework.argDB:
       self.framework.argDB['with-'+self.package] = 1
@@ -383,9 +360,9 @@ class Package(config.base.Configure):
         raise RuntimeError('Cannot use '+self.name+' with MPIUNI, you need a real MPI')
       if self.libraryOptions.integerSize == 64 and self.requires32bitint:
         raise RuntimeError('Cannot use '+self.name+' with 64 bit integers, it is not coded for this capability')    
-      if self.double and not self.languages.precision.lower() == 'double':
+      if self.double and not self.scalartypes.precision.lower() == 'double':
         raise RuntimeError('Cannot use '+self.name+' withOUT double precision numbers, it is not coded for this capability')    
-      if not self.complex and self.languages.scalartype.lower() == 'complex':
+      if not self.complex and self.scalartypes.scalartype.lower() == 'complex':
         raise RuntimeError('Cannot use '+self.name+' with complex numbers it is not coded for this capability')    
       if self.cxx and not self.languages.clanguage == 'Cxx':
         raise RuntimeError('Cannot use '+self.name+' without C++, run config/configure.py --with-clanguage=C++')    
@@ -400,3 +377,31 @@ class Package(config.base.Configure):
       self.executeTest(self.alternateConfigureLibrary)
     return
 
+class NewPackage(config.package.Package):
+  def __init__(self, framework):
+    config.package.Package.__init__(self, framework)
+    # These are specified for the package
+    self.double           = 1   # 1 means requires double precision 
+    self.complex          = 0   # 0 means cannot use complex
+    self.requires32bitint = 1;  # 1 means that the package will not work in 64 bit mode
+    return
+
+  def setupDependencies(self, framework):
+    config.package.Package.setupDependencies(self, framework)
+    self.languages      = framework.require('PETSc.utilities.languages', self)
+    self.scalartypes    = self.framework.require('PETSc.utilities.scalarTypes',self)
+    self.libraryOptions = framework.require('PETSc.utilities.libraryOptions', self)
+    return
+
+  def consistencyChecks(self):
+    config.package.Package.consistencyChecks(self)
+    if self.framework.argDB['with-'+self.package]:
+      if self.cxx and not self.languages.clanguage == 'Cxx':
+        raise RuntimeError('Cannot use '+self.name+' without C++, run config/configure.py --with-clanguage=C++')    
+      if self.double and not self.scalartypes.precision.lower() == 'double':
+        raise RuntimeError('Cannot use '+self.name+' withOUT double precision numbers, it is not coded for this capability')    
+      if not self.complex and self.scalartypes.scalartype.lower() == 'complex':
+        raise RuntimeError('Cannot use '+self.name+' with complex numbers it is not coded for this capability')    
+      if self.libraryOptions.integerSize == 64 and self.requires32bitint:
+        raise RuntimeError('Cannot use '+self.name+' with 64 bit integers, it is not coded for this capability')    
+    return
