@@ -35,7 +35,7 @@ class Configure(PETSc.package.Package):
 
   def setupDependencies(self, framework):
     PETSc.package.Package.setupDependencies(self, framework)
-    self.mpi = framework.require('PETSc.packages.MPI',self)
+    self.mpi = framework.require('config.packages.MPI',self)
     return
 
   def generateIncludeGuesses(self):
