@@ -8,7 +8,7 @@ import PETSc.package
 class Configure(PETSc.package.Package):
   def __init__(self, framework):
     PETSc.package.Package.__init__(self, framework)
-    self.download          = ['http://www.columbia.edu/~ma2325/Prometheus-1.8.3.tar.gz']
+    self.download          = ['http://www.columbia.edu/~ma2325/Prometheus-1.8.5.tar.gz']
     self.functions         = []
     self.includes          = []
     self.liblist           = [['libpromfei.a','libprometheus.a']]
@@ -17,8 +17,8 @@ class Configure(PETSc.package.Package):
 
   def setupDependencies(self, framework):
     PETSc.package.Package.setupDependencies(self, framework)
-    self.mpi        = framework.require('PETSc.packages.MPI',self)
-    self.blasLapack = framework.require('PETSc.packages.BlasLapack',self)
+    self.mpi        = framework.require('config.packages.MPI',self)
+    self.blasLapack = framework.require('config.packages.BlasLapack',self)
     self.parmetis   = framework.require('PETSc.packages.ParMetis',self)
     self.deps       = [self.parmetis,self.mpi,self.blasLapack]
     return
