@@ -38,7 +38,7 @@ class Configure(config.base.Configure):
     self.compilers      = framework.require('config.compilers', self)
     self.headers        = framework.require('config.headers', self)
     self.libraries      = framework.require('config.libraries', self)
-    self.mpi            = framework.require('PETSc.packages.MPI', self)
+    self.mpi            = framework.require('config.packages.MPI', self)
     self.libraryOptions = framework.require('PETSc.utilities.libraryOptions', self)
     return
 
