@@ -19,8 +19,8 @@ class Configure(PETSc.package.Package):
 
   def setupDependencies(self, framework):
     PETSc.package.Package.setupDependencies(self, framework)
-    self.mpi        = framework.require('PETSc.packages.MPI',self)
-    self.blasLapack = framework.require('PETSc.packages.BlasLapack',self)
+    self.mpi        = framework.require('config.packages.MPI',self)
+    self.blasLapack = framework.require('config.packages.BlasLapack',self)
     self.deps       = [self.mpi,self.blasLapack]
     return
 
@@ -63,8 +63,7 @@ class Configure(PETSc.package.Package):
         g.write('CDEFS   = -DNoChange\n')
       self.setCompilers.popLanguage()
     else:
-      g.write('FORTRAN      = \n')
-      g.write('FFLAGS       = \n')
+      raise RuntimeError('SuperLU_DIST requires a fortran compiler! No fortran compiler configured!')
     g.write('NOOPTS       =  -O0\n')
     g.close()
     if not os.path.isdir(installDir):
@@ -94,15 +93,17 @@ class Configure(PETSc.package.Package):
     if self.blasLapack.f2c:
       raise RuntimeError('SuperLU_DIST requires a COMPLETE BLAS and LAPACK, it cannot be used with --download-c-blas-lapack=1 \nUse --download-f-blas-lapack option instead.')
 
-    # SuperLU_DIST requires slamch() & dlamch() LAPACK routines and PETSc version of superlu
-    # have the internal versions disabled in favour of generic blas/lapack
+    errormsg = ', the current Lapack libraries '+str(self.blasLapack.lib)+' does not have it\nTry using --download-f-blas-lapack=1 option or see \nhttp://www-unix.mcs.anl.gov/petsc/petsc-as/documentation/installation.html#BLAS/LAPACK'
     if not self.blasLapack.checkForRoutine('slamch'): 
-      raise RuntimeError('SuperLU_DIST requires the LAPACK routine slamch(), the current Lapack libraries '+str(self.blasLapack.lib)+' does not have it\nTry using --download-f-blas-lapack=1 option \nIf you are using the IBM ESSL library, it does not contain this function.')
-    self.framework.log.write('Found slamch() in Lapack library as needed by SuperLU_DIST\n')
+      raise RuntimeError('SuperLU_DIST requires the BLAS routine slamch()'+errormsg)
+    self.framework.log.write('Found slamch() in BLAS library as needed by SuperLU_DIST\n')
 
     if not self.blasLapack.checkForRoutine('dlamch'): 
-      raise RuntimeError('SuperLU_DIST requires the LAPACK routine dlamch(), the current Lapack libraries '+str(self.blasLapack.lib)+' does not have it\nTry using --download-f-blas-lapack=1 option \nIf you are using the IBM ESSL library, it does not contain this function.')
-    self.framework.log.write('Found dlamch() in Lapack library as needed by SuperLU_DIST\n')
+      raise RuntimeError('SuperLU_DIST requires the BLAS routine dlamch()'+errormsg)
+    self.framework.log.write('Found dlamch() in BLAS library as needed by SuperLU_DIST\n')
+    if not self.blasLapack.checkForRoutine('xerbla'): 
+      raise RuntimeError('SuperLU_DIST requires the BLAS routine xerbla()'+errormsg)
+    self.framework.log.write('Found xerbla() in BLAS library as needed by SuperLU_DIST\n')
     return
   
 if __name__ == '__main__':
