@@ -21,8 +21,8 @@ class Configure(PETSc.package.Package):
   def setupDependencies(self, framework):
 
     PETSc.package.Package.setupDependencies(self, framework)
-    self.mpi        = framework.require('PETSc.packages.MPI',self)
-    self.blasLapack = framework.require('PETSc.packages.BlasLapack',self)
+    self.mpi        = framework.require('config.packages.MPI',self)
+    self.blasLapack = framework.require('config.packages.BlasLapack',self)
     self.deps       = [self.mpi,self.blasLapack]
     return
 
@@ -38,7 +38,10 @@ class Configure(PETSc.package.Package):
     g.write('SHELL     = /bin/sh\n')
     g.write('COMMLIB   = MPI\n')
     g.write('SENDIS    = -DSndIsLocBlk\n')
-    g.write('WHATMPI   = -DUseF77Mpi\n')
+    if (self.mpi.commf2c):
+      g.write('WHATMPI      = -DUseMpi2\n')
+    else:
+      g.write('WHATMPI      = -DCSAMEF77\n')
     g.write('DEBUGLVL  = -DBlacsDebugLvl=1\n')
     g.write('BLACSdir  = '+blacsDir+'\n')
     g.write('BLACSLIB  = '+os.path.join(installDir,'libblacs.a')+'\n')
