@@ -16,10 +16,10 @@ class Configure(config.base.Configure):
     
   def setupHelp(self, help):
     import nargs
-    help.addArgument('PETSc', '-with-log=<bool>',              nargs.ArgBool(None, 1, 'Activate logging code in PETSc'))
+    help.addArgument('PETSc', '-with-gnu-copyright-code=<bool>',nargs.ArgBool(None, 1, 'Compile in GNU copyright code (see http://www.mcs.anl.gov/petsc/petsc-as/documentation/copyright.html'))
+    help.addArgument('PETSc', '-with-log=<bool>',              nargs.ArgBool(None, 1, 'Activate logging code in PETSc'))    
     help.addArgument('PETSc', '-with-info=<bool>',             nargs.ArgBool(None, 1, 'Activate PetscInfo() (i.e. -info)  code in PETSc'))
     help.addArgument('PETSc', '-with-ctable=<bool>',           nargs.ArgBool(None, 1, 'Activate CTABLE hashing for certain search functions - to conserve memory'))
-    help.addArgument('PETSc', '-with-sieve=<bool>',            nargs.ArgBool(None, 0, 'Activate SIEVE mesh functionality[requires cxx]'))
     help.addArgument('PETSc', '-with-fortran-kernels=<none,generic,bgl>',  nargs.ArgString(None, None, 'Use Fortran for linear algebra kernels'))
     help.addArgument('PETSc', '-with-64-bit-indices=<bool>',   nargs.ArgBool(None, 0, 'Use 64 bit integers (long long) for indexing in vectors and matrices'))
     help.addArgument('PETSc', '-with-is-color-value-type=<char,short>',nargs.ArgString(None, 'char', 'char, short can store 256, 65536 colors'))
@@ -27,11 +27,11 @@ class Configure(config.base.Configure):
 
   def setupDependencies(self, framework):
     config.base.Configure.setupDependencies(self, framework)
-    self.debugging = framework.require('PETSc.utilities.debugging', self)
-    self.compilers = framework.require('config.compilers', self)
-    self.libraries = framework.require('config.libraries', self)
-    self.types     = framework.require('config.types', self)
-    self.languages = framework.require('PETSc.utilities.languages', self)
+    self.debugging   = framework.require('PETSc.utilities.debugging', self)
+    self.compilers   = framework.require('config.compilers', self)
+    self.libraries   = framework.require('config.libraries', self)
+    self.types       = framework.require('config.types', self)
+    self.scalarTypes = framework.require('PETSc.utilities.scalarTypes', self)
     return
 
   def isBGL(self):
@@ -51,6 +51,9 @@ class Configure(config.base.Configure):
     if self.debugging.debugging:
       self.addDefine('USE_DEBUG', '1')
 
+    if not self.framework.argDB['with-gnu-copyright-code']:
+      self.addDefine('AVOID_GNUCOPYRIGHT_CODE', '1')
+      
     self.useInfo   = self.framework.argDB['with-info']
     self.addDefine('USE_INFO',   self.useInfo)
 
@@ -58,16 +61,12 @@ class Configure(config.base.Configure):
     if self.useCtable:
       self.addDefine('USE_CTABLE', '1')
 
-    self.useSieve = self.framework.argDB['with-sieve']
-    if self.useSieve:
-      self.addDefine('USE_SIEVE', '1')
-
     # If user doesn't specify this option - automatically enable bgl-kernels for IBM-bgl-crosscompilers
     if 'with-fortran-kernels' not in self.framework.argDB and self.isBGL():
       self.useFortranKernels = 'bgl'
     elif 'with-fortran-kernels' in self.framework.argDB:
       self.useFortranKernels = self.framework.argDB['with-fortran-kernels'].lower()
-    elif self.languages.precision == 'matsingle':
+    elif self.scalarTypes.precision == 'matsingle':
       self.logPrint('Enabling fortran kernels automatically due to matsingle option')
       self.useFortranKernels = 'generic'
     else:
