@@ -1,4 +1,4 @@
-/*$Id: appalgebra.c,v 1.9 2001/08/07 03:04:50 balay Exp $*/
+
 #include "appctx.h"
 #include "math.h"
 
@@ -9,7 +9,7 @@
 #define __FUNCT__ "pde_rhs"
 int pde_rhs(void *dummy,int n,double *xx,double *f)
 {
-  double pi = M_PI, x = xx[0], y = xx[1];
+  double pi = PETSC_PI, x = xx[0], y = xx[1];
   PetscFunctionBegin;
   *f = 8*pi*pi*sin(2*pi*x)*sin(2*pi*y)-20*pi*cos(2*pi*x)*sin(2*pi*y);
   PetscFunctionReturn(0);
@@ -81,12 +81,10 @@ int AppCtxSolve(AppCtx* appctx)
       }
     }
     ierr = KSPSetFromOptions(ksp);CHKERRQ(ierr);
-    ierr = KSPSetRhs(ksp,appctx->algebra.b);CHKERRQ(ierr);
-    ierr = KSPSetSolution(ksp,appctx->algebra.x);CHKERRQ(ierr);
     ierr = KSPSetUp(ksp);CHKERRQ(ierr);
 
     PreLoadStage("Solve");  
-    ierr = KSPSolve(ksp);CHKERRQ(ierr);
+    ierr = KSPSolve(ksp,appctx->algebra.b,appctx->algebra.x);CHKERRQ(ierr);
 
     {
       PetscTruth flg;
@@ -145,7 +143,8 @@ int AppCtxCreateRhsAndMatrix (AppCtx *appctx)
     ierr = VecSetFromOptions(algebra->b);CHKERRQ(ierr);
   }
   /* Create the structure for the stiffness matrix */
-  ierr = MatCreate(comm,part->m,part->m,PETSC_DETERMINE,PETSC_DETERMINE,&algebra->A);CHKERRQ(ierr);
+  ierr = MatCreate(comm,&algebra->A);CHKERRQ(ierr);
+  ierr = MatSetSizes(algebra->A,part->m,part->m,PETSC_DETERMINE,PETSC_DETERMINE,&algebra->A);CHKERRQ(ierr);
   ierr = MatSetFromOptions(algebra->A);CHKERRQ(ierr);
   ierr = MatMPIAIJSetPreallocation(algebra->A,9,0,3,0);CHKERRQ(ierr);
 
@@ -301,7 +300,7 @@ int SetBoundaryConditions(AppCtx *appctx)
   ierr = VecAssemblyEnd(algebra->b);CHKERRQ(ierr);
 
   /* set initial guess satisfying boundary conditions */
-  ierr = VecSet(&zero,algebra->x);CHKERRQ(ierr);
+  ierr = VecSet(algebra->x,zero);CHKERRQ(ierr);
   ierr = VecSetValuesLocal(algebra->x,n,vertex_ptr,values,INSERT_VALUES);CHKERRQ(ierr);
   ierr = VecAssemblyBegin(algebra->x);CHKERRQ(ierr);
   ierr = VecAssemblyEnd(algebra->x);CHKERRQ(ierr);
@@ -343,7 +342,7 @@ int SetMatrixBoundaryConditions(AppCtx *appctx)
 
   ierr = PetscFree(vertex_ptr);CHKERRQ(ierr);
 
-  ierr = MatZeroRowsLocal(algebra->A,is,&one);CHKERRQ(ierr); 
+  ierr = MatZeroRowsLocalIS(algebra->A,is,one);CHKERRQ(ierr); 
 
   ierr = ISDestroy(is);CHKERRQ(ierr);
   
