@@ -17,24 +17,24 @@ int main( int argc, char **argv )
   PetscInitialize(&argc,&argv,(char *)0,help);
 
   /*  Load the grid database*/
-  ierr = AppCtxCreate(PETSC_COMM_WORLD,&appctx); CHKERRA(ierr);
+  ierr = AppCtxCreate(PETSC_COMM_WORLD,&appctx); CHKERRQ(ierr);
   algebra = &appctx->algebra; grid = &appctx->grid;
 
   /*      Initialize graphics */
-  ierr = AppCtxGraphics(appctx); CHKERRA(ierr);
+  ierr = AppCtxGraphics(appctx); CHKERRQ(ierr);
 
   /*   Setup the linear system and solve it*/
   ierr = AppCtxSolve(appctx);CHKERRQ(ierr);
 
   /*      Destroy all datastructures  */
-  ierr = AppCtxDestroy(appctx); CHKERRA(ierr);
+  ierr = AppCtxDestroy(appctx); CHKERRQ(ierr);
 
   PetscFinalize();
   PetscFunctionReturn(0);
 }
 
-extern  int FormInitialGuess(AppCtx*);
-extern int  SetBoundaryConditions(Vec, AppCtx*,Vec);
+extern  PetscErrorCode FormInitialGuess(AppCtx*);
+extern PetscErrorCode  SetBoundaryConditions(Vec, AppCtx*,Vec);
 /*
          Sets up the non-linear system associated with the PDE and solves it
 */
@@ -42,13 +42,12 @@ extern int  SetBoundaryConditions(Vec, AppCtx*,Vec);
 #define __FUNC__ "AppCxtSolve"
 int AppCtxSolve(AppCtx* appctx)
 {
-  AppGrid                *grid = &appctx->grid;
   AppAlgebra             *algebra = &appctx->algebra;
-  MPI_Comm               comm = appctx->comm;
-  SLES                   sles;
+  KSP ksp;
   SNES                   snes;
-  int ierr, its;
- int zero = 0;
+  PetscErrorCode ierr;
+  PetscInt its;
+  PetscInt zero = 0;
   PetscFunctionBegin;
 
   /*        Create vector to contain load and various work vectors  */
@@ -65,10 +64,10 @@ int AppCtxSolve(AppCtx* appctx)
   /*      Set the matrix entries   */
   ierr = AppCtxSetMatrix(appctx); CHKERRQ(ierr);
 
-   MatView(algebra->A, VIEWER_STDOUT_SELF);   
+   MatView(algebra->A, PETSC_VIEWER_STDOUT_SELF);   
 
   /*     Create the nonlinear solver context  */
-  ierr = SNESCreate(PETSC_COMM_WORLD,SNES_NONLINEAR_EQUATIONS,&snes); CHKERRQ(ierr);
+  ierr = SNESCreate(PETSC_COMM_WORLD,&snes); CHKERRQ(ierr);
 
   /********* solve the stationary problem with boundary conditions.  ************/
   /*      Set function evaluation rountine and vector */
@@ -92,13 +91,13 @@ int AppCtxSolve(AppCtx* appctx)
    if (appctx->view.matlabgraphics) {AppCtxViewMatlab(appctx);  } 
 
   /*       Solve the non-linear system  */
-  ierr = SNESSolve(snes, algebra->g, &its);CHKERRQ(ierr);
-
+  ierr = SNESSolve(snes,PETSC_NULL,algebra->g);CHKERRQ(ierr);
+  ierr = SNESGetIterationNumber(snes,&its);CHKERRQ(ierr);
   /* First, send solution vector to Matlab */
-  ierr = VecView(appctx->algebra.g,VIEWER_SOCKET_WORLD); CHKERRQ(ierr);
+  ierr = VecView(appctx->algebra.g,PETSC_VIEWER_SOCKET_WORLD); CHKERRQ(ierr);
 
   /* send the done signal */
-ierr = PetscIntView(1, &zero, VIEWER_SOCKET_WORLD);CHKERRQ(ierr);
+ierr = PetscIntView(1, &zero, PETSC_VIEWER_SOCKET_WORLD);CHKERRQ(ierr);
  /*  VecView(algebra->g, VIEWER_STDOUT_SELF); */
 
   printf("the number of its, %d\n", its);
@@ -142,7 +141,7 @@ int FormInitialGuess(AppCtx* appctx)
     ierr = VecSetValuesLocal(algebra->g, 9, df_ptr, values, INSERT_VALUES ); CHKERRQ(ierr);
   }
     }
-/* ierr = VecSet(&val, algebra->g);CHKERRQ(ierr); */
+/* ierr = VecSet(algebra->g,val);CHKERRQ(ierr); */
     PetscFunctionReturn(0);
 }
 
@@ -176,9 +175,9 @@ to see if they need to be recomputed */
 
 /****** Perform computation ***********/
   /* need to zero f */
-  ierr = VecSet(&zero, f); CHKERRQ(ierr); 
+  ierr = VecSet(f,zero); CHKERRQ(ierr); 
   /* add rhs to get constant part */
-  ierr = VecAXPY(&mone, b, f); CHKERRQ(ierr); /* this says f = f - 1*b */
+  ierr = VecAXPY(f,mone,b); CHKERRQ(ierr); /* this says f = f - 1*b */
   /*apply matrix to the input vector x, to get linear part */
   /* Assuming matrix doesn't need to be recomputed */
   ierr = MatMultAdd(A, x, f, f); CHKERRQ(ierr);  /* f = A*x - b */
@@ -410,15 +409,15 @@ IS is_single_pressure;
 
   /**********  boundary conditions ************/
   /* here should zero rows corresponding to dfs where bc imposed */
- ierr = MatZeroRowsLocal(*jac, grid->iswall_vdf,&one);CHKERRQ(ierr); 
+ ierr = MatZeroRowsLocalIS(*jac, grid->iswall_vdf,one);CHKERRQ(ierr); 
   if(equations->vin_flag){
-    ierr = MatZeroRowsLocal(*jac, grid->isinlet_vdf,&one);CHKERRQ(ierr);}
+    ierr = MatZeroRowsLocalIS(*jac, grid->isinlet_vdf,one);CHKERRQ(ierr);}
   if(equations->vout_flag){
-    ierr = MatZeroRowsLocal(*jac, grid->isoutlet_vdf,&one);CHKERRQ(ierr);}
+    ierr = MatZeroRowsLocalIS(*jac, grid->isoutlet_vdf,one);CHKERRQ(ierr);}
  if(equations->pout_flag){
-   ierr = MatZeroRowsLocal(*jac, grid->isoutlet_pdf,&one);CHKERRQ(ierr);}
+   ierr = MatZeroRowsLocalIS(*jac, grid->isoutlet_pdf,one);CHKERRQ(ierr);}
  if(equations->pin_flag){
-   ierr = MatZeroRowsLocal(*jac, grid->isinlet_pdf,&one);CHKERRQ(ierr);}
+   ierr = MatZeroRowsLocalIS(*jac, grid->isinlet_pdf,one);CHKERRQ(ierr);}
 
   ierr = MatAssemblyBegin(*jac,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
   ierr = MatAssemblyEnd(*jac,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
