@@ -232,8 +232,8 @@ int NV = grid->NV;
   ierr = MatSetLocalToGlobalMappingBlocked(J,ltog);CHKERRQ(ierr); 
  ierr = MatSetLocalToGlobalMapping(J,dltog);CHKERRQ(ierr); 
 
-  PetscFree(dnz);
-  PetscFree(onz);
+  ierr = PetscFree(dnz);CHKERRQ(ierr);
+  ierr = PetscFree(onz);CHKERRQ(ierr);
   algebra->A = A;
   algebra->J = J;
   PetscFunctionReturn(0);
