@@ -1,4 +1,3 @@
-/*$Id: ex2.c,v 1.46 2001/09/11 16:34:32 bsmith Exp $*/
 
 static char help[] = "Reads a a simple unstructured grid from a file. Partitions it,\n\
 and distributes the grid data accordingly\n\n";
@@ -71,13 +70,13 @@ T*/
     This is the user-defined grid data context 
 */
 typedef struct {
-  int    n_vert,n_ele;
-  int    mlocal_vert,mlocal_ele;
-  int    *ele;
+  PetscInt    n_vert,n_ele;
+  PetscInt    mlocal_vert,mlocal_ele;
+  PetscInt    *ele;
   PetscScalar *vert;
-  int    *ia,*ja;
+  PetscInt    *ia,*ja;
   IS     isnewproc;
-  int    *localvert,nlocal; /* used to stash temporarily old global vertex number of new vertex */
+  PetscInt    *localvert,nlocal; /* used to stash temporarily old global vertex number of new vertex */
 } GridData;
 
 /*
@@ -116,21 +115,21 @@ typedef struct {
    the profiling results are meaningless.
 */
 
-extern int DataRead(GridData *);
-extern int DataPartitionElements(GridData *);
-extern int DataMoveElements(GridData *);
-extern int DataPartitionVertices(GridData *);
-extern int DataMoveVertices(GridData *);
-extern int DataDestroy(GridData *);
+extern PetscErrorCode DataRead(GridData *);
+extern PetscErrorCode DataPartitionElements(GridData *);
+extern PetscErrorCode DataMoveElements(GridData *);
+extern PetscErrorCode DataPartitionVertices(GridData *);
+extern PetscErrorCode DataMoveVertices(GridData *);
+extern PetscErrorCode DataDestroy(GridData *);
 
 #undef __FUNCT__
 #define __FUNCT__ "main"
 int main(int argc,char **args)
 {
-  int          ierr;
-  int          READ_EVENT,PARTITION_ELEMENT_EVENT,MOVE_ELEMENT_EVENT;
-  int          PARTITION_VERTEX_EVENT,MOVE_VERTEX_EVENT;
-  GridData     gdata;
+  PetscErrorCode ierr;
+  PetscEvent     READ_EVENT,PARTITION_ELEMENT_EVENT,MOVE_ELEMENT_EVENT;
+  PetscEvent     PARTITION_VERTEX_EVENT,MOVE_VERTEX_EVENT;
+  GridData       gdata;
 
   PetscInitialize(&argc,&args,(char *)0,help);
 
@@ -169,14 +168,16 @@ int main(int argc,char **args)
   assigned a continuous chunk of vertex and element data. Later the data
   will be partitioned and moved to the appropriate processor.
 */
-int DataRead(GridData *gdata)
+PetscErrorCode DataRead(GridData *gdata)
 {
-  int          rank,size,n_vert,*mmlocal_vert,mlocal_vert,i,*ia,*ja,cnt,j;
-  int          mlocal_ele,*mmlocal_ele,*ele,*tmpele,n_ele,net,a1,a2,a3;
-  int          *iatmp,*jatmp,ierr;
-  char         msg[128];
-  PetscScalar  *vert,*tmpvert;
-  MPI_Status   status;
+  PetscMPIInt    rank,size;
+  PetscInt       n_vert,*mmlocal_vert,mlocal_vert,i,*ia,*ja,cnt,j;
+  PetscInt       mlocal_ele,*mmlocal_ele,*ele,*tmpele,n_ele,net,a1,a2,a3;
+  PetscInt       *iatmp,*jatmp;
+  PetscErrorCode ierr;
+  char           msg[128];
+  PetscScalar    *vert,*tmpvert;
+  MPI_Status     status;
 
   PetscFunctionBegin;
   /*
@@ -211,7 +212,7 @@ int DataRead(GridData *gdata)
       vertices are assigned to each processor. Splitting vertices equally amoung
       all processors.
     */ 
-    ierr = PetscMalloc(size*sizeof(int),&mmlocal_vert);CHKERRQ(ierr);
+    ierr = PetscMalloc(size*sizeof(PetscInt),&mmlocal_vert);CHKERRQ(ierr);
     for (i=0; i<size; i++) {
       mmlocal_vert[i] = n_vert/size + ((n_vert % size) > i);
       printf("Processor %d assigned %d vertices\n",i,mmlocal_vert[i]);
@@ -255,7 +256,7 @@ int DataRead(GridData *gdata)
       Allocate enough room for the first processor to keep track of how many 
       elements are assigned to each processor.
     */ 
-    ierr = PetscMalloc(size*sizeof(int),&mmlocal_ele);CHKERRQ(ierr);
+    ierr = PetscMalloc(size*sizeof(PetscInt),&mmlocal_ele);CHKERRQ(ierr);
     for (i=0; i<size; i++) {
       mmlocal_ele[i] = n_ele/size + ((n_ele % size) > i);
       printf("Processor %d assigned %d elements\n",i,mmlocal_ele[i]);
@@ -264,7 +265,7 @@ int DataRead(GridData *gdata)
     /*
         read in element information for the first processor
     */
-    ierr = PetscMalloc(3*mmlocal_ele[0]*sizeof(int),&ele);CHKERRQ(ierr);   
+    ierr = PetscMalloc(3*mmlocal_ele[0]*sizeof(PetscInt),&ele);CHKERRQ(ierr);   
     printf("Elements assigned to processor 0\n");
     for (i=0; i<mlocal_ele; i++) {
       fscanf(fd,"%d %d %d %d\n",&cnt,ele+3*i,ele+3*i+1,ele+3*i+2);
@@ -274,7 +275,7 @@ int DataRead(GridData *gdata)
     /* 
        Read in elements for all the other processors 
     */
-    ierr = PetscMalloc(3*mmlocal_ele[0]*sizeof(int),&tmpele);CHKERRQ(ierr);
+    ierr = PetscMalloc(3*mmlocal_ele[0]*sizeof(PetscInt),&tmpele);CHKERRQ(ierr);
     for (j=1; j<size; j++) {
       printf("Elements assigned to processor %d\n",j);
       for (i=0; i<mmlocal_ele[j]; i++) {
@@ -290,8 +291,8 @@ int DataRead(GridData *gdata)
          We don't know how many spaces in ja[] to allocate so we allocate 
        3*the number of local elements, this is the maximum it could be
     */
-    ierr = PetscMalloc((mlocal_ele+1)*sizeof(int),&ia);CHKERRQ(ierr);
-    ierr = PetscMalloc((3*mlocal_ele+1)*sizeof(int),&ja);CHKERRQ(ierr);
+    ierr = PetscMalloc((mlocal_ele+1)*sizeof(PetscInt),&ia);CHKERRQ(ierr);
+    ierr = PetscMalloc((3*mlocal_ele+1)*sizeof(PetscInt),&ja);CHKERRQ(ierr);
     net   = 0;
     ia[0] = 0;
     printf("Element neighbors on processor 0\n");
@@ -319,8 +320,8 @@ int DataRead(GridData *gdata)
     /*
        Read in element neighbor information for all other processors
     */
-    ierr = PetscMalloc((mlocal_ele+1)*sizeof(int),&iatmp);CHKERRQ(ierr);
-    ierr = PetscMalloc((3*mlocal_ele+1)*sizeof(int),&jatmp);CHKERRQ(ierr);
+    ierr = PetscMalloc((mlocal_ele+1)*sizeof(PetscInt),&iatmp);CHKERRQ(ierr);
+    ierr = PetscMalloc((3*mlocal_ele+1)*sizeof(PetscInt),&jatmp);CHKERRQ(ierr);
     for (j=1; j<size; j++) {
       net   = 0;
       iatmp[0] = 0;
@@ -373,14 +374,14 @@ int DataRead(GridData *gdata)
     mlocal_ele = n_ele/size + ((n_ele % size) > rank);
 
     /* receive elements */
-    ierr = PetscMalloc(3*(mlocal_ele+1)*sizeof(int),&ele);CHKERRQ(ierr);
+    ierr = PetscMalloc(3*(mlocal_ele+1)*sizeof(PetscInt),&ele);CHKERRQ(ierr);
     ierr = MPI_Recv(ele,3*mlocal_ele,MPI_INT,0,0,PETSC_COMM_WORLD,&status);CHKERRQ(ierr);
 
     /* receive element adjacency graph */
-    ierr = PetscMalloc((mlocal_ele+1)*sizeof(int),&ia);CHKERRQ(ierr);
+    ierr = PetscMalloc((mlocal_ele+1)*sizeof(PetscInt),&ia);CHKERRQ(ierr);
     ierr = MPI_Recv(ia,mlocal_ele+1,MPI_INT,0,0,PETSC_COMM_WORLD,&status);CHKERRQ(ierr);
 
-    ierr = PetscMalloc((ia[mlocal_ele]+1)*sizeof(int),&ja);CHKERRQ(ierr);
+    ierr = PetscMalloc((ia[mlocal_ele]+1)*sizeof(PetscInt),&ja);CHKERRQ(ierr);
     ierr = MPI_Recv(ja,ia[mlocal_ele],MPI_INT,0,0,PETSC_COMM_WORLD,&status);CHKERRQ(ierr);
   }
 
@@ -405,11 +406,12 @@ int DataRead(GridData *gdata)
    new partitioning of the CELLS (elements) to reduce the number of cut edges between
    cells (elements).
 */
-int DataPartitionElements(GridData *gdata)
+PetscErrorCode DataPartitionElements(GridData *gdata)
 {
   Mat             Adj;                /* adjacency matrix */
-  int             *ia,*ja;
-  int             mlocal_ele,n_ele,ierr;
+  PetscInt        *ia,*ja;
+  PetscInt        mlocal_ele,n_ele;
+  PetscErrorCode  ierr;
   MatPartitioning part;
   IS              isnewproc; 
 
@@ -456,13 +458,15 @@ int DataPartitionElements(GridData *gdata)
       Moves the grid element data to be on the correct processor for the new
    element partitioning.
 */
-int DataMoveElements(GridData *gdata)
+PetscErrorCode DataMoveElements(GridData *gdata)
 {
-  int          ierr,*counts,rank,size,i,*idx;
-  Vec          vele,veleold;
-  PetscScalar  *array;
-  IS           isscat,isnum;
-  VecScatter   vecscat;
+  PetscErrorCode ierr;
+  PetscInt       *counts,i,*idx;
+  PetscMPIInt    rank,size;
+  Vec            vele,veleold;
+  PetscScalar    *array;
+  IS             isscat,isnum;
+  VecScatter     vecscat;
 
   PetscFunctionBegin;
 
@@ -472,8 +476,8 @@ int DataMoveElements(GridData *gdata)
   /* 
       Determine how many elements are assigned to each processor 
   */
-  ierr = PetscMalloc(size*sizeof(int),&counts);CHKERRQ(ierr);
-  ierr   = ISPartitioningCount(gdata->isnewproc,counts);CHKERRQ(ierr);
+  ierr = PetscMalloc(size*sizeof(PetscInt),&counts);CHKERRQ(ierr);
+  ierr = ISPartitioningCount(gdata->isnewproc,counts);CHKERRQ(ierr);
 
   /* 
      Create a vector to contain the newly ordered element information 
@@ -496,7 +500,7 @@ int DataMoveElements(GridData *gdata)
   /* 
       There are three data items per cell (element), the integer vertex numbers of its three 
     coordinates (we convert to double to use the scatter) (one can think 
-    of the vectors of having a block size of 3 and there is one index in idx[] for each block)
+    of the vectors of having a block size of 3, then there is one index in idx[] for each element)
   */
   ierr = ISGetIndices(isnum,&idx);CHKERRQ(ierr);
   for (i=0; i<gdata->mlocal_ele; i++) {
@@ -507,7 +511,7 @@ int DataMoveElements(GridData *gdata)
   ierr = ISDestroy(isnum);CHKERRQ(ierr);
 
   /* 
-     Create a vector to contain the old ordered element information
+     Create a vector to contain the original vertex information for each element 
   */
   ierr = VecCreateSeq(PETSC_COMM_SELF,3*gdata->mlocal_ele,&veleold);CHKERRQ(ierr);
   ierr = VecGetArray(veleold,&array);CHKERRQ(ierr);
@@ -517,7 +521,7 @@ int DataMoveElements(GridData *gdata)
   ierr = VecRestoreArray(veleold,&array);CHKERRQ(ierr);
   
   /* 
-     Scatter the element vertex information to the correct processor
+     Scatter the element vertex information (still in the original vertex ordering) to the correct processor
   */
   ierr = VecScatterCreate(veleold,PETSC_NULL,vele,isscat,&vecscat);CHKERRQ(ierr);
   ierr = ISDestroy(isscat);CHKERRQ(ierr);
@@ -532,7 +536,7 @@ int DataMoveElements(GridData *gdata)
   ierr = PetscFree(gdata->ele);CHKERRQ(ierr);
   gdata->mlocal_ele = counts[rank];
   ierr = PetscFree(counts);CHKERRQ(ierr);
-  ierr = PetscMalloc(3*gdata->mlocal_ele*sizeof(int),&gdata->ele);CHKERRQ(ierr);
+  ierr = PetscMalloc(3*gdata->mlocal_ele*sizeof(PetscInt),&gdata->ele);CHKERRQ(ierr);
   ierr = VecGetArray(vele,&array);CHKERRQ(ierr);
   for (i=0; i<3*gdata->mlocal_ele; i++) {
     gdata->ele[i] = (int)PetscRealPart(array[i]);
@@ -581,12 +585,14 @@ int DataMoveElements(GridData *gdata)
      time. An advantage is it requires no searching or sorting.
      
 */
-int DataPartitionVertices(GridData *gdata)
+PetscErrorCode DataPartitionVertices(GridData *gdata)
 {
-  int        n_vert = gdata->n_vert,ierr,*localvert;
-  int        rank,size,mlocal_ele = gdata->mlocal_ele,*ele = gdata->ele,i,j,nlocal = 0,nmax;
-  PetscBT    mask;
-  MPI_Status status;
+  PetscInt       n_vert = gdata->n_vert,*localvert;
+  PetscInt       mlocal_ele = gdata->mlocal_ele,*ele = gdata->ele,i,j,nlocal = 0,nmax;
+  PetscMPIInt    rank,size;
+  PetscErrorCode ierr;
+  PetscBT        mask;
+  MPI_Status     status;
 
   PetscFunctionBegin;
   ierr = MPI_Comm_rank(PETSC_COMM_WORLD,&rank);CHKERRQ(ierr);
@@ -626,7 +632,7 @@ int DataPartitionVertices(GridData *gdata)
   /* 
      Now we know how many are local, allocated enough space for them and mark them 
   */
-  ierr = PetscMalloc((nmax+1)*sizeof(int),&localvert);CHKERRQ(ierr);
+  ierr = PetscMalloc((nmax+1)*sizeof(PetscInt),&localvert);CHKERRQ(ierr);
 
   /* generate local list and fill in mask */
   nlocal = 0;
@@ -674,17 +680,18 @@ int DataPartitionVertices(GridData *gdata)
      Given the partitioning of the vertices; renumbers the element vertex lists for the 
      new vertex numbering and moves the vertex coordinate values to the correct processor
 */
-int DataMoveVertices(GridData *gdata)
+PetscErrorCode DataMoveVertices(GridData *gdata)
 {
-  AO           ao;
-  int          ierr,rank,i;
-  Vec          vert,overt;
-  VecScatter   vecscat;
-  IS           isscat;
-  PetscScalar  *avert;
+  AO             ao;
+  PetscErrorCode ierr;
+  PetscMPIInt    rank;
+  PetscInt       i;
+  Vec            vert,overt;
+  VecScatter     vecscat;
+  IS             isscat;
+  PetscScalar    *avert;
 
   PetscFunctionBegin;
-
   ierr = MPI_Comm_rank(PETSC_COMM_WORLD,&rank);CHKERRQ(ierr);
 
   /* ---------------------------------------------------------------------
@@ -751,8 +758,8 @@ int DataMoveVertices(GridData *gdata)
   ierr = VecDestroy(vert);CHKERRQ(ierr);
 
   ierr = PetscPrintf(PETSC_COMM_WORLD,"Vertex coordinates in new numbering\n");CHKERRQ(ierr);
-  for (i=0; i<2*gdata->mlocal_vert; i++) {
-    ierr = PetscSynchronizedPrintf(PETSC_COMM_WORLD,"%g\n",gdata->vert[i]);CHKERRQ(ierr);
+  for (i=0; i<gdata->mlocal_vert; i++) {
+    ierr = PetscSynchronizedPrintf(PETSC_COMM_WORLD,"(%g,%g)\n",gdata->vert[2*i],gdata->vert[2*i+1]);CHKERRQ(ierr);
   }
   ierr = PetscSynchronizedFlush(PETSC_COMM_WORLD);CHKERRQ(ierr);
 
@@ -762,9 +769,9 @@ int DataMoveVertices(GridData *gdata)
 
 #undef __FUNCT__
 #define __FUNCT__ "DataDestroy"
-int DataDestroy(GridData *gdata)
+PetscErrorCode DataDestroy(GridData *gdata)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   ierr = PetscFree(gdata->ele);CHKERRQ(ierr);
