@@ -1,4 +1,4 @@
-/*$Id: aoreduced.c,v 1.28 2001/03/23 23:24:52 balay Exp $*/
+#define PETSCDM_DLL
 
 #include "src/dm/ao/aoimpl.h"     /*I   "petscao.h"  I*/
 #include "petscsys.h"
@@ -6,14 +6,15 @@
 
 #undef __FUNCT__  
 #define __FUNCT__ "AODataSegmentGetReduced_Basic"
-int AODataSegmentGetReduced_Basic(AOData ao,const char name[],const char segname[],int n,int *keys,IS *is)
+PetscErrorCode AODataSegmentGetReduced_Basic(AOData ao,const char name[],const char segname[],PetscInt n,PetscInt *keys,IS *is)
 {
-  AODataSegment *segment; 
-  AODataKey     *key;
-  int           ierr,dsize,i,bs,*found,count,imin,imax,*out;
-  char          *idata,*odata;
-  PetscBT       mask;
-  PetscTruth    flag;
+  AODataSegment  *segment; 
+  AODataKey      *key;
+  PetscErrorCode ierr;
+  PetscInt       dsize,i,bs,*found,count,imin,imax,*out;
+  char           *idata,*odata;
+  PetscBT        mask;
+  PetscTruth     flag;
 
   PetscFunctionBegin;
   /* find the correct segment */
@@ -34,7 +35,7 @@ int AODataSegmentGetReduced_Basic(AOData ao,const char name[],const char segname
     ierr = PetscMemcpy(odata + i*bs*dsize,idata + keys[i]*bs*dsize,bs*dsize);CHKERRQ(ierr);
   }
 
-  found = (int*)odata;
+  found = (PetscInt*)odata;
   n     = n*bs;
 
   /*  Determine the max and min values */
@@ -57,7 +58,7 @@ int AODataSegmentGetReduced_Basic(AOData ao,const char name[],const char segname
     if (!PetscBTLookupSet(mask,found[i] - imin)) count++;
   }
   ierr = PetscBTMemzero(imax-imin,mask);CHKERRQ(ierr);
-  ierr = PetscMalloc((count+1)*sizeof(int),&out);CHKERRQ(ierr);
+  ierr = PetscMalloc((count+1)*sizeof(PetscInt),&out);CHKERRQ(ierr);
   count = 0;
   for (i=0; i<n; i++) {
     if (found[i] < 0) continue;
