@@ -1,4 +1,4 @@
-/*$Id: aodataalias.c,v 1.8 2001/03/23 23:24:50 balay Exp $*/
+#define PETSCDM_DLL
 
 #include "src/dm/ao/aoimpl.h"      /*I "petscao.h" I*/
 
@@ -21,10 +21,10 @@
 
 .seealso:  
 @*/ 
-int AODataAddAlias(AOData ao,char *alias,char *name)
+PetscErrorCode PETSCDM_DLLEXPORT AODataAddAlias(AOData ao,char *alias,char *name)
 {
   AODataAlias *aoalias,*t;
-  int         ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ao,AODATA_COOKIE,1);
