@@ -693,7 +693,6 @@ PetscErrorCode FATest(FA fa)
   Field          **la;
   PetscInt       x,y,m,n,j,i,k,p;
   PetscMPIInt    rank;
-  PetscScalar    zero = 0.0;
 
   PetscFunctionBegin;
   ierr = MPI_Comm_rank(PETSC_COMM_WORLD,&rank);CHKERRQ(ierr);
@@ -704,7 +703,7 @@ PetscErrorCode FATest(FA fa)
   /* fill up global vector of one region at a time with ITS logical coordinates, then update LOCAL
      vector; print local vectors to confirm they are correctly filled */
   for (j=0; j<3; j++) {
-    ierr = VecSet(g,zero);CHKERRQ(ierr);
+    ierr = VecSet(g,0.0);CHKERRQ(ierr);
     ierr = FAGetGlobalCorners(fa,j,&x,&y,&m,&n);CHKERRQ(ierr);
     ierr = PetscPrintf(PETSC_COMM_WORLD,"\nFilling global region %d, showing local results \n",j+1);CHKERRQ(ierr);
     ierr = FAGetGlobalArray(fa,g,j,&la);CHKERRQ(ierr);
@@ -726,7 +725,7 @@ PetscErrorCode FATest(FA fa)
       ierr = PetscSynchronizedPrintf(PETSC_COMM_WORLD,"\n[%d] Local array for region %d \n",rank,p+1);CHKERRQ(ierr);
       for (k=y+n-1; k>=y; k--) { /* print in reverse order to match diagram in paper */
         for (i=x; i<x+m; i++) {
-          ierr = PetscSynchronizedPrintf(PETSC_COMM_WORLD,"(%g,%g) ",la[k][i].X,la[k][i].Y);CHKERRQ(ierr);
+          ierr = PetscSynchronizedPrintf(PETSC_COMM_WORLD,"(%G,%G) ",la[k][i].X,la[k][i].Y);CHKERRQ(ierr);
         }
         ierr = PetscSynchronizedPrintf(PETSC_COMM_WORLD,"\n");CHKERRQ(ierr);
       }
