@@ -266,7 +266,6 @@ PetscErrorCode PETSCDM_DLLEXPORT DACreate2d(MPI_Comm comm,DAPeriodicType wrap,DA
   PetscInt       s_x,s_y; /* s proportionalized to w */
   PetscInt       *flx = 0,*fly = 0;
   PetscInt       sn0 = 0,sn2 = 0,sn6 = 0,sn8 = 0,refine_x = 2, refine_y = 2,tM = M,tN = N;
-  PetscTruth     flg1;
   DA             da;
   Vec            local,global;
   VecScatter     ltog,gtol;
@@ -788,54 +787,11 @@ PetscErrorCode PETSCDM_DLLEXPORT DACreate2d(MPI_Comm comm,DAPeriodicType wrap,DA
   }
   da->lx = flx;
   da->ly = fly;
-
-  ierr = PetscOptionsHasName(PETSC_NULL,"-da_view",&flg1);CHKERRQ(ierr);
-  if (flg1) {ierr = DAView(da,PETSC_VIEWER_STDOUT_(da->comm));CHKERRQ(ierr);}
-  ierr = PetscOptionsHasName(PETSC_NULL,"-da_view_draw",&flg1);CHKERRQ(ierr);
-  if (flg1) {ierr = DAView(da,PETSC_VIEWER_DRAW_(da->comm));CHKERRQ(ierr);}
-  ierr = PetscOptionsHasName(PETSC_NULL,"-help",&flg1);CHKERRQ(ierr);
-  if (flg1) {ierr = DAPrintHelp(da);CHKERRQ(ierr);}
-
+  ierr = DAView_Private(da);CHKERRQ(ierr);
   ierr = PetscPublishAll(da);CHKERRQ(ierr);
   PetscFunctionReturn(0); 
 }
 
-#undef __FUNCT__  
-#define __FUNCT__ "DAPrintHelp"
-/*@
-   DAPrintHelp - Prints command line options for DA.
-
-   Collective on DA
-
-   Input Parameters:
-.  da - the distributed array
-
-   Level: intermediate
-
-.seealso: DACreate1d(), DACreate2d(), DACreate3d()
-
-.keywords: DA, help
-
-@*/
-PetscErrorCode PETSCDM_DLLEXPORT DAPrintHelp(DA da)
-{
-  static PetscTruth called = PETSC_FALSE;
-  MPI_Comm          comm;
-  PetscErrorCode    ierr;
-
-  PetscFunctionBegin;
-  PetscValidHeaderSpecific(da,DA_COOKIE,1);
-
-  comm = da->comm;
-  if (!called) {
-    ierr = (*PetscHelpPrintf)(comm,"General Distributed Array (DA) options:\n");CHKERRQ(ierr);
-    ierr = (*PetscHelpPrintf)(comm,"  -da_view: print DA distribution to screen\n");CHKERRQ(ierr);
-    ierr = (*PetscHelpPrintf)(comm,"  -da_view_draw: display DA in window\n");CHKERRQ(ierr);
-    called = PETSC_TRUE;
-  }
-  PetscFunctionReturn(0);
-}
-
 #undef __FUNCT__  
 #define __FUNCT__ "DARefine"
 /*@
@@ -887,13 +843,8 @@ PetscErrorCode PETSCDM_DLLEXPORT DARefine(DA da,MPI_Comm comm,DA *daref)
   } else {
     P = 1 + da->refine_z*(da->P - 1);
   }
-  if (da->dim == 1) {
-    ierr = DACreate1d(da->comm,da->wrap,M,da->w,da->s,PETSC_NULL,&da2);CHKERRQ(ierr);
-  } else if (da->dim == 2) {
-    ierr = DACreate2d(da->comm,da->wrap,da->stencil_type,M,N,da->m,da->n,da->w,da->s,PETSC_NULL,PETSC_NULL,&da2);CHKERRQ(ierr);
-  } else if (da->dim == 3) {
-    ierr = DACreate3d(da->comm,da->wrap,da->stencil_type,M,N,P,da->m,da->n,da->p,da->w,da->s,0,0,0,&da2);CHKERRQ(ierr);
-  }
+  ierr = DACreate(da->comm,da->dim,da->wrap,da->stencil_type,M,N,P,da->m,da->n,da->p,da->w,da->s,0,0,0,&da2);CHKERRQ(ierr);
+
   /* allow overloaded (user replaced) operations to be inherited by refinement clones */
   da2->ops->getmatrix        = da->ops->getmatrix;
   da2->ops->getinterpolation = da->ops->getinterpolation;
@@ -1346,6 +1297,107 @@ PetscErrorCode PETSCDM_DLLEXPORT DAGetLocalFunction(DA da,DALocalFunction1 *lf)
   PetscFunctionReturn(0);
 }
 
+#undef __FUNCT__
+#define __FUNCT__ "DAFormFunction"
+/*@
+    DAFormFunction - Evaluates a user provided function on each processor that 
+        share a DA
+
+   Input Parameters:
++    da - the DA that defines the grid
+.    vu - input vector
+.    vfu - output vector 
+-    w - any user data
+
+    Notes: Does NOT do ghost updates on vu upon entry
+
+           This should eventually replace DAFormFunction1
+
+    Level: advanced
+
+.seealso: DAComputeJacobian1WithAdic()
+
+@*/
+PetscErrorCode PETSCDM_DLLEXPORT DAFormFunction(DA da,PetscErrorCode (*lf)(void),Vec vu,Vec vfu,void *w)
+{
+  PetscErrorCode ierr;
+  void           *u,*fu;
+  DALocalInfo    info;
+  PetscErrorCode (*f)(DALocalInfo*,void*,void*,void*) = (PetscErrorCode (*)(DALocalInfo*,void*,void*,void*))lf;
+  
+  PetscFunctionBegin;
+  ierr = DAGetLocalInfo(da,&info);CHKERRQ(ierr);
+  ierr = DAVecGetArray(da,vu,&u);CHKERRQ(ierr);
+  ierr = DAVecGetArray(da,vfu,&fu);CHKERRQ(ierr);
+
+  ierr = (*f)(&info,u,fu,w);
+  if (PetscExceptionValue(ierr)) {
+    PetscErrorCode pierr = DAVecRestoreArray(da,vu,&u);CHKERRQ(pierr);
+    pierr = DAVecRestoreArray(da,vfu,&fu);CHKERRQ(pierr);
+  }
+  CHKERRQ(ierr);
+
+  ierr = DAVecRestoreArray(da,vu,&u);CHKERRQ(ierr);
+  ierr = DAVecRestoreArray(da,vfu,&fu);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
+#undef __FUNCT__
+#define __FUNCT__ "DAFormFunctionLocal"
+/*@C 
+   DAFormFunctionLocal - This is a universal function evaluation routine for
+   a local DA function.
+
+   Collective on DA
+
+   Input Parameters:
++  da - the DA context
+.  func - The local function
+.  X - input vector
+.  F - function vector
+-  ctx - A user context
+
+   Level: intermediate
+
+.seealso: DASetLocalFunction(), DASetLocalJacobian(), DASetLocalAdicFunction(), DASetLocalAdicMFFunction(),
+          SNESSetFunction(), SNESSetJacobian()
+
+@*/
+PetscErrorCode PETSCDM_DLLEXPORT DAFormFunctionLocal(DA da, DALocalFunction1 func, Vec X, Vec F, void *ctx)
+{
+  Vec            localX;
+  DALocalInfo    info;
+  void          *u;
+  void          *fu;
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  ierr = DAGetLocalVector(da,&localX);CHKERRQ(ierr);
+  /*
+     Scatter ghost points to local vector, using the 2-step process
+        DAGlobalToLocalBegin(), DAGlobalToLocalEnd().
+  */
+  ierr = DAGlobalToLocalBegin(da,X,INSERT_VALUES,localX);CHKERRQ(ierr);
+  ierr = DAGlobalToLocalEnd(da,X,INSERT_VALUES,localX);CHKERRQ(ierr);
+  ierr = DAGetLocalInfo(da,&info);CHKERRQ(ierr);
+  ierr = DAVecGetArray(da,localX,&u);CHKERRQ(ierr);
+  ierr = DAVecGetArray(da,F,&fu);CHKERRQ(ierr);
+  ierr = (*func)(&info,u,fu,ctx);
+  if (PetscExceptionValue(ierr)) {
+    PetscErrorCode pierr = DAVecRestoreArray(da,localX,&u);CHKERRQ(pierr);
+    pierr = DAVecRestoreArray(da,F,&fu);CHKERRQ(pierr);
+  }
+  CHKERRQ(ierr);
+  ierr = DAVecRestoreArray(da,localX,&u);CHKERRQ(ierr);
+  ierr = DAVecRestoreArray(da,F,&fu);CHKERRQ(ierr);
+  if (PetscExceptionValue(ierr)) {
+    PetscErrorCode pierr = DARestoreLocalVector(da,&localX);CHKERRQ(pierr);
+  }
+  CHKERRQ(ierr);
+  ierr = DARestoreLocalVector(da,&localX);CHKERRQ(ierr);
+  PetscFunctionReturn(0); 
+}
+
 #undef __FUNCT__
 #define __FUNCT__ "DAFormFunction1"
 /*@
@@ -1377,12 +1429,14 @@ PetscErrorCode PETSCDM_DLLEXPORT DAFormFunction1(DA da,Vec vu,Vec vfu,void *w)
   ierr = DAVecGetArray(da,vu,&u);CHKERRQ(ierr);
   ierr = DAVecGetArray(da,vfu,&fu);CHKERRQ(ierr);
 
+  CHKMEMQ;
   ierr = (*da->lf)(&info,u,fu,w);
   if (PetscExceptionValue(ierr)) {
     PetscErrorCode pierr = DAVecRestoreArray(da,vu,&u);CHKERRQ(pierr);
     pierr = DAVecRestoreArray(da,vfu,&fu);CHKERRQ(pierr);
   }
   CHKERRQ(ierr);
+  CHKMEMQ;
 
   ierr = DAVecRestoreArray(da,vu,&u);CHKERRQ(ierr);
   ierr = DAVecRestoreArray(da,vfu,&fu);CHKERRQ(ierr);
@@ -1402,7 +1456,8 @@ PetscErrorCode PETSCDM_DLLEXPORT DAFormFunctioniTest1(DA da,void *w)
 
   PetscFunctionBegin;
   ierr = DAGetLocalVector(da,&vu);CHKERRQ(ierr);
-  ierr = PetscRandomCreate(PETSC_COMM_SELF,RANDOM_DEFAULT,&rnd);CHKERRQ(ierr);
+  ierr = PetscRandomCreate(PETSC_COMM_SELF,&rnd);CHKERRQ(ierr);
+  ierr = PetscRandomSetFromOptions(rnd);CHKERRQ(ierr);
   ierr = VecSetRandom(vu,rnd);CHKERRQ(ierr);
   ierr = PetscRandomDestroy(rnd);CHKERRQ(ierr);
 
