@@ -1,5 +1,5 @@
-/*$Id: dagtol.c,v 1.29 2001/03/23 23:25:00 balay Exp $*/
- 
+#define PETSCDM_DLL
+
 /*
   Code for manipulating distributed regular arrays in parallel.
 */
@@ -39,14 +39,14 @@
           
 
 @*/
-int DAGlobalToLocalBegin(DA da,Vec g,InsertMode mode,Vec l)
+PetscErrorCode PETSCDM_DLLEXPORT DAGlobalToLocalBegin(DA da,Vec g,InsertMode mode,Vec l)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
-  PetscValidHeaderSpecific(l,VEC_COOKIE,2);
-  PetscValidHeaderSpecific(g,VEC_COOKIE,4);
+  PetscValidHeaderSpecific(g,VEC_COOKIE,2);
+  PetscValidHeaderSpecific(l,VEC_COOKIE,4);
   ierr = VecScatterBegin(g,l,mode,SCATTER_FORWARD,da->gtol);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -82,9 +82,9 @@ int DAGlobalToLocalBegin(DA da,Vec g,InsertMode mode,Vec l)
           DALocalToLocalBegin(), DALocalToLocalEnd(), DALocalToGlobalEnd()
 
 @*/
-int DALocalToGlobalBegin(DA da,Vec l,Vec g)
+PetscErrorCode PETSCDM_DLLEXPORT DALocalToGlobalBegin(DA da,Vec l,Vec g)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
@@ -125,9 +125,9 @@ int DALocalToGlobalBegin(DA da,Vec l,Vec g)
           DALocalToLocalBegin(), DALocalToLocalEnd(), DALocalToGlobalBegin()
 
 @*/
-int DALocalToGlobalEnd(DA da,Vec l,Vec g)
+PetscErrorCode PETSCDM_DLLEXPORT DALocalToGlobalEnd(DA da,Vec l,Vec g)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
@@ -167,19 +167,19 @@ int DALocalToGlobalEnd(DA da,Vec l,Vec g)
 .seealso: DAGlobalToLocalBegin(), DALocalToGlobal(), DACreate2d(),
      DALocalToLocalBegin(), DALocalToLocalEnd(), DALocalToGlobalBegin(), DALocalToGlobalEnd()
 @*/
-int DAGlobalToLocalEnd(DA da,Vec g,InsertMode mode,Vec l)
+PetscErrorCode PETSCDM_DLLEXPORT DAGlobalToLocalEnd(DA da,Vec g,InsertMode mode,Vec l)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
-  PetscValidHeaderSpecific(l,VEC_COOKIE,2);
-  PetscValidHeaderSpecific(g,VEC_COOKIE,4);
+  PetscValidHeaderSpecific(g,VEC_COOKIE,2);
+  PetscValidHeaderSpecific(l,VEC_COOKIE,4);
   ierr = VecScatterEnd(g,l,mode,SCATTER_FORWARD,da->gtol);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-extern int DAGetNatural_Private(DA,int*,IS*);
+EXTERN PetscErrorCode DAGetNatural_Private(DA,PetscInt*,IS*);
 #undef __FUNCT__  
 #define __FUNCT__ "DAGlobalToNatural_Create"
 /*
@@ -200,16 +200,17 @@ extern int DAGetNatural_Private(DA,int*,IS*);
 .seealso: DAGlobalToNaturalEnd(), DALocalToGlobal(), DACreate2d(), 
           DAGlobalToLocalBegin(), DAGlobalToLocalEnd(), DACreateNaturalVector()
 */
-int DAGlobalToNatural_Create(DA da)
+PetscErrorCode DAGlobalToNatural_Create(DA da)
 {
-  int ierr,m,start,Nlocal;
+  PetscErrorCode ierr;
+  PetscInt  m,start,Nlocal;
   IS  from,to;
   Vec global;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
   if (!da->natural) {
-    SETERRQ(1,"Natural layout vector not yet created; cannot scatter into it");
+    SETERRQ(PETSC_ERR_ORDER,"Natural layout vector not yet created; cannot scatter into it");
   }
 
   /* create the scatter context */
@@ -217,9 +218,10 @@ int DAGlobalToNatural_Create(DA da)
   ierr = VecGetOwnershipRange(da->natural,&start,PETSC_NULL);CHKERRQ(ierr);
 
   ierr = DAGetNatural_Private(da,&Nlocal,&to);CHKERRQ(ierr);
-  if (Nlocal != m) SETERRQ2(1,"Internal error: Nlocal %d local vector size %d",Nlocal,m);
+  if (Nlocal != m) SETERRQ2(PETSC_ERR_PLIB,"Internal error: Nlocal %D local vector size %D",Nlocal,m);
   ierr = ISCreateStride(da->comm,m,start,1,&from);CHKERRQ(ierr);
   ierr = VecCreateMPIWithArray(da->comm,da->Nlocal,PETSC_DETERMINE,0,&global);
+  ierr = VecSetBlockSize(global,da->w);CHKERRQ(ierr);
   ierr = VecScatterCreate(global,from,da->natural,to,&da->gton);CHKERRQ(ierr);
   ierr = VecDestroy(global);CHKERRQ(ierr);
   ierr = ISDestroy(from);CHKERRQ(ierr);
@@ -258,9 +260,9 @@ int DAGlobalToNatural_Create(DA da)
           DAGlobalToLocalBegin(), DAGlobalToLocalEnd(), DACreateNaturalVector(),
           DALocalToGlobalBegin(), DALocalToGlobalEnd()
 @*/
-int DAGlobalToNaturalBegin(DA da,Vec g,InsertMode mode,Vec l)
+PetscErrorCode PETSCDM_DLLEXPORT DAGlobalToNaturalBegin(DA da,Vec g,InsertMode mode,Vec l)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
@@ -304,9 +306,9 @@ int DAGlobalToNaturalBegin(DA da,Vec g,InsertMode mode,Vec l)
           DAGlobalToLocalBegin(), DAGlobalToLocalEnd(), DACreateNaturalVector(),
           DALocalToGlobalBegin(), DALocalToGlobalEnd()
 @*/
-int DAGlobalToNaturalEnd(DA da,Vec g,InsertMode mode,Vec l)
+PetscErrorCode PETSCDM_DLLEXPORT DAGlobalToNaturalEnd(DA da,Vec g,InsertMode mode,Vec l)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
@@ -348,9 +350,9 @@ int DAGlobalToNaturalEnd(DA da,Vec g,InsertMode mode,Vec l)
           DALocalToGlobalBegin(), DALocalToGlobalEnd()
 
 @*/
-int DANaturalToGlobalBegin(DA da,Vec g,InsertMode mode,Vec l)
+PetscErrorCode PETSCDM_DLLEXPORT DANaturalToGlobalBegin(DA da,Vec g,InsertMode mode,Vec l)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
@@ -395,9 +397,9 @@ int DANaturalToGlobalBegin(DA da,Vec g,InsertMode mode,Vec l)
           DALocalToGlobalBegin(), DALocalToGlobalEnd()
 
 @*/
-int DANaturalToGlobalEnd(DA da,Vec g,InsertMode mode,Vec l)
+PetscErrorCode PETSCDM_DLLEXPORT DANaturalToGlobalEnd(DA da,Vec g,InsertMode mode,Vec l)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
