@@ -48,7 +48,7 @@ EXTERN_C_END
 
 #undef __FUNCT__  
 #define __FUNCT__ "DACreateLocalVector"
-/*@C
+/*@
    DACreateLocalVector - Creates a Seq PETSc vector that
    may be used with the DAXXX routines.
 
@@ -92,7 +92,7 @@ PetscErrorCode PETSCDM_DLLEXPORT DACreateLocalVector(DA da,Vec* g)
 
 #undef __FUNCT__  
 #define __FUNCT__ "DAGetLocalVector"
-/*@C
+/*@
    DAGetLocalVector - Gets a Seq PETSc vector that
    may be used with the DAXXX routines.
 
@@ -150,7 +150,7 @@ PetscErrorCode PETSCDM_DLLEXPORT DAGetLocalVector(DA da,Vec* g)
 
 #undef __FUNCT__  
 #define __FUNCT__ "DARestoreLocalVector"
-/*@C
+/*@
    DARestoreLocalVector - Returns a Seq PETSc vector that
      obtained from DAGetLocalVector(). Do not use with vector obtained via
      DACreateLocalVector().
@@ -195,7 +195,7 @@ PetscErrorCode PETSCDM_DLLEXPORT DARestoreLocalVector(DA da,Vec* g)
 
 #undef __FUNCT__  
 #define __FUNCT__ "DAGetGlobalVector"
-/*@C
+/*@
    DAGetGlobalVector - Gets a MPI PETSc vector that
    may be used with the DAXXX routines.
 
@@ -255,7 +255,7 @@ PetscErrorCode PETSCDM_DLLEXPORT DAGetGlobalVector(DA da,Vec* g)
 
 #undef __FUNCT__  
 #define __FUNCT__ "DARestoreGlobalVector"
-/*@C
+/*@
    DARestoreGlobalVector - Returns a Seq PETSc vector that
      obtained from DAGetGlobalVector(). Do not use with vector obtained via
      DACreateGlobalVector().
@@ -867,6 +867,335 @@ PetscErrorCode PETSCDM_DLLEXPORT DAGetAdicMFArray(DA da,PetscTruth ghosted,void
   PetscFunctionReturn(0);
 }
 
+#undef __FUNCT__
+#define __FUNCT__ "DAGetAdicMFArray4"
+PetscErrorCode PETSCDM_DLLEXPORT DAGetAdicMFArray4(DA da,PetscTruth ghosted,void **iptr,void **array_start,PetscInt *tdof)
+{
+  PetscErrorCode ierr;
+  PetscInt j,i,xs,ys,xm,ym,zs,zm,itdof = 0;
+  char *iarray_start;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(da,DA_COOKIE,1);
+  if (ghosted) {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (da->admfarrayghostedin[i]) {
+        *iptr                     = da->admfarrayghostedin[i];
+        iarray_start              = (char*)da->admfstartghostedin[i];
+        itdof                     = da->ghostedtdof;
+        da->admfarrayghostedin[i] = PETSC_NULL;
+        da->admfstartghostedin[i] = PETSC_NULL;
+        
+        goto done;
+      }
+    }
+    xs = da->Xs;
+    ys = da->Ys;
+    zs = da->Zs;
+    xm = da->Xe-da->Xs;
+    ym = da->Ye-da->Ys;
+    zm = da->Ze-da->Zs;
+  } else {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (da->admfarrayin[i]) {
+        *iptr              = da->admfarrayin[i];
+        iarray_start       = (char*)da->admfstartin[i];
+        itdof              = da->tdof;
+        da->admfarrayin[i] = PETSC_NULL;
+        da->admfstartin[i] = PETSC_NULL;
+        
+        goto done;
+      }
+    }
+    xs = da->xs;
+    ys = da->ys;
+    zs = da->zs;
+    xm = da->xe-da->xs;
+    ym = da->ye-da->ys;
+    zm = da->ze-da->zs;
+  }
+
+  switch (da->dim) {
+    case 2: {
+      void **ptr;
+      itdof = xm*ym;
+
+      ierr  = PetscMalloc((ym+1)*sizeof(void*)+xm*ym*5*sizeof(PetscScalar),&iarray_start);CHKERRQ(ierr);
+
+      ptr  = (void**)(iarray_start + xm*ym*5*sizeof(PetscScalar) - ys*sizeof(void*));
+      for(j=ys;j<ys+ym;j++) {
+        ptr[j] = iarray_start + 5*sizeof(PetscScalar)*(xm*(j-ys) - xs);
+      }
+      *iptr = (void*)ptr; 
+      break;}
+    default:
+      SETERRQ1(PETSC_ERR_SUP,"Dimension %D not supported",da->dim);
+  }
+
+  done:
+  /* add arrays to the checked out list */
+  if (ghosted) {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (!da->admfarrayghostedout[i]) {
+        da->admfarrayghostedout[i] = *iptr ;
+        da->admfstartghostedout[i] = iarray_start;
+        da->ghostedtdof            = itdof;
+        break;
+      }
+    }
+  } else {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (!da->admfarrayout[i]) {
+        da->admfarrayout[i] = *iptr ;
+        da->admfstartout[i] = iarray_start;
+        da->tdof            = itdof;
+        break;
+      }
+    }
+  }
+  if (i == DA_MAX_AD_ARRAYS+1) SETERRQ(PETSC_ERR_ARG_WRONG,"Too many DA ADIC arrays obtained");
+  if (tdof)        *tdof = itdof;
+  if (array_start) *array_start = iarray_start;
+  PetscFunctionReturn(0);
+}
+
+#undef __FUNCT__
+#define __FUNCT__ "DAGetAdicMFArray9"
+PetscErrorCode PETSCDM_DLLEXPORT DAGetAdicMFArray9(DA da,PetscTruth ghosted,void **iptr,void **array_start,PetscInt *tdof)
+{
+  PetscErrorCode ierr;
+  PetscInt j,i,xs,ys,xm,ym,zs,zm,itdof = 0;
+  char *iarray_start;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(da,DA_COOKIE,1);
+  if (ghosted) {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (da->admfarrayghostedin[i]) {
+        *iptr                     = da->admfarrayghostedin[i];
+        iarray_start              = (char*)da->admfstartghostedin[i];
+        itdof                     = da->ghostedtdof;
+        da->admfarrayghostedin[i] = PETSC_NULL;
+        da->admfstartghostedin[i] = PETSC_NULL;
+        
+        goto done;
+      }
+    }
+    xs = da->Xs;
+    ys = da->Ys;
+    zs = da->Zs;
+    xm = da->Xe-da->Xs;
+    ym = da->Ye-da->Ys;
+    zm = da->Ze-da->Zs;
+  } else {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (da->admfarrayin[i]) {
+        *iptr              = da->admfarrayin[i];
+        iarray_start       = (char*)da->admfstartin[i];
+        itdof              = da->tdof;
+        da->admfarrayin[i] = PETSC_NULL;
+        da->admfstartin[i] = PETSC_NULL;
+        
+        goto done;
+      }
+    }
+    xs = da->xs;
+    ys = da->ys;
+    zs = da->zs;
+    xm = da->xe-da->xs;
+    ym = da->ye-da->ys;
+    zm = da->ze-da->zs;
+  }
+
+  switch (da->dim) {
+    case 2: {
+      void **ptr;
+      itdof = xm*ym;
+
+      ierr  = PetscMalloc((ym+1)*sizeof(void*)+xm*ym*10*sizeof(PetscScalar),&iarray_start);CHKERRQ(ierr);
+
+      ptr  = (void**)(iarray_start + xm*ym*10*sizeof(PetscScalar) - ys*sizeof(void*));
+      for(j=ys;j<ys+ym;j++) {
+        ptr[j] = iarray_start + 10*sizeof(PetscScalar)*(xm*(j-ys) - xs);
+      }
+      *iptr = (void*)ptr; 
+      break;}
+    default:
+      SETERRQ1(PETSC_ERR_SUP,"Dimension %D not supported",da->dim);
+  }
+
+  done:
+  /* add arrays to the checked out list */
+  if (ghosted) {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (!da->admfarrayghostedout[i]) {
+        da->admfarrayghostedout[i] = *iptr ;
+        da->admfstartghostedout[i] = iarray_start;
+        da->ghostedtdof            = itdof;
+        break;
+      }
+    }
+  } else {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (!da->admfarrayout[i]) {
+        da->admfarrayout[i] = *iptr ;
+        da->admfstartout[i] = iarray_start;
+        da->tdof            = itdof;
+        break;
+      }
+    }
+  }
+  if (i == DA_MAX_AD_ARRAYS+1) SETERRQ(PETSC_ERR_ARG_WRONG,"Too many DA ADIC arrays obtained");
+  if (tdof)        *tdof = itdof;
+  if (array_start) *array_start = iarray_start;
+  PetscFunctionReturn(0);
+}
+
+#undef __FUNCT__
+#define __FUNCT__ "DAGetAdicMFArrayb"
+/*@C
+     DAGetAdicMFArrayb - Gets an array of derivative types for a DA for matrix-free ADIC.
+          
+     Input Parameter:
++    da - information about my local patch
+-    ghosted - do you want arrays for the ghosted or nonghosted patch?
+
+     Output Parameters:
++    iptr - array data structured to be passed to ad_FormFunctionLocal()
+.    array_start - actual start of 1d array of all values that adiC can access directly (may be null)
+-    tdof - total number of degrees of freedom represented in array_start (may be null)
+
+     Notes: 
+     The vector values are NOT initialized and may have garbage in them, so you may need
+     to zero them.
+
+     This routine returns the same type of object as the DAVecGetArray(), except its
+     elements are derivative types instead of PetscScalars.
+
+     Level: advanced
+
+.seealso: DARestoreAdicMFArray(), DAGetArray(), DAGetAdicArray()
+
+@*/
+PetscErrorCode PETSCDM_DLLEXPORT DAGetAdicMFArrayb(DA da,PetscTruth ghosted,void **iptr,void **array_start,PetscInt *tdof)
+{
+  PetscErrorCode ierr;
+  PetscInt       j,i,xs,ys,xm,ym,zs,zm,itdof = 0;
+  char           *iarray_start;
+  PetscInt       bs = da->w,bs1 = bs+1;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(da,DA_COOKIE,1);
+  if (ghosted) {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (da->admfarrayghostedin[i]) {
+        *iptr                     = da->admfarrayghostedin[i];
+        iarray_start              = (char*)da->admfstartghostedin[i];
+        itdof                     = da->ghostedtdof;
+        da->admfarrayghostedin[i] = PETSC_NULL;
+        da->admfstartghostedin[i] = PETSC_NULL;
+        
+        goto done;
+      }
+    }
+    xs = da->Xs;
+    ys = da->Ys;
+    zs = da->Zs;
+    xm = da->Xe-da->Xs;
+    ym = da->Ye-da->Ys;
+    zm = da->Ze-da->Zs;
+  } else {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (da->admfarrayin[i]) {
+        *iptr              = da->admfarrayin[i];
+        iarray_start       = (char*)da->admfstartin[i];
+        itdof              = da->tdof;
+        da->admfarrayin[i] = PETSC_NULL;
+        da->admfstartin[i] = PETSC_NULL;
+        
+        goto done;
+      }
+    }
+    xs = da->xs;
+    ys = da->ys;
+    zs = da->zs;
+    xm = da->xe-da->xs;
+    ym = da->ye-da->ys;
+    zm = da->ze-da->zs;
+  }
+
+  switch (da->dim) {
+    case 1: {
+      void *ptr;
+      itdof = xm;
+
+      ierr  = PetscMalloc(xm*bs1*sizeof(PetscScalar),&iarray_start);CHKERRQ(ierr);
+
+      ptr   = (void*)(iarray_start - xs*bs1*sizeof(PetscScalar));
+      *iptr = (void*)ptr; 
+      break;}
+    case 2: {
+      void **ptr;
+      itdof = xm*ym;
+
+      ierr  = PetscMalloc((ym+1)*sizeof(void*)+xm*ym*bs1*sizeof(PetscScalar),&iarray_start);CHKERRQ(ierr);
+
+      ptr  = (void**)(iarray_start + xm*ym*bs1*sizeof(PetscScalar) - ys*sizeof(void*));
+      for(j=ys;j<ys+ym;j++) {
+        ptr[j] = iarray_start + bs1*sizeof(PetscScalar)*(xm*(j-ys) - xs);
+      }
+      *iptr = (void*)ptr; 
+      break;}
+    case 3: {
+      void ***ptr,**bptr;
+      itdof = xm*ym*zm;
+
+      ierr  = PetscMalloc((zm+1)*sizeof(void **)+(ym*zm+1)*sizeof(void*)+xm*ym*zm*bs1*sizeof(PetscScalar),&iarray_start);CHKERRQ(ierr);
+
+      ptr  = (void***)(iarray_start + xm*ym*zm*2*sizeof(PetscScalar) - zs*sizeof(void*));
+      bptr = (void**)(iarray_start + xm*ym*zm*2*sizeof(PetscScalar) + zm*sizeof(void**));
+      for(i=zs;i<zs+zm;i++) {
+        ptr[i] = bptr + ((i-zs)*ym* - ys)*sizeof(void*);
+      }
+      for (i=zs; i<zs+zm; i++) {
+        for (j=ys; j<ys+ym; j++) {
+          ptr[i][j] = iarray_start + bs1*sizeof(PetscScalar)*(xm*ym*(i-zs) + xm*(j-ys) - xs);
+        }
+      }
+
+      *iptr = (void*)ptr; 
+      break;}
+    default:
+      SETERRQ1(PETSC_ERR_SUP,"Dimension %D not supported",da->dim);
+  }
+
+  done:
+  /* add arrays to the checked out list */
+  if (ghosted) {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (!da->admfarrayghostedout[i]) {
+        da->admfarrayghostedout[i] = *iptr ;
+        da->admfstartghostedout[i] = iarray_start;
+        da->ghostedtdof            = itdof;
+        break;
+      }
+    }
+  } else {
+    for (i=0; i<DA_MAX_AD_ARRAYS; i++) {
+      if (!da->admfarrayout[i]) {
+        da->admfarrayout[i] = *iptr ;
+        da->admfstartout[i] = iarray_start;
+        da->tdof            = itdof;
+        break;
+      }
+    }
+  }
+  if (i == DA_MAX_AD_ARRAYS+1) SETERRQ(PETSC_ERR_ARG_WRONG,"Too many DA ADIC arrays obtained");
+  if (tdof)        *tdof = itdof;
+  if (array_start) *array_start = iarray_start;
+  PetscFunctionReturn(0);
+}
+
 #undef __FUNCT__
 #define __FUNCT__ "DARestoreAdicMFArray"
 /*@C
