@@ -1,5 +1,5 @@
-/*$Id: daltol.c,v 1.24 2001/03/23 23:25:00 balay Exp $*/
- 
+#define PETSCDM_DLL
+
 /*
   Code for manipulating distributed regular arrays in parallel.
 */
@@ -17,9 +17,10 @@
 .  da - the distributed array
 
 */
-int DALocalToLocalCreate(DA da)
+PetscErrorCode PETSCDM_DLLEXPORT DALocalToLocalCreate(DA da)
 {
-  int *idx,left,j,ierr,count,up,down,i,bottom,top,k;
+  PetscErrorCode ierr;
+  PetscInt *idx,left,j,count,up,down,i,bottom,top,k;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
@@ -31,16 +32,16 @@ int DALocalToLocalCreate(DA da)
      rather then from the plain array.
   */
   ierr = VecScatterCopy(da->gtol,&da->ltol);CHKERRQ(ierr);
-  PetscLogObjectParent(da,da->ltol);
+  ierr = PetscLogObjectParent(da,da->ltol);CHKERRQ(ierr);
   if (da->dim == 1) {
     left = da->xs - da->Xs;
-    ierr = PetscMalloc((da->xe-da->xs)*sizeof(int),&idx);CHKERRQ(ierr);
+    ierr = PetscMalloc((da->xe-da->xs)*sizeof(PetscInt),&idx);CHKERRQ(ierr);
     for (j=0; j<da->xe-da->xs; j++) {
       idx[j] = left + j;
     }  
   } else if (da->dim == 2) {
     left  = da->xs - da->Xs; down  = da->ys - da->Ys; up    = down + da->ye-da->ys;
-    ierr = PetscMalloc((da->xe-da->xs)*(up - down)*sizeof(int),&idx);CHKERRQ(ierr);
+    ierr = PetscMalloc((da->xe-da->xs)*(up - down)*sizeof(PetscInt),&idx);CHKERRQ(ierr);
     count = 0;
     for (i=down; i<up; i++) {
       for (j=0; j<da->xe-da->xs; j++) {
@@ -52,7 +53,7 @@ int DALocalToLocalCreate(DA da)
     bottom = da->ys - da->Ys; top = bottom + da->ye-da->ys ;
     down   = da->zs - da->Zs; up  = down + da->ze-da->zs;
     count  = (da->xe-da->xs)*(top-bottom)*(up-down);
-    ierr = PetscMalloc(count*sizeof(int),&idx);CHKERRQ(ierr);
+    ierr = PetscMalloc(count*sizeof(PetscInt),&idx);CHKERRQ(ierr);
     count  = 0;
     for (i=down; i<up; i++) {
       for (j=bottom; j<top; j++) {
@@ -61,7 +62,7 @@ int DALocalToLocalCreate(DA da)
 	}
       }
     }
-  } else SETERRQ1(1,"DA has invalid dimension %d",da->dim);
+  } else SETERRQ1(PETSC_ERR_ARG_CORRUPT,"DA has invalid dimension %D",da->dim);
 
   ierr = VecScatterRemap(da->ltol,idx,PETSC_NULL);CHKERRQ(ierr); 
   ierr = PetscFree(idx);CHKERRQ(ierr);
@@ -97,9 +98,9 @@ int DALocalToLocalCreate(DA da)
 
 .seealso: DALocalToLocalEnd(), DALocalToGlobal()
 @*/
-int DALocalToLocalBegin(DA da,Vec g,InsertMode mode,Vec l)
+PetscErrorCode PETSCDM_DLLEXPORT DALocalToLocalBegin(DA da,Vec g,InsertMode mode,Vec l)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
@@ -140,9 +141,9 @@ int DALocalToLocalBegin(DA da,Vec g,InsertMode mode,Vec l)
 
 .seealso: DALocalToLocalBegin(), DALocalToGlobal()
 @*/
-int DALocalToLocalEnd(DA da,Vec g,InsertMode mode,Vec l)
+PetscErrorCode PETSCDM_DLLEXPORT DALocalToLocalEnd(DA da,Vec g,InsertMode mode,Vec l)
 {
-  int ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(da,DA_COOKIE,1);
