@@ -98,13 +98,22 @@ int main(int argc,char **args)
        reading from this file.
     */
     ierr = PetscViewerBinaryOpen(PETSC_COMM_WORLD,file[PreLoadIt],FILE_MODE_READ,&fd);CHKERRQ(ierr);
-
+    
     /*
        Load the matrix and vector; then destroy the viewer.
     */
     ierr = MatLoad(fd,MATAIJ,&A);CHKERRQ(ierr);
+    
+    if (!preload){
+      flg = PETSC_FALSE;
+      ierr = PetscOptionsGetString(PETSC_NULL,"-rhs",file[2],PETSC_MAX_PATH_LEN-1,&flg);CHKERRQ(ierr);
+      if (flg){ /* rhs is stored in a separate file */
+        ierr = PetscViewerDestroy(fd);CHKERRQ(ierr); 
+        ierr = PetscViewerBinaryOpen(PETSC_COMM_WORLD,file[2],FILE_MODE_READ,&fd);CHKERRQ(ierr);
+      }
+    }
     if (rank){
-      ierr = PetscExceptionTry1(VecLoad(fd,PETSC_NULL,&b),PETSC_ERR_FILE_UNEXPECTED);
+        ierr = PetscExceptionTry1(VecLoad(fd,PETSC_NULL,&b),PETSC_ERR_FILE_UNEXPECTED);
     } else {
       ierr = PetscExceptionTry1(VecLoad(fd,PETSC_NULL,&b),PETSC_ERR_FILE_READ); 
     }   
@@ -145,6 +154,29 @@ int main(int argc,char **args)
       }
     }
 
+    /* Make A singular for testing zero-pivot of ilu factorization        */
+    /* Example: ./ex10 -f0 <datafile> -test_zeropivot -set_row_zero -pc_factor_shift_nonzero */
+    ierr = PetscOptionsHasName(PETSC_NULL, "-test_zeropivot", &flg);CHKERRQ(ierr);
+    if (flg) {
+      PetscInt          row,ncols;
+      const PetscInt    *cols;
+      const PetscScalar *vals;
+      PetscTruth        flg1=PETSC_FALSE;
+      PetscScalar       *zeros;
+      row = 0;      
+      ierr = MatGetRow(A,row,&ncols,&cols,&vals);CHKERRQ(ierr);     
+      ierr = PetscMalloc(sizeof(PetscScalar)*(ncols+1),&zeros);
+      ierr = PetscMemzero(zeros,(ncols+1)*sizeof(PetscScalar));CHKERRQ(ierr);
+      ierr = PetscOptionsHasName(PETSC_NULL, "-set_row_zero", &flg1);CHKERRQ(ierr);
+      if (flg1){ /* set entire row as zero */
+        ierr = MatSetValues(A,1,&row,ncols,cols,zeros,INSERT_VALUES);CHKERRQ(ierr);
+      } else { /* only set (row,row) entry as zero */
+        ierr = MatSetValues(A,1,&row,1,&row,zeros,INSERT_VALUES);CHKERRQ(ierr);
+      }
+      ierr = MatAssemblyBegin(A,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+      ierr = MatAssemblyEnd(A,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+    }
+
     /* Check whether A is symmetric */
     ierr = PetscOptionsHasName(PETSC_NULL, "-check_symmetry", &flg);CHKERRQ(ierr);
     if (flg) {
