@@ -5,21 +5,26 @@
 T*/
 
 /*
-Added at the request of Marc Garbey.
+Laplacian in 2D. Modeled by the partial differential equation
 
-Inhomogeneous Laplacian in 2D. Modeled by the partial differential equation
-
-   div \rho grad u = f,  0 < x,y < 1,
+   -div grad u = f,  0 < x,y < 2,
 
 with forcing function
 
-   f = e^{-(1 - x)^2/\nu} e^{-(1 - y)^2/\nu}
+   f = 2
+   f = 2y (1 - y) + 2x (1 - x)
 
 with Dirichlet boundary conditions
 
-   u = f(x,y) for x = 0, x = 1, y = 0, y = 1
+   u = 0 for x = 0, x = 2 and u = x (2 - x) for y = 0, y = 2
+   u = 0 for x = 0, x = 2, y = 0, y = 2
 
-or pure Neumman boundary conditions
+or pure Neumman boundary conditions.
+
+This has exact solution
+
+   u = x (2 - x)
+   u = x (2 - x) y (2 - y)
 
 This uses multigrid to solve the linear system
 
@@ -54,14 +59,16 @@ PetscErrorCode MeshView_Sieve_Newer(ALE::Obj<ALE::Two::Mesh>, PetscViewer);
 PetscErrorCode CreateMeshBoundary(ALE::Obj<ALE::Two::Mesh>);
 PetscErrorCode updateOperator(Mat, ALE::Obj<ALE::Two::Mesh::field_type>, const ALE::Two::Mesh::point_type&, PetscScalar [], InsertMode);
 
+extern PetscErrorCode CheckElementGeometry(ALE::Obj<ALE::Two::Mesh>);
 extern PetscErrorCode ComputeRHS(DMMG,Vec);
 extern PetscErrorCode ComputeJacobian(DMMG,Mat,Mat);
+extern PetscErrorCode ComputeError(DMMG,Vec,double*);
 
 typedef enum {DIRICHLET, NEUMANN} BCType;
 
 typedef struct {
-  PetscScalar   nu;
-  BCType        bcType;
+  BCType      bcType;
+  VecScatter  injection;
 } UserContext;
 
 PetscInt debug;
@@ -75,27 +82,27 @@ int main(int argc,char **argv)
   UserContext    user;
   PetscViewer    viewer;
   const char    *bcTypes[2] = {"dirichlet", "neumann"};
-  PetscReal      refinementLimit, norm;
-  PetscInt       dim, bc, l;
+  PetscReal      refinementLimit, norm, error;
+  PetscInt       dim, bc, l, meshDebug;
   PetscErrorCode ierr;
 
   ierr = PetscInitialize(&argc,&argv,(char *)0,help);CHKERRQ(ierr);
+  comm = PETSC_COMM_WORLD;
   ierr = PetscOptionsBegin(comm, "", "Options for the inhomogeneous Poisson equation", "DMMG");CHKERRQ(ierr);
     debug = 0;
     ierr = PetscOptionsInt("-debug", "The debugging flag", "ex33.c", 0, &debug, PETSC_NULL);CHKERRQ(ierr);
+    meshDebug = 0;
+    ierr = PetscOptionsInt("-mesh_debug", "The mesh debugging flag", "ex33.c", 0, &meshDebug, PETSC_NULL);CHKERRQ(ierr);
     dim  = 2;
     ierr = PetscOptionsInt("-dim", "The mesh dimension", "ex33.c", 2, &dim, PETSC_NULL);CHKERRQ(ierr);
     refinementLimit = 0.0;
     ierr = PetscOptionsReal("-refinement_limit", "The area of the largest triangle in the mesh", "ex33.c", 1.0, &refinementLimit, PETSC_NULL);CHKERRQ(ierr);
-    user.nu = 0.1;
-    ierr = PetscOptionsScalar("-nu", "The width of the Gaussian source", "ex33.c", 0.1, &user.nu, PETSC_NULL);CHKERRQ(ierr);
     bc = (PetscInt)DIRICHLET;
     ierr = PetscOptionsEList("-bc_type","Type of boundary condition","ex33.c",bcTypes,2,bcTypes[0],&bc,PETSC_NULL);CHKERRQ(ierr);
     user.bcType = (BCType) bc;
   ierr = PetscOptionsEnd();
-  comm = PETSC_COMM_WORLD;
 
-  ALE::Obj<ALE::Two::Mesh> meshBoundary = ALE::Two::Mesh(comm, dim-1, debug);
+  ALE::Obj<ALE::Two::Mesh> meshBoundary = ALE::Two::Mesh(comm, dim-1, meshDebug);
   ALE::Obj<ALE::Two::Mesh> mesh;
 
   try {
@@ -105,12 +112,15 @@ int main(int argc,char **argv)
     ierr = CreateMeshBoundary(meshBoundary);CHKERRQ(ierr);
     mesh = ALE::Two::Generator::generate(meshBoundary);
     ALE::Obj<ALE::Two::Mesh::sieve_type> topology = mesh->getTopology();
-    ierr = PetscPrintf(comm, "  Read %d elements\n", topology->heightStratum(0)->size());CHKERRQ(ierr);
-    ierr = PetscPrintf(comm, "  Read %d vertices\n", topology->depthStratum(0)->size());CHKERRQ(ierr);
-#if 0
+    ierr = PetscPrintf(comm, "  Generated %d elements\n", topology->heightStratum(0)->size());CHKERRQ(ierr);
+    ierr = PetscPrintf(comm, "  Generated %d vertices\n", topology->depthStratum(0)->size());CHKERRQ(ierr);
+    ALE::LogStagePop(stage);
+
+    stage = ALE::LogStageRegister("MeshDistribution");
+    ALE::LogStagePush(stage);
     ierr = PetscPrintf(comm, "Distributing mesh\n");CHKERRQ(ierr);
-    mesh->distribute();
-#endif
+    mesh = mesh->distribute();
+    ALE::LogStagePop(stage);
 
     if (refinementLimit > 0.0) {
       stage = ALE::LogStageRegister("MeshRefine");
@@ -118,47 +128,60 @@ int main(int argc,char **argv)
       ierr = PetscPrintf(comm, "Refining mesh\n");CHKERRQ(ierr);
       mesh = ALE::Two::Generator::refine(mesh, refinementLimit);
       ALE::LogStagePop(stage);
-      ierr = PetscPrintf(comm, "  Read %d elements\n", topology->heightStratum(0)->size());CHKERRQ(ierr);
-      ierr = PetscPrintf(comm, "  Read %d vertices\n", topology->depthStratum(0)->size());CHKERRQ(ierr);
     }
+    topology = mesh->getTopology();
 
-    ierr = PetscPrintf(comm, "Creating boundary\n");CHKERRQ(ierr);
+    stage = ALE::LogStageRegister("BndValues");
+    ALE::LogStagePush(stage);
+    ierr = PetscPrintf(comm, "Calculating boundary values\n");CHKERRQ(ierr);
     ALE::Obj<ALE::Two::Mesh::field_type> boundary = mesh->getBoundary();
+    ALE::Obj<ALE::Two::Mesh::sieve_type::traits::depthSequence> vertices = topology->depthStratum(0);
+    ALE::Two::Mesh::field_type::patch_type bdPatch(0, 1);
     ALE::Two::Mesh::field_type::patch_type patch;
 
-    boundary->setTopology(topology);
-    boundary->setPatch(topology->leaves(), patch);
-    boundary->setFiberDimensionByDepth(patch, 0, 1);
-    boundary->orderPatches();
+    for(ALE::Two::Mesh::sieve_type::traits::depthSequence::iterator v_iter = vertices->begin(); v_iter != vertices->end(); ++v_iter) {
+      if (boundary->getIndex(bdPatch, *v_iter).index > 0) {
+        const double *coords = mesh->getCoordinates()->restrict(patch, *v_iter);
+        double        values[1];
 
-    ALE::Obj<ALE::Two::Mesh::sieve_type::depthMarkerSequence> bdVertices = boundary->getTopology()->depthStratum(0, 1);
-
-    for(ALE::Two::Mesh::sieve_type::depthMarkerSequence::iterator v_iter = bdVertices->begin(); v_iter != bdVertices->end(); ++v_iter) {
-      //double *coords = mesh->getCoordinates()->restrict(patch, *v_iter);
-      double values[1] = {0.0};
-
-      boundary->update(patch, *v_iter, values);
+        values[0] = coords[0]*(2.0 - coords[0]);
+        boundary->update(bdPatch, *v_iter, values);
+      }
     }
+    if (debug) {boundary->view("Mesh Boundary");}
+    ALE::LogStagePop(stage);
 
     ALE::Obj<ALE::Two::Mesh::field_type> u = mesh->getField("u");
+    ALE::Obj<ALE::Two::Mesh::field_type> b = mesh->getField("b");
     u->setPatch(topology->leaves(), ALE::Two::Mesh::field_type::patch_type());
     u->setFiberDimensionByDepth(patch, 0, 1);
     u->orderPatches();
-    ALE::Obj<ALE::Two::Mesh::sieve_type::heightSequence> elements = topology->heightStratum(0);
+    if (debug) {u->view("u");}
+    u->createGlobalOrder();
+    b->setPatch(topology->leaves(), ALE::Two::Mesh::field_type::patch_type());
+    b->setFiberDimensionByDepth(patch, 0, 1);
+    b->orderPatches();
+    if (debug) {b->view("b");}
+    b->createGlobalOrder();
+    ALE::Obj<ALE::Two::Mesh::sieve_type::traits::heightSequence> elements = topology->heightStratum(0);
     ALE::Obj<ALE::Two::Mesh::bundle_type> vertexBundle = mesh->getBundle(0);
     std::string orderName("element");
 
-    for(ALE::Two::Mesh::sieve_type::heightSequence::iterator e_iter = elements->begin(); e_iter != elements->end(); e_iter++) {
+    for(ALE::Two::Mesh::sieve_type::traits::heightSequence::iterator e_iter = elements->begin(); e_iter != elements->end(); e_iter++) {
       // setFiberDimensionByDepth() does not work here since we only want it to apply to the patch cone
       //   What we really need is the depthStratum relative to the patch
-      ALE::Obj<ALE::Two::Mesh::bundle_type::coneSequence> cone = vertexBundle->getPatch(*e_iter);
+      ALE::Obj<ALE::Two::Mesh::bundle_type::order_type::coneSequence> cone = vertexBundle->getPatch(orderName, *e_iter);
 
       u->setPatch(orderName, cone, *e_iter);
-      for(ALE::def::PointSet::iterator c_iter = cone->begin(); c_iter != cone->end(); ++c_iter) {
+      b->setPatch(orderName, cone, *e_iter);
+      for(ALE::Two::Mesh::bundle_type::order_type::coneSequence::iterator c_iter = cone->begin(); c_iter != cone->end(); ++c_iter) {
         u->setFiberDimension(orderName, *e_iter, *c_iter, 1);
+        b->setFiberDimension(orderName, *e_iter, *c_iter, 1);
       }
     }
     u->orderPatches(orderName);
+    b->orderPatches(orderName);
+    CheckElementGeometry(mesh);
 
     Mesh petscMesh;
     ierr = MeshCreate(comm, &petscMesh);CHKERRQ(ierr);
@@ -174,9 +197,17 @@ int main(int argc,char **argv)
     if (user.bcType == NEUMANN) {
       ierr = DMMGSetNullSpace(dmmg,PETSC_TRUE,0,PETSC_NULL);CHKERRQ(ierr);
     }
+    ierr = MeshGetGlobalScatter(mesh, "u", DMMGGetx(dmmg), &user.injection); CHKERRQ(ierr);
 
     ierr = DMMGSolve(dmmg);CHKERRQ(ierr);
 
+    if (debug) {
+      ierr = PetscPrintf(mesh->comm(), "Solution vector:");CHKERRQ(ierr);
+      ierr = VecView(DMMGGetx(dmmg), PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
+    }
+    ierr = ComputeError(dmmg[DMMGGetLevels(dmmg)-1], DMMGGetx(dmmg), &error);CHKERRQ(ierr);
+    ierr = PetscPrintf(comm,"Error norm %g\n",error);CHKERRQ(ierr);
+
     ierr = MatMult(DMMGGetJ(dmmg),DMMGGetx(dmmg),DMMGGetr(dmmg));CHKERRQ(ierr);
     ierr = VecAXPY(DMMGGetr(dmmg),-1.0,DMMGGetRHS(dmmg));CHKERRQ(ierr);
     ierr = VecNorm(DMMGGetr(dmmg),NORM_2,&norm);CHKERRQ(ierr);
@@ -222,7 +253,7 @@ int main(int argc,char **argv)
 */
 PetscErrorCode CreateSquareBoundary(ALE::Obj<ALE::Two::Mesh> mesh)
 {
-  MPI_Comm          comm = mesh->getComm();
+  MPI_Comm          comm = mesh->comm();
   ALE::Obj<ALE::Two::Mesh::sieve_type> topology = mesh->getTopology();
   PetscScalar       coords[18] = {0.0, 0.0,
                                   1.0, 0.0,
@@ -233,6 +264,18 @@ PetscErrorCode CreateSquareBoundary(ALE::Obj<ALE::Two::Mesh> mesh)
                                   0.0, 2.0,
                                   0.0, 1.0,
                                   1.0, 1.0};
+  PetscInt    connectivity[40] = {0, 1,
+                                  1, 2,
+                                  2, 3,
+                                  3, 4,
+                                  4, 5,
+                                  5, 6,
+                                  6, 7,
+                                  7, 0,
+                                  1, 8,
+                                  3, 8,
+                                  5, 8,
+                                  7, 8};
   ALE::Two::Mesh::point_type vertices[9];
   PetscInt          order = 0;
   PetscMPIInt       rank;
@@ -266,18 +309,16 @@ PetscErrorCode CreateSquareBoundary(ALE::Obj<ALE::Two::Mesh> mesh)
     topology->addArrow(vertices[8], edge, order++);
   }
   topology->stratify();
+  mesh->createVertexBundle(20, connectivity);
   mesh->createSerialCoordinates(2, 0, coords);
   /* Create boundary conditions */
   if (rank == 0) {
-    ALE::Obj<ALE::def::PointSet> cone = ALE::def::PointSet();
-
     for(int v = 0; v < 8; v++) {
-      cone->insert(ALE::Two::Mesh::point_type(0, v));
+      topology->setMarker(ALE::Two::Mesh::point_type(0, v), 1);
     }
     for(int e = 9; e < 17; e++) {
-      cone->insert(ALE::Two::Mesh::point_type(0, e));
+      topology->setMarker(ALE::Two::Mesh::point_type(0, e), 1);
     }
-    topology->setMarker(cone, 1);
   }
   PetscFunctionReturn(0);
 }
@@ -297,7 +338,7 @@ PetscErrorCode CreateSquareBoundary(ALE::Obj<ALE::Two::Mesh> mesh)
 */
 PetscErrorCode CreateCubeBoundary(ALE::Obj<ALE::Two::Mesh> mesh)
 {
-  MPI_Comm          comm = mesh->getComm();
+  MPI_Comm          comm = mesh->comm();
   ALE::Obj<ALE::Two::Mesh::sieve_type> topology = mesh->getTopology();
   PetscScalar       coords[24] = {0.0, 0.0, 0.0,
                                   1.0, 0.0, 0.0,
@@ -307,7 +348,12 @@ PetscErrorCode CreateCubeBoundary(ALE::Obj<ALE::Two::Mesh> mesh)
                                   1.0, 0.0, 1.0,
                                   1.0, 1.0, 1.0,
                                   0.0, 1.0, 1.0};
-
+  PetscInt    connectivity[24] = {0, 1, 2, 3,
+                                  7, 6, 5, 4,
+                                  0, 4, 5, 1,
+                                  1, 5, 6, 2,
+                                  2, 6, 7, 3,
+                                  3, 7, 4, 0};
   ALE::Obj<std::set<ALE::Two::Mesh::point_type> > cone = std::set<ALE::Two::Mesh::point_type>();
   ALE::Two::Mesh::point_type            vertices[8];
   ALE::Two::Mesh::point_type            edges[12];
@@ -407,6 +453,7 @@ PetscErrorCode CreateCubeBoundary(ALE::Obj<ALE::Two::Mesh> mesh)
       vertexBundle->setPatch(orderName, points, face);
     }
   }
+  mesh->createVertexBundle(6, connectivity);
   mesh->createSerialCoordinates(embedDim, 0, coords);
 
   /* Create boundary conditions: set marker 1 to all of the sieve elements, 
@@ -1138,21 +1185,6 @@ static double BasisDerivatives[324] = {
 
 #endif
 
-#undef __FUNCT__
-#define __FUNCT__ "ExpandSetIntervals"
-PetscErrorCode ExpandSetIntervals(ALE::Point_set intervals, PetscInt *indices)
-{
-  int k = 0;
-
-  PetscFunctionBegin;
-  for(ALE::Point_set::iterator i_itor = intervals.begin(); i_itor != intervals.end(); i_itor++) {
-    for(int i = 0; i < (*i_itor).index; i++) {
-      indices[k++] = (*i_itor).prefix + i;
-    }
-  }
-  PetscFunctionReturn(0);
-}
-
 #undef __FUNCT__
 #define __FUNCT__ "ElementGeometry"
 PetscErrorCode ElementGeometry(ALE::Obj<ALE::Two::Mesh> mesh, const ALE::Two::Mesh::point_type& e, PetscReal v0[], PetscReal J[], PetscReal invJ[], PetscReal *detJ)
@@ -1160,9 +1192,24 @@ PetscErrorCode ElementGeometry(ALE::Obj<ALE::Two::Mesh> mesh, const ALE::Two::Me
   const double  *coords = mesh->getCoordinates()->restrict(std::string("element"), e);
   int            dim = mesh->getDimension();
   PetscReal      det, invDet;
-  PetscErrorCode ierr;
 
   PetscFunctionBegin;
+  if (debug) {
+    MPI_Comm comm = mesh->comm();
+    int      rank = mesh->commRank();
+
+    PetscSynchronizedPrintf(comm, "[%d]Element (%d, %d)\n", rank, e.prefix, e.index);
+    PetscSynchronizedPrintf(comm, "[%d]Coordinates:\n[%d]  ", rank, rank);
+    for(int f = 0; f <= dim; f++) {
+      PetscSynchronizedPrintf(comm, " (");
+      for(int d = 0; d < dim; d++) {
+        if (d > 0) PetscSynchronizedPrintf(comm, ", ");
+        PetscSynchronizedPrintf(comm, "%g", coords[f*dim+d]);
+      }
+      PetscSynchronizedPrintf(comm, ")");
+    }
+    PetscSynchronizedPrintf(comm, "\n");
+  }
   if (v0) {
     for(int d = 0; d < dim; d++) {
       v0[d] = coords[d];
@@ -1175,10 +1222,9 @@ PetscErrorCode ElementGeometry(ALE::Obj<ALE::Two::Mesh> mesh, const ALE::Two::Me
       }
     }
     if (debug) {
-      MPI_Comm    comm = mesh->getComm();
-      PetscMPIInt rank;
+      MPI_Comm comm = mesh->comm();
+      int      rank = mesh->commRank();
 
-      ierr = MPI_Comm_rank(comm, &rank);CHKERRQ(ierr);
       for(int d = 0; d < dim; d++) {
         if (d == 0) {
           PetscSynchronizedPrintf(comm, "[%d]J = /", rank);
@@ -1230,10 +1276,9 @@ PetscErrorCode ElementGeometry(ALE::Obj<ALE::Two::Mesh> mesh, const ALE::Two::Me
         invJ[2*3+2] = invDet*(J[0*3+0]*J[1*3+1] - J[0*3+1]*J[1*3+0]);
       }
       if (debug) {
-        MPI_Comm    comm = mesh->getComm();
-        PetscMPIInt rank;
+        MPI_Comm comm = mesh->comm();
+        int      rank = mesh->commRank();
 
-        ierr = MPI_Comm_rank(comm, &rank);CHKERRQ(ierr);
         for(int d = 0; d < dim; d++) {
           if (d == 0) {
             PetscSynchronizedPrintf(comm, "[%d]Jinv = /", rank);
@@ -1260,95 +1305,25 @@ PetscErrorCode ElementGeometry(ALE::Obj<ALE::Two::Mesh> mesh, const ALE::Two::Me
 }
 
 #undef __FUNCT__
-#define __FUNCT__ "ComputeRho"
-PetscErrorCode ComputeRho(PetscReal x, PetscReal y, PetscScalar *rho)
+#define __FUNCT__ "CheckElementGeometry"
+PetscErrorCode CheckElementGeometry(ALE::Obj<ALE::Two::Mesh> mesh)
 {
+  ALE::Obj<ALE::Two::Mesh::sieve_type::traits::heightSequence> elements = mesh->getTopology()->heightStratum(0);
+  PetscInt       dim = mesh->getDimension();
+  PetscReal     *v0, *Jac;
+  PetscReal      detJ;
+  PetscErrorCode ierr;
+
   PetscFunctionBegin;
-  if ((x > 1.0/3.0) && (x < 2.0/3.0) && (y > 1.0/3.0) && (y < 2.0/3.0)) {
-    //*rho = 100.0;
-    *rho = 1.0;
-  } else {
-    *rho = 1.0;
+  ierr = PetscMalloc2(dim,PetscReal,&v0,dim*dim,PetscReal,&Jac);CHKERRQ(ierr);
+  for(ALE::Two::Mesh::sieve_type::traits::heightSequence::iterator e_iter = elements->begin(); e_iter != elements->end(); ++e_iter) {
+    ierr = ElementGeometry(mesh, *e_iter, v0, Jac, PETSC_NULL, &detJ);
   }
+  ierr = PetscSynchronizedFlush(mesh->comm());CHKERRQ(ierr);
+  ierr = PetscFree2(v0,Jac);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
-#if 0
-#undef __FUNCT__
-#define __FUNCT__ "ComputeBlock"
-PetscErrorCode ComputeBlock(DMMG dmmg, Vec u, Vec r, ALE::Point_set block)
-{
-  Mesh              mesh = (Mesh) dmmg->dm;
-  UserContext      *user = (UserContext *) dmmg->user;
-  ALE::Sieve       *topology;
-  ALE::PreSieve    *orientation;
-  ALE::IndexBundle *bundle;
-  ALE::IndexBundle *coordBundle;
-  ALE::Point_set    elements;
-  PetscInt          dim;
-  Vec               coordinates;
-  PetscScalar      *coords;
-  PetscScalar      *array;
-  PetscScalar      *field;
-  PetscReal         elementVec[NUM_BASIS_FUNCTIONS];
-  PetscReal         linearVec[NUM_BASIS_FUNCTIONS];
-  PetscReal        *v0, *Jac, *Jinv, *t_der, *b_der;
-  PetscReal         xi, eta, x_q, y_q, detJ, rho, funcValue;
-  PetscInt          f, g, q;
-  PetscErrorCode    ierr;
 
-  ierr = MeshGetTopology(mesh, (void **) &topology);CHKERRQ(ierr);
-  ierr = MeshGetOrientation(mesh, (void **) &orientation);CHKERRQ(ierr);
-  ierr = MeshGetBundle(mesh, (void **) &bundle);CHKERRQ(ierr);
-  ierr = MeshGetCoordinateBundle(mesh, (void **) &coordBundle);CHKERRQ(ierr);
-  ierr = MeshGetCoordinates(mesh, &coordinates);CHKERRQ(ierr);
-  ierr = VecGetArray(coordinates, &coords);CHKERRQ(ierr);
-  ierr = VecGetArray(u, &array); CHKERRQ(ierr);
-  dim = coordBundle->getFiberDimension(*coordBundle->getTopology()->depthStratum(0).begin());
-  ierr = PetscMalloc(dim * sizeof(PetscReal), &v0);CHKERRQ(ierr);
-  ierr = PetscMalloc(dim * sizeof(PetscReal), &t_der);CHKERRQ(ierr);
-  ierr = PetscMalloc(dim * sizeof(PetscReal), &b_der);CHKERRQ(ierr);
-  ierr = PetscMalloc(dim*dim * sizeof(PetscReal), &Jac);CHKERRQ(ierr);
-  ierr = PetscMalloc(dim*dim * sizeof(PetscReal), &Jinv);CHKERRQ(ierr);
-  elements = topology->star(block);
-  for(ALE::Point_set::iterator element_itor = elements.begin(); element_itor != elements.end(); element_itor++) {
-    ALE::Point e = *element_itor;
-
-    ierr = ElementGeometry(coordBundle, orientation, coords, e, v0, Jac, Jinv, &detJ); CHKERRQ(ierr);
-    ierr = restrictField(bundle, orientation, array, e, &field); CHKERRQ(ierr);
-    /* Element integral */
-    ierr = PetscMemzero(elementVec, NUM_BASIS_FUNCTIONS*sizeof(PetscScalar));CHKERRQ(ierr);
-    for(q = 0; q < NUM_QUADRATURE_POINTS; q++) {
-      xi = points[q*2+0] + 1.0;
-      eta = points[q*2+1] + 1.0;
-      x_q = Jac[0]*xi + Jac[1]*eta + v0[0];
-      y_q = Jac[2]*xi + Jac[3]*eta + v0[1];
-      ierr = ComputeRho(x_q, y_q, &rho);CHKERRQ(ierr);
-      funcValue = PetscExpScalar(-(x_q*x_q)/user->nu)*PetscExpScalar(-(y_q*y_q)/user->nu);
-      for(f = 0; f < NUM_BASIS_FUNCTIONS; f++) {
-        t_der[0] = Jinv[0]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+f)*2+0] + Jinv[2]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+f)*2+1];
-        t_der[1] = Jinv[1]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+f)*2+0] + Jinv[3]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+f)*2+1];
-        for(g = 0; g < NUM_BASIS_FUNCTIONS; g++) {
-          b_der[0] = Jinv[0]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+g)*2+0] + Jinv[2]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+g)*2+1];
-          b_der[1] = Jinv[1]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+g)*2+0] + Jinv[3]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+g)*2+1];
-          linearVec[f] += rho*(t_der[0]*b_der[0] + t_der[1]*b_der[1])*field[g];
-        }
-        elementVec[f] += (Basis[q*NUM_BASIS_FUNCTIONS+f]*funcValue - linearVec[f])*weights[q]*detJ;
-      }
-    }
-    if (debug) {printf("elementVec = [%g %g %g]\n", elementVec[0], elementVec[1], elementVec[2]);}
-    /* Assembly */
-    ierr = assembleField(bundle, orientation, r, e, elementVec, ADD_VALUES); CHKERRQ(ierr);
-  }
-  ierr = PetscFree(v0);CHKERRQ(ierr);
-  ierr = PetscFree(t_der);CHKERRQ(ierr);
-  ierr = PetscFree(b_der);CHKERRQ(ierr);
-  ierr = PetscFree(Jac);CHKERRQ(ierr);
-  ierr = PetscFree(Jinv);CHKERRQ(ierr);
-  ierr = VecRestoreArray(coordinates, &coords);CHKERRQ(ierr);
-  ierr = VecRestoreArray(u, &array); CHKERRQ(ierr);
-  PetscFunctionReturn(0);
-}
-#endif
 #undef __FUNCT__
 #define __FUNCT__ "ComputeRHS"
 PetscErrorCode ComputeRHS(DMMG dmmg, Vec b)
@@ -1370,10 +1345,10 @@ PetscErrorCode ComputeRHS(DMMG dmmg, Vec b)
   dim  = m->getDimension();
   ierr = PetscMalloc(dim * sizeof(PetscReal), &v0);CHKERRQ(ierr);
   ierr = PetscMalloc(dim*dim * sizeof(PetscReal), &Jac);CHKERRQ(ierr);
-  ALE::Obj<ALE::Two::Mesh::field_type> field = m->getField("u");
-  ALE::Obj<ALE::Two::Mesh::sieve_type::heightSequence> elements = m->getTopology()->heightStratum(0);
+  ALE::Obj<ALE::Two::Mesh::field_type> field = m->getField("b");
+  ALE::Obj<ALE::Two::Mesh::sieve_type::traits::heightSequence> elements = m->getTopology()->heightStratum(0);
   ALE::Two::Mesh::field_type::patch_type patch;
-  for(ALE::Two::Mesh::sieve_type::heightSequence::iterator e_itor = elements->begin(); e_itor != elements->end(); e_itor++) {
+  for(ALE::Two::Mesh::sieve_type::traits::heightSequence::iterator e_itor = elements->begin(); e_itor != elements->end(); e_itor++) {
     ierr = ElementGeometry(m, *e_itor, v0, Jac, PETSC_NULL, &detJ);CHKERRQ(ierr);
     /* Element integral */
     ierr = PetscMemzero(elementVec, NUM_BASIS_FUNCTIONS*sizeof(PetscScalar));CHKERRQ(ierr);
@@ -1382,7 +1357,8 @@ PetscErrorCode ComputeRHS(DMMG dmmg, Vec b)
       eta = points[q*2+1] + 1.0;
       x_q = Jac[0]*xi + Jac[1]*eta + v0[0];
       y_q = Jac[2]*xi + Jac[3]*eta + v0[1];
-      funcValue = PetscExpScalar(-(x_q*x_q)/user->nu)*PetscExpScalar(-(y_q*y_q)/user->nu);
+      funcValue = 2.0;
+      //funcValue = 2.0*y_q*(2.0 - y_q) + 2.0*x_q*(2.0 - x_q);
       for(f = 0; f < NUM_BASIS_FUNCTIONS; f++) {
         elementVec[f] += Basis[q*NUM_BASIS_FUNCTIONS+f]*funcValue*weights[q]*detJ;
       }
@@ -1394,12 +1370,12 @@ PetscErrorCode ComputeRHS(DMMG dmmg, Vec b)
   }
   ierr = PetscFree(v0);CHKERRQ(ierr);
   ierr = PetscFree(Jac);CHKERRQ(ierr);
-  PetscScalar *array;
-  ierr = VecGetArray(b, &array);CHKERRQ(ierr);
-  ierr = PetscMemcpy(array, field->restrict(patch), field->getSize(patch)*sizeof(double));CHKERRQ(ierr);
-  ierr = VecRestoreArray(b, &array);CHKERRQ(ierr);
-  ierr = VecAssemblyBegin(b);CHKERRQ(ierr);
-  ierr = VecAssemblyEnd(b);CHKERRQ(ierr);
+
+  Vec locB;
+  ierr = VecCreateSeqWithArray(PETSC_COMM_SELF, field->getSize(patch), field->restrict(patch), &locB);CHKERRQ(ierr);
+  ierr = VecScatterBegin(locB, b, ADD_VALUES, SCATTER_FORWARD, user->injection);CHKERRQ(ierr);
+  ierr = VecScatterEnd(locB, b, ADD_VALUES, SCATTER_FORWARD, user->injection);CHKERRQ(ierr);
+  ierr = VecDestroy(locB);CHKERRQ(ierr);
 
   /* force right hand side to be consistent for singular matrix */
   /* note this is really a hack, normally the model would provide you with a consistent right handside */
@@ -1409,6 +1385,45 @@ PetscErrorCode ComputeRHS(DMMG dmmg, Vec b)
     ierr = KSPGetNullSpace(dmmg->ksp,&nullspace);CHKERRQ(ierr);
     ierr = MatNullSpaceRemove(nullspace,b,PETSC_NULL);CHKERRQ(ierr);
   }
+  if (user->bcType == DIRICHLET) {
+    /* Zero out BC rows */
+    ALE::Two::Mesh::field_type::patch_type patch;
+    ALE::Two::Mesh::field_type::patch_type bdPatch(0, 1);
+    ALE::Obj<ALE::Two::Mesh::field_type> boundary = m->getBoundary();
+    ALE::Obj<ALE::Two::Mesh::field_type::order_type::coneSequence> cone = boundary->getPatch(bdPatch);
+    PetscScalar *boundaryValues;
+    PetscInt    *boundaryIndices;
+    PetscInt     numBoundaryIndices = 0;
+    PetscInt     k = 0;
+
+    for(ALE::Two::Mesh::field_type::order_type::coneSequence::iterator p = cone->begin(); p != cone->end(); ++p) {
+      numBoundaryIndices += field->getGlobalOrder()->getIndex(patch, *p).index;
+    }
+    ierr = PetscMalloc2(numBoundaryIndices,PetscInt,&boundaryIndices,numBoundaryIndices,PetscScalar,&boundaryValues); CHKERRQ(ierr);
+    for(ALE::Two::Mesh::field_type::order_type::coneSequence::iterator p = cone->begin(); p != cone->end(); ++p) {
+      const ALE::Two::Mesh::field_type::index_type& idx = field->getGlobalOrder()->getIndex(patch, *p);
+      const double *data = boundary->restrict(bdPatch, *p);
+
+      for(int i = 0; i < idx.index; i++) {
+        boundaryIndices[k] = idx.prefix + i;
+        boundaryValues[k] = data[i];
+        k++;
+      }
+    }
+    if (debug) {
+      boundary->view("Boundary for rhs conditions");
+      for(int i = 0; i < numBoundaryIndices; i++) {
+        ierr = PetscSynchronizedPrintf(comm, "[%d]boundaryIndices[%d] = %d\n", m->commRank(), i, boundaryIndices[i]);CHKERRQ(ierr);
+      }
+    }
+    ierr = PetscSynchronizedFlush(comm);
+    ierr = VecSetValues(b, numBoundaryIndices, boundaryIndices, boundaryValues, INSERT_VALUES);CHKERRQ(ierr);
+    ierr = PetscFree2(boundaryIndices, boundaryValues);CHKERRQ(ierr);
+  }
+  if (debug) {
+    ierr = PetscPrintf(comm, "Rhs vector:");CHKERRQ(ierr);
+    ierr = VecView(b, PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);
+  }
   PetscFunctionReturn(0);
 }
 
@@ -1422,7 +1437,7 @@ PetscErrorCode ComputeJacobian(DMMG dmmg, Mat J, Mat jac)
   MPI_Comm          comm;
   PetscReal         elementMat[NUM_BASIS_FUNCTIONS*NUM_BASIS_FUNCTIONS];
   PetscReal        *v0, *Jac, *Jinv, *t_der, *b_der;
-  PetscReal         xi, eta, x_q, y_q, detJ, rho;
+  PetscReal         xi, eta, x_q, y_q, detJ;
   PetscInt          dim;
   PetscInt          f, g, q;
   PetscMPIInt       rank;
@@ -1439,8 +1454,8 @@ PetscErrorCode ComputeJacobian(DMMG dmmg, Mat J, Mat jac)
   ierr = PetscMalloc(dim*dim * sizeof(PetscReal), &Jac);CHKERRQ(ierr);
   ierr = PetscMalloc(dim*dim * sizeof(PetscReal), &Jinv);CHKERRQ(ierr);
   ALE::Obj<ALE::Two::Mesh::field_type> field = m->getField("u");
-  ALE::Obj<ALE::Two::Mesh::sieve_type::heightSequence> elements = m->getTopology()->heightStratum(0);
-  for(ALE::Two::Mesh::sieve_type::heightSequence::iterator e_itor = elements->begin(); e_itor != elements->end(); e_itor++) {
+  ALE::Obj<ALE::Two::Mesh::sieve_type::traits::heightSequence> elements = m->getTopology()->heightStratum(0);
+  for(ALE::Two::Mesh::sieve_type::traits::heightSequence::iterator e_itor = elements->begin(); e_itor != elements->end(); e_itor++) {
     CHKMEMQ;
     ierr = ElementGeometry(m, *e_itor, v0, Jac, Jinv, &detJ);CHKERRQ(ierr);
     /* Element integral */
@@ -1450,14 +1465,13 @@ PetscErrorCode ComputeJacobian(DMMG dmmg, Mat J, Mat jac)
       eta = points[q*2+1] + 1.0;
       x_q = Jac[0]*xi + Jac[1]*eta + v0[0];
       y_q = Jac[2]*xi + Jac[3]*eta + v0[1];
-      ierr = ComputeRho(x_q, y_q, &rho);CHKERRQ(ierr);
       for(f = 0; f < NUM_BASIS_FUNCTIONS; f++) {
         t_der[0] = Jinv[0]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+f)*2+0] + Jinv[2]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+f)*2+1];
         t_der[1] = Jinv[1]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+f)*2+0] + Jinv[3]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+f)*2+1];
         for(g = 0; g < NUM_BASIS_FUNCTIONS; g++) {
           b_der[0] = Jinv[0]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+g)*2+0] + Jinv[2]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+g)*2+1];
           b_der[1] = Jinv[1]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+g)*2+0] + Jinv[3]*BasisDerivatives[(q*NUM_BASIS_FUNCTIONS+g)*2+1];
-          elementMat[f*NUM_BASIS_FUNCTIONS+g] += rho*(t_der[0]*b_der[0] + t_der[1]*b_der[1])*weights[q]*detJ;
+          elementMat[f*NUM_BASIS_FUNCTIONS+g] += (t_der[0]*b_der[0] + t_der[1]*b_der[1])*weights[q]*detJ;
         }
       }
     }
@@ -1480,21 +1494,20 @@ PetscErrorCode ComputeJacobian(DMMG dmmg, Mat J, Mat jac)
 
   if (user->bcType == DIRICHLET) {
     /* Zero out BC rows */
-    ALE::Obj<ALE::Two::Mesh::sieve_type::depthMarkerSequence> bdVertices = m->getBoundary()->getTopology()->depthStratum(0, 1);
     ALE::Two::Mesh::field_type::patch_type patch;
+    ALE::Two::Mesh::field_type::patch_type bdPatch(0, 1);
+    ALE::Obj<ALE::Two::Mesh::field_type> boundary = m->getBoundary();
+    ALE::Obj<ALE::Two::Mesh::field_type::order_type::coneSequence> cone = boundary->getPatch(bdPatch);
     PetscInt *boundaryIndices;
-    PetscInt k = 0;
+    PetscInt  numBoundaryIndices = 0;
+    PetscInt  k = 0;
 
-    ALE::Obj<ALE::Two::Mesh::bundle_type> bdBundle = ALE::Two::Mesh::bundle_type(m->debug);
-    bdBundle->setTopology(m->getTopology());
-    bdBundle->setPatch(bdVertices, patch);
-    bdBundle->setFiberDimensionByDepth(patch, 0, 1);
-    bdBundle->orderPatches();
-
-    int numBoundaryIndices = bdBundle->getSize(patch);
+    for(ALE::Two::Mesh::field_type::order_type::coneSequence::iterator p = cone->begin(); p != cone->end(); ++p) {
+      numBoundaryIndices += field->getGlobalOrder()->getIndex(patch, *p).index;
+    }
     ierr = PetscMalloc(numBoundaryIndices * sizeof(PetscInt), &boundaryIndices); CHKERRQ(ierr);
-    for(ALE::Two::Mesh::sieve_type::depthMarkerSequence::iterator p = bdVertices->begin(); p != bdVertices->end(); ++p) {
-      const ALE::Two::Mesh::field_type::index_type& idx = field->getIndex(patch, *p);
+    for(ALE::Two::Mesh::field_type::order_type::coneSequence::iterator p = cone->begin(); p != cone->end(); ++p) {
+      const ALE::Two::Mesh::field_type::index_type& idx = field->getGlobalOrder()->getIndex(patch, *p);
 
       for(int i = 0; i < idx.index; i++) {
         boundaryIndices[k++] = idx.prefix + i;
@@ -1513,3 +1526,66 @@ PetscErrorCode ComputeJacobian(DMMG dmmg, Mat J, Mat jac)
   ierr = MatAssemblyEnd(jac, MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
+
+#undef __FUNCT__
+#define __FUNCT__ "ComputeError"
+PetscErrorCode ComputeError(DMMG dmmg, Vec u, double *error)
+{
+  ALE::Obj<ALE::Two::Mesh> m;
+  Mesh                mesh = (Mesh) dmmg->dm;
+  UserContext        *user = (UserContext *) dmmg->user;
+  MPI_Comm            comm;
+  PetscReal           *v0, *Jac;
+  PetscReal           detJ, totalError;
+  PetscInt            dim;
+  PetscInt            f, q;
+  PetscErrorCode      ierr;
+
+  PetscFunctionBegin;
+  ierr = PetscObjectGetComm((PetscObject) mesh, &comm);CHKERRQ(ierr);
+  ierr = MeshGetMesh(mesh, &m);CHKERRQ(ierr);
+  dim  = m->getDimension();
+  ierr = PetscMalloc(dim * sizeof(PetscReal), &v0);CHKERRQ(ierr);
+  ierr = PetscMalloc(dim*dim * sizeof(PetscReal), &Jac);CHKERRQ(ierr);
+  ALE::Obj<ALE::Two::Mesh::field_type> field = m->getField("u");
+  ALE::Obj<ALE::Two::Mesh::sieve_type::traits::heightSequence> elements = m->getTopology()->heightStratum(0);
+  ALE::Two::Mesh::field_type::patch_type patch;
+
+  Vec locU;
+  ierr = VecCreateSeqWithArray(PETSC_COMM_SELF, field->getSize(patch), field->restrict(patch), &locU);CHKERRQ(ierr);
+  ierr = VecScatterBegin(u, locU, INSERT_VALUES, SCATTER_REVERSE, user->injection);CHKERRQ(ierr);
+  ierr = VecScatterEnd(u, locU, INSERT_VALUES, SCATTER_REVERSE, user->injection);CHKERRQ(ierr);
+  ierr = VecDestroy(locU);CHKERRQ(ierr);
+
+  totalError = 0.0;
+  for(ALE::Two::Mesh::sieve_type::traits::heightSequence::iterator e_itor = elements->begin(); e_itor != elements->end(); e_itor++) {
+    const double *elementVec = field->restrict("element", *e_itor);
+    double e;
+
+    e = 0.0;
+    ierr = ElementGeometry(m, *e_itor, v0, Jac, PETSC_NULL, &detJ);CHKERRQ(ierr);
+    /* Element integral */
+    for(q = 0; q < NUM_QUADRATURE_POINTS; q++) {
+      PetscReal xi, eta, x_q, y_q, uExact, uComputed;
+
+      xi = points[q*2+0] + 1.0;
+      eta = points[q*2+1] + 1.0;
+      x_q = Jac[0]*xi + Jac[1]*eta + v0[0];
+      y_q = Jac[2]*xi + Jac[3]*eta + v0[1];
+      uExact = x_q*(2.0 - x_q);
+      //uExact = x_q*(2.0 - x_q)*y_q*(2.0 - y_q);
+      uComputed = 0.0;
+      for(f = 0; f < NUM_BASIS_FUNCTIONS; f++) {
+        uComputed += elementVec[f]*Basis[q*NUM_BASIS_FUNCTIONS+f];
+      }
+      e += (uComputed - uExact)*(uComputed - uExact)*weights[q]*detJ;
+    }
+    totalError += e;
+    if (debug) {PetscSynchronizedPrintf(comm, "elementError = %g\n", e);}
+    if (debug) {ierr = PetscSynchronizedFlush(comm);CHKERRQ(ierr);}
+  }
+  ierr = PetscFree(v0);CHKERRQ(ierr);
+  ierr = PetscFree(Jac);CHKERRQ(ierr);
+  *error = sqrt(totalError);
+  PetscFunctionReturn(0);
+}
