@@ -38,7 +38,7 @@ int main(int argc,char **args)
   PetscInt       ntimes = 3;     /* number of times to solve the linear systems */
   PetscEvent     CHECK_ERROR;    /* event number for error checking */
   PetscInt       ldim,low,high,iglobal,Istart,Iend,Istart2,Iend2;
-  PetscInt       I,J,i,j,m = 3,n = 2,its,t;
+  PetscInt       Ii,J,i,j,m = 3,n = 2,its,t;
   PetscErrorCode ierr;
   PetscTruth     flg;
   PetscScalar    v;
@@ -186,17 +186,17 @@ int main(int argc,char **args)
           appropriate processor during matrix assembly). 
         - Always specify global row and columns of matrix entries.
     */
-    for (I=Istart; I<Iend; I++) { 
-      v = -1.0; i = I/n; j = I - i*n;  
-      if (i>0)   {J = I - n; ierr = MatSetValues(C1,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
-      if (i<m-1) {J = I + n; ierr = MatSetValues(C1,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
-      if (j>0)   {J = I - 1; ierr = MatSetValues(C1,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
-      if (j<n-1) {J = I + 1; ierr = MatSetValues(C1,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
-      v = 4.0; ierr = MatSetValues(C1,1,&I,1,&I,&v,ADD_VALUES);CHKERRQ(ierr);
+    for (Ii=Istart; Ii<Iend; Ii++) { 
+      v = -1.0; i = Ii/n; j = Ii - i*n;  
+      if (i>0)   {J = Ii - n; ierr = MatSetValues(C1,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+      if (i<m-1) {J = Ii + n; ierr = MatSetValues(C1,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+      if (j>0)   {J = Ii - 1; ierr = MatSetValues(C1,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+      if (j<n-1) {J = Ii + 1; ierr = MatSetValues(C1,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+      v = 4.0; ierr = MatSetValues(C1,1,&Ii,1,&Ii,&v,ADD_VALUES);CHKERRQ(ierr);
     }
-    for (I=Istart; I<Iend; I++) { /* Make matrix nonsymmetric */
-      v = -1.0*(t+0.5); i = I/n;
-      if (i>0)   {J = I - n; ierr = MatSetValues(C1,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+    for (Ii=Istart; Ii<Iend; Ii++) { /* Make matrix nonsymmetric */
+      v = -1.0*(t+0.5); i = Ii/n;
+      if (i>0)   {J = Ii - n; ierr = MatSetValues(C1,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
     }
     ierr = PetscLogFlops(2*(Istart-Iend));CHKERRQ(ierr);
 
@@ -296,17 +296,17 @@ int main(int argc,char **args)
     */
     for (i=0; i<m; i++) { 
       for (j=2*rank; j<2*rank+2; j++) {
-        v = -1.0;  I = j + n*i;
-        if (i>0)   {J = I - n; ierr = MatSetValues(C2,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
-        if (i<m-1) {J = I + n; ierr = MatSetValues(C2,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
-        if (j>0)   {J = I - 1; ierr = MatSetValues(C2,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
-        if (j<n-1) {J = I + 1; ierr = MatSetValues(C2,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
-        v = 6.0 + t*0.5; ierr = MatSetValues(C2,1,&I,1,&I,&v,ADD_VALUES);CHKERRQ(ierr);
+        v = -1.0;  Ii = j + n*i;
+        if (i>0)   {J = Ii - n; ierr = MatSetValues(C2,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+        if (i<m-1) {J = Ii + n; ierr = MatSetValues(C2,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+        if (j>0)   {J = Ii - 1; ierr = MatSetValues(C2,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+        if (j<n-1) {J = Ii + 1; ierr = MatSetValues(C2,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+        v = 6.0 + t*0.5; ierr = MatSetValues(C2,1,&Ii,1,&Ii,&v,ADD_VALUES);CHKERRQ(ierr);
       }
     } 
-    for (I=Istart2; I<Iend2; I++) { /* Make matrix nonsymmetric */
-      v = -1.0*(t+0.5); i = I/n;
-      if (i>0)   {J = I - n; ierr = MatSetValues(C2,1,&I,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
+    for (Ii=Istart2; Ii<Iend2; Ii++) { /* Make matrix nonsymmetric */
+      v = -1.0*(t+0.5); i = Ii/n;
+      if (i>0)   {J = Ii - n; ierr = MatSetValues(C2,1,&Ii,1,&J,&v,ADD_VALUES);CHKERRQ(ierr);}
     }
     ierr = MatAssemblyBegin(C2,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
     ierr = MatAssemblyEnd(C2,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr); 
