@@ -72,7 +72,7 @@ PetscErrorCode  KSPSolve_CGNE(KSP ksp)
 {
   PetscErrorCode ierr;
   PetscInt       i,stored_max_it,eigs;
-  PetscScalar    dpi,a = 1.0,beta,betaold = 1.0,b = 0,*e = 0,*d = 0,mone = -1.0,ma;
+  PetscScalar    dpi,a = 1.0,beta,betaold = 1.0,b = 0,*e = 0,*d = 0;
   PetscReal      dp = 0.0;
   Vec            X,B,Z,R,P,T;
   KSP_CG         *cg;
@@ -101,7 +101,7 @@ PetscErrorCode  KSPSolve_CGNE(KSP ksp)
 #define VecXDot(x,y,a) (((cg->type) == (KSP_CG_HERMITIAN)) ? VecDot(x,y,a) : VecTDot(x,y,a))
 #endif
 
-  if (eigs) {e = cg->e; d = cg->d; e[0] = 0.0; b = 0.0; }
+  if (eigs) {e = cg->e; d = cg->d; e[0] = 0.0; }
   ierr = PCGetOperators(ksp->pc,&Amat,&Pmat,&pflag);CHKERRQ(ierr);
 
   ksp->its = 0;
@@ -109,7 +109,7 @@ PetscErrorCode  KSPSolve_CGNE(KSP ksp)
   if (!ksp->guess_zero) {
     ierr = KSP_MatMult(ksp,Amat,X,P);CHKERRQ(ierr);
     ierr = KSP_MatMultTranspose(ksp,Amat,P,R);CHKERRQ(ierr);
-    ierr = VecAYPX(R,mone,T);CHKERRQ(ierr);
+    ierr = VecAYPX(R,-1.0,T);CHKERRQ(ierr);
   } else { 
     ierr = VecCopy(T,R);CHKERRQ(ierr);              /*     r <- b (x is 0) */
   }
@@ -140,26 +140,27 @@ PetscErrorCode  KSPSolve_CGNE(KSP ksp)
      ierr = VecXDot(Z,R,&beta);CHKERRQ(ierr);     /*     beta <- r'z     */
      if (beta == 0.0) {
        ksp->reason = KSP_CONVERGED_ATOL;
-       ierr = PetscLogInfo((ksp,"KSPSolve_CGNE:converged due to beta = 0\n"));CHKERRQ(ierr);
+       ierr = PetscInfo(ksp,"converged due to beta = 0\n");CHKERRQ(ierr);
        break;
 #if !defined(PETSC_USE_COMPLEX)
      } else if (beta < 0.0) {
        ksp->reason = KSP_DIVERGED_INDEFINITE_PC;
-       ierr = PetscLogInfo((ksp,"KSPSolve_CGNE:diverging due to indefinite preconditioner\n"));CHKERRQ(ierr);
+       ierr = PetscInfo(ksp,"diverging due to indefinite preconditioner\n");CHKERRQ(ierr);
        break;
 #endif
      }
      if (!i) {
        ierr = VecCopy(Z,P);CHKERRQ(ierr);         /*     p <- z          */
+       b = 0.0;
      } else {
-         b = beta/betaold;
-         if (eigs) {
-	   if (ksp->max_it != stored_max_it) {
-	     SETERRQ(PETSC_ERR_SUP,"Can not change maxit AND calculate eigenvalues");
-	   }
-           e[i] = sqrt(PetscAbsScalar(b))/a;  
-         }
-         ierr = VecAYPX(P,b,Z);CHKERRQ(ierr);    /*     p <- z + b* p   */
+       b = beta/betaold;
+       if (eigs) {
+	 if (ksp->max_it != stored_max_it) {
+	   SETERRQ(PETSC_ERR_SUP,"Can not change maxit AND calculate eigenvalues");
+	 }
+	 e[i] = sqrt(PetscAbsScalar(b))/a;  
+       }
+       ierr = VecAYPX(P,b,Z);CHKERRQ(ierr);    /*     p <- z + b* p   */
      }
      betaold = beta;
      ierr = MatMult(Amat,P,T);CHKERRQ(ierr);
@@ -170,7 +171,7 @@ PetscErrorCode  KSPSolve_CGNE(KSP ksp)
        d[i] = sqrt(PetscAbsScalar(b))*e[i] + 1.0/a;
      }
      ierr = VecAXPY(X,a,P);CHKERRQ(ierr);          /*     x <- x + ap     */
-     ma = -a; VecAXPY(R,ma,Z);                      /*     r <- r - az     */
+     ierr = VecAXPY(R,-a,Z);CHKERRQ(ierr);                      /*     r <- r - az     */
      if (ksp->normtype == KSP_PRECONDITIONED_NORM) {
        ierr = KSP_PCApply(ksp,R,T);CHKERRQ(ierr);
        if (transpose_pc) {
