@@ -38,17 +38,16 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPGMRESClassicalGramSchmidtOrthogonalization(
   KSP_GMRES      *gmres = (KSP_GMRES *)(ksp->data);
   PetscErrorCode ierr;
   PetscInt       j;
-  PetscScalar    *hh,*hes,shh[500],*lhh;
+  PetscScalar    *hh,*hes,*lhh;
   PetscReal      hnrm, wnrm;
   PetscTruth     refine = (PetscTruth)(gmres->cgstype == KSP_GMRES_CGS_REFINE_ALWAYS);
 
   PetscFunctionBegin;
   ierr = PetscLogEventBegin(KSP_GMRESOrthogonalization,ksp,0,0,0);CHKERRQ(ierr);
-  /* Don't allocate small arrays */
-  if (it < 501) lhh = shh;
-  else {
-    ierr = PetscMalloc((it+1) * sizeof(PetscScalar),&lhh);CHKERRQ(ierr);
+  if (!gmres->orthogwork) {
+    ierr = PetscMalloc((gmres->max_k + 2)*sizeof(PetscScalar),&gmres->orthogwork);CHKERRQ(ierr);
   }
+  lhh = gmres->orthogwork;
   
   /* update Hessenberg matrix and do unmodified Gram-Schmidt */
   hh  = HH(0,it);
@@ -64,7 +63,7 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPGMRESClassicalGramSchmidtOrthogonalization(
      This is really a matrix-vector product, with the matrix stored
      as pointer to rows 
   */
-  ierr = VecMDot(it+1,VEC_VV(it+1),&(VEC_VV(0)),lhh);CHKERRQ(ierr); /* <v,vnew> */
+  ierr = VecMDot(VEC_VV(it+1),it+1,&(VEC_VV(0)),lhh);CHKERRQ(ierr); /* <v,vnew> */
   for (j=0; j<=it; j++) {
     lhh[j] = - lhh[j];
   }
@@ -93,12 +92,12 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPGMRESClassicalGramSchmidtOrthogonalization(
     ierr = VecNorm(VEC_VV(it+1),NORM_2, &wnrm);CHKERRQ(ierr);
     if (wnrm < 1.0286 * hnrm) {
       refine = PETSC_TRUE;
-      ierr = PetscLogInfo((ksp,"KSPGMRESClassicalGramSchmidtOrthogonalization:Performing iterative refinement wnorm %g hnorm %g\n",wnrm,hnrm));CHKERRQ(ierr);
+      ierr = PetscInfo2(ksp,"Performing iterative refinement wnorm %G hnorm %G\n",wnrm,hnrm);CHKERRQ(ierr);
     }
   }
 
   if (refine) {
-    ierr = VecMDot(it+1,VEC_VV(it+1),&(VEC_VV(0)),lhh);CHKERRQ(ierr); /* <v,vnew> */
+    ierr = VecMDot(VEC_VV(it+1),it+1,&(VEC_VV(0)),lhh);CHKERRQ(ierr); /* <v,vnew> */
     for (j=0; j<=it; j++) lhh[j] = - lhh[j];
     ierr = VecMAXPY(VEC_VV(it+1),it+1,lhh,&VEC_VV(0));CHKERRQ(ierr);
     /* note lhh[j] is -<v,vnew> , hence the subtraction */
@@ -107,8 +106,6 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPGMRESClassicalGramSchmidtOrthogonalization(
       hes[j] -= lhh[j];     /* hes += <v,vnew> */
     }
   }
-
-  if (it >= 501) {ierr = PetscFree(lhh);CHKERRQ(ierr);}
   ierr = PetscLogEventEnd(KSP_GMRESOrthogonalization,ksp,0,0,0);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
