@@ -1,4 +1,4 @@
-/*$Id: gmpre.c,v 1.29 2001/04/10 19:36:32 bsmith Exp $*/
+#define PETSCKSP_DLL
 
 #include "src/ksp/ksp/impls/gmres/gmresp.h"       /*I  "petscksp.h"  I*/
 
@@ -23,9 +23,9 @@
 
 .seealso: KSPGMRESSetRestart(), KSPGMRESSetOrthogonalization()
 @*/
-int KSPGMRESSetPreAllocateVectors(KSP ksp)
+PetscErrorCode PETSCKSP_DLLEXPORT KSPGMRESSetPreAllocateVectors(KSP ksp)
 {
-  int ierr,(*f)(KSP);
+  PetscErrorCode ierr,(*f)(KSP);
 
   PetscFunctionBegin;
   ierr = PetscObjectQueryFunction((PetscObject)ksp,"KSPGMRESSetPreAllocateVectors_C",(void (**)(void))&f);CHKERRQ(ierr);
