@@ -128,8 +128,8 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPQCGGetQuadratic(KSP ksp,PetscReal *quadrati
      D is a scaling matrix.
 
    KSPConvergedReason may be 
-$  KSP_CONVERGED_QCG_NEG_CURVE if convergence is reached along a negative curvature direction,
-$  KSP_CONVERGED_QCG_CONSTRAINED if convergence is reached along a constrained step,
+$  KSP_CONVERGED_STCG_NEG_CURVE if convergence is reached along a negative curvature direction,
+$  KSP_CONVERGED_STCG_CONSTRAINED if convergence is reached along a constrained step,
 $  other KSP converged/diverged reasons
 
 
@@ -155,7 +155,7 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
   MatStructure   pflag;
   Mat            Amat,Pmat;
   Vec            W,WA,WA2,R,P,ASP,BS,X,B;
-  PetscScalar    zero = 0.0,negone = -1.0,scal,nstep,btx,xtax,beta,rntrn,step;
+  PetscScalar    scal,btx,xtax,beta,rntrn,step;
   PetscReal      ptasp,q1,q2,wtasp,bstp,rtr,xnorm,step1,step2,rnrm,p5 = 0.5;
   PetscReal      dzero = 0.0,bsnrm;
   PetscErrorCode ierr;
@@ -191,8 +191,8 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
   if (side != PC_SYMMETRIC) SETERRQ(PETSC_ERR_ARG_OUTOFRANGE,"Requires symmetric preconditioner!");
 
   /* Initialize variables */
-  ierr = VecSet(W,zero);CHKERRQ(ierr);	/* W = 0 */
-  ierr = VecSet(X,zero);CHKERRQ(ierr);	/* X = 0 */
+  ierr = VecSet(W,0.0);CHKERRQ(ierr);	/* W = 0 */
+  ierr = VecSet(X,0.0);CHKERRQ(ierr);	/* X = 0 */
   ierr = PCGetOperators(pc,&Amat,&Pmat,&pflag);CHKERRQ(ierr);
 
   /* Compute:  BS = D^{-1} B */
@@ -210,7 +210,7 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
 
   /* Compute the initial scaled direction and scaled residual */
   ierr = VecCopy(BS,R);CHKERRQ(ierr);
-  ierr = VecScale(R,negone);CHKERRQ(ierr);
+  ierr = VecScale(R,-1.0);CHKERRQ(ierr);
   ierr = VecCopy(R,P);CHKERRQ(ierr);
 #if defined(PETSC_USE_COMPLEX)
   ierr = VecDot(R,R,&crtr);CHKERRQ(ierr); rtr = PetscRealPart(crtr);
@@ -270,11 +270,11 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
 #endif
        }
        pcgP->ltsnrm = pcgP->delta;                       /* convergence in direction of */
-       ksp->reason  = KSP_CONVERGED_QCG_NEG_CURVE;  /* negative curvature */
+       ksp->reason  = KSP_CONVERGED_STCG_NEG_CURVE;  /* negative curvature */
        if (!i) {
-         ierr = PetscLogInfo((ksp,"KSPSolve_QCG: negative curvature: delta=%g\n",pcgP->delta));CHKERRQ(ierr);
+         ierr = PetscInfo1(ksp,"negative curvature: delta=%G\n",pcgP->delta);CHKERRQ(ierr);
        } else {
-         ierr = PetscLogInfo((ksp,"KSPSolve_QCG: negative curvature: step1=%g, step2=%g, delta=%g\n",step1,step2,pcgP->delta));CHKERRQ(ierr);
+         ierr = PetscInfo3(ksp,"negative curvature: step1=%G, step2=%G, delta=%G\n",step1,step2,pcgP->delta);CHKERRQ(ierr);
        }
          
     } else {
@@ -307,11 +307,11 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
 #endif
          }
          pcgP->ltsnrm = pcgP->delta;
-         ksp->reason  = KSP_CONVERGED_QCG_CONSTRAINED;	/* convergence along constrained step */
+         ksp->reason  = KSP_CONVERGED_STCG_CONSTRAINED;	/* convergence along constrained step */
          if (!i) {
-           ierr = PetscLogInfo((ksp,"KSPSolve_QCG: constrained step: delta=%g\n",pcgP->delta));CHKERRQ(ierr);
+           ierr = PetscInfo1(ksp,"constrained step: delta=%G\n",pcgP->delta);CHKERRQ(ierr);
          } else {
-           ierr = PetscLogInfo((ksp,"KSPSolve_QCG: constrained step: step1=%g, step2=%g, delta=%g\n",step1,step2,pcgP->delta));CHKERRQ(ierr);
+           ierr = PetscInfo3(ksp,"constrained step: step1=%G, step2=%G, delta=%G\n",step1,step2,pcgP->delta);CHKERRQ(ierr);
          }
 
        } else {
@@ -319,8 +319,7 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
          /* Evaluate the current step */
 
          ierr = VecCopy(X,W);CHKERRQ(ierr);	/* update interior iterate */
-         nstep = -step;
-         ierr = VecAXPY(R,nstep,ASP);CHKERRQ(ierr); /* r <- -step*asp + r */
+         ierr = VecAXPY(R,-step,ASP);CHKERRQ(ierr); /* r <- -step*asp + r */
          ierr = VecNorm(R,NORM_2,&rnrm);CHKERRQ(ierr);
 
          ierr = PetscObjectTakeAccess(ksp);CHKERRQ(ierr);
@@ -331,9 +330,9 @@ PetscErrorCode KSPSolve_QCG(KSP ksp)
          ierr = (*ksp->converged)(ksp,i+1,rnrm,&ksp->reason,ksp->cnvP);CHKERRQ(ierr);
          if (ksp->reason) {                 /* convergence for */
 #if defined(PETSC_USE_COMPLEX)               
-           ierr = PetscLogInfo((ksp,"KSPSolve_QCG: truncated step: step=%g, rnrm=%g, delta=%g\n",PetscRealPart(step),rnrm,pcgP->delta));CHKERRQ(ierr);
+           ierr = PetscInfo3(ksp,"truncated step: step=%G, rnrm=%G, delta=%G\n",PetscRealPart(step),rnrm,pcgP->delta);CHKERRQ(ierr);
 #else
-           ierr = PetscLogInfo((ksp,"KSPSolve_QCG: truncated step: step=%g, rnrm=%g, delta=%g\n",step,rnrm,pcgP->delta));CHKERRQ(ierr);
+           ierr = PetscInfo3(ksp,"truncated step: step=%G, rnrm=%G, delta=%G\n",step,rnrm,pcgP->delta);CHKERRQ(ierr);
 #endif
          }
       }
@@ -533,7 +532,7 @@ EXTERN_C_END
 */
 static PetscErrorCode QuadraticRoots_Private(Vec s,Vec p,PetscReal *delta,PetscReal *step1,PetscReal *step2)
 { 
-  PetscReal      zero = 0.0,dsq,ptp,pts,rad,sts;
+  PetscReal      dsq,ptp,pts,rad,sts;
   PetscErrorCode ierr;
 #if defined(PETSC_USE_COMPLEX)
   PetscScalar    cptp,cpts,csts;
@@ -551,7 +550,7 @@ static PetscErrorCode QuadraticRoots_Private(Vec s,Vec p,PetscReal *delta,PetscR
 #endif
   dsq  = (*delta)*(*delta);
   rad  = sqrt((pts*pts) - ptp*(sts - dsq));
-  if (pts > zero) {
+  if (pts > 0.0) {
     *step2 = -(pts + rad)/ptp;
     *step1 = (sts - dsq)/(ptp * *step2);
   } else {
