@@ -73,7 +73,7 @@ const char *KSPConvergedReasons_Shifted[] = {"DIVERGED_INDEFINITE_MAT","DIVERGED
                                              "DIVERGED_DTOL","DIVERGED_ITS","DIVERGED_NULL","","CONVERGED_ITERATING",
                                              "","CONVERGED_RTOL","CONVERGED_ATOL","CONVERGED_ITS",
                                              "CONVERGED_STCG_NEG_CURVE","CONVERGED_STCG_CONSTRAINED","CONVERGED_STEP_LENGTH",
-                                             "KSPConvergedReason","KSP_",0};
+                                             "CONVERGED_HAPPY_BREAKDOWN","KSPConvergedReason","KSP_",0};
 const char **KSPConvergedReasons = KSPConvergedReasons_Shifted + 10;
 
 #undef __FUNCT__  
