@@ -245,7 +245,7 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPTrueMonitor(KSP ksp,PetscInt n,PetscReal rn
 {
   PetscErrorCode ierr;
   Vec            resid,work;
-  PetscReal      scnorm;
+  PetscReal      scnorm,bnorm;
   PC             pc;
   Mat            A,B;
   PetscViewer    viewer = (PetscViewer) dummy;
@@ -268,7 +268,8 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPTrueMonitor(KSP ksp,PetscInt n,PetscReal rn
   }
   ierr = VecNorm(work,NORM_2,&scnorm);CHKERRQ(ierr);
   ierr = VecDestroy(work);CHKERRQ(ierr);
-  ierr = PetscViewerASCIIPrintf(viewer,"%3D KSP preconditioned resid norm %14.12e true resid norm %14.12e\n",n,rnorm,scnorm);CHKERRQ(ierr);
+  ierr = VecNorm(ksp->vec_rhs,NORM_2,&bnorm);CHKERRQ(ierr);
+  ierr = PetscViewerASCIIPrintf(viewer,"%3D KSP preconditioned resid norm %14.12e true resid norm %14.12e ||Ae||/||Ax|| %14.12e\n",n,rnorm,scnorm,scnorm/bnorm);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -334,6 +335,76 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPSkipConverged(KSP ksp,PetscInt n,PetscReal
   PetscFunctionReturn(0);
 }
 
+#undef __FUNCT__  
+#define __FUNCT__ "KSPDefaultConvergedSetUIRNorm"
+/*@C
+   KSPDefaultConvergedSetUIRNorm - makes the default convergence test use || B*(b - A*(initial guess))||
+      instead of || B*b ||. In the case of right preconditioner or if KSPSetNormType(ksp,KSP_UNPRECONDIITONED_NORM)
+      is used there is no B in the above formula. UIRNorm is short for Use Initial Residual Norm.
+
+   Collective on KSP
+
+   Input Parameters:
+.  ksp   - iterative context
+
+   Options Database:
+.   -ksp_converged_use_initial_residual_norm
+
+   Use KSPSetTolerances() to alter the defaults for rtol, abstol, dtol.
+
+   The precise values of reason are macros such as KSP_CONVERGED_RTOL, which
+   are defined in petscksp.h.
+
+   Level: intermediate
+
+.keywords: KSP, default, convergence, residual
+
+.seealso: KSPSetConvergenceTest(), KSPSetTolerances(), KSPSkipConverged(), KSPConvergedReason, KSPGetConvergedReason(), KSPDefaultConvergedSetUMIRNorm()
+@*/
+PetscErrorCode PETSCKSP_DLLEXPORT KSPDefaultConvergedSetUIRNorm(KSP ksp)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(ksp,KSP_COOKIE,1);
+  if (ksp->defaultconvergedmininitialrtol) SETERRQ(PETSC_ERR_ARG_WRONGSTATE,"Can use KSPDefaultConvergedSetUIRNorm() and KSPDefaultConvergedSetUMIRNorm() together");
+  ksp->defaultconvergedinitialrtol = PETSC_TRUE;
+  PetscFunctionReturn(0);
+}
+
+#undef __FUNCT__  
+#define __FUNCT__ "KSPDefaultConvergedSetUMIRNorm"
+/*@C
+   KSPDefaultConvergedSetUMIRNorm - makes the default convergence test use min(|| B*(b - A*(initial guess))||,|| B*b ||)
+      In the case of right preconditioner or if KSPSetNormType(ksp,KSP_UNPRECONDIITONED_NORM)
+      is used there is no B in the above formula. UMIRNorm is short for Use Minimum Initial Residual Norm.
+
+   Collective on KSP
+
+   Input Parameters:
+.  ksp   - iterative context
+
+   Options Database:
+.   -ksp_converged_use_min_initial_residual_norm
+
+   Use KSPSetTolerances() to alter the defaults for rtol, abstol, dtol.
+
+   The precise values of reason are macros such as KSP_CONVERGED_RTOL, which
+   are defined in petscksp.h.
+
+   Level: intermediate
+
+.keywords: KSP, default, convergence, residual
+
+.seealso: KSPSetConvergenceTest(), KSPSetTolerances(), KSPSkipConverged(), KSPConvergedReason, KSPGetConvergedReason(), KSPDefaultConvergedSetUIRNorm()
+@*/
+PetscErrorCode PETSCKSP_DLLEXPORT KSPDefaultConvergedSetUMIRNorm(KSP ksp)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(ksp,KSP_COOKIE,1);
+  if (ksp->defaultconvergedinitialrtol) SETERRQ(PETSC_ERR_ARG_WRONGSTATE,"Can use KSPDefaultConvergedSetUIRNorm() and KSPDefaultConvergedSetUMIRNorm() together");
+  ksp->defaultconvergedmininitialrtol = PETSC_TRUE;
+  PetscFunctionReturn(0);
+}
+
 #undef __FUNCT__  
 #define __FUNCT__ "KSPDefaultConverged"
 /*@C
@@ -363,7 +434,9 @@ $      rnorm > dtol * rnorm_0,
 +     rtol = relative tolerance,
 .     abstol = absolute tolerance.
 .     dtol = divergence tolerance,
--     rnorm_0 = initial residual norm
+-     rnorm_0 is the two norm of the right hand side. When initial guess is non-zero you 
+          can call KSPDefaultConvergedSetUIRNorm() to use the norm of (b - A*(initial guess))
+          as the starting point for relative norm convergence testing.
 
    Use KSPSetTolerances() to alter the defaults for rtol, abstol, dtol.
 
@@ -374,7 +447,8 @@ $      rnorm > dtol * rnorm_0,
 
 .keywords: KSP, default, convergence, residual
 
-.seealso: KSPSetConvergenceTest(), KSPSetTolerances(), KSPSkipConverged(), KSPConvergedReason, KSPGetConvergedReason()
+.seealso: KSPSetConvergenceTest(), KSPSetTolerances(), KSPSkipConverged(), KSPConvergedReason, KSPGetConvergedReason(),
+          KSPDefaultConvergedSetUIRNorm().
 @*/
 PetscErrorCode PETSCKSP_DLLEXPORT KSPDefaultConverged(KSP ksp,PetscInt n,PetscReal rnorm,KSPConvergedReason *reason,void *dummy)
 {
@@ -387,7 +461,7 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPDefaultConverged(KSP ksp,PetscInt n,PetscRe
 
   if (!n) {
     /* if user gives initial guess need to compute norm of b */
-    if (!ksp->guess_zero) {
+    if (!ksp->guess_zero && !ksp->defaultconvergedinitialrtol) {
       PetscReal      snorm;
       if (ksp->normtype == KSP_UNPRECONDITIONED_NORM || ksp->pc_side == PC_RIGHT) {
         ierr = PetscInfo(ksp,"user has provided nonzero initial guess, computing 2-norm of RHS\n");CHKERRQ(ierr);
@@ -412,12 +486,15 @@ PetscErrorCode PETSCKSP_DLLEXPORT KSPDefaultConverged(KSP ksp,PetscInt n,PetscRe
         ierr = PetscInfo(ksp,"Special case, user has provided nonzero initial guess and zero RHS\n");CHKERRQ(ierr);
         snorm = rnorm;
       }
-      ksp->ttol   = PetscMax(ksp->rtol*snorm,ksp->abstol);
-      ksp->rnorm0 = snorm;
+      if (ksp->defaultconvergedmininitialrtol) {
+        ksp->rnorm0 = PetscMin(snorm,rnorm);
+      } else {
+        ksp->rnorm0 = snorm;
+      }
     } else {
-      ksp->ttol   = PetscMax(ksp->rtol*rnorm,ksp->abstol);
       ksp->rnorm0 = rnorm;
     }
+    ksp->ttol   = PetscMax(ksp->rtol*ksp->rnorm0,ksp->abstol);
   }
 
   if (rnorm != rnorm) {
@@ -510,7 +587,7 @@ PetscErrorCode KSPDefaultBuildResidual(KSP ksp,Vec t,Vec v,Vec *V)
   Mat            Amat,Pmat;
 
   PetscFunctionBegin;
-  PCGetOperators(ksp->pc,&Amat,&Pmat,&pflag);
+  ierr = PCGetOperators(ksp->pc,&Amat,&Pmat,&pflag);CHKERRQ(ierr);
   ierr = KSPBuildSolution(ksp,t,PETSC_NULL);CHKERRQ(ierr);
   ierr = KSP_MatMult(ksp,Amat,t,v);CHKERRQ(ierr);
   ierr = VecAYPX(v,-1.0,ksp->vec_rhs);CHKERRQ(ierr);
@@ -551,8 +628,8 @@ PetscErrorCode KSPGetVecs(KSP ksp,PetscInt rightn, Vec **right,PetscInt leftn,Ve
     if (ksp->vec_sol) vecr = ksp->vec_sol;
     else {
       Mat pmat;
-      ierr = PCGetOperators(ksp->pc,0,&pmat,0);CHKERRQ(ierr);
-      ierr = MatGetVecs(pmat,&vecr,0);CHKERRQ(ierr);
+      ierr = PCGetOperators(ksp->pc,PETSC_NULL,&pmat,PETSC_NULL);CHKERRQ(ierr);
+      ierr = MatGetVecs(pmat,&vecr,PETSC_NULL);CHKERRQ(ierr);
     }
     ierr = VecDuplicateVecs(vecr,rightn,right);CHKERRQ(ierr);
     if (!ksp->vec_sol) {
@@ -564,8 +641,8 @@ PetscErrorCode KSPGetVecs(KSP ksp,PetscInt rightn, Vec **right,PetscInt leftn,Ve
     if (ksp->vec_rhs) vecl = ksp->vec_rhs;
     else {
       Mat pmat;
-      ierr = PCGetOperators(ksp->pc,0,&pmat,0);CHKERRQ(ierr);
-      ierr = MatGetVecs(pmat,0,&vecl);CHKERRQ(ierr);
+      ierr = PCGetOperators(ksp->pc,PETSC_NULL,&pmat,PETSC_NULL);CHKERRQ(ierr);
+      ierr = MatGetVecs(pmat,PETSC_NULL,&vecl);CHKERRQ(ierr);
     }
     ierr = VecDuplicateVecs(vecl,leftn,left);CHKERRQ(ierr);
     if (!ksp->vec_rhs) {
