@@ -425,8 +425,7 @@ PetscErrorCode PETSCKSP_DLLEXPORT PCASMSetTotalSubdomains_ASM(PC pc,PetscInt N,I
 
   PetscFunctionBegin;
 
-  if (is) SETERRQ(PETSC_ERR_SUP,"Use PCASMSetLocalSubdomains() to set specific index sets\n\
-they cannot be set globally yet.");
+  if (is) SETERRQ(PETSC_ERR_SUP,"Use PCASMSetLocalSubdomains() to set specific index sets\n\they cannot be set globally yet.");
 
   /*
      Split the subdomains equally amoung all processors 
@@ -811,7 +810,7 @@ PetscErrorCode PETSCKSP_DLLEXPORT PCASMGetSubKSP(PC pc,PetscInt *n_local,PetscIn
      than one processor. Defaults to one block per processor.
 
      To set options on the solvers for each block append -sub_ to all the KSP, and PC
-        options database keys. For example, -sub_pc_type ilu -sub_pc_ilu_levels 1 -sub_ksp_type preonly
+        options database keys. For example, -sub_pc_type ilu -sub_pc_factor_levels 1 -sub_ksp_type preonly
         
      To set the options on the solvers separate for each block call PCASMGetSubKSP()
          and set the options directly on the resulting KSP object (you can access its PC
