@@ -1,7 +1,7 @@
 #define PETSCKSP_DLL
 
 /* 
-   Provides an interface to the ML 3.0 smoothed Aggregation 
+   Provides an interface to the ML 4.0 smoothed Aggregation 
 */
 #include "private/pcimpl.h"   /*I "petscpc.h" I*/
 #include "src/ksp/pc/impls/mg/mgimpl.h"                    /*I "petscmg.h" I*/
@@ -374,7 +374,7 @@ PetscErrorCode PCSetFromOptions_ML(PC pc)
 */
 
 /*MC
-     PCML - Use geometric multigrid preconditioning. This preconditioner requires you provide 
+     PCML - Use algebraic multigrid preconditioning. This preconditioner requires you provide 
        fine grid discretization matrix. The coarser grid matrices and restriction/interpolation 
        operators are computed by ML, with the matrices coverted to PETSc matrices in aij format
        and the restriction/interpolation operators wrapped as PETSc shell matrices.
@@ -545,7 +545,6 @@ PetscErrorCode MatMultAdd_ML(Mat A,Vec x,Vec w,Vec y)
   PetscErrorCode    ierr;
   Mat_MLShell       *shell;
   PetscScalar       *xarray,*yarray;
-  const PetscScalar one=1.0;
   PetscInt          x_length,y_length;
   
   PetscFunctionBegin;
@@ -614,7 +613,9 @@ PetscErrorCode MatConvert_MPIAIJ_ML(Mat A,MatType newtype,MatReuse scall,Mat *Al
     /* MatCreateSeqAIJWithArrays flags matrix so PETSc doesn't free the user's arrays. */
     /* Since these are PETSc arrays, change flags to free them as necessary. */
     mat = (Mat_SeqAIJ*)(*Aloc)->data;
-    mat->freedata = PETSC_TRUE;
+    mat->free_a       = PETSC_TRUE;
+    mat->free_ij      = PETSC_TRUE;
+
     mat->nonew    = 0;
   } else if (scall == MAT_REUSE_MATRIX){
     mat=(Mat_SeqAIJ*)(*Aloc)->data; 
@@ -645,6 +646,7 @@ PetscErrorCode MatDestroy_ML(Mat A)
   ierr = VecDestroy(shell->y);CHKERRQ(ierr);
   ierr = PetscFree(shell);CHKERRQ(ierr); 
   ierr = MatDestroy_Shell(A);CHKERRQ(ierr);
+  ierr = PetscObjectChangeTypeName((PetscObject)A,0);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -770,7 +772,7 @@ PetscErrorCode MatWrapML_MPIAIJ(ML_Operator *mlmat,Mat *newmat)
   nz_max++;
   ierr = PetscMalloc(nz_max*(sizeof(PetscInt)+sizeof(PetscScalar)),&aj);CHKERRQ(ierr);
   aa = (PetscScalar*)(aj + nz_max);
-  ML_build_global_numbering(mlmat,(ML_Comm*)mlmat->comm,&gordering);
+  ML_build_global_numbering(mlmat,&gordering);
   for (i=0; i<m; i++){
     row = gordering[i];
     k = 0;
