@@ -1,4 +1,3 @@
-/*$Id: ex70.c,v 1.13 2001/08/07 03:03:07 balay Exp $*/
 
 static char help[] = "Tests Vec/MatSetValues() with negative row and column indices.\n\n"; 
 
@@ -9,14 +8,16 @@ static char help[] = "Tests Vec/MatSetValues() with negative row and column indi
 #define __FUNCT__ "main"
 int main(int argc,char **args)
 {
-  Mat         C; 
-  int         i[2],j[2],ierr;
-  PetscScalar v[] = {1.0,2.0,3.0,4.0};
-  Vec         x;
+  Mat            C; 
+  PetscInt       i[2],j[2];
+  PetscErrorCode ierr;
+  PetscScalar    v[] = {1.0,2.0,3.0,4.0};
+  Vec            x;
 
   PetscInitialize(&argc,&args,(char *)0,help);
 
-  ierr = MatCreate(PETSC_COMM_WORLD,PETSC_DECIDE,PETSC_DECIDE,3,3,&C);CHKERRQ(ierr);
+  ierr = MatCreate(PETSC_COMM_WORLD,&C);CHKERRQ(ierr);
+  ierr = MatSetSizes(C,PETSC_DECIDE,PETSC_DECIDE,3,3);CHKERRQ(ierr);
   ierr = MatSetFromOptions(C);CHKERRQ(ierr);
   ierr = VecCreateSeq(PETSC_COMM_WORLD,3,&x);CHKERRQ(ierr);
   
