@@ -13,7 +13,7 @@ int main(int argc,char **argv)
 {
   Mat            A,A11,A12,A21,A22;
   Vec            X,X1,X2,Y,Z,Z1,Z2;
-  PetscScalar    *a,*b,*x,*y,*z,v,one=1,mone=-1;
+  PetscScalar    *a,*b,*x,*y,*z,v,one=1;
   PetscReal      nrm;
   PetscErrorCode ierr;
   PetscInt       size=8,size1=6,size2=2, i,j;
@@ -104,7 +104,7 @@ int main(int argc,char **argv)
   ierr = MatMultAdd(A12,X2,Z1,Z1);CHKERRQ(ierr);
   ierr = MatMult(A22,X2,Z2);CHKERRQ(ierr);
   ierr = MatMultAdd(A21,X1,Z2,Z2);CHKERRQ(ierr);
-  ierr = VecAXPY(Z,mone,Y);CHKERRQ(ierr);
+  ierr = VecAXPY(Z,-1.0,Y);CHKERRQ(ierr);
   ierr = VecNorm(Z,NORM_2,&nrm);
   printf("Test1; error norm=%e\n",nrm);
   /*
@@ -135,7 +135,7 @@ int main(int argc,char **argv)
   ierr = MatMultAdd(A12,X2,Z1,Z1);CHKERRQ(ierr);
   ierr = MatMult(A22,X2,Z2);CHKERRQ(ierr);
   ierr = MatMultAdd(A21,X1,Z2,Z2);CHKERRQ(ierr);
-  ierr = VecAXPY(Z,mone,Y);CHKERRQ(ierr);
+  ierr = VecAXPY(Z,-1.0,Y);CHKERRQ(ierr);
   ierr = VecNorm(Z,NORM_2,&nrm);
   printf("Test2; error norm=%e\n",nrm);
 
@@ -147,10 +147,31 @@ int main(int argc,char **argv)
   ierr = MatMultTransposeAdd(A21,X2,Z1,Z1);CHKERRQ(ierr);
   ierr = MatMultTranspose(A22,X2,Z2);CHKERRQ(ierr);
   ierr = MatMultTransposeAdd(A12,X1,Z2,Z2);CHKERRQ(ierr);
-  ierr = VecAXPY(Z,mone,Y);CHKERRQ(ierr);
+  ierr = VecAXPY(Z,-1.0,Y);CHKERRQ(ierr);
   ierr = VecNorm(Z,NORM_2,&nrm);
   printf("Test3; error norm=%e\n",nrm);
 
+  ierr = PetscFree(a);CHKERRQ(ierr);
+  ierr = PetscFree(b);CHKERRQ(ierr);
+  ierr = PetscFree(x);CHKERRQ(ierr);
+  ierr = PetscFree(y);CHKERRQ(ierr);
+  ierr = PetscFree(z);CHKERRQ(ierr);
+  ierr = MatDestroy(A);CHKERRQ(ierr);
+  ierr = MatDestroy(A11);CHKERRQ(ierr);
+  ierr = MatDestroy(A12);CHKERRQ(ierr);
+  ierr = MatDestroy(A21);CHKERRQ(ierr);
+  ierr = MatDestroy(A22);CHKERRQ(ierr);
+
+  ierr = VecDestroy(X);CHKERRQ(ierr);
+  ierr = VecDestroy(Y);CHKERRQ(ierr);
+  ierr = VecDestroy(Z);CHKERRQ(ierr);
+
+  ierr = VecDestroy(X1);CHKERRQ(ierr);
+  ierr = VecDestroy(X2);CHKERRQ(ierr);
+  ierr = VecDestroy(Z1);CHKERRQ(ierr);
+  ierr = VecDestroy(Z2);CHKERRQ(ierr);
+
+
   ierr = PetscFinalize();CHKERRQ(ierr);
   return 0;
 }
