@@ -73,7 +73,7 @@ PetscErrorCode MatDestroy_MPIAdj(Mat mat)
     ierr = PetscFree(a->values);CHKERRQ(ierr);
   }
   ierr = PetscFree(a);CHKERRQ(ierr);
-
+  ierr = PetscObjectChangeTypeName((PetscObject)mat,0);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)mat,"MatMPIAdjSetPreallocation_C","",PETSC_NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -118,20 +118,19 @@ PetscErrorCode MatMarkDiagonal_MPIAdj(Mat A)
 {
   Mat_MPIAdj     *a = (Mat_MPIAdj*)A->data; 
   PetscErrorCode ierr;
-  PetscInt       i,j,*diag,m = A->rmap.n;
+  PetscInt       i,j,m = A->rmap.n;
 
   PetscFunctionBegin;
-  ierr = PetscMalloc((m+1)*sizeof(PetscInt),&diag);CHKERRQ(ierr);
-  ierr = PetscLogObjectMemory(A,(m+1)*sizeof(PetscInt));CHKERRQ(ierr);
+  ierr = PetscMalloc(m*sizeof(PetscInt),&a->diag);CHKERRQ(ierr);
+  ierr = PetscLogObjectMemory(A,m*sizeof(PetscInt));CHKERRQ(ierr);
   for (i=0; i<A->rmap.n; i++) {
     for (j=a->i[i]; j<a->i[i+1]; j++) {
       if (a->j[j] == i) {
-        diag[i] = j;
+        a->diag[i] = j;
         break;
       }
     }
   }
-  a->diag = diag;
   PetscFunctionReturn(0);
 }
 
@@ -235,6 +234,67 @@ PetscErrorCode MatRestoreRowIJ_MPIAdj(Mat A,PetscInt oshift,PetscTruth symmetric
   PetscFunctionReturn(0);
 }
 
+#undef __FUNCT__  
+#define __FUNCT__ "MatConvertFrom_MPIAdj"
+PetscErrorCode PETSCMAT_DLLEXPORT MatConvertFrom_MPIAdj(Mat A,MatType type,MatReuse reuse,Mat *newmat)
+{
+  Mat               B;
+  PetscErrorCode    ierr;
+  PetscInt          i,m,N,nzeros = 0,*ia,*ja,len,rstart,cnt,j,*a;
+  const PetscInt    *rj;
+  const PetscScalar *ra;
+  MPI_Comm          comm;
+
+  PetscFunctionBegin;
+  ierr = MatGetSize(A,PETSC_NULL,&N);CHKERRQ(ierr);
+  ierr = MatGetLocalSize(A,&m,PETSC_NULL);CHKERRQ(ierr);
+  ierr = MatGetOwnershipRange(A,&rstart,PETSC_NULL);CHKERRQ(ierr);
+  
+  /* count the number of nonzeros per row */
+  for (i=0; i<m; i++) {
+    ierr   = MatGetRow(A,i+rstart,&len,&rj,PETSC_NULL);CHKERRQ(ierr);
+    for (j=0; j<len; j++) {
+      if (rj[j] == i+rstart) {len--; break;}    /* don't count diagonal */
+    }
+    ierr   = MatRestoreRow(A,i+rstart,&len,&rj,PETSC_NULL);CHKERRQ(ierr);
+    nzeros += len;
+  }
+
+  /* malloc space for nonzeros */
+  ierr = PetscMalloc((nzeros+1)*sizeof(PetscInt),&a);CHKERRQ(ierr);
+  ierr = PetscMalloc((N+1)*sizeof(PetscInt),&ia);CHKERRQ(ierr);
+  ierr = PetscMalloc((nzeros+1)*sizeof(PetscInt),&ja);CHKERRQ(ierr);
+
+  nzeros = 0;
+  ia[0]  = 0;
+  for (i=0; i<m; i++) {
+    ierr    = MatGetRow(A,i+rstart,&len,&rj,&ra);CHKERRQ(ierr);
+    cnt     = 0;
+    for (j=0; j<len; j++) {
+      if (rj[j] != i+rstart) { /* if not diagonal */
+        a[nzeros+cnt]    = (PetscInt) PetscAbsScalar(ra[j]);
+        ja[nzeros+cnt++] = rj[j];
+      } 
+    }
+    ierr    = MatRestoreRow(A,i+rstart,&len,&rj,&ra);CHKERRQ(ierr);
+    nzeros += cnt;
+    ia[i+1] = nzeros; 
+  }
+
+  ierr = PetscObjectGetComm((PetscObject)A,&comm);CHKERRQ(ierr);
+  ierr = MatCreate(comm,&B);CHKERRQ(ierr);
+  ierr = MatSetSizes(B,m,N,PETSC_DETERMINE,N);CHKERRQ(ierr);
+  ierr = MatSetType(B,type);CHKERRQ(ierr);
+  ierr = MatMPIAdjSetPreallocation(B,ia,ja,a);CHKERRQ(ierr);
+
+  if (reuse == MAT_REUSE_MATRIX) {
+    ierr = MatHeaderReplace(A,B);CHKERRQ(ierr);
+  } else {
+    *newmat = B;
+  }
+  PetscFunctionReturn(0);
+}
+
 /* -------------------------------------------------------------------*/
 static struct _MatOps MatOps_Values = {0,
        MatGetRow_MPIAdj,
@@ -299,7 +359,7 @@ static struct _MatOps MatOps_Values = {0,
 /*60*/ 0,
        MatDestroy_MPIAdj,
        MatView_MPIAdj,
-       0,
+       MatConvertFrom_MPIAdj,
        0,
 /*65*/ 0,
        0,
@@ -408,11 +468,13 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_MPIAdj(Mat B)
   B->assembled        = PETSC_FALSE;
   
   ierr = PetscMapInitialize(B->comm,&B->rmap);CHKERRQ(ierr);
-  ierr = PetscMapInitialize(B->comm,&B->cmap);CHKERRQ(ierr);
+  if (B->cmap.n < 0) B->cmap.n = B->cmap.N;
+  if (B->cmap.N < 0) B->cmap.N = B->cmap.n;
 
   ierr = PetscObjectComposeFunctionDynamic((PetscObject)B,"MatMPIAdjSetPreallocation_C",
                                     "MatMPIAdjSetPreallocation_MPIAdj",
                                      MatMPIAdjSetPreallocation_MPIAdj);CHKERRQ(ierr);
+  ierr = PetscObjectChangeTypeName((PetscObject)B,MATMPIADJ);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 EXTERN_C_END
@@ -490,74 +552,13 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreateMPIAdj(MPI_Comm comm,PetscInt m,Petsc
 
   PetscFunctionBegin;
   ierr = MatCreate(comm,A);CHKERRQ(ierr);
-  ierr = MatSetSizes(*A,m,n,PETSC_DETERMINE,PETSC_DETERMINE);CHKERRQ(ierr);
+  ierr = MatSetSizes(*A,m,n,PETSC_DETERMINE,n);CHKERRQ(ierr);
   ierr = MatSetType(*A,MATMPIADJ);CHKERRQ(ierr);
   ierr = MatMPIAdjSetPreallocation(*A,i,j,values);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
-EXTERN_C_BEGIN
-#undef __FUNCT__  
-#define __FUNCT__ "MatConvertTo_MPIAdj"
-PetscErrorCode PETSCMAT_DLLEXPORT MatConvertTo_MPIAdj(Mat A,MatType type,MatReuse reuse,Mat *newmat)
-{
-  Mat               B;
-  PetscErrorCode    ierr;
-  PetscInt          i,m,N,nzeros = 0,*ia,*ja,len,rstart,cnt,j,*a;
-  const PetscInt    *rj;
-  const PetscScalar *ra;
-  MPI_Comm          comm;
 
-  PetscFunctionBegin;
-  ierr = MatGetSize(A,PETSC_NULL,&N);CHKERRQ(ierr);
-  ierr = MatGetLocalSize(A,&m,PETSC_NULL);CHKERRQ(ierr);
-  ierr = MatGetOwnershipRange(A,&rstart,PETSC_NULL);CHKERRQ(ierr);
-  
-  /* count the number of nonzeros per row */
-  for (i=0; i<m; i++) {
-    ierr   = MatGetRow(A,i+rstart,&len,&rj,PETSC_NULL);CHKERRQ(ierr);
-    for (j=0; j<len; j++) {
-      if (rj[j] == i+rstart) {len--; break;}    /* don't count diagonal */
-    }
-    ierr   = MatRestoreRow(A,i+rstart,&len,&rj,PETSC_NULL);CHKERRQ(ierr);
-    nzeros += len;
-  }
-
-  /* malloc space for nonzeros */
-  ierr = PetscMalloc((nzeros+1)*sizeof(PetscInt),&a);CHKERRQ(ierr);
-  ierr = PetscMalloc((N+1)*sizeof(PetscInt),&ia);CHKERRQ(ierr);
-  ierr = PetscMalloc((nzeros+1)*sizeof(PetscInt),&ja);CHKERRQ(ierr);
-
-  nzeros = 0;
-  ia[0]  = 0;
-  for (i=0; i<m; i++) {
-    ierr    = MatGetRow(A,i+rstart,&len,&rj,&ra);CHKERRQ(ierr);
-    cnt     = 0;
-    for (j=0; j<len; j++) {
-      if (rj[j] != i+rstart) { /* if not diagonal */
-        a[nzeros+cnt]    = (PetscInt) PetscAbsScalar(ra[j]);
-        ja[nzeros+cnt++] = rj[j];
-      } 
-    }
-    ierr    = MatRestoreRow(A,i+rstart,&len,&rj,&ra);CHKERRQ(ierr);
-    nzeros += cnt;
-    ia[i+1] = nzeros; 
-  }
-
-  ierr = PetscObjectGetComm((PetscObject)A,&comm);CHKERRQ(ierr);
-  ierr = MatCreate(comm,&B);CHKERRQ(ierr);
-  ierr = MatSetSizes(B,m,N,PETSC_DETERMINE,N);CHKERRQ(ierr);
-  ierr = MatSetType(B,type);CHKERRQ(ierr);
-  ierr = MatMPIAdjSetPreallocation(B,ia,ja,a);CHKERRQ(ierr);
-
-  if (reuse == MAT_REUSE_MATRIX) {
-    ierr = MatHeaderReplace(A,B);CHKERRQ(ierr);
-  } else {
-    *newmat = B;
-  }
-  PetscFunctionReturn(0);
-}
-EXTERN_C_END
 
 
 
