@@ -19,6 +19,8 @@ PetscErrorCode MatFDColoringCreate_MPIAIJ(Mat mat,ISColoring iscoloring,MatFDCol
   PetscInt       *columnsforrow,l;
   IS             *isa;
   PetscTruth     done,flg;
+  ISLocalToGlobalMapping map = mat->mapping;
+  PetscInt       *ltog = map->indices,ctype=c->ctype;
 
   PetscFunctionBegin;
   if (!mat->assembled) {
@@ -49,24 +51,14 @@ PetscErrorCode MatFDColoringCreate_MPIAIJ(Mat mat,ISColoring iscoloring,MatFDCol
   */
   ierr = MatGetColumnIJ_SeqAIJ(aij->A,0,PETSC_FALSE,&ncols,&A_ci,&A_cj,&done);CHKERRQ(ierr); 
   ierr = MatGetColumnIJ_SeqAIJ(aij->B,0,PETSC_FALSE,&ncols,&B_ci,&B_cj,&done);CHKERRQ(ierr); 
-
-  ierr = MPI_Comm_size(mat->comm,&size);CHKERRQ(ierr); 
-  ierr = PetscMalloc(2*size*sizeof(PetscInt*),&ncolsonproc);CHKERRQ(ierr);
-  disp = ncolsonproc + size;
-
+  
   ierr = PetscMalloc((M+1)*sizeof(PetscInt),&rowhit);CHKERRQ(ierr);
   ierr = PetscMalloc((M+1)*sizeof(PetscInt),&columnsforrow);CHKERRQ(ierr);
 
-  /*
-     Temporary option to allow for debugging/testing
-  */
-  ierr = PetscOptionsHasName(PETSC_NULL,"-matfdcoloring_slow",&flg);CHKERRQ(ierr);
-
   for (i=0; i<nis; i++) {
     ierr = ISGetLocalSize(isa[i],&n);CHKERRQ(ierr);
     ierr = ISGetIndices(isa[i],&is);CHKERRQ(ierr);
     c->ncolumns[i] = n;
-    c->ncolumns[i] = n;
     if (n) {
       ierr = PetscMalloc(n*sizeof(PetscInt),&c->columns[i]);CHKERRQ(ierr);
       ierr = PetscLogObjectMemory(c,n*sizeof(PetscInt));CHKERRQ(ierr);
@@ -75,32 +67,52 @@ PetscErrorCode MatFDColoringCreate_MPIAIJ(Mat mat,ISColoring iscoloring,MatFDCol
       c->columns[i]  = 0;
     }
 
-    /* Determine the total (parallel) number of columns of this color */
-    nn   = (PetscMPIInt)n;
-    ierr = MPI_Allgather(&nn,1,MPI_INT,ncolsonproc,1,MPI_INT,mat->comm);CHKERRQ(ierr);
-    nctot = 0; for (j=0; j<size; j++) {nctot += ncolsonproc[j];}
-    if (!nctot) {
-      ierr = PetscInfo(mat,"Coloring of matrix has some unneeded colors with no corresponding rows\n");CHKERRQ(ierr);
-    }
+    if (ctype == IS_COLORING_LOCAL){
+      /* Determine the total (parallel) number of columns of this color */
+      ierr = MPI_Comm_size(mat->comm,&size);CHKERRQ(ierr); 
+      ierr = PetscMalloc(2*size*sizeof(PetscInt*),&ncolsonproc);CHKERRQ(ierr);
+      disp = ncolsonproc + size;
 
-    disp[0] = 0;
-    for (j=1; j<size; j++) {
-      disp[j] = disp[j-1] + ncolsonproc[j-1];
+      nn   = (PetscMPIInt)n;
+      ierr = MPI_Allgather(&nn,1,MPI_INT,ncolsonproc,1,MPI_INT,mat->comm);CHKERRQ(ierr);
+      nctot = 0; for (j=0; j<size; j++) {nctot += ncolsonproc[j];}
+      if (!nctot) {
+        ierr = PetscInfo(mat,"Coloring of matrix has some unneeded colors with no corresponding rows\n");CHKERRQ(ierr);
+      }
+
+      disp[0] = 0;
+      for (j=1; j<size; j++) {
+        disp[j] = disp[j-1] + ncolsonproc[j-1];
+      }
+
+      /* Get complete list of columns for color on each processor */
+      ierr = PetscMalloc((nctot+1)*sizeof(PetscInt),&cols);CHKERRQ(ierr);
+      ierr = MPI_Allgatherv(is,n,MPIU_INT,cols,ncolsonproc,disp,MPIU_INT,mat->comm);CHKERRQ(ierr);
+      ierr = PetscFree(ncolsonproc);CHKERRQ(ierr);
+    } else if (ctype == IS_COLORING_GHOSTED){
+      /* Determine local number of columns of this color on this process, including ghost points */
+      nctot = n;
+      ierr = PetscMalloc((nctot+1)*sizeof(PetscInt),&cols);CHKERRQ(ierr);
+      ierr = PetscMemcpy(cols,is,n*sizeof(PetscInt));CHKERRQ(ierr);
+    } else {
+      SETERRQ(PETSC_ERR_SUP,"Not provided for this MatFDColoring type");
     }
-    
-    /* Get complete list of columns for color on each processor */
-    ierr = PetscMalloc((nctot+1)*sizeof(PetscInt),&cols);CHKERRQ(ierr);
-    ierr = MPI_Allgatherv(is,n,MPIU_INT,cols,ncolsonproc,disp,MPIU_INT,mat->comm);CHKERRQ(ierr);
 
     /*
        Mark all rows affect by these columns
     */
+    /* Temporary option to allow for debugging/testing */
+    ierr = PetscOptionsHasName(PETSC_NULL,"-matfdcoloring_slow",&flg);CHKERRQ(ierr);
     if (!flg) {/*-----------------------------------------------------------------------------*/
       /* crude, fast version */
       ierr = PetscMemzero(rowhit,M*sizeof(PetscInt));CHKERRQ(ierr);
       /* loop over columns*/
       for (j=0; j<nctot; j++) {
-        col  = cols[j];
+        if (ctype == IS_COLORING_GHOSTED) {
+          col = ltog[cols[j]];       
+        } else {
+          col  = cols[j];
+        }
         if (col >= cstart && col < cend) {
           /* column is in diagonal block of matrix */
           rows = A_cj + A_ci[col-cstart]; 
@@ -149,14 +161,18 @@ PetscErrorCode MatFDColoringCreate_MPIAIJ(Mat mat,ISColoring iscoloring,MatFDCol
       nrows     = 0;
       /* loop over columns*/
       for (j=0; j<nctot; j++) {
-        col  = cols[j];
+        if (ctype == IS_COLORING_GHOSTED) {
+          col = ltog[cols[j]];
+        } else {
+          col  = cols[j];
+        }
         if (col >= cstart && col < cend) {
           /* column is in diagonal block of matrix */
           rows = A_cj + A_ci[col-cstart]; 
           m    = A_ci[col-cstart+1] - A_ci[col-cstart];
         } else {
 #if defined (PETSC_USE_CTABLE)
-	  ierr = PetscTableFind(aij->colmap,col+1,&colb);CHKERRQ(ierr);
+          ierr = PetscTableFind(aij->colmap,col+1,&colb);CHKERRQ(ierr);
           colb --;
 #else
           colb = aij->colmap[col] - 1;
@@ -168,6 +184,7 @@ PetscErrorCode MatFDColoringCreate_MPIAIJ(Mat mat,ISColoring iscoloring,MatFDCol
             m    = B_ci[colb+1] - B_ci[colb];
           }
         }
+
         /* loop over columns marking them in rowhit */
         fm    = M; /* fm points to first entry in linked list */
         for (k=0; k<m; k++) {
@@ -211,33 +228,51 @@ PetscErrorCode MatFDColoringCreate_MPIAIJ(Mat mat,ISColoring iscoloring,MatFDCol
   /*
        vscale will contain the "diagonal" on processor scalings followed by the off processor
   */
-  ierr = VecCreateGhost(mat->comm,aij->A->rmap.n,PETSC_DETERMINE,aij->B->cmap.n,aij->garray,&c->vscale);CHKERRQ(ierr)
-  ierr = PetscMalloc(c->ncolors*sizeof(PetscInt*),&c->vscaleforrow);CHKERRQ(ierr);
-  for (k=0; k<c->ncolors; k++) { 
-    ierr = PetscMalloc((c->nrows[k]+1)*sizeof(PetscInt),&c->vscaleforrow[k]);CHKERRQ(ierr);
-    for (l=0; l<c->nrows[k]; l++) {
-      col = c->columnsforrow[k][l];
-      if (col >= cstart && col < cend) {
-        /* column is in diagonal block of matrix */
-        colb = col - cstart;
-      } else {
-        /* column  is in "off-processor" part */
+  if (ctype == IS_COLORING_LOCAL) {
+    ierr = VecCreateGhost(mat->comm,aij->A->rmap.n,PETSC_DETERMINE,aij->B->cmap.n,aij->garray,&c->vscale);CHKERRQ(ierr);
+    ierr = PetscMalloc(c->ncolors*sizeof(PetscInt*),&c->vscaleforrow);CHKERRQ(ierr);
+    for (k=0; k<c->ncolors; k++) { 
+      ierr = PetscMalloc((c->nrows[k]+1)*sizeof(PetscInt),&c->vscaleforrow[k]);CHKERRQ(ierr);
+      for (l=0; l<c->nrows[k]; l++) {
+        col = c->columnsforrow[k][l];
+        if (col >= cstart && col < cend) {
+          /* column is in diagonal block of matrix */
+          colb = col - cstart;
+        } else {
+          /* column  is in "off-processor" part */
 #if defined (PETSC_USE_CTABLE)
-        ierr = PetscTableFind(aij->colmap,col+1,&colb);CHKERRQ(ierr);
-        colb --;
+          ierr = PetscTableFind(aij->colmap,col+1,&colb);CHKERRQ(ierr);
+          colb --;
 #else
-        colb = aij->colmap[col] - 1;
+          colb = aij->colmap[col] - 1;
 #endif
-        colb += cend - cstart;
+          colb += cend - cstart;
+        }
+        c->vscaleforrow[k][l] = colb;
+      }
+    } 
+  } else if (ctype == IS_COLORING_GHOSTED) {
+    /* Get gtol mapping */
+    PetscInt N = mat->cmap.N, *gtol;
+    ierr = PetscMalloc((N+1)*sizeof(PetscInt),&gtol);CHKERRQ(ierr);
+    for (i=0; i<N; i++) gtol[i] = -1;
+    for (i=0; i<map->n; i++) gtol[ltog[i]] = i;
+   
+    c->vscale = 0; /* will be created in MatFDColoringApply() */
+    ierr = PetscMalloc(c->ncolors*sizeof(PetscInt*),&c->vscaleforrow);CHKERRQ(ierr);
+    for (k=0; k<c->ncolors; k++) { 
+      ierr = PetscMalloc((c->nrows[k]+1)*sizeof(PetscInt),&c->vscaleforrow[k]);CHKERRQ(ierr);
+      for (l=0; l<c->nrows[k]; l++) {
+        col = c->columnsforrow[k][l];      /* global column index */
+        c->vscaleforrow[k][l] = gtol[col]; /* local column index */
       }
-      c->vscaleforrow[k][l] = colb;
     }
+    ierr = PetscFree(gtol);CHKERRQ(ierr);
   }
   ierr = ISColoringRestoreIS(iscoloring,&isa);CHKERRQ(ierr);
 
   ierr = PetscFree(rowhit);CHKERRQ(ierr);
   ierr = PetscFree(columnsforrow);CHKERRQ(ierr);
-  ierr = PetscFree(ncolsonproc);CHKERRQ(ierr);
   ierr = MatRestoreColumnIJ_SeqAIJ(aij->A,0,PETSC_FALSE,&ncols,&A_ci,&A_cj,&done);CHKERRQ(ierr); 
   ierr = MatRestoreColumnIJ_SeqAIJ(aij->B,0,PETSC_FALSE,&ncols,&B_ci,&B_cj,&done);CHKERRQ(ierr); 
   PetscFunctionReturn(0);
