@@ -95,6 +95,8 @@ EXTERN_C_END
 #if !defined(PETSC_USE_COMPLEX) && !defined(PETSC_USE_SINGLE) && !defined(PETSC_USE_MAT_SINGLE)
 EXTERN PetscErrorCode MatLUFactorSymbolic_MPIAIJ_TFS(Mat,IS,IS,MatFactorInfo*,Mat*);
 #endif
+EXTERN PetscErrorCode MatSolve_MPIAIJ(Mat,Vec,Vec);
+EXTERN PetscErrorCode MatILUFactor_MPIAIJ(Mat,IS,IS,MatFactorInfo *);
 
 EXTERN_C_BEGIN
 EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatGetDiagonalBlock_MPIAIJ(Mat,PetscTruth *,MatReuse,Mat *);
