@@ -1,4 +1,8 @@
-/*$Id: ilut.c,v 1.7 2001/08/06 21:15:14 bsmith Exp $*/
+#define PETSCMAT_DLL
+
+#include "petsc.h"
+#if !defined(PETSC_AVOID_GNUCOPYRIGHT_CODE)
+
 /* ilut.f -- translated by f2c (version of 25 March 1992  12:58:56).
 
      The Fortran version of this code was developed by Yousef Saad.
@@ -345,18 +349,17 @@ library.  If this is what you want to do, use the GNU Library General
 Public License instead of this License.
 
 */
-#include "petsc.h"
 
-static int SPARSEKIT2qsplit(PetscScalar *a,int *ind,int *n,int *ncut)
+static PetscErrorCode SPARSEKIT2qsplit(PetscScalar *a,PetscInt *ind,PetscInt *n,PetscInt *ncut)
 {
     /* System generated locals */
-    int i__1;
+    PetscInt i__1;
     PetscScalar d__1;
 
     /* Local variables */
-    int last,itmp,j,first;
+    PetscInt last,itmp,j,first;
     PetscReal abskey;
-    int mid;
+    PetscInt mid;
     PetscScalar tmp;
 
 /* -----------------------------------------------------------------------
@@ -433,25 +436,25 @@ L1:
 
 
 /* ---------------------------------------------------------------------- */
-int SPARSEKIT2ilutp(int *n,PetscScalar *a,int *ja,int * ia,int *lfil,PetscReal droptol,PetscReal *permtol,int *mbloc,PetscScalar *alu,
-	int *jlu,int *ju,int *iwk,PetscScalar *w,int *jw,  int *iperm,int *ierr)
+PetscErrorCode SPARSEKIT2ilutp(PetscInt *n,PetscScalar *a,PetscInt *ja,PetscInt * ia,PetscInt *lfil,PetscReal droptol,PetscReal *permtol,PetscInt *mbloc,PetscScalar *alu,
+	PetscInt *jlu,PetscInt *ju,PetscInt *iwk,PetscScalar *w,PetscInt *jw,  PetscInt *iperm,PetscErrorCode *ierr)
 {
     /* System generated locals */
-    int i__1,i__2;
+    PetscInt i__1,i__2;
     PetscScalar d__1;
 
     /* Local variables */
     PetscScalar fact;
-    int lenl,imax,lenu,icut,jpos;
+    PetscInt lenl,imax,lenu,icut,jpos;
     PetscReal xmax;
-    int jrow;
+    PetscInt jrow;
     PetscReal xmax0;
-    int i,j,k;
+    PetscInt i,j,k;
     PetscScalar s,t;
-    int j_1,j2;
+    PetscInt j_1,j2;
     PetscReal tnorm,t1;
-    int ii,jj;
-    int ju0,len;
+    PetscInt ii,jj;
+    PetscInt ju0,len;
     PetscScalar tmp;
 
 /* -----------------------------------------------------------------------
@@ -615,7 +618,7 @@ int SPARSEKIT2ilutp(int *n,PetscScalar *a,int *ja,int * ia,int *lfil,PetscReal d
 	    tnorm += (d__1 = a[k], PetscAbsScalar(d__1));
 /* L501: */
 	}
-	if (tnorm == 0.) {
+	if (!tnorm) {
 	    goto L999;
 	}
 	tnorm /= j2 - j_1 + 1;
@@ -719,7 +722,7 @@ ect */
 
 /*     dealing with upper part. */
 
-		if (jpos == 0) {
+		if (!jpos) {
 
 /*     this is a fill-in element */
 
@@ -739,7 +742,7 @@ ect */
 
 /*     dealing with lower part. */
 
-		if (jpos == 0) {
+		if (!jpos) {
 
 /*     this is a fill-in element */
 
@@ -871,7 +874,7 @@ L160:
 
 /*     store inverse of diagonal element of u */
 
-	if (w[ii] == 0.) {
+	if (w[ii] == 0.0) {
 	    w[ii] = (droptol + 1e-4) * tnorm;
 	}
 	alu[ii] = 1. / w[ii];
@@ -938,4 +941,5 @@ L999:
 /* -----------------------------------------------------------------------
  */
 } /* ilutp_ */
+#endif
 
