@@ -41,7 +41,7 @@ typedef struct {
 
 EXTERN PetscErrorCode MatDuplicate_DSCPACK(Mat,MatDuplicateOption,Mat*);
 EXTERN_C_BEGIN
-EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatConvert_Base_DSCPACK(Mat,const MatType,MatReuse,Mat*);
+EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatConvert_BAIJ_DSCPACK(Mat,const MatType,MatReuse,Mat*);
 EXTERN_C_END
 
 /* DSC function */
@@ -161,8 +161,8 @@ PetscErrorCode  BAIJtoMyANonz( PetscInt *AIndex, PetscInt *AStruct, PetscInt bs,
 
 EXTERN_C_BEGIN
 #undef __FUNCT__
-#define __FUNCT__ "MatConvert_DSCPACK_Base"
-PetscErrorCode PETSCMAT_DLLEXPORT MatConvert_DSCPACK_Base(Mat A,const MatType type,MatReuse reuse,Mat *newmat) 
+#define __FUNCT__ "MatConvert_DSCPACK_BAIJ"
+PetscErrorCode PETSCMAT_DLLEXPORT MatConvert_DSCPACK_BAIJ(Mat A,const MatType type,MatReuse reuse,Mat *newmat) 
 {
   PetscErrorCode ierr;
   Mat            B=*newmat;
@@ -200,7 +200,7 @@ EXTERN_C_END
 #define __FUNCT__ "MatDestroy_DSCPACK"
 PetscErrorCode MatDestroy_DSCPACK(Mat A) 
 {
-  Mat_DSC *lu=(Mat_DSC*)A->spptr;  
+  Mat_DSC        *lu=(Mat_DSC*)A->spptr;  
   PetscErrorCode ierr;
     
   PetscFunctionBegin;
@@ -223,9 +223,9 @@ PetscErrorCode MatDestroy_DSCPACK(Mat A)
     if (lu->size >1 && lu->iden) {ierr = ISDestroy(lu->iden);CHKERRQ(ierr);}
   }
   if (lu->size == 1) {
-    ierr = MatConvert_DSCPACK_Base(A,MATSEQBAIJ,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
+    ierr = MatConvert_DSCPACK_BAIJ(A,MATSEQBAIJ,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
   } else {
-    ierr = MatConvert_DSCPACK_Base(A,MATMPIBAIJ,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
+    ierr = MatConvert_DSCPACK_BAIJ(A,MATMPIBAIJ,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
   }
   ierr = (*A->ops->destroy)(A);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -431,8 +431,10 @@ PetscErrorCode MatCholeskyFactorNumeric_DSCPACK(Mat A,MatFactorInfo *info,Mat *F
     ierr = PetscFree(my_a_nonz);CHKERRQ(ierr);
   }  
   
-  F_diag = ((Mat_MPIBAIJ *)(*F)->data)->A;
-  F_diag->assembled = PETSC_TRUE;
+  if (size > 1) {
+    F_diag = ((Mat_MPIBAIJ *)(*F)->data)->A;
+    F_diag->assembled = PETSC_TRUE;
+  }
   (*F)->assembled   = PETSC_TRUE; 
   lu->flg           = SAME_NONZERO_PATTERN;
 
@@ -461,7 +463,7 @@ PetscErrorCode MatCholeskyFactorSymbolic_DSCPACK(Mat A,IS r,MatFactorInfo *info,
   ierr = MatMPIBAIJSetPreallocation(B,bs,0,PETSC_NULL,0,PETSC_NULL);CHKERRQ(ierr);
     
   lu = (Mat_DSC*)B->spptr;
-  B->bs = bs;
+  B->rmap.bs = bs;
 
   B->ops->choleskyfactornumeric  = MatCholeskyFactorNumeric_DSCPACK;
   B->ops->solve                  = MatSolve_DSCPACK;
@@ -562,7 +564,7 @@ PetscErrorCode MatFactorInfo_DSCPACK(Mat A,PetscViewer viewer)
 {
   Mat_DSC *lu=(Mat_DSC*)A->spptr;  
   PetscErrorCode ierr;
-  char    *s=0;
+  const char    *s=0;
   
   PetscFunctionBegin;   
   ierr = PetscViewerASCIIPrintf(viewer,"DSCPACK run parameters:\n");CHKERRQ(ierr);
@@ -590,6 +592,8 @@ PetscErrorCode MatFactorInfo_DSCPACK(Mat A,PetscViewer viewer)
     s = "LLT";
   } else if ( lu->factor_type == DSC_LDLT){
     s = "LDLT";
+  } else if (lu->factor_type == 0) {
+    s = "None";
   } else {
     SETERRQ(PETSC_ERR_PLIB,"Unknown factor type");
   }
@@ -601,6 +605,8 @@ PetscErrorCode MatFactorInfo_DSCPACK(Mat A,PetscViewer viewer)
     s = "BLAS2";
   } else if ( lu->LBLASLevel == DSC_LBLAS3){
     s = "BLAS3";
+  } else if (lu->LBLASLevel == 0) {
+    s = "None";
   } else {
     SETERRQ(PETSC_ERR_PLIB,"Unknown local phase BLAS level");
   }
@@ -610,6 +616,8 @@ PetscErrorCode MatFactorInfo_DSCPACK(Mat A,PetscViewer viewer)
     s = "BLAS1";
   } else if ( lu->DBLASLevel == DSC_DBLAS2){
     s = "BLAS2";
+  } else if (lu->DBLASLevel == 0) {
+    s = "None";
   } else {
     SETERRQ(PETSC_ERR_PLIB,"Unknown distributed phase BLAS level");
   }
@@ -617,6 +625,10 @@ PetscErrorCode MatFactorInfo_DSCPACK(Mat A,PetscViewer viewer)
   PetscFunctionReturn(0);
 }
 
+EXTERN PetscErrorCode MatView_SeqBAIJ(Mat,PetscViewer);
+EXTERN PetscErrorCode MatView_MPIBAIJ(Mat,PetscViewer);
+
+
 #undef __FUNCT__
 #define __FUNCT__ "MatView_DSCPACK"
 PetscErrorCode MatView_DSCPACK(Mat A,PetscViewer viewer) {
@@ -627,22 +639,22 @@ PetscErrorCode MatView_DSCPACK(Mat A,PetscViewer viewer) {
   Mat_DSC           *lu=(Mat_DSC*)A->spptr;
 
   PetscFunctionBegin;
+  /* Cannot view factored matrix */
+  if (A->factor) {
+    PetscFunctionReturn(0);
+  }
   /* This convertion ugliness is because MatView for BAIJ types calls MatConvert to AIJ */ 
   size = lu->size;
   if (size==1) {
-    ierr = MatConvert(A,MATSEQBAIJ,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
+    ierr = MatView_SeqBAIJ(A,viewer);CHKERRQ(ierr);
   } else {
-    ierr = MatConvert(A,MATMPIBAIJ,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
+    ierr = MatView_MPIBAIJ(A,viewer);CHKERRQ(ierr);
   }    
 
-  ierr = MatView(A,viewer);CHKERRQ(ierr);
-
-  ierr = MatConvert(A,MATDSCPACK,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
-
   ierr = PetscTypeCompare((PetscObject)viewer,PETSC_VIEWER_ASCII,&iascii);CHKERRQ(ierr);
   if (iascii) {
     ierr = PetscViewerGetFormat(viewer,&format);CHKERRQ(ierr);
-    if (format == PETSC_VIEWER_ASCII_FACTOR_INFO) {
+    if (format == PETSC_VIEWER_ASCII_INFO) {
       ierr = MatFactorInfo_DSCPACK(A,viewer);CHKERRQ(ierr);
     }
   }
@@ -668,15 +680,15 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatMPIBAIJSetPreallocation_MPIDSCPACK(Mat  B,P
   */
   ierr = (*lu->MatPreallocate)(B,bs,d_nz,d_nnz,o_nz,o_nnz);
   A    = ((Mat_MPIBAIJ *)B->data)->A;
-  ierr = MatConvert_Base_DSCPACK(A,MATDSCPACK,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
+  ierr = MatConvert_BAIJ_DSCPACK(A,MATDSCPACK,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 EXTERN_C_END
 
 EXTERN_C_BEGIN
 #undef __FUNCT__
-#define __FUNCT__ "MatConvert_Base_DSCPACK"
-PetscErrorCode PETSCMAT_DLLEXPORT MatConvert_Base_DSCPACK(Mat A,const MatType type,MatReuse reuse,Mat *newmat) 
+#define __FUNCT__ "MatConvert_BAIJ_DSCPACK"
+PetscErrorCode PETSCMAT_DLLEXPORT MatConvert_BAIJ_DSCPACK(Mat A,const MatType type,MatReuse reuse,Mat *newmat) 
 {
   /* This routine is only called to convert to MATDSCPACK */
   /* from MATSEQBAIJ if A has a single process communicator */
@@ -701,7 +713,10 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatConvert_Base_DSCPACK(Mat A,const MatType ty
   lu->MatCholeskyFactorSymbolic  = A->ops->choleskyfactorsymbolic;
   lu->MatDestroy                 = A->ops->destroy;
   lu->CleanUpDSCPACK             = PETSC_FALSE;
-  lu->bs                         = A->bs;
+  lu->bs                         = A->rmap.bs;
+  lu->factor_type                = 0;
+  lu->LBLASLevel                 = 0;
+  lu->DBLASLevel                 = 0;
 
   B->spptr                       = (void*)lu;
   B->ops->duplicate              = MatDuplicate_DSCPACK;
@@ -713,9 +728,9 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatConvert_Base_DSCPACK(Mat A,const MatType ty
   ierr = MPI_Comm_size(comm,&(lu->size));CHKERRQ(ierr);CHKERRQ(ierr);
   if (lu->size == 1) {
     ierr = PetscObjectComposeFunctionDynamic((PetscObject)B,"MatConvert_seqbaij_dscpack_C",
-                                             "MatConvert_Base_DSCPACK",MatConvert_Base_DSCPACK);CHKERRQ(ierr);
+                                             "MatConvert_BAIJ_DSCPACK",MatConvert_BAIJ_DSCPACK);CHKERRQ(ierr);
     ierr = PetscObjectComposeFunctionDynamic((PetscObject)B,"MatConvert_dscpack_seqbaij_C",
-                                             "MatConvert_DSCPACK_Base",MatConvert_DSCPACK_Base);CHKERRQ(ierr);
+                                             "MatConvert_DSCPACK_BAIJ",MatConvert_DSCPACK_BAIJ);CHKERRQ(ierr);
   } else {
       /* I really don't like needing to know the tag: MatMPIBAIJSetPreallocation_C */
     ierr = PetscObjectQueryFunction((PetscObject)B,"MatMPIBAIJSetPreallocation_C",&f);CHKERRQ(ierr);
@@ -726,9 +741,9 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatConvert_Base_DSCPACK(Mat A,const MatType ty
                                                MatMPIBAIJSetPreallocation_MPIDSCPACK);CHKERRQ(ierr);
     }
     ierr = PetscObjectComposeFunctionDynamic((PetscObject)B,"MatConvert_mpibaij_dscpack_C",
-                                             "MatConvert_Base_DSCPACK",MatConvert_Base_DSCPACK);CHKERRQ(ierr);
+                                             "MatConvert_BAIJ_DSCPACK",MatConvert_BAIJ_DSCPACK);CHKERRQ(ierr);
     ierr = PetscObjectComposeFunctionDynamic((PetscObject)B,"MatConvert_dscpack_mpibaij_C",
-                                             "MatConvert_DSCPACK_Base",MatConvert_DSCPACK_Base);CHKERRQ(ierr);
+                                             "MatConvert_DSCPACK_BAIJ",MatConvert_DSCPACK_BAIJ);CHKERRQ(ierr);
   }
   ierr = PetscObjectChangeTypeName((PetscObject)B,MATDSCPACK);CHKERRQ(ierr);
   *newmat = B;
@@ -789,16 +804,13 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_DSCPACK(Mat A)
   PetscMPIInt    size;
 
   PetscFunctionBegin;
-  /* Change type name before calling MatSetType to force proper construction of SeqBAIJ or MPIBAIJ */
-  /*   and DSCPACK types */
-  ierr = PetscObjectChangeTypeName((PetscObject)A,MATDSCPACK);CHKERRQ(ierr);
   ierr = MPI_Comm_size(A->comm,&size);CHKERRQ(ierr);CHKERRQ(ierr);
   if (size == 1) {
     ierr = MatSetType(A,MATSEQBAIJ);CHKERRQ(ierr);
   } else {
     ierr = MatSetType(A,MATMPIBAIJ);CHKERRQ(ierr);
   }
-  ierr = MatConvert_Base_DSCPACK(A,MATDSCPACK,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
+  ierr = MatConvert_BAIJ_DSCPACK(A,MATDSCPACK,MAT_REUSE_MATRIX,&A);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 EXTERN_C_END
