@@ -599,7 +599,7 @@ void PETSCMAT_DLLEXPORT matsetvaluesblocked4_(Mat *AA,PetscInt *mm,const PetscIn
       col = in[l]; 
       if (col <= lastcol) low = 0; else high = nrow;
       lastcol = col;
-      value = v + k*(stepval+4)*4 + l*4;
+      value = v + k*(stepval+4 + l)*4;
       while (high-low > 7) {
         t = (low+high)/2;
         if (rp[t] > col) high = t;
@@ -753,23 +753,21 @@ PetscErrorCode MatMarkDiagonal_SeqBAIJ(Mat A)
 {
   Mat_SeqBAIJ    *a = (Mat_SeqBAIJ*)A->data; 
   PetscErrorCode ierr;
-  PetscInt       i,j,*diag,m = a->mbs;
+  PetscInt       i,j,m = a->mbs;
 
   PetscFunctionBegin;
-  if (a->diag) PetscFunctionReturn(0);
-
-  ierr = PetscMalloc((m+1)*sizeof(PetscInt),&diag);CHKERRQ(ierr);
-  ierr = PetscLogObjectMemory(A,(m+1)*sizeof(PetscInt));CHKERRQ(ierr);
+  if (!a->diag) {
+    ierr = PetscMalloc(m*sizeof(PetscInt),&a->diag);CHKERRQ(ierr);
+  }
   for (i=0; i<m; i++) {
-    diag[i] = a->i[i+1];
+    a->diag[i] = a->i[i+1];
     for (j=a->i[i]; j<a->i[i+1]; j++) {
       if (a->j[j] == i) {
-        diag[i] = j;
+        a->diag[i] = j;
         break;
       }
     }
   }
-  a->diag = diag;
   PetscFunctionReturn(0);
 }
 
@@ -834,7 +832,7 @@ PetscErrorCode MatDestroy_SeqBAIJ(Mat A)
 #if defined(PETSC_USE_LOG)
   PetscLogObjectState((PetscObject)A,"Rows=%D, Cols=%D, NZ=%D",A->rmap.N,A->cmap.n,a->nz);
 #endif
-  ierr = MatSeqXAIJFreeAIJ(a->singlemalloc,&a->a,&a->j,&a->i);CHKERRQ(ierr);
+  ierr = MatSeqXAIJFreeAIJ(A,&a->a,&a->j,&a->i);CHKERRQ(ierr);
   if (a->row) {
     ierr = ISDestroy(a->row);CHKERRQ(ierr);
   }
@@ -856,6 +854,7 @@ PetscErrorCode MatDestroy_SeqBAIJ(Mat A)
 
   ierr = PetscFree(a);CHKERRQ(ierr);
 
+  ierr = PetscObjectChangeTypeName((PetscObject)A,0);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)A,"MatSeqBAIJInvertBlockDiagonal_C","",PETSC_NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)A,"MatStoreValues_C","",PETSC_NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)A,"MatRetrieveValues_C","",PETSC_NULL);CHKERRQ(ierr);
@@ -907,7 +906,7 @@ PetscErrorCode MatSetOption_SeqBAIJ(Mat A,MatOption op)
   case MAT_YES_NEW_DIAGONALS:
   case MAT_IGNORE_OFF_PROC_ENTRIES:
   case MAT_USE_HASH_TABLE:
-    ierr = PetscInfo(A,"Option ignored\n");CHKERRQ(ierr);
+    ierr = PetscInfo1(A,"Option %d ignored\n",op);CHKERRQ(ierr);
     break;
   case MAT_NO_NEW_DIAGONALS:
     SETERRQ(PETSC_ERR_SUP,"MAT_NO_NEW_DIAGONALS");
@@ -921,7 +920,7 @@ PetscErrorCode MatSetOption_SeqBAIJ(Mat A,MatOption op)
   case MAT_NOT_SYMMETRY_ETERNAL:
     break;
   default:
-    SETERRQ(PETSC_ERR_SUP,"unknown option");
+    SETERRQ1(PETSC_ERR_SUP,"unknown option %d",op);
   }
   PetscFunctionReturn(0);
 }
@@ -1466,7 +1465,7 @@ PetscErrorCode MatSetValuesBlocked_SeqBAIJ_MatScalar(Mat A,PetscInt m,const Pets
       } 
       if (nonew == 1) goto noinsert2;
       if (nonew == -1) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Inserting a new nonzero (%D, %D) in the matrix", row, col);
-      MatSeqXAIJReallocateAIJ(a,bs2,nrow,row,col,rmax,aa,ai,aj,a->mbs,rp,ap,imax,nonew);
+      MatSeqXAIJReallocateAIJ(A,a->mbs,bs2,nrow,row,col,rmax,aa,ai,aj,rp,ap,imax,nonew);
       N = nrow++ - 1; high++;
       /* shift up all the later entries in this row */
       for (ii=N; ii>=i; ii--) {
@@ -1728,7 +1727,7 @@ PetscErrorCode MatSetValues_SeqBAIJ(Mat A,PetscInt m,const PetscInt im[],PetscIn
       } 
       if (nonew == 1) goto noinsert1;
       if (nonew == -1) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Inserting a new nonzero (%D, %D) in the matrix", row, col);
-      MatSeqXAIJReallocateAIJ(a,bs2,nrow,brow,bcol,rmax,aa,ai,aj,a->mbs,rp,ap,imax,nonew);
+      MatSeqXAIJReallocateAIJ(A,a->mbs,bs2,nrow,brow,bcol,rmax,aa,ai,aj,rp,ap,imax,nonew);
       N = nrow++ - 1; high++;
       /* shift up all the later entries in this row */
       for (ii=N; ii>=i; ii--) {
@@ -1771,9 +1770,7 @@ PetscErrorCode MatILUFactor_SeqBAIJ(Mat inA,IS row,IS col,MatFactorInfo *info)
   outA          = inA; 
   inA->factor   = FACTOR_LU;
 
-  if (!a->diag) {
-    ierr = MatMarkDiagonal_SeqBAIJ(inA);CHKERRQ(ierr);
-  }
+  ierr = MatMarkDiagonal_SeqBAIJ(inA);CHKERRQ(ierr);
 
   a->row        = row;
   a->col        = col;
@@ -1801,20 +1798,6 @@ PetscErrorCode MatILUFactor_SeqBAIJ(Mat inA,IS row,IS col,MatFactorInfo *info)
 
   PetscFunctionReturn(0);
 }
-#undef __FUNCT__  
-#define __FUNCT__ "MatPrintHelp_SeqBAIJ"
-PetscErrorCode MatPrintHelp_SeqBAIJ(Mat A)
-{
-  static PetscTruth called = PETSC_FALSE; 
-  MPI_Comm          comm = A->comm;
-  PetscErrorCode    ierr;
-
-  PetscFunctionBegin;
-  if (called) {PetscFunctionReturn(0);} else called = PETSC_TRUE;
-  ierr = (*PetscHelpPrintf)(comm," Options for MATSEQBAIJ and MATMPIBAIJ matrix formats (the defaults):\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"  -mat_block_size <block_size>\n");CHKERRQ(ierr);
-  PetscFunctionReturn(0);
-}
 
 EXTERN_C_BEGIN
 #undef __FUNCT__  
@@ -2084,7 +2067,7 @@ static struct _MatOps MatOps_Values = {MatSetValues_SeqBAIJ,
        MatIncreaseOverlap_SeqBAIJ,
        MatGetValues_SeqBAIJ,
        MatCopy_SeqBAIJ,
-/*45*/ MatPrintHelp_SeqBAIJ,
+/*45*/ 0,
        MatScale_SeqBAIJ,
        0,
        0,
@@ -2218,7 +2201,11 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatSeqBAIJSetPreallocation_SeqBAIJ(Mat B,Petsc
     skipallocation = PETSC_TRUE;
     nz             = 0;
   }
-  ierr = PetscOptionsGetInt(B->prefix,"-mat_block_size",&newbs,PETSC_NULL);CHKERRQ(ierr);
+
+  ierr = PetscOptionsBegin(B->comm,B->prefix,"Options for SEQBAIJ matrix","Mat");CHKERRQ(ierr);
+    ierr = PetscOptionsInt("-mat_block_size","Set the blocksize used to store the matrix","MatSeqBAIJSetPreallocation",bs,&newbs,PETSC_NULL);CHKERRQ(ierr);
+  ierr = PetscOptionsEnd();CHKERRQ(ierr);
+
   if (nnz && newbs != bs) {
     SETERRQ(PETSC_ERR_ARG_WRONG,"Cannot change blocksize from command line if setting nnz");
   }
@@ -2248,7 +2235,10 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatSeqBAIJSetPreallocation_SeqBAIJ(Mat B,Petsc
   }
 
   b       = (Mat_SeqBAIJ*)B->data;
-  ierr    = PetscOptionsHasName(PETSC_NULL,"-mat_no_unroll",&flg);CHKERRQ(ierr);
+  ierr = PetscOptionsBegin(B->comm,PETSC_NULL,"Options for SEQBAIJ matrix","Mat");CHKERRQ(ierr);
+    ierr = PetscOptionsTruth("-mat_no_unroll","Do not optimize for block size (slow)",PETSC_NULL,PETSC_FALSE,&flg,PETSC_NULL);CHKERRQ(ierr);
+  ierr = PetscOptionsEnd();CHKERRQ(ierr);
+
   B->ops->solve               = MatSolve_SeqBAIJ_Update;
   B->ops->solvetranspose      = MatSolveTranspose_SeqBAIJ_Update;
   if (!flg) {
@@ -2326,6 +2316,11 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatSeqBAIJSetPreallocation_SeqBAIJ(Mat B,Petsc
     for (i=1; i<mbs+1; i++) {
       b->i[i] = b->i[i-1] + b->imax[i-1];
     }
+    b->free_a     = PETSC_TRUE;
+    b->free_ij    = PETSC_TRUE;
+  } else {
+    b->free_a     = PETSC_FALSE;
+    b->free_ij    = PETSC_FALSE;
   }
 
   B->rmap.bs          = bs;
@@ -2417,6 +2412,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_SeqBAIJ(Mat B)
   ierr = PetscObjectComposeFunctionDynamic((PetscObject)B,"MatSeqBAIJSetPreallocation_C",
                                      "MatSeqBAIJSetPreallocation_SeqBAIJ",
                                       MatSeqBAIJSetPreallocation_SeqBAIJ);CHKERRQ(ierr);
+  ierr = PetscObjectChangeTypeName((PetscObject)B,MATSEQBAIJ);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 EXTERN_C_END
@@ -2480,6 +2476,8 @@ PetscErrorCode MatDuplicate_SeqBAIJ(Mat A,MatDuplicateOption cpvalues,Mat *B)
   c->maxnz              = a->maxnz;
   c->solve_work         = 0;
   c->mult_work          = 0;
+  c->free_a             = PETSC_TRUE;
+  c->free_ij            = PETSC_TRUE;
   C->preallocated       = PETSC_TRUE;
   C->assembled          = PETSC_TRUE;
 
@@ -2520,7 +2518,9 @@ PetscErrorCode MatLoad_SeqBAIJ(PetscViewer viewer, MatType type,Mat *A)
   MPI_Comm       comm = ((PetscObject)viewer)->comm;
 
   PetscFunctionBegin;
-  ierr = PetscOptionsGetInt(PETSC_NULL,"-matload_block_size",&bs,PETSC_NULL);CHKERRQ(ierr);
+  ierr = PetscOptionsBegin(comm,PETSC_NULL,"Options for loading SEQBAIJ matrix","Mat");CHKERRQ(ierr);
+    ierr = PetscOptionsInt("-matload_block_size","Set the blocksize used to store the matrix","MatLoad",bs,&bs,PETSC_NULL);CHKERRQ(ierr);
+  ierr = PetscOptionsEnd();CHKERRQ(ierr);
   bs2  = bs*bs;
 
   ierr = MPI_Comm_size(comm,&size);CHKERRQ(ierr);
@@ -2764,3 +2764,78 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatSeqBAIJSetPreallocation(Mat B,PetscInt bs,P
   PetscFunctionReturn(0);
 }
 
+#undef __FUNCT__  
+#define __FUNCT__ "MatCreateSeqBAIJWithArrays"
+/*@
+     MatCreateSeqBAIJWithArrays - Creates an sequential BAIJ matrix using matrix elements 
+              (upper triangular entries in CSR format) provided by the user.
+
+     Collective on MPI_Comm
+
+   Input Parameters:
++  comm - must be an MPI communicator of size 1
+.  bs - size of block
+.  m - number of rows
+.  n - number of columns
+.  i - row indices
+.  j - column indices
+-  a - matrix values
+
+   Output Parameter:
+.  mat - the matrix
+
+   Level: intermediate
+
+   Notes:
+       The i, j, and a arrays are not copied by this routine, the user must free these arrays
+    once the matrix is destroyed
+
+       You cannot set new nonzero locations into this matrix, that will generate an error.
+
+       The i and j indices are 0 based
+
+.seealso: MatCreate(), MatCreateMPIBAIJ(), MatCreateSeqBAIJ()
+
+@*/
+PetscErrorCode PETSCMAT_DLLEXPORT MatCreateSeqBAIJWithArrays(MPI_Comm comm,PetscInt bs,PetscInt m,PetscInt n,PetscInt* i,PetscInt*j,PetscScalar *a,Mat *mat)
+{
+  PetscErrorCode ierr;
+  PetscInt       ii;
+  Mat_SeqBAIJ    *baij;
+
+  PetscFunctionBegin;
+  if (bs != 1) SETERRQ1(PETSC_ERR_SUP,"block size %D > 1 is not supported yet",bs);
+  if (i[0]) SETERRQ(PETSC_ERR_ARG_OUTOFRANGE,"i (row indices) must start with 0");
+  
+  ierr = MatCreate(comm,mat);CHKERRQ(ierr);
+  ierr = MatSetSizes(*mat,m,n,m,n);CHKERRQ(ierr);
+  ierr = MatSetType(*mat,MATSEQBAIJ);CHKERRQ(ierr);
+  ierr = MatSeqBAIJSetPreallocation_SeqBAIJ(*mat,bs,MAT_SKIP_ALLOCATION,0);CHKERRQ(ierr);
+  baij = (Mat_SeqBAIJ*)(*mat)->data;
+  ierr = PetscMalloc2(m,PetscInt,&baij->imax,m,PetscInt,&baij->ilen);CHKERRQ(ierr);
+
+  baij->i = i;
+  baij->j = j;
+  baij->a = a;
+  baij->singlemalloc = PETSC_FALSE;
+  baij->nonew        = -1;             /*this indicates that inserting a new value in the matrix that generates a new nonzero is an error*/
+  baij->free_a       = PETSC_FALSE; 
+  baij->free_ij       = PETSC_FALSE; 
+
+  for (ii=0; ii<m; ii++) {
+    baij->ilen[ii] = baij->imax[ii] = i[ii+1] - i[ii];
+#if defined(PETSC_USE_DEBUG)
+    if (i[ii+1] - i[ii] < 0) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Negative row length in i (row indices) row = %d length = %d",ii,i[ii+1] - i[ii]);
+#endif    
+  }
+#if defined(PETSC_USE_DEBUG)
+  for (ii=0; ii<baij->i[m]; ii++) {
+    if (j[ii] < 0) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Negative column index at location = %d index = %d",ii,j[ii]);
+    if (j[ii] > n - 1) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Column index to large at location = %d index = %d",ii,j[ii]);
+  }
+#endif    
+
+  ierr = MatAssemblyBegin(*mat,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  ierr = MatAssemblyEnd(*mat,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
