@@ -1,4 +1,5 @@
-/*$Id: baijfact14.c,v 1.4 2001/03/23 23:22:07 balay Exp $*/
+#define PETSCMAT_DLL
+
 /*
     Factorization code for BAIJ format. 
 */
@@ -9,17 +10,18 @@
 */
 #undef __FUNCT__  
 #define __FUNCT__ "MatLUFactorNumeric_SeqBAIJ_3_NaturalOrdering"
-int MatLUFactorNumeric_SeqBAIJ_3_NaturalOrdering(Mat A,Mat *B)
+PetscErrorCode MatLUFactorNumeric_SeqBAIJ_3_NaturalOrdering(Mat A,MatFactorInfo *info,Mat *B)
 {
-  Mat                C = *B;
-  Mat_SeqBAIJ        *a = (Mat_SeqBAIJ*)A->data,*b = (Mat_SeqBAIJ *)C->data;
-  int                ierr,i,j,n = a->mbs,*bi = b->i,*bj = b->j;
-  int                *ajtmpold,*ajtmp,nz,row;
-  int                *diag_offset = b->diag,*ai=a->i,*aj=a->j,*pj;
-  MatScalar          *pv,*v,*rtmp,*pc,*w,*x;
-  MatScalar          p1,p2,p3,p4,m1,m2,m3,m4,m5,m6,m7,m8,m9,x1,x2,x3,x4;
-  MatScalar          p5,p6,p7,p8,p9,x5,x6,x7,x8,x9;
-  MatScalar          *ba = b->a,*aa = a->a;
+  Mat            C = *B;
+  Mat_SeqBAIJ    *a = (Mat_SeqBAIJ*)A->data,*b = (Mat_SeqBAIJ *)C->data;
+  PetscErrorCode ierr;
+  PetscInt       i,j,n = a->mbs,*bi = b->i,*bj = b->j;
+  PetscInt       *ajtmpold,*ajtmp,nz,row;
+  PetscInt       *diag_offset = b->diag,*ai=a->i,*aj=a->j,*pj;
+  MatScalar      *pv,*v,*rtmp,*pc,*w,*x;
+  MatScalar      p1,p2,p3,p4,m1,m2,m3,m4,m5,m6,m7,m8,m9,x1,x2,x3,x4;
+  MatScalar      p5,p6,p7,p8,p9,x5,x6,x7,x8,x9;
+  MatScalar      *ba = b->a,*aa = a->a;
 
   PetscFunctionBegin;
   ierr = PetscMalloc(9*(n+1)*sizeof(MatScalar),&rtmp);CHKERRQ(ierr);
@@ -83,7 +85,7 @@ int MatLUFactorNumeric_SeqBAIJ_3_NaturalOrdering(Mat A,Mat *B)
           x[8] -= m3*x7 + m6*x8 + m9*x9;
           pv   += 9;
         }
-        PetscLogFlops(54*nz+36);
+        ierr = PetscLogFlops(54*nz+36);CHKERRQ(ierr);
       } 
       row = *ajtmp++;
     }
@@ -105,6 +107,6 @@ int MatLUFactorNumeric_SeqBAIJ_3_NaturalOrdering(Mat A,Mat *B)
   ierr = PetscFree(rtmp);CHKERRQ(ierr);
   C->factor    = FACTOR_LU;
   C->assembled = PETSC_TRUE;
-  PetscLogFlops(1.3333*27*b->mbs); /* from inverting diagonal blocks */
+  ierr = PetscLogFlops(1.3333*27*b->mbs);CHKERRQ(ierr); /* from inverting diagonal blocks */
   PetscFunctionReturn(0);
 }
