@@ -423,6 +423,8 @@ PetscErrorCode MatDestroy_MPIBDiag(Mat mat)
   if (mbd->lvec) {ierr = VecDestroy(mbd->lvec);CHKERRQ(ierr);}
   if (mbd->Mvctx) {ierr = VecScatterDestroy(mbd->Mvctx);CHKERRQ(ierr);}
   ierr = PetscFree(mbd);CHKERRQ(ierr);
+
+  ierr = PetscObjectChangeTypeName((PetscObject)mat,0);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)mat,"MatGetDiagonalBlock_C","",PETSC_NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)mat,"MatMPIBDiagSetPreallocation_C","",PETSC_NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -588,7 +590,7 @@ PetscErrorCode MatSetOption_MPIBDiag(Mat A,MatOption op)
   case MAT_ROWS_UNSORTED:
   case MAT_COLUMNS_SORTED:
   case MAT_COLUMNS_UNSORTED:
-    ierr = PetscInfo(A,"Option ignored\n");CHKERRQ(ierr);
+    ierr = PetscInfo1(A,"Option %d ignored\n",op);CHKERRQ(ierr);
     break;
   case MAT_SYMMETRIC:
   case MAT_STRUCTURALLY_SYMMETRIC:
@@ -600,7 +602,7 @@ PetscErrorCode MatSetOption_MPIBDiag(Mat A,MatOption op)
   case MAT_NOT_SYMMETRY_ETERNAL:
     break;
   default:
-    SETERRQ(PETSC_ERR_SUP,"unknown option");
+    SETERRQ1(PETSC_ERR_SUP,"unknown option %d",op);
   }
   PetscFunctionReturn(0);
 }
@@ -684,20 +686,6 @@ PetscErrorCode MatNorm_MPIBDiag(Mat A,NormType type,PetscReal *nrm)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__  
-#define __FUNCT__ "MatPrintHelp_MPIBDiag"
-PetscErrorCode MatPrintHelp_MPIBDiag(Mat A)
-{
-  Mat_MPIBDiag   *a = (Mat_MPIBDiag*)A->data;
-  PetscErrorCode ierr;
-
-  PetscFunctionBegin;
-  if (!a->rank) {
-    ierr = MatPrintHelp_SeqBDiag(a->A);CHKERRQ(ierr);
-  }
-  PetscFunctionReturn(0);
-}
-
 #undef __FUNCT__  
 #define __FUNCT__ "MatScale_MPIBDiag"
 PetscErrorCode MatScale_MPIBDiag(Mat A,PetscScalar alpha)
@@ -768,7 +756,7 @@ static struct _MatOps MatOps_Values = {MatSetValues_MPIBDiag,
        0,
        MatGetValues_MPIBDiag,
        0,
-/*45*/ MatPrintHelp_MPIBDiag,
+/*45*/ 0,
        MatScale_MPIBDiag,
        0,
        0,
@@ -988,6 +976,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_MPIBDiag(Mat B)
   ierr = PetscObjectComposeFunctionDynamic((PetscObject)B,"MatMPIBDiagSetPreallocation_C",
                                      "MatMPIBDiagSetPreallocation_MPIBDiag",
                                       MatMPIBDiagSetPreallocation_MPIBDiag);CHKERRQ(ierr);
+  ierr = PetscObjectChangeTypeName((PetscObject)B,MATMPIBDIAG);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 EXTERN_C_END
@@ -1015,7 +1004,6 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_BDiag(Mat A)
   PetscMPIInt   size;
 
   PetscFunctionBegin;
-  ierr = PetscObjectChangeTypeName((PetscObject)A,MATBDIAG);CHKERRQ(ierr);
   ierr = MPI_Comm_size(A->comm,&size);CHKERRQ(ierr);
   if (size == 1) {
     ierr = MatSetType(A,MATSEQBDIAG);CHKERRQ(ierr);
