@@ -34,6 +34,8 @@ PetscErrorCode MatDestroy_SeqBDiag(Mat A)
   ierr = PetscFree(a->dvalue);CHKERRQ(ierr);
   ierr = PetscFree(a->solvework);CHKERRQ(ierr);
   ierr = PetscFree(a);CHKERRQ(ierr);
+
+  ierr = PetscObjectChangeTypeName((PetscObject)A,0);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)A,"MatSeqBDiagSetPreallocation_C","",PETSC_NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -110,7 +112,7 @@ PetscErrorCode MatSetOption_SeqBDiag(Mat A,MatOption op)
   case MAT_NEW_NONZERO_LOCATION_ERR:
   case MAT_NEW_NONZERO_ALLOCATION_ERR:
   case MAT_USE_HASH_TABLE:
-    ierr = PetscInfo(A,"Option ignored\n");CHKERRQ(ierr);
+    ierr = PetscInfo1(A,"Option %d ignored\n",op);CHKERRQ(ierr);
     break;
   case MAT_SYMMETRIC:
   case MAT_STRUCTURALLY_SYMMETRIC:
@@ -122,28 +124,11 @@ PetscErrorCode MatSetOption_SeqBDiag(Mat A,MatOption op)
   case MAT_NOT_SYMMETRY_ETERNAL:
     break;
   default:
-    SETERRQ(PETSC_ERR_SUP,"unknown option");
+    SETERRQ1(PETSC_ERR_SUP,"unknown option %d",op);
   }
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__  
-#define __FUNCT__ "MatPrintHelp_SeqBDiag"
-PetscErrorCode MatPrintHelp_SeqBDiag(Mat A)
-{
-  static PetscTruth called = PETSC_FALSE; 
-  MPI_Comm          comm = A->comm;
-  PetscErrorCode    ierr;
-
-  PetscFunctionBegin;
-  if (called) {PetscFunctionReturn(0);} else called = PETSC_TRUE;
-  ierr = (*PetscHelpPrintf)(comm," Options for MATSEQBDIAG and MATMPIBDIAG matrix formats:\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"  -mat_block_size <block_size>\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"  -mat_bdiag_diags <d1,d2,d3,...> (diagonal numbers)\n");CHKERRQ(ierr); 
-  ierr = (*PetscHelpPrintf)(comm,"   (for example) -mat_bdiag_diags -5,-1,0,1,5\n");CHKERRQ(ierr);
-  PetscFunctionReturn(0);
-}
-
 #undef __FUNCT__  
 #define __FUNCT__ "MatGetDiagonal_SeqBDiag_N"
 static PetscErrorCode MatGetDiagonal_SeqBDiag_N(Mat A,Vec v)
@@ -446,7 +431,7 @@ static struct _MatOps MatOps_Values = {MatSetValues_SeqBDiag_N,
        0,
        MatGetValues_SeqBDiag_N,
        0,
-/*45*/ MatPrintHelp_SeqBDiag,
+/*45*/ 0,
        MatScale_SeqBDiag,
        0,
        0,
@@ -838,6 +823,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_SeqBDiag(Mat B)
                                     "MatSeqBDiagSetPreallocation_SeqBDiag",
                                      MatSeqBDiagSetPreallocation_SeqBDiag);CHKERRQ(ierr);
 
+  ierr = PetscObjectChangeTypeName((PetscObject)B,MATSEQBDIAG);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 EXTERN_C_END
