@@ -571,8 +571,12 @@ PetscErrorCode MatDestroy_MPIDense(Mat mat)
     ierr = PetscFree(mdn->factor);CHKERRQ(ierr);
   }
   ierr = PetscFree(mdn);CHKERRQ(ierr);
+  ierr = PetscObjectChangeTypeName((PetscObject)mat,0);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunctionDynamic((PetscObject)mat,"MatGetDiagonalBlock_C","",PETSC_NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunctionDynamic((PetscObject)mat,"MatMPIDenseSetPreallocation_C","",PETSC_NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)mat,"MatMatMult_mpiaij_mpidense_C","",PETSC_NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)mat,"MatMatMultSymbolic_mpiaij_mpidense_C","",PETSC_NULL);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunction((PetscObject)mat,"MatMatMultNumeric_mpiaij_mpidense_C","",PETSC_NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -767,7 +771,7 @@ PetscErrorCode MatSetOption_MPIDense(Mat A,MatOption op)
   case MAT_ROWS_UNSORTED:
   case MAT_YES_NEW_DIAGONALS:
   case MAT_USE_HASH_TABLE:
-    ierr = PetscInfo(A,"Option ignored\n");CHKERRQ(ierr);
+    ierr = PetscInfo1(A,"Option %d ignored\n",op);CHKERRQ(ierr);
     break;
   case MAT_COLUMN_ORIENTED:
     a->roworiented = PETSC_FALSE;
@@ -788,7 +792,7 @@ PetscErrorCode MatSetOption_MPIDense(Mat A,MatOption op)
   case MAT_NOT_SYMMETRY_ETERNAL:
     break;
   default:
-    SETERRQ(PETSC_ERR_SUP,"unknown option");
+    SETERRQ1(PETSC_ERR_SUP,"unknown option %d",op);
   }
   PetscFunctionReturn(0);
 }
@@ -959,6 +963,26 @@ PetscErrorCode MatSetUpPreallocation_MPIDense(Mat A)
   PetscFunctionReturn(0);
 }
 
+#undef __FUNCT__
+#define __FUNCT__ "MatMatMultSymbolic_MPIDense_MPIDense"
+PetscErrorCode MatMatMultSymbolic_MPIDense_MPIDense(Mat A,Mat B,PetscReal fill,Mat *C) 
+{
+  PetscErrorCode ierr;
+  PetscInt       m=A->rmap.n,n=B->cmap.n;
+  Mat            Cmat;
+
+  PetscFunctionBegin;
+  if (A->cmap.n != B->rmap.n) SETERRQ2(PETSC_ERR_ARG_SIZ,"A->cmap.n %d != B->rmap.n %d\n",A->cmap.n,B->rmap.n);
+  ierr = MatCreate(B->comm,&Cmat);CHKERRQ(ierr);
+  ierr = MatSetSizes(Cmat,m,n,A->rmap.N,B->cmap.N);CHKERRQ(ierr);
+  ierr = MatSetType(Cmat,MATMPIDENSE);CHKERRQ(ierr);
+  ierr = MatMPIDenseSetPreallocation(Cmat,PETSC_NULL);CHKERRQ(ierr);
+  ierr = MatAssemblyBegin(Cmat,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  ierr = MatAssemblyEnd(Cmat,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  *C = Cmat;
+  PetscFunctionReturn(0);
+}
+
 /* -------------------------------------------------------------------*/
 static struct _MatOps MatOps_Values = {MatSetValues_MPIDense,
        MatGetRow_MPIDense,
@@ -976,7 +1000,7 @@ static struct _MatOps MatOps_Values = {MatSetValues_MPIDense,
        0,
        MatTranspose_MPIDense,
 /*15*/ MatGetInfo_MPIDense,
-       0,
+       MatEqual_MPIDense,
        MatGetDiagonal_MPIDense,
        MatDiagonalScale_MPIDense,
        MatNorm_MPIDense,
@@ -1051,7 +1075,7 @@ static struct _MatOps MatOps_Values = {MatSetValues_MPIDense,
        0,
        0,
 /*90*/ 0,
-       0,
+       MatMatMultSymbolic_MPIDense_MPIDense,
        0,
        0,
        0,
@@ -1134,6 +1158,16 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_MPIDense(Mat mat)
   ierr = PetscObjectComposeFunctionDynamic((PetscObject)mat,"MatMPIDenseSetPreallocation_C",
                                      "MatMPIDenseSetPreallocation_MPIDense",
                                      MatMPIDenseSetPreallocation_MPIDense);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunctionDynamic((PetscObject)mat,"MatMatMult_mpiaij_mpidense_C",
+                                     "MatMatMult_MPIAIJ_MPIDense",
+                                      MatMatMult_MPIAIJ_MPIDense);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunctionDynamic((PetscObject)mat,"MatMatMultSymbolic_mpiaij_mpidense_C",
+                                     "MatMatMultSymbolic_MPIAIJ_MPIDense",
+                                      MatMatMultSymbolic_MPIAIJ_MPIDense);CHKERRQ(ierr);
+  ierr = PetscObjectComposeFunctionDynamic((PetscObject)mat,"MatMatMultNumeric_mpiaij_mpidense_C",
+                                     "MatMatMultNumeric_MPIAIJ_MPIDense",
+                                      MatMatMultNumeric_MPIAIJ_MPIDense);CHKERRQ(ierr);
+  ierr = PetscObjectChangeTypeName((PetscObject)mat,MATMPIDENSE);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 EXTERN_C_END
@@ -1161,7 +1195,6 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_Dense(Mat A)
   PetscMPIInt    size;
 
   PetscFunctionBegin;
-  ierr = PetscObjectChangeTypeName((PetscObject)A,MATDENSE);CHKERRQ(ierr);
   ierr = MPI_Comm_size(A->comm,&size);CHKERRQ(ierr);
   if (size == 1) {
     ierr = MatSetType(A,MATSEQDENSE);CHKERRQ(ierr);
@@ -1292,8 +1325,6 @@ static PetscErrorCode MatDuplicate_MPIDense(Mat A,MatDuplicateOption cpvalues,Ma
   a->nvec              = oldmat->nvec;
   a->donotstash        = oldmat->donotstash;
  
-  ierr = PetscMalloc((a->size+1)*sizeof(PetscInt),&mat->rmap.range);CHKERRQ(ierr);
-  ierr = PetscMalloc((a->size+1)*sizeof(PetscInt),&mat->cmap.range);CHKERRQ(ierr);
   ierr = PetscMemcpy(mat->rmap.range,A->rmap.range,(a->size+1)*sizeof(PetscInt));CHKERRQ(ierr);
   ierr = PetscMemcpy(mat->cmap.range,A->cmap.range,(a->size+1)*sizeof(PetscInt));CHKERRQ(ierr);
   ierr = MatStashCreate_Private(A->comm,1,&mat->stash);CHKERRQ(ierr);
@@ -1560,7 +1591,21 @@ PetscErrorCode MatLoad_MPIDense(PetscViewer viewer, MatType type,Mat *newmat)
   PetscFunctionReturn(0);
 }
 
+#undef __FUNCT__  
+#define __FUNCT__ "MatEqual_MPIDense"
+PetscErrorCode MatEqual_MPIDense(Mat A,Mat B,PetscTruth *flag)
+{
+  Mat_MPIDense   *matB = (Mat_MPIDense*)B->data,*matA = (Mat_MPIDense*)A->data;
+  Mat            a,b;
+  PetscTruth     flg;
+  PetscErrorCode ierr;
 
+  PetscFunctionBegin;
+  a = matA->A; 
+  b = matB->A;
+  ierr = MatEqual(a,b,&flg);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
 
 
 
