@@ -39,6 +39,7 @@ PetscErrorCode MatDestroy_IS(Mat A)
     ierr = ISLocalToGlobalMappingDestroy(b->mapping);CHKERRQ(ierr);
   }
   ierr = PetscFree(b);CHKERRQ(ierr);
+  ierr = PetscObjectChangeTypeName((PetscObject)A,0);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)A,"MatISGetLocalMat_C","",PETSC_NULL);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -368,6 +369,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_IS(Mat A)
   b->x          = 0;  
   b->y          = 0;  
   ierr = PetscObjectComposeFunctionDynamic((PetscObject)A,"MatISGetLocalMat_C","MatISGetLocalMat_IS",MatISGetLocalMat_IS);CHKERRQ(ierr);
+  ierr = PetscObjectChangeTypeName((PetscObject)A,MATIS);CHKERRQ(ierr);
 
   PetscFunctionReturn(0);
 }
