@@ -36,14 +36,13 @@ PetscErrorCode MatMarkDiagonal_SeqSBAIJ(Mat A)
 {
   Mat_SeqSBAIJ   *a = (Mat_SeqSBAIJ*)A->data; 
   PetscErrorCode ierr;
-  PetscInt       i,mbs = a->mbs;
+  PetscInt       i;
 
   PetscFunctionBegin;
-  if (a->diag) PetscFunctionReturn(0);
-
-  ierr = PetscMalloc((mbs+1)*sizeof(PetscInt),&a->diag);CHKERRQ(ierr); 
-  ierr = PetscLogObjectMemory(A,(mbs+1)*sizeof(PetscInt));CHKERRQ(ierr);
-  for (i=0; i<mbs; i++) a->diag[i] = a->i[i];  
+  if (!a->diag) {
+    ierr = PetscMalloc(a->mbs*sizeof(PetscInt),&a->diag);CHKERRQ(ierr); 
+  }
+  for (i=0; i<a->mbs; i++) a->diag[i] = a->i[i];  
   PetscFunctionReturn(0);
 }
 
@@ -99,14 +98,14 @@ PetscErrorCode MatDestroy_SeqSBAIJ(Mat A)
 #if defined(PETSC_USE_LOG)
   PetscLogObjectState((PetscObject)A,"Rows=%D, NZ=%D",A->rmap.N,a->nz);
 #endif
-  ierr = MatSeqXAIJFreeAIJ(a->singlemalloc,&a->a,&a->j,&a->i);CHKERRQ(ierr);
-  if (a->row) {
-    ierr = ISDestroy(a->row);CHKERRQ(ierr);
-  }
+  ierr = MatSeqXAIJFreeAIJ(A,&a->a,&a->j,&a->i);CHKERRQ(ierr);
+  if (a->row) {ierr = ISDestroy(a->row);CHKERRQ(ierr);}
+  if (a->col){ierr = ISDestroy(a->col);CHKERRQ(ierr);}
+  if (a->icol) {ierr = ISDestroy(a->icol);CHKERRQ(ierr);}
   ierr = PetscFree(a->diag);CHKERRQ(ierr);
   ierr = PetscFree2(a->imax,a->ilen);CHKERRQ(ierr);
-  if (a->icol) {ierr = ISDestroy(a->icol);CHKERRQ(ierr);}
   ierr = PetscFree(a->solve_work);CHKERRQ(ierr);
+  ierr = PetscFree(a->relax_work);CHKERRQ(ierr);
   ierr = PetscFree(a->solves_work);CHKERRQ(ierr);
   ierr = PetscFree(a->mult_work);CHKERRQ(ierr);
   ierr = PetscFree(a->saved_values);CHKERRQ(ierr);
@@ -115,6 +114,7 @@ PetscErrorCode MatDestroy_SeqSBAIJ(Mat A)
   ierr = PetscFree(a->inew);CHKERRQ(ierr);
   ierr = PetscFree(a);CHKERRQ(ierr);
 
+  ierr = PetscObjectChangeTypeName((PetscObject)A,0);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)A,"MatStoreValues_C","",PETSC_NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)A,"MatRetrieveValues_C","",PETSC_NULL);CHKERRQ(ierr);
   ierr = PetscObjectComposeFunction((PetscObject)A,"MatSeqSBAIJSetColumnIndices_C","",PETSC_NULL);CHKERRQ(ierr);
@@ -165,7 +165,7 @@ PetscErrorCode MatSetOption_SeqSBAIJ(Mat A,MatOption op)
   case MAT_YES_NEW_DIAGONALS:
   case MAT_IGNORE_OFF_PROC_ENTRIES:
   case MAT_USE_HASH_TABLE:
-    ierr = PetscInfo(A,"Option ignored\n");CHKERRQ(ierr);
+    ierr = PetscInfo1(A,"Option %d ignored\n",op);CHKERRQ(ierr);
     break;
   case MAT_NO_NEW_DIAGONALS:
     SETERRQ(PETSC_ERR_SUP,"MAT_NO_NEW_DIAGONALS");
@@ -188,7 +188,7 @@ PetscErrorCode MatSetOption_SeqSBAIJ(Mat A,MatOption op)
     a->getrow_utriangular = PETSC_TRUE;
     break;
   default:
-    SETERRQ(PETSC_ERR_SUP,"unknown option");
+    SETERRQ1(PETSC_ERR_SUP,"unknown option %d",op);
   }
   PetscFunctionReturn(0);
 }
@@ -375,7 +375,7 @@ static PetscErrorCode MatView_SeqSBAIJ_ASCII(Mat A,PetscViewer viewer)
               ierr = PetscViewerASCIIPrintf(viewer," (%D, %G) ",bs*a->j[k]+l,PetscRealPart(a->a[bs2*k + l*bs + j]));CHKERRQ(ierr);
             }
 #else
-            ierr = PetscViewerASCIIPrintf(viewer," %D %G ",bs*a->j[k]+l,a->a[bs2*k + l*bs + j]);CHKERRQ(ierr);
+            ierr = PetscViewerASCIIPrintf(viewer," (%D, %G) ",bs*a->j[k]+l,a->a[bs2*k + l*bs + j]);CHKERRQ(ierr);
 #endif
           }
         }
@@ -645,7 +645,7 @@ PetscErrorCode MatSetValuesBlocked_SeqSBAIJ(Mat A,PetscInt m,const PetscInt im[]
       } 
       if (nonew == 1) goto noinsert2;
       if (nonew == -1) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Inserting a new nonzero (%D, %D) in the matrix", row, col);
-      MatSeqXAIJReallocateAIJ(a,bs2,nrow,row,col,rmax,aa,ai,aj,a->mbs,rp,ap,imax,nonew);
+      MatSeqXAIJReallocateAIJ(A,a->mbs,bs2,nrow,row,col,rmax,aa,ai,aj,rp,ap,imax,nonew);
       N = nrow++ - 1; high++;
       /* shift up all the later entries in this row */
       for (ii=N; ii>=i; ii--) {
@@ -854,7 +854,7 @@ PetscErrorCode MatSetValues_SeqSBAIJ(Mat A,PetscInt m,const PetscInt im[],PetscI
         
         if (nonew == 1) goto noinsert1;
         if (nonew == -1) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Inserting a new nonzero (%D, %D) in the matrix", row, col);
-        MatSeqXAIJReallocateAIJ(a,bs2,nrow,brow,bcol,rmax,aa,ai,aj,a->mbs,rp,ap,imax,nonew);
+        MatSeqXAIJReallocateAIJ(A,a->mbs,bs2,nrow,brow,bcol,rmax,aa,ai,aj,rp,ap,imax,nonew);
         
         N = nrow++ - 1; high++;
         /* shift up all the later entries in this row */
@@ -953,9 +953,7 @@ PetscErrorCode MatICCFactor_SeqSBAIJ(Mat inA,IS row,MatFactorInfo *info)
   outA          = inA; 
   inA->factor   = FACTOR_CHOLESKY;
   
-  if (!a->diag) {
-    ierr = MatMarkDiagonal_SeqSBAIJ(inA);CHKERRQ(ierr);
-  }
+  ierr = MatMarkDiagonal_SeqSBAIJ(inA);CHKERRQ(ierr);
   /*
     Blocksize 2, 3, 4, 5, 6 and 7 have a special faster factorization/solver 
     for ILU(0) factorization with natural ordering
@@ -1023,23 +1021,6 @@ PetscErrorCode MatICCFactor_SeqSBAIJ(Mat inA,IS row,MatFactorInfo *info)
 }
 #endif
 
-#undef __FUNCT__  
-#define __FUNCT__ "MatPrintHelp_SeqSBAIJ"
-PetscErrorCode MatPrintHelp_SeqSBAIJ(Mat A)
-{
-  static PetscTruth called = PETSC_FALSE; 
-  MPI_Comm          comm = A->comm;
-  PetscErrorCode    ierr;
-  
-  PetscFunctionBegin;
-  if (called) {PetscFunctionReturn(0);} else called = PETSC_TRUE;
-  ierr = (*PetscHelpPrintf)(comm," Options for MATSEQSBAIJ and MATMPISBAIJ matrix formats (the defaults):\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"  -mat_block_size <block_size>\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"  -mat_ignore_lower_triangular: Ignore lower triangular values set by user\n");CHKERRQ(ierr);
-  ierr = (*PetscHelpPrintf)(comm,"  -mat_getrow_uppertriangular: Enable MatGetRow() for retrieving the upper triangular part of the row\n");CHKERRQ(ierr);
-  PetscFunctionReturn(0);
-}
-
 EXTERN_C_BEGIN
 #undef __FUNCT__  
 #define __FUNCT__ "MatSeqSBAIJSetColumnIndices_SeqSBAIJ"
@@ -1294,7 +1275,7 @@ static struct _MatOps MatOps_Values = {MatSetValues_SeqSBAIJ,
        MatIncreaseOverlap_SeqSBAIJ,
        MatGetValues_SeqSBAIJ,
        MatCopy_SeqSBAIJ,
-/*45*/ MatPrintHelp_SeqSBAIJ,
+/*45*/ 0,
        MatScale_SeqSBAIJ,
        0,
        0,
@@ -1551,6 +1532,11 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatSeqSBAIJSetPreallocation_SeqSBAIJ(Mat B,Pet
     for (i=1; i<mbs+1; i++) {
       b->i[i] = b->i[i-1] + b->imax[i-1];
     }
+    b->free_a     = PETSC_TRUE;
+    b->free_ij    = PETSC_TRUE;
+  } else {
+    b->free_a     = PETSC_FALSE;
+    b->free_ij    = PETSC_FALSE;
   }
   
   B->rmap.bs               = bs;
@@ -1659,6 +1645,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatCreate_SeqSBAIJ(Mat B)
   B->structurally_symmetric     = PETSC_TRUE;
   B->symmetric_set              = PETSC_TRUE;
   B->structurally_symmetric_set = PETSC_TRUE;
+  ierr = PetscObjectChangeTypeName((PetscObject)B,MATSEQSBAIJ);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 EXTERN_C_END
@@ -1796,8 +1783,7 @@ PetscErrorCode MatDuplicate_SeqSBAIJ(Mat A,MatDuplicateOption cpvalues,Mat *B)
   c->mbs  = a->mbs;
   c->nbs  = a->nbs;
 
-  ierr = PetscMalloc((mbs+1)*sizeof(PetscInt),&c->imax);CHKERRQ(ierr);
-  ierr = PetscMalloc((mbs+1)*sizeof(PetscInt),&c->ilen);CHKERRQ(ierr);
+  ierr = PetscMalloc2((mbs+1),PetscInt,&c->imax,(mbs+1),PetscInt,&c->ilen);CHKERRQ(ierr);
   for (i=0; i<mbs; i++) {
     c->imax[i] = a->imax[i];
     c->ilen[i] = a->ilen[i]; 
@@ -1827,11 +1813,13 @@ PetscErrorCode MatDuplicate_SeqSBAIJ(Mat A,MatDuplicateOption cpvalues,Mat *B)
     for (i=0; i<mbs; i++) {
       c->diag[i] = a->diag[i];
     }
-  } else c->diag        = 0;
-  c->nz               = a->nz;
-  c->maxnz            = a->maxnz;
-  c->solve_work         = 0;
-  c->mult_work          = 0;
+  } else c->diag  = 0;
+  c->nz           = a->nz;
+  c->maxnz        = a->maxnz;
+  c->solve_work   = 0;
+  c->mult_work    = 0;
+  c->free_a       = PETSC_TRUE;
+  c->free_ij      = PETSC_TRUE;
   *B = C;
   ierr = PetscFListDuplicate(A->qlist,&C->qlist);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -2015,7 +2003,10 @@ PetscErrorCode MatRelax_SeqSBAIJ(Mat A,Vec bb,PetscReal omega,MatSORType flag,Pe
     b = x;
   } 
 
-  ierr = PetscMalloc(m*sizeof(PetscScalar),&t);CHKERRQ(ierr);
+  if (!a->relax_work) {
+    ierr = PetscMalloc(m*sizeof(PetscScalar),&a->relax_work);CHKERRQ(ierr);
+  }
+  t = a->relax_work;
  
   if (flag & SOR_ZERO_INITIAL_GUESS) {
     if (flag & SOR_FORWARD_SWEEP || flag & SOR_LOCAL_FORWARD_SWEEP){ 
@@ -2027,33 +2018,28 @@ PetscErrorCode MatRelax_SeqSBAIJ(Mat A,Vec bb,PetscReal omega,MatSORType flag,Pe
         v  = aa + ai[i] + 1; 
         vj = aj + ai[i] + 1;    
         nz = ai[i+1] - ai[i] - 1;       
+        ierr = PetscLogFlops(2*nz-1);CHKERRQ(ierr);
         x[i] = omega*t[i]/d;
         while (nz--) t[*vj++] -= x[i]*(*v++); /* update rhs */
-        ierr = PetscLogFlops(2*nz-1);CHKERRQ(ierr);
       }
     } 
 
     if (flag & SOR_BACKWARD_SWEEP || flag & SOR_LOCAL_BACKWARD_SWEEP){ 
-      for (i=0; i<m; i++)
-        t[i] = b[i];
-  
-      for (i=0; i<m-1; i++){  /* update rhs */
-        v  = aa + ai[i] + 1; 
-        vj = aj + ai[i] + 1;    
-        nz = ai[i+1] - ai[i] - 1;
-        while (nz--) t[*vj++] -= x[i]*(*v++);
-        ierr = PetscLogFlops(2*nz-1);CHKERRQ(ierr);
+      if (!(flag & SOR_FORWARD_SWEEP || flag & SOR_LOCAL_FORWARD_SWEEP)){ 
+        t = b;
       }
+  
       for (i=m-1; i>=0; i--){
         d  = *(aa + ai[i]);  
         v  = aa + ai[i] + 1; 
         vj = aj + ai[i] + 1;    
         nz = ai[i+1] - ai[i] - 1;
+        ierr = PetscLogFlops(2*nz-1);CHKERRQ(ierr);
         sum = t[i];
         while (nz--) sum -= x[*vj++]*(*v++);
-        ierr = PetscLogFlops(2*nz-1);CHKERRQ(ierr);
         x[i] =   (1-omega)*x[i] + omega*sum/d;        
       }
+      t = a->relax_work;
     }
     its--;
   } 
@@ -2077,21 +2063,22 @@ PetscErrorCode MatRelax_SeqSBAIJ(Mat A,Vec bb,PetscReal omega,MatSORType flag,Pe
         vj = aj + ai[i] + 1; vj1=vj;   
         nz = ai[i+1] - ai[i] - 1; nz1=nz;
         sum = t[i];
+        ierr = PetscLogFlops(4*nz-2);CHKERRQ(ierr);
         while (nz1--) sum -= (*v1++)*x[*vj1++]; 
         x[i] = (1-omega)*x[i] + omega*sum/d;
         while (nz--) t[*vj++] -= x[i]*(*v++); 
-        ierr = PetscLogFlops(4*nz-2);CHKERRQ(ierr);
       }
     }
   
-  if (flag & SOR_BACKWARD_SWEEP || flag & SOR_LOCAL_BACKWARD_SWEEP){ 
+    if (flag & SOR_BACKWARD_SWEEP || flag & SOR_LOCAL_BACKWARD_SWEEP){ 
       /* 
        backward sweep:
        b = b - x[i]*U^T(i,:), i=0,...,n-2
        for i=m-1,...,0:
          sum[i] = (b[i] - U(i,:)x )/d[i];
          x[i]   = (1-omega)x[i] + omega*sum[i];
-      */ 
+      */
+      /* if there was a forward sweep done above then I thing the next two for loops are not needed */ 
       for (i=0; i<m; i++)
         t[i] = b[i];
   
@@ -2099,23 +2086,22 @@ PetscErrorCode MatRelax_SeqSBAIJ(Mat A,Vec bb,PetscReal omega,MatSORType flag,Pe
         v  = aa + ai[i] + 1; 
         vj = aj + ai[i] + 1;    
         nz = ai[i+1] - ai[i] - 1;
-        while (nz--) t[*vj++] -= x[i]*(*v++);
         ierr = PetscLogFlops(2*nz-1);CHKERRQ(ierr);
+        while (nz--) t[*vj++] -= x[i]*(*v++);
       }
       for (i=m-1; i>=0; i--){
         d  = *(aa + ai[i]);  
         v  = aa + ai[i] + 1; 
         vj = aj + ai[i] + 1;    
         nz = ai[i+1] - ai[i] - 1;
+        ierr = PetscLogFlops(2*nz-1);CHKERRQ(ierr);
         sum = t[i];
         while (nz--) sum -= x[*vj++]*(*v++);
-        ierr = PetscLogFlops(2*nz-1);CHKERRQ(ierr);
         x[i] =   (1-omega)*x[i] + omega*sum/d;        
       }
     }
   } 
 
-  ierr = PetscFree(t);CHKERRQ(ierr);
   ierr = VecRestoreArray(xx,&x);CHKERRQ(ierr);
   if (bb != xx) { 
     ierr = VecRestoreArray(bb,&b);CHKERRQ(ierr);
@@ -2123,6 +2109,81 @@ PetscErrorCode MatRelax_SeqSBAIJ(Mat A,Vec bb,PetscReal omega,MatSORType flag,Pe
   PetscFunctionReturn(0);
 } 
 
+#undef __FUNCT__  
+#define __FUNCT__ "MatCreateSeqSBAIJWithArrays"
+/*@
+     MatCreateSeqSBAIJWithArrays - Creates an sequential SBAIJ matrix using matrix elements 
+              (upper triangular entries in CSR format) provided by the user.
+
+     Collective on MPI_Comm
+
+   Input Parameters:
++  comm - must be an MPI communicator of size 1
+.  bs - size of block
+.  m - number of rows
+.  n - number of columns
+.  i - row indices
+.  j - column indices
+-  a - matrix values
+
+   Output Parameter:
+.  mat - the matrix
+
+   Level: intermediate
+
+   Notes:
+       The i, j, and a arrays are not copied by this routine, the user must free these arrays
+    once the matrix is destroyed
+
+       You cannot set new nonzero locations into this matrix, that will generate an error.
+
+       The i and j indices are 0 based
+
+.seealso: MatCreate(), MatCreateMPISBAIJ(), MatCreateSeqSBAIJ()
+
+@*/
+PetscErrorCode PETSCMAT_DLLEXPORT MatCreateSeqSBAIJWithArrays(MPI_Comm comm,PetscInt bs,PetscInt m,PetscInt n,PetscInt* i,PetscInt*j,PetscScalar *a,Mat *mat)
+{
+  PetscErrorCode ierr;
+  PetscInt       ii;
+  Mat_SeqSBAIJ   *sbaij;
+
+  PetscFunctionBegin;
+  if (bs != 1) SETERRQ1(PETSC_ERR_SUP,"block size %D > 1 is not supported yet",bs);
+  if (i[0]) SETERRQ(PETSC_ERR_ARG_OUTOFRANGE,"i (row indices) must start with 0");
+  
+  ierr = MatCreate(comm,mat);CHKERRQ(ierr);
+  ierr = MatSetSizes(*mat,m,n,m,n);CHKERRQ(ierr);
+  ierr = MatSetType(*mat,MATSEQSBAIJ);CHKERRQ(ierr);
+  ierr = MatSeqSBAIJSetPreallocation_SeqSBAIJ(*mat,bs,MAT_SKIP_ALLOCATION,0);CHKERRQ(ierr);
+  sbaij = (Mat_SeqSBAIJ*)(*mat)->data;
+  ierr = PetscMalloc2(m,PetscInt,&sbaij->imax,m,PetscInt,&sbaij->ilen);CHKERRQ(ierr);
+
+  sbaij->i = i;
+  sbaij->j = j;
+  sbaij->a = a;
+  sbaij->singlemalloc = PETSC_FALSE;
+  sbaij->nonew        = -1;             /*this indicates that inserting a new value in the matrix that generates a new nonzero is an error*/
+  sbaij->free_a       = PETSC_FALSE; 
+  sbaij->free_ij      = PETSC_FALSE; 
+
+  for (ii=0; ii<m; ii++) {
+    sbaij->ilen[ii] = sbaij->imax[ii] = i[ii+1] - i[ii];
+#if defined(PETSC_USE_DEBUG)
+    if (i[ii+1] - i[ii] < 0) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Negative row length in i (row indices) row = %d length = %d",ii,i[ii+1] - i[ii]);
+#endif    
+  }
+#if defined(PETSC_USE_DEBUG)
+  for (ii=0; ii<sbaij->i[m]; ii++) {
+    if (j[ii] < 0) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Negative column index at location = %d index = %d",ii,j[ii]);
+    if (j[ii] > n - 1) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"Column index to large at location = %d index = %d",ii,j[ii]);
+  }
+#endif    
+
+  ierr = MatAssemblyBegin(*mat,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  ierr = MatAssemblyEnd(*mat,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
 
 
 
