@@ -1,4 +1,4 @@
-/*$Id: sro.c,v 1.26 2001/06/21 21:17:00 bsmith Exp $*/
+#define PETSCMAT_DLL
 
 #include "src/mat/impls/baij/seq/baij.h"
 #include "src/inline/spops.h"
@@ -34,13 +34,14 @@ C    STORED IN ROW J (AND THUS M(I,J) IS NOT STORED).
 */
 #undef __FUNCT__  
 #define __FUNCT__ "MatReorderingSeqSBAIJ"
-int MatReorderingSeqSBAIJ(Mat A,IS perm)
+PetscErrorCode PETSCMAT_DLLEXPORT MatReorderingSeqSBAIJ(Mat A,IS perm)
 {
-  Mat_SeqSBAIJ    *a=(Mat_SeqSBAIJ *)A->data;
-  int             *r,ierr,i,mbs=a->mbs,*rip,*riip;
-  int             *ai,*aj;
-  int             *nzr,nz,jmin,jmax,j,k,ajk,len;
-  IS              iperm;  /* inverse of perm */
+  Mat_SeqSBAIJ   *a=(Mat_SeqSBAIJ *)A->data;
+  PetscErrorCode ierr;
+  PetscInt       *r,i,mbs=a->mbs,*rip,*riip;
+  PetscInt       *ai,*aj;
+  PetscInt       *nzr,nz,jmin,jmax,j,k,ajk,len;
+  IS             iperm;  /* inverse of perm */
 
   PetscFunctionBegin;
   if (!mbs) PetscFunctionReturn(0);  
@@ -49,20 +50,20 @@ int MatReorderingSeqSBAIJ(Mat A,IS perm)
   ierr = ISGetIndices(iperm,&riip);CHKERRQ(ierr);
 
   for (i=0; i<mbs; i++) {
-    if (rip[i] != riip[i]) SETERRQ(1,"Non-symm. permutation, use symm. permutation or general matrix format");     
+    if (rip[i] != riip[i]) SETERRQ(PETSC_ERR_ARG_INCOMP,"Non-symmetric permutation, use symmetric permutation for symmetric matrices");
   }
   ierr = ISRestoreIndices(iperm,&riip);CHKERRQ(ierr);
   ierr = ISDestroy(iperm);CHKERRQ(ierr);
   
   if (!a->inew){ 
-    len  = (mbs+1 + 2*(a->i[mbs]))*sizeof(int);
+    len  = (mbs+1 + 2*(a->i[mbs]))*sizeof(PetscInt);
     ierr = PetscMalloc(len,&ai);CHKERRQ(ierr);
     aj   = ai + mbs+1;    
   } else {
     ai = a->inew; aj = a->jnew;
   }  
-  ierr  = PetscMemcpy(ai,a->i,(mbs+1)*sizeof(int));CHKERRQ(ierr);
-  ierr  = PetscMemcpy(aj,a->j,(a->i[mbs])*sizeof(int));CHKERRQ(ierr);
+  ierr  = PetscMemcpy(ai,a->i,(mbs+1)*sizeof(PetscInt));CHKERRQ(ierr);
+  ierr  = PetscMemcpy(aj,a->j,(a->i[mbs])*sizeof(PetscInt));CHKERRQ(ierr);
   
   /* 
      Phase 1: Find row index r in which to store each nonzero. 
@@ -71,8 +72,8 @@ int MatReorderingSeqSBAIJ(Mat A,IS perm)
               s.t. a(perm(r),perm(aj)) will fall into upper triangle part.
   */
 
-  ierr = PetscMalloc(mbs*sizeof(int),&nzr);CHKERRQ(ierr); 
-  ierr = PetscMalloc(ai[mbs]*sizeof(int),&r);CHKERRQ(ierr); 
+  ierr = PetscMalloc(mbs*sizeof(PetscInt),&nzr);CHKERRQ(ierr); 
+  ierr = PetscMalloc(ai[mbs]*sizeof(PetscInt),&r);CHKERRQ(ierr); 
   for (i=0; i<mbs; i++) nzr[i] = 0;
   for (i=0; i<ai[mbs]; i++) r[i] = 0; 
                                                               
@@ -120,7 +121,7 @@ int MatReorderingSeqSBAIJ(Mat A,IS perm)
   }         
   
   a->a2anew = aj + ai[mbs];
-  ierr  = PetscMemcpy(a->a2anew,r,ai[mbs]*sizeof(int));CHKERRQ(ierr);
+  ierr  = PetscMemcpy(a->a2anew,r,ai[mbs]*sizeof(PetscInt));CHKERRQ(ierr);
                                          
   /* Phase 3: permute (aj,a) to upper triangular form (wrt new ordering) */
   for (j=jmin; j<jmax; j++){
