@@ -10,8 +10,35 @@
 PetscCookie PETSCMAT_DLLEXPORT MAT_NULLSPACE_COOKIE = 0;
 
 #undef __FUNCT__  
-#define __FUNCT__ "MatNullSpaceCreate"
+#define __FUNCT__ "MatNullSpaceSetFunction"
 /*@C
+   MatNullSpaceSetFunction - set a function that removes a null space from a vector
+   out of null spaces.
+
+   Collective on MatNullSpace
+
+   Input Parameters:
++  sp - the null space object
+.  rem - the function that removes the null space
+-  ctx - context for the remove function
+
+   Level: advanced
+
+.keywords: PC, null space, create
+
+.seealso: MatNullSpaceDestroy(), MatNullSpaceRemove(), KSPSetNullSpace(), MatNullSpace, MatNullSpaceCreate()
+@*/
+PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceSetFunction(MatNullSpace sp, PetscErrorCode (*rem)(Vec,void*),void *ctx)
+{
+  PetscFunctionBegin;
+  sp->remove = rem;
+  sp->rmctx  = ctx;
+  PetscFunctionReturn(0);
+}
+
+#undef __FUNCT__  
+#define __FUNCT__ "MatNullSpaceCreate"
+/*@
    MatNullSpaceCreate - Creates a data structure used to project vectors 
    out of null spaces.
 
@@ -35,7 +62,7 @@ PetscCookie PETSCMAT_DLLEXPORT MAT_NULLSPACE_COOKIE = 0;
 
 .keywords: PC, null space, create
 
-.seealso: MatNullSpaceDestroy(), MatNullSpaceRemove(), KSPSetNullSpace(), MatNullSpace
+.seealso: MatNullSpaceDestroy(), MatNullSpaceRemove(), KSPSetNullSpace(), MatNullSpace, MatNullSpaceSetFunction()
 @*/
 PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceCreate(MPI_Comm comm,PetscTruth has_cnst,PetscInt n,const Vec vecs[],MatNullSpace *SP)
 {
@@ -44,6 +71,15 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceCreate(MPI_Comm comm,PetscTruth ha
   PetscInt       i;
 
   PetscFunctionBegin;
+  if (n) PetscValidPointer(vecs,4); 
+  for (i=0; i<n; i++) PetscValidHeaderSpecific(vecs[i],VEC_COOKIE,4); 
+  PetscValidPointer(SP,5); 
+ 
+  *SP = PETSC_NULL; 
+#ifndef PETSC_USE_DYNAMIC_LIBRARIES 
+  ierr = MatInitializePackage(PETSC_NULL);CHKERRQ(ierr); 
+#endif 
+
   ierr = PetscHeaderCreate(sp,_p_MatNullSpace,int,MAT_NULLSPACE_COOKIE,0,"MatNullSpace",comm,MatNullSpaceDestroy,0);CHKERRQ(ierr);
   ierr = PetscLogObjectMemory(sp,sizeof(struct _p_MatNullSpace));CHKERRQ(ierr);
 
@@ -79,7 +115,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceCreate(MPI_Comm comm,PetscTruth ha
 
 .keywords: PC, null space, destroy
 
-.seealso: MatNullSpaceCreate(), MatNullSpaceRemove()
+.seealso: MatNullSpaceCreate(), MatNullSpaceRemove(), MatNullSpaceSetFunction()
 @*/
 PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceDestroy(MatNullSpace sp)
 {
@@ -109,13 +145,13 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceDestroy(MatNullSpace sp)
 -  out - if this is requested (not PETSC_NULL) then this is a vector with the null space removed otherwise
          the removal is done in-place (in vec)
 
-
+   Note: The user is not responsible for the vector returned and should not destroy it.
 
    Level: advanced
 
 .keywords: PC, null space, remove
 
-.seealso: MatNullSpaceCreate(), MatNullSpaceDestroy()
+.seealso: MatNullSpaceCreate(), MatNullSpaceDestroy(), MatNullSpaceSetFunction()
 @*/
 PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceRemove(MatNullSpace sp,Vec vec,Vec *out)
 {
@@ -125,7 +161,11 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceRemove(MatNullSpace sp,Vec vec,Vec
   Vec            l = vec;
 
   PetscFunctionBegin;
+  PetscValidHeaderSpecific(sp,MAT_NULLSPACE_COOKIE,1); 
+  PetscValidHeaderSpecific(vec,VEC_COOKIE,2); 
+
   if (out) {
+    PetscValidPointer(out,3); 
     if (!sp->vec) {
       ierr = VecDuplicate(vec,&sp->vec);CHKERRQ(ierr);
     }
@@ -143,10 +183,12 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceRemove(MatNullSpace sp,Vec vec,Vec
 
   for (j=0; j<n; j++) {
     ierr = VecDot(l,sp->vecs[j],&sum);CHKERRQ(ierr);
-    sum  = -sum;
-    ierr = VecAXPY(l,sum,sp->vecs[j]);CHKERRQ(ierr);
+    ierr = VecAXPY(l,-sum,sp->vecs[j]);CHKERRQ(ierr);
+  }
+
+  if (sp->remove){
+    ierr = (*sp->remove)(l,sp->rmctx);
   }
-  
   PetscFunctionReturn(0);
 }
 
@@ -166,7 +208,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceRemove(MatNullSpace sp,Vec vec,Vec
 
 .keywords: PC, null space, remove
 
-.seealso: MatNullSpaceCreate(), MatNullSpaceDestroy()
+.seealso: MatNullSpaceCreate(), MatNullSpaceDestroy(), MatNullSpaceSetFunction()
 @*/
 PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceTest(MatNullSpace sp,Mat mat)
 {
@@ -201,7 +243,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceTest(MatNullSpace sp,Mat mat)
     ierr = VecNorm(r,NORM_2,&nrm);CHKERRQ(ierr);
     if (nrm < 1.e-7) {ierr = PetscPrintf(comm,"Constants are likely null vector");CHKERRQ(ierr);}
     else {ierr = PetscPrintf(comm,"Constants are unlikely null vector ");CHKERRQ(ierr);}
-    ierr = PetscPrintf(comm,"|| A * 1 || = %g\n",nrm);CHKERRQ(ierr);
+    ierr = PetscPrintf(comm,"|| A * 1 || = %G\n",nrm);CHKERRQ(ierr);
     if (nrm > 1.e-7 && flg1) {ierr = VecView(r,PETSC_VIEWER_STDOUT_(comm));CHKERRQ(ierr);}
     if (nrm > 1.e-7 && flg2) {ierr = VecView(r,PETSC_VIEWER_DRAW_(comm));CHKERRQ(ierr);}
     ierr = VecDestroy(r);CHKERRQ(ierr);
@@ -212,10 +254,14 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatNullSpaceTest(MatNullSpace sp,Mat mat)
     ierr = VecNorm(l,NORM_2,&nrm);CHKERRQ(ierr);
     if (nrm < 1.e-7) {ierr = PetscPrintf(comm,"Null vector %D is likely null vector",j);CHKERRQ(ierr);}
     else {ierr = PetscPrintf(comm,"Null vector %D unlikely null vector ",j);CHKERRQ(ierr);}
-    ierr = PetscPrintf(comm,"|| A * v[%D] || = %g\n",j,nrm);CHKERRQ(ierr);
+    ierr = PetscPrintf(comm,"|| A * v[%D] || = %G\n",j,nrm);CHKERRQ(ierr);
     if (nrm > 1.e-7 && flg1) {ierr = VecView(l,PETSC_VIEWER_STDOUT_(comm));CHKERRQ(ierr);}
     if (nrm > 1.e-7 && flg2) {ierr = VecView(l,PETSC_VIEWER_DRAW_(comm));CHKERRQ(ierr);}
   }
+
+  if (sp->remove){
+    SETERRQ(PETSC_ERR_SUP,"Cannot test a null space provided as a function with MatNullSpaceSetFunction()");
+  }
   
   PetscFunctionReturn(0);
 }
