@@ -70,7 +70,7 @@ struct _MatOps {
   PetscErrorCode (*getvalues)(Mat,PetscInt,const PetscInt[],PetscInt,const PetscInt[],PetscScalar []);
   PetscErrorCode (*copy)(Mat,Mat,MatStructure);
   /*45*/
-  PetscErrorCode (*printhelp)(Mat);
+  PetscErrorCode (*dummy)(void);
   PetscErrorCode (*scale)(Mat,PetscScalar);
   PetscErrorCode (*shift)(Mat,PetscScalar);
   PetscErrorCode (*diagonalset)(Mat,Vec,InsertMode);
@@ -91,7 +91,7 @@ struct _MatOps {
   PetscErrorCode (*getsubmatrix)(Mat,IS,IS,PetscInt,MatReuse,Mat*);
   PetscErrorCode (*destroy)(Mat);
   PetscErrorCode (*view)(Mat,PetscViewer);
-  PetscErrorCode (*dummy)();
+  PetscErrorCode (*convertfrom)(Mat, MatType,MatReuse,Mat*);
   PetscErrorCode (*usescaledform)(Mat,PetscTruth);
   /*65*/
   PetscErrorCode (*scalesystem)(Mat,Vec,Vec);
@@ -166,6 +166,7 @@ EXTERN PetscErrorCode MatHeaderCopy(Mat,Mat);
 EXTERN PetscErrorCode MatHeaderReplace(Mat,Mat);
 EXTERN PetscErrorCode MatAXPYGetxtoy_Private(PetscInt,PetscInt*,PetscInt*,PetscInt*, PetscInt*,PetscInt*,PetscInt*, PetscInt**);
 EXTERN PetscErrorCode MatPtAP_Basic(Mat,Mat,MatReuse,PetscReal,Mat*);
+EXTERN PetscErrorCode MatDiagonalSet_Default(Mat,Vec,InsertMode);
 
 /* 
   The stash is used to temporarily store inserted matrix values that 
@@ -253,56 +254,6 @@ struct _p_Mat {
 
 #define MatPreallocated(A)  ((!(A)->preallocated) ? MatSetUpPreallocation(A) : 0)
 extern PetscErrorCode MatAXPY_Basic(Mat,PetscScalar,Mat,MatStructure);
-/*
-    Frees the a, i, and j arrays from the XAIJ (AIJ, BAIJ, and SBAIJ) matrix types
-*/
-#undef __FUNCT__  
-#define __FUNCT__ "MatSeqXAIJFreeAIJ"
-PETSC_STATIC_INLINE PetscErrorCode MatSeqXAIJFreeAIJ(PetscTruth singlemalloc,PetscScalar **a,PetscInt **j,PetscInt **i) {
-                                     PetscErrorCode ierr;
-                                     if (singlemalloc) {
-                                       ierr = PetscFree3(*a,*j,*i);CHKERRQ(ierr);
-                                     } else {
-                                       if (*a) {ierr = PetscFree(*a);CHKERRQ(ierr);}
-                                       if (*j) {ierr = PetscFree(*j);CHKERRQ(ierr);}
-                                       if (*i) {ierr = PetscFree(*i);CHKERRQ(ierr);}
-                                     }
-                                     *a = 0; *j = 0; *i = 0;
-                                     return 0;
-                                   }
-
-/*
-    Allocates larger a, i, and j arrays for the XAIJ (AIJ, BAIJ, and SBAIJ) matrix types
-*/
-#define MatSeqXAIJReallocateAIJ(A,BS2,NROW,ROW,COL,RMAX,AA,AI,AJ,AM,RP,AP,AIMAX,NONEW) \
-      if (NROW >= RMAX) { \
-        /* there is no extra room in row, therefore enlarge */ \
-        PetscInt    new_nz = AI[AM] + CHUNKSIZE,len,*new_i=0,*new_j=0; \
-        PetscScalar *new_a; \
- \
-        if (NONEW == -2) SETERRQ2(PETSC_ERR_ARG_OUTOFRANGE,"New nonzero at (%D,%D) caused a malloc",ROW,COL); \
-        /* malloc new storage space */ \
-        ierr = PetscMalloc3(BS2*new_nz,PetscScalar,&new_a,new_nz,PetscInt,&new_j,AM+1,PetscInt,&new_i);CHKERRQ(ierr);\
- \
-        /* copy over old data into new slots */ \
-        for (ii=0; ii<ROW+1; ii++) {new_i[ii] = AI[ii];} \
-        for (ii=ROW+1; ii<AM+1; ii++) {new_i[ii] = AI[ii]+CHUNKSIZE;} \
-        ierr = PetscMemcpy(new_j,AJ,(AI[ROW]+NROW)*sizeof(PetscInt));CHKERRQ(ierr); \
-        len = (new_nz - CHUNKSIZE - AI[ROW] - NROW); \
-        ierr = PetscMemcpy(new_j+AI[ROW]+NROW+CHUNKSIZE,AJ+AI[ROW]+NROW,len*sizeof(PetscInt));CHKERRQ(ierr); \
-        ierr = PetscMemcpy(new_a,AA,BS2*(AI[ROW]+NROW)*sizeof(PetscScalar));CHKERRQ(ierr); \
-        ierr = PetscMemzero(new_a+BS2*(AI[ROW]+NROW),BS2*CHUNKSIZE*sizeof(MatScalar));CHKERRQ(ierr);\
-        ierr = PetscMemcpy(new_a+BS2*(AI[ROW]+NROW+CHUNKSIZE),AA+BS2*(AI[ROW]+NROW),BS2*len*sizeof(PetscScalar));CHKERRQ(ierr);  \
-        /* free up old matrix storage */ \
-        ierr = MatSeqXAIJFreeAIJ(A->singlemalloc,&A->a,&A->j,&A->i);CHKERRQ(ierr);\
-        AA = A->a = new_a; AI = A->i = new_i; AJ = A->j = new_j;  \
-        A->singlemalloc = PETSC_TRUE; \
- \
-        RP        = AJ + AI[ROW]; AP = AA + BS2*AI[ROW]; \
-        RMAX      = AIMAX[ROW] = AIMAX[ROW] + CHUNKSIZE; \
-        A->maxnz += CHUNKSIZE; \
-        A->reallocs++; \
-      } \
 
 /*
     Object for partitioning graphs
@@ -390,6 +341,7 @@ struct  _p_MatFDColoring{
   Vec            F;                /* current value of user provided function; can set with MatFDColoringSetF() */
   PetscInt       currentcolor;     /* color for which function evaluation is being done now */
   const char     *htype;            /* "wp" or "ds" */
+  ISColoringType ctype;            /* IS_COLORING_LOCAL or IS_COLORING_GHOSTED */
 };
 
 /*
@@ -416,6 +368,8 @@ typedef struct {
   PetscScalar    pv;  /* pivot of the active row */
 } LUShift_Ctx;
 
+EXTERN PetscErrorCode MatFactorDumpMatrix(Mat);
+
 #undef __FUNCT__  
 #define __FUNCT__ "MatLUCheckShift_inline"
 /*@C
@@ -426,14 +380,19 @@ typedef struct {
    Input Parameters:
 +  info - information about the matrix factorization 
 .  sctx - pointer to the struct LUShift_Ctx
--  newshift - 0: shift is unchanged; 1: shft is updated; -1: zeropivot  
+.  row  - active row index
+-  idiag - index of diagonals in array aval
+
+   Output  Parameter:
++  newshift - 0: shift is unchanged; 1: shft is updated; -1: zeropivot  
 
    Level: developer
 @*/
-#define MatLUCheckShift_inline(info,sctx,newshift) 0;\
+#define MatLUCheckShift_inline(info,sctx,row,idiag,newshift) 0;\
 {\
-  PetscInt _newshift;\
-  PetscReal _zero = info->zeropivot*rs;\
+  PetscInt  _newshift;\
+  PetscReal _rs   = sctx.rs;\
+  PetscReal _zero = info->zeropivot*_rs;\
   if (info->shiftnz && PetscAbsScalar(sctx.pv) <= _zero){\
     /* force |diag| > zeropivot*rs */\
     if (!sctx.nshift){\
@@ -447,7 +406,8 @@ typedef struct {
   } else if (info->shiftpd && PetscRealPart(sctx.pv) <= _zero){\
     /* force matfactor to be diagonally dominant */\
     if (sctx.nshift > sctx.nshift_max) {\
-      SETERRQ(PETSC_ERR_CONV_FAILED,"Unable to determine shift to enforce positive definite preconditioner");\
+      ierr = MatFactorDumpMatrix(A);CHKERRQ(ierr);\
+      SETERRQ1(PETSC_ERR_CONV_FAILED,"Unable to determine shift to enforce positive definite preconditioner after %d tries",sctx.nshift);\
     } else if (sctx.nshift == sctx.nshift_max) {\
       info->shift_fraction = sctx.shift_hi;\
       sctx.lushift        = PETSC_TRUE;\
@@ -460,7 +420,8 @@ typedef struct {
     sctx.nshift++;\
     _newshift = 1;\
   } else if (PetscAbsScalar(sctx.pv) <= _zero){\
-    _newshift = -1;\
+    ierr = MatFactorDumpMatrix(A);CHKERRQ(ierr);\
+    SETERRQ4(PETSC_ERR_MAT_LU_ZRPVT,"Zero pivot row %D value %G tolerance %G * rowsum %G",row,PetscAbsScalar(sctx.pv),_zero,_rs); \
   } else {\
     _newshift = 0;\
   }\
@@ -488,6 +449,7 @@ typedef struct {
    Input Parameters:
 +  info - information about the matrix factorization 
 .  sctx - pointer to the struct CholeskyShift_Ctx
+.  row  - pivot row
 -  newshift - 0: shift is unchanged; 1: shft is updated; -1: zeropivot  
 
    Level: developer
@@ -496,10 +458,11 @@ typedef struct {
        this algorithm converges faster or slower, or is better or worse
        than the ILU algorithm. 
 @*/
-#define MatCholeskyCheckShift_inline(info,sctx,newshift) 0;\
+#define MatCholeskyCheckShift_inline(info,sctx,row,newshift) 0;	\
 {\
-  PetscInt _newshift;\
-  PetscReal _zero = info->zeropivot*rs;\
+  PetscInt  _newshift;\
+  PetscReal _rs   = sctx.rs;\
+  PetscReal _zero = info->zeropivot*_rs;\
   if (info->shiftnz && PetscAbsScalar(sctx.pv) <= _zero){\
     /* force |diag| > zeropivot*sctx.rs */\
     if (!sctx.nshift){\
@@ -512,12 +475,12 @@ typedef struct {
     _newshift = 1;\
   } else if (info->shiftpd && PetscRealPart(sctx.pv) <= _zero){\
     /* calculate a shift that would make this row diagonally dominant */\
-    sctx.shift_amount = PetscMax(sctx.rs+PetscAbs(PetscRealPart(sctx.pv)),1.1*sctx.shift_amount);\
+    sctx.shift_amount = PetscMax(_rs+PetscAbs(PetscRealPart(sctx.pv)),1.1*sctx.shift_amount);\
     sctx.chshift      = PETSC_TRUE;\
     sctx.nshift++;\
     _newshift = 1;\
   } else if (PetscAbsScalar(sctx.pv) <= _zero){\
-    _newshift = -1;\
+    SETERRQ4(PETSC_ERR_MAT_CH_ZRPVT,"Zero pivot row %D value %G tolerance %G * rowsum %G",row,PetscAbsScalar(sctx.pv),_zero,_rs); \
   } else {\
     _newshift = 0; \
   }\
