@@ -5,7 +5,7 @@
   sequential matrix Ordering routines.
 */
 #include "src/mat/matimpl.h"
-#include "petscsys.h"
+#include "petscmat.h"  /*I "petscmat.h" I*/
 
 PetscFList      MatOrderingList = 0;
 PetscTruth MatOrderingRegisterAllCalled = PETSC_FALSE;
@@ -112,7 +112,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatOrderingRegister(const char sname[],const c
 
 #undef __FUNCT__  
 #define __FUNCT__ "MatOrderingRegisterDestroy"
-/*@C
+/*@
    MatOrderingRegisterDestroy - Frees the list of ordering routines.
 
    Not collective
@@ -166,7 +166,7 @@ $      MATORDERING_QMD - Quotient Minimum Degree
    Notes:
       This DOES NOT actually reorder the matrix; it merely returns two index sets
    that define a reordering. This is usually not used directly, rather use the 
-   options PCLUSetMatOrdering() or PCILUSetMatOrdering().
+   options PCFactorSetMatOrdering()
 
    The user can define additional orderings; see MatOrderingRegisterDynamic().
 
@@ -175,7 +175,7 @@ $      MATORDERING_QMD - Quotient Minimum Degree
            One-way Dissection, Cholesky, Reverse Cuthill-McKee, 
            Quotient Minimum Degree
 
-.seealso:   MatOrderingRegisterDynamic(), PCLUSetMatOrdering(), PCILUSetMatOrdering()
+.seealso:   MatOrderingRegisterDynamic(), PCFactorSetMatOrdering()
 @*/
 PetscErrorCode PETSCMAT_DLLEXPORT MatGetOrdering(Mat mat,const MatOrderingType type,IS *rperm,IS *cperm)
 {
@@ -207,7 +207,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatGetOrdering(Mat mat,const MatOrderingType t
     PetscFunctionReturn(0);
   }
 
-  if (!mat->M) { /* matrix has zero rows */
+  if (!mat->rmap.N) { /* matrix has zero rows */
     ierr = ISCreateStride(PETSC_COMM_SELF,0,0,1,cperm);CHKERRQ(ierr);
     ierr = ISCreateStride(PETSC_COMM_SELF,0,0,1,rperm);CHKERRQ(ierr);
     ierr = ISSetIdentity(*cperm);CHKERRQ(ierr);
