@@ -1,4 +1,4 @@
-/*$Id: sp1wd.c,v 1.39 2001/03/23 23:22:51 balay Exp $*/
+#define PETSCMAT_DLL
 
 #include "petscmat.h"
 #include "src/mat/order/order.h"
@@ -9,16 +9,17 @@ EXTERN_C_BEGIN
 */    
 #undef __FUNCT__  
 #define __FUNCT__ "MatOrdering_1WD"
-int MatOrdering_1WD(Mat mat,const MatOrderingType type,IS *row,IS *col)
+PetscErrorCode PETSCMAT_DLLEXPORT MatOrdering_1WD(Mat mat,const MatOrderingType type,IS *row,IS *col)
 {
-  int        i,*mask,*xls,nblks,*xblk,*ls,nrow,*perm,ierr,*ia,*ja;
-  PetscTruth done;
+  PetscErrorCode ierr;
+  PetscInt       i,*mask,*xls,nblks,*xblk,*ls,nrow,*perm,*ia,*ja;
+  PetscTruth     done;
 
   PetscFunctionBegin;
   ierr = MatGetRowIJ(mat,1,PETSC_TRUE,&nrow,&ia,&ja,&done);CHKERRQ(ierr);
   if (!done) SETERRQ(PETSC_ERR_SUP,"Cannot get rows for matrix");
 
-  ierr = PetscMalloc((5*nrow+1) * sizeof(int),&mask);CHKERRQ(ierr);
+  ierr = PetscMalloc((5*nrow+1) * sizeof(PetscInt),&mask);CHKERRQ(ierr);
   xls  = mask + nrow;
   ls   = xls + nrow + 1;
   xblk = ls + nrow;
