@@ -1,15 +1,15 @@
-/*$Id: sregis.c,v 1.39 2001/08/06 21:16:14 bsmith Exp $*/
+#define PETSCMAT_DLL
 
 #include "src/mat/matimpl.h"     /*I       "petscmat.h"   I*/
 
 EXTERN_C_BEGIN
-EXTERN int MatOrdering_Natural(Mat,const MatOrderingType,IS*,IS*);
-EXTERN int MatOrdering_ND(Mat,const MatOrderingType,IS*,IS*);
-EXTERN int MatOrdering_1WD(Mat,const MatOrderingType,IS*,IS*);
-EXTERN int MatOrdering_QMD(Mat,const MatOrderingType,IS*,IS*);
-EXTERN int MatOrdering_RCM(Mat,const MatOrderingType,IS*,IS*);
-EXTERN int MatOrdering_RowLength(Mat,const MatOrderingType,IS*,IS*);
-EXTERN int MatOrdering_DSC(Mat,const MatOrderingType,IS*,IS*);
+EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatOrdering_Natural(Mat,const MatOrderingType,IS*,IS*);
+EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatOrdering_ND(Mat,const MatOrderingType,IS*,IS*);
+EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatOrdering_1WD(Mat,const MatOrderingType,IS*,IS*);
+EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatOrdering_QMD(Mat,const MatOrderingType,IS*,IS*);
+EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatOrdering_RCM(Mat,const MatOrderingType,IS*,IS*);
+EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatOrdering_RowLength(Mat,const MatOrderingType,IS*,IS*);
+EXTERN PetscErrorCode PETSCMAT_DLLEXPORT MatOrdering_DSC(Mat,const MatOrderingType,IS*,IS*);
 EXTERN_C_END
 
 #undef __FUNCT__  
@@ -36,9 +36,9 @@ EXTERN_C_END
 
 .seealso: MatOrderingRegisterDynamic(), MatOrderingRegisterDestroy()
 @*/
-int MatOrderingRegisterAll(const char path[])
+PetscErrorCode PETSCMAT_DLLEXPORT MatOrderingRegisterAll(const char path[])
 {
-  int           ierr;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   MatOrderingRegisterAllCalled = PETSC_TRUE;
