@@ -194,7 +194,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatPartitioningSetNParts(MatPartitioning part,
 
 #undef __FUNCT__  
 #define __FUNCT__ "MatPartitioningApply" 
-/*@C
+/*@
    MatPartitioningApply - Gets a partitioning for a matrix.
 
    Collective on Mat
@@ -248,7 +248,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatPartitioningApply(MatPartitioning matp,IS *
  
 #undef __FUNCT__  
 #define __FUNCT__ "MatPartitioningSetAdjacency"
-/*@C
+/*@
    MatPartitioningSetAdjacency - Sets the adjacency graph (matrix) of the thing to be
       partitioned.
 
@@ -275,7 +275,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatPartitioningSetAdjacency(MatPartitioning pa
 
 #undef __FUNCT__  
 #define __FUNCT__ "MatPartitioningDestroy"
-/*@C
+/*@
    MatPartitioningDestroy - Destroys the partitioning context.
 
    Collective on Partitioning
@@ -300,12 +300,8 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatPartitioningDestroy(MatPartitioning part)
   if (part->ops->destroy) {
     ierr = (*part->ops->destroy)(part);CHKERRQ(ierr);
   }
-  if (part->vertex_weights){
-    ierr = PetscFree(part->vertex_weights);CHKERRQ(ierr);
-  }
-  if (part->part_weights){
-    ierr = PetscFree(part->part_weights);CHKERRQ(ierr);
-  }
+  ierr = PetscFree(part->vertex_weights);CHKERRQ(ierr);
+  ierr = PetscFree(part->part_weights);CHKERRQ(ierr);
   ierr = PetscHeaderDestroy(part);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
@@ -338,9 +334,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatPartitioningSetVertexWeights(MatPartitionin
   PetscFunctionBegin;
   PetscValidHeaderSpecific(part,MAT_PARTITIONING_COOKIE,1);
 
-  if (part->vertex_weights){
-    ierr = PetscFree(part->vertex_weights);CHKERRQ(ierr);
-  }
+  ierr = PetscFree(part->vertex_weights);CHKERRQ(ierr);
   part->vertex_weights = (PetscInt*)weights;
   PetscFunctionReturn(0);
 }
@@ -373,16 +367,14 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatPartitioningSetPartitionWeights(MatPartitio
   PetscFunctionBegin;
   PetscValidHeaderSpecific(part,MAT_PARTITIONING_COOKIE,1);
 
-  if (part->part_weights){
-    ierr = PetscFree(part->part_weights);CHKERRQ(ierr);
-  }
+  ierr = PetscFree(part->part_weights);CHKERRQ(ierr);
   part->part_weights = (PetscReal*)weights;
   PetscFunctionReturn(0);
 }
 
 #undef __FUNCT__  
 #define __FUNCT__ "MatPartitioningCreate"
-/*@C
+/*@
    MatPartitioningCreate - Creates a partitioning context.
 
    Collective on MPI_Comm
