@@ -15,8 +15,6 @@
 .  Y - the second matrix
 -  str - either SAME_NONZERO_PATTERN, DIFFERENT_NONZERO_PATTERN or SUBSET_NONZERO_PATTERN
 
-   Contributed by: Matthew Knepley
-
    Notes:
      Will only be efficient if one has the SAME_NONZERO_PATTERN or SUBSET_NONZERO_PATTERN
 
@@ -126,6 +124,30 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatShift(Mat Y,PetscScalar a)
   PetscFunctionReturn(0);
 }
 
+#undef __FUNCT__  
+#define __FUNCT__ "MatDiagonalSet_Default"
+PetscErrorCode PETSCMAT_DLLEXPORT MatDiagonalSet_Default(Mat Y,Vec D,InsertMode is)
+{
+  PetscErrorCode ierr;
+  PetscInt       i,start,end,vstart,vend;
+  PetscScalar    *v;
+
+  PetscFunctionBegin;
+  ierr = VecGetOwnershipRange(D,&vstart,&vend);CHKERRQ(ierr);
+  ierr = MatGetOwnershipRange(Y,&start,&end);CHKERRQ(ierr);
+  if (vstart != start || vend != end) {
+    SETERRQ4(PETSC_ERR_ARG_SIZ,"Vector ownership range not compatible with matrix: %D %D vec %D %D mat",vstart,vend,start,end);
+  }
+  ierr = VecGetArray(D,&v);CHKERRQ(ierr);
+  for (i=start; i<end; i++) {
+    ierr = MatSetValues(Y,1,&i,1,&i,v+i-start,is);CHKERRQ(ierr);
+  }
+  ierr = VecRestoreArray(D,&v);CHKERRQ(ierr);
+  ierr = MatAssemblyBegin(Y,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  ierr = MatAssemblyEnd(Y,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  PetscFunctionReturn(0);
+}
+
 #undef __FUNCT__  
 #define __FUNCT__ "MatDiagonalSet"
 /*@
@@ -149,7 +171,6 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatShift(Mat Y,PetscScalar a)
 PetscErrorCode PETSCMAT_DLLEXPORT MatDiagonalSet(Mat Y,Vec D,InsertMode is)
 {
   PetscErrorCode ierr;
-  PetscInt       i,start,end;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(Y,MAT_COOKIE,1);
@@ -157,20 +178,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatDiagonalSet(Mat Y,Vec D,InsertMode is)
   if (Y->ops->diagonalset) {
     ierr = (*Y->ops->diagonalset)(Y,D,is);CHKERRQ(ierr);
   } else {
-    PetscInt    vstart,vend;
-    PetscScalar *v;
-    ierr = VecGetOwnershipRange(D,&vstart,&vend);CHKERRQ(ierr);
-    ierr = MatGetOwnershipRange(Y,&start,&end);CHKERRQ(ierr);
-    if (vstart != start || vend != end) {
-      SETERRQ4(PETSC_ERR_ARG_SIZ,"Vector ownership range not compatible with matrix: %D %D vec %D %D mat",vstart,vend,start,end);
-    }
-    ierr = VecGetArray(D,&v);CHKERRQ(ierr);
-    for (i=start; i<end; i++) {
-      ierr = MatSetValues(Y,1,&i,1,&i,v+i-start,is);CHKERRQ(ierr);
-    }
-    ierr = VecRestoreArray(D,&v);CHKERRQ(ierr);
-    ierr = MatAssemblyBegin(Y,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-    ierr = MatAssemblyEnd(Y,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+    ierr = MatDiagonalSet_Default(Y,D,is);CHKERRQ(ierr);
   }
   PetscFunctionReturn(0);
 }
@@ -178,20 +186,18 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatDiagonalSet(Mat Y,Vec D,InsertMode is)
 #undef __FUNCT__  
 #define __FUNCT__ "MatAYPX"
 /*@
-   MatAYPX - Computes Y = X + a*Y.
+   MatAYPX - Computes Y = a*Y + X.
 
    Collective on Mat
 
    Input Parameters:
-+  X,Y - the matrices
--  a - the PetscScalar multiplier
-
-   Contributed by: Matthew Knepley
++  a - the PetscScalar multiplier
+.  Y - the first matrix
+.  X - the second matrix
+-  str - either SAME_NONZERO_PATTERN, DIFFERENT_NONZERO_PATTERN or SUBSET_NONZERO_PATTERN 
 
    Notes:
-   This routine currently uses the MatAXPY() implementation.
-
-   This is slow, if you need it fast send email to petsc-maint@mcs.anl.gov
+     Will only be efficient if one has the SAME_NONZERO_PATTERN or SUBSET_NONZERO_PATTERN
 
    Level: intermediate
 
@@ -199,7 +205,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatDiagonalSet(Mat Y,Vec D,InsertMode is)
 
 .seealso: MatAXPY()
  @*/
-PetscErrorCode PETSCMAT_DLLEXPORT MatAYPX(Mat Y,PetscScalar a,Mat X)
+PetscErrorCode PETSCMAT_DLLEXPORT MatAYPX(Mat Y,PetscScalar a,Mat X,MatStructure str)
 {
   PetscScalar    one = 1.0;
   PetscErrorCode ierr;
@@ -214,7 +220,7 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatAYPX(Mat Y,PetscScalar a,Mat X)
   if (mX != mY || nX != nY) SETERRQ4(PETSC_ERR_ARG_SIZ,"Non conforming matrices: %D %D first %D %D second",mX,mY,nX,nY);
 
   ierr = MatScale(Y,a);CHKERRQ(ierr);
-  ierr = MatAXPY(Y,one,X,DIFFERENT_NONZERO_PATTERN);CHKERRQ(ierr);
+  ierr = MatAXPY(Y,one,X,str);CHKERRQ(ierr)
   PetscFunctionReturn(0);
 }
 
