@@ -1,4 +1,4 @@
-/*$Id: convert.c,v 1.76 2001/08/07 03:03:20 balay Exp $*/
+#define PETSCMAT_DLL
 
 #include "src/mat/matimpl.h"
 
@@ -10,18 +10,22 @@
 
   Does not do preallocation so in general will be slow
  */
-int MatConvert_Basic(Mat mat,const MatType newtype,Mat *newmat) {
-  Mat          M;
-  PetscScalar  *vwork;
-  int          ierr,i,nz,m,n,*cwork,rstart,rend,lm,ln;
+PetscErrorCode MatConvert_Basic(Mat mat, MatType newtype,MatReuse reuse,Mat *newmat)
+{
+  Mat                M;
+  const PetscScalar  *vwork;
+  PetscErrorCode     ierr;
+  PetscInt           i,nz,m,n,rstart,rend,lm,ln;
+  const PetscInt     *cwork;
 
   PetscFunctionBegin;
   ierr = MatGetSize(mat,&m,&n);CHKERRQ(ierr);
   ierr = MatGetLocalSize(mat,&lm,&ln);CHKERRQ(ierr);
 
   if (ln == n) ln = PETSC_DECIDE; /* try to preserve column ownership */
-
-  ierr = MatCreate(mat->comm,lm,ln,m,n,&M);CHKERRQ(ierr);
+  
+  ierr = MatCreate(mat->comm,&M);CHKERRQ(ierr);
+  ierr = MatSetSizes(M,lm,ln,m,n);CHKERRQ(ierr);
   ierr = MatSetType(M,newtype);CHKERRQ(ierr);
 
   ierr = MatGetOwnershipRange(mat,&rstart,&rend);CHKERRQ(ierr);
@@ -33,10 +37,10 @@ int MatConvert_Basic(Mat mat,const MatType newtype,Mat *newmat) {
   ierr = MatAssemblyBegin(M,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
   ierr = MatAssemblyEnd(M,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
 
-  /* Fake support for "inplace" convert. */
-  if (*newmat == mat) {
-    ierr = MatDestroy(mat);CHKERRQ(ierr);
+  if (reuse == MAT_REUSE_MATRIX) {
+    ierr = MatHeaderReplace(mat,M);CHKERRQ(ierr);
+  } else {
+    *newmat = M;
   }
-  *newmat = M;
   PetscFunctionReturn(0);
 }
