@@ -225,10 +225,9 @@ PetscErrorCode PETSCMAT_DLLEXPORT MatSetUpPreallocation(Mat B)
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
-  if (B->ops->setuppreallocation) {
+  if (!B->preallocated && B->ops->setuppreallocation) {
     ierr = PetscInfo(B,"Warning not preallocating matrix storage\n");CHKERRQ(ierr);
     ierr = (*B->ops->setuppreallocation)(B);CHKERRQ(ierr);
-    B->ops->setuppreallocation = 0;
   }
   B->preallocated = PETSC_TRUE;
   PetscFunctionReturn(0);
@@ -249,17 +248,17 @@ PetscErrorCode MatHeaderCopy(Mat A,Mat C)
   void           *spptr;
 
   PetscFunctionBegin;
-  /* free all the interior data structures from mat */
-  ierr = (*A->ops->destroy)(A);CHKERRQ(ierr);
-
   /* save the parts of A we need */
   Abops = A->bops;
   Aops  = A->ops;
   refct = A->refct;
-  mtype = A->type_name;
-  mname = A->name;
+  mtype = A->type_name; A->type_name = 0;
+  mname = A->name; A->name = 0;
   spptr = A->spptr;
 
+  /* free all the interior data structures from mat */
+  ierr = (*A->ops->destroy)(A);CHKERRQ(ierr);
+
   ierr = PetscFree(C->spptr);CHKERRQ(ierr);
 
   ierr = PetscFree(A->rmap.range);CHKERRQ(ierr);
