@@ -1,4 +1,3 @@
-/*$Id: ex11.c,v 1.38 1999/11/05 14:47:16 bsmith Exp bsmith $*/
 
 static char help[] =
 "This program demonstrates use of the SNES package to solve systems of\n\
@@ -43,7 +42,7 @@ options are:\n\
 /* User-defined application contexts */
 
 typedef struct {
-   int        mx,my;            /* number grid points in x and y direction */
+   PetscInt        mx,my;            /* number grid points in x and y direction */
    Vec        localX,localF;    /* local vectors with ghost region */
    DA         da;
    Vec        x,b,r;            /* global vectors */
@@ -56,7 +55,7 @@ typedef struct {
    GridCtx     coarse;
    KSP        ksp_coarse;
    KSP        ksp_fine;
-   int         ratio;
+   PetscInt         ratio;
    Mat         R;               /* restriction fine to coarse */
    Vec         Rscale;
    PetscTruth  redundant_build; /* build coarse matrix redundantly */
@@ -68,9 +67,9 @@ typedef struct {
 #define COARSE_LEVEL 0
 #define FINE_LEVEL   1
 
-extern int FormFunction(SNES,Vec,Vec,void*), FormInitialGuess1(AppCtx*,Vec);
-extern int FormJacobian(SNES,Vec,Mat*,Mat*,MatStructure*,void*);
-extern int FormInterpolation(AppCtx *);
+extern PetscErrorCode FormFunction(SNES,Vec,Vec,void*), FormInitialGuess1(AppCtx*,Vec);
+extern PetscErrorCode FormJacobian(SNES,Vec,Mat*,Mat*,MatStructure*,void*);
+extern PetscErrorCode FormInterpolation(AppCtx *);
 
 /*
       Mm_ratio - ration of grid lines between fine and coarse grids.
@@ -79,14 +78,14 @@ extern int FormInterpolation(AppCtx *);
 #define __FUNC__ "main"
 int main( int argc, char **argv )
 {
-  SNES          snes;                      
-  AppCtx        user;                      
-  int           ierr, its, N, n, Nx = PETSC_DECIDE, Ny = PETSC_DECIDE;
-  int           size, nlocal,Nlocal;
-  double        bratu_lambda_max = 6.81, bratu_lambda_min = 0.;
-  KSP          ksp;
-  PC            pc;
-  KSP           ksp;
+  SNES           snes;                      
+  AppCtx         user;                      
+  PetscErrorCode ierr;
+  PetscInt       its, N, n, Nx = PETSC_DECIDE, Ny = PETSC_DECIDE, nlocal,Nlocal;
+  PetscMPIInt    size;
+  double         bratu_lambda_max = 6.81, bratu_lambda_min = 0.;
+  KSP            ksp;
+  PC             pc;
 
   /*
       Initialize PETSc, note that default options in ex11options can be 
@@ -106,8 +105,8 @@ int main( int argc, char **argv )
     ierr = PetscPrintf(PETSC_COMM_WORLD,"Building coarse Jacobian redundantly\n");CHKERRQ(ierr);
   }
 
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Coarse grid size %d by %d\n",user.coarse.mx,user.coarse.my);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Fine grid size %d by %d\n",user.fine.mx,user.fine.my);CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD,"Coarse grid size %D by %D\n",user.coarse.mx,user.coarse.my);CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD,"Fine grid size %D by %D\n",user.fine.mx,user.fine.my);CHKERRQ(ierr);
 
   ierr = PetscOptionsGetReal(PETSC_NULL,"-par",&user.param,PETSC_NULL);CHKERRQ(ierr);
   if (user.param >= bratu_lambda_max || user.param < bratu_lambda_min) {
@@ -161,46 +160,45 @@ int main( int argc, char **argv )
   ierr = SNESGetKSP(snes,&ksp);CHKERRQ(ierr);
   ierr = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
   ierr = PCSetType(pc,PCMG);CHKERRQ(ierr);
-  ierr = MGSetLevels(pc,2,PETSC_NULL);CHKERRQ(ierr);
-  ierr = MGSetType(pc,MGADDITIVE);CHKERRQ(ierr);
+  ierr = PCMGSetLevels(pc,2,PETSC_NULL);CHKERRQ(ierr);
+  ierr = PCMGSetType(pc,PC_MG_ADDITIVE);CHKERRQ(ierr);
 
   /* always solve the coarse problem redundantly with direct LU solver */
   ierr = PetscOptionsSetValue("-coarse_pc_type","redundant");CHKERRQ(ierr);
   ierr = PetscOptionsSetValue("-coarse_redundant_pc_type","lu");CHKERRQ(ierr);
 
   /* Create coarse level */
-  ierr = MGGetCoarseSolve(pc,&user.ksp_coarse);CHKERRQ(ierr);
+  ierr = PCMGGetCoarseSolve(pc,&user.ksp_coarse);CHKERRQ(ierr);
   ierr = KSPSetOptionsPrefix(user.ksp_coarse,"coarse_");CHKERRQ(ierr);
   ierr = KSPSetFromOptions(user.ksp_coarse);CHKERRQ(ierr);
   ierr = KSPSetOperators(user.ksp_coarse,user.coarse.J,user.coarse.J,DIFFERENT_NONZERO_PATTERN);CHKERRQ(ierr);
-  ierr = MGSetX(pc,COARSE_LEVEL,user.coarse.x);CHKERRQ(ierr); 
-  ierr = MGSetRhs(pc,COARSE_LEVEL,user.coarse.b);CHKERRQ(ierr); 
+  ierr = PCMGSetX(pc,COARSE_LEVEL,user.coarse.x);CHKERRQ(ierr); 
+  ierr = PCMGSetRhs(pc,COARSE_LEVEL,user.coarse.b);CHKERRQ(ierr); 
   if (user.redundant_build) {
     PC  rpc;
-    KSP rksp;
     ierr = KSPGetPC(user.ksp_coarse,&rpc);CHKERRQ(ierr);
     ierr = PCRedundantSetScatter(rpc,user.tolocalall,user.fromlocalall);CHKERRQ(ierr);
   }
 
   /* Create fine level */
-  ierr = MGGetSmoother(pc,FINE_LEVEL,&user.ksp_fine);CHKERRQ(ierr);
+  ierr = PCMGGetSmoother(pc,FINE_LEVEL,&user.ksp_fine);CHKERRQ(ierr);
   ierr = KSPSetOptionsPrefix(user.ksp_fine,"fine_");CHKERRQ(ierr);
   ierr = KSPSetFromOptions(user.ksp_fine);CHKERRQ(ierr);
   ierr = KSPSetOperators(user.ksp_fine,user.fine.J,user.fine.J,DIFFERENT_NONZERO_PATTERN);CHKERRQ(ierr);
-  ierr = MGSetR(pc,FINE_LEVEL,user.fine.r);CHKERRQ(ierr); 
-  ierr = MGSetResidual(pc,FINE_LEVEL,MGDefaultResidual,user.fine.J);CHKERRQ(ierr);
+  ierr = PCMGSetR(pc,FINE_LEVEL,user.fine.r);CHKERRQ(ierr); 
+  ierr = PCMGSetResidual(pc,FINE_LEVEL,PCMGDefaultResidual,user.fine.J);CHKERRQ(ierr);
 
   /* Create interpolation between the levels */
   ierr = FormInterpolation(&user);CHKERRQ(ierr);
-  ierr = MGSetInterpolate(pc,FINE_LEVEL,user.R);CHKERRQ(ierr);
-  ierr = MGSetRestriction(pc,FINE_LEVEL,user.R);CHKERRQ(ierr);
+  ierr = PCMGSetInterpolate(pc,FINE_LEVEL,user.R);CHKERRQ(ierr);
+  ierr = PCMGSetRestriction(pc,FINE_LEVEL,user.R);CHKERRQ(ierr);
 
   /* Set options, then solve nonlinear system */
   ierr = SNESSetFromOptions(snes);CHKERRQ(ierr);
   ierr = FormInitialGuess1(&user,user.fine.x);CHKERRQ(ierr);
-  ierr = SNESSolve(snes,user.fine.x);CHKERRQ(ierr);
+  ierr = SNESSolve(snes,PETSC_NULL,user.fine.x);CHKERRQ(ierr);
   ierr = SNESGetIterationNumber(snes,&its);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Newton iterations = %d\n", its );CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Newton iterations = %D\n", its );CHKERRQ(ierr);
 
   /* Free data structures */
   if (user.redundant_build) {
@@ -234,12 +232,13 @@ int main( int argc, char **argv )
 }/* --------------------  Form initial approximation ----------------- */
 #undef __FUNC__
 #define __FUNC__ "FormInitialGuess1"
-int FormInitialGuess1(AppCtx *user,Vec X)
+PetscErrorCode FormInitialGuess1(AppCtx *user,Vec X)
 {
-  int     i, j, row, mx, my, ierr, xs, ys, xm, ym, Xm, Ym, Xs, Ys;
-  double  one = 1.0, lambda, temp1, temp, hx, hy, hxdhy, hydhx,sc;
-  PetscScalar  *x;
-  Vec     localX = user->fine.localX;
+  PetscInt       i, j, row, mx, my, xs, ys, xm, ym, Xm, Ym, Xs, Ys;
+  PetscErrorCode ierr;
+  double         one = 1.0, lambda, temp1, temp, hx, hy, hxdhy, hydhx,sc;
+  PetscScalar    *x;
+  Vec            localX = user->fine.localX;
 
   mx = user->fine.mx;       my = user->fine.my;            lambda = user->param;
   hx = one/(double)(mx-1);  hy = one/(double)(my-1);
@@ -274,13 +273,14 @@ int FormInitialGuess1(AppCtx *user,Vec X)
  /* --------------------  Evaluate Function F(x) --------------------- */
 #undef __FUNC__
 #define __FUNC__ "FormFunction"
-int FormFunction(SNES snes,Vec X,Vec F,void *ptr)
+PetscErrorCode FormFunction(SNES snes,Vec X,Vec F,void *ptr)
 {
-  AppCtx  *user = (AppCtx *) ptr;
-  int     ierr, i, j, row, mx, my, xs, ys, xm, ym, Xs, Ys, Xm, Ym;
-  double  two = 2.0, one = 1.0, lambda,hx, hy, hxdhy, hydhx,sc;
-  PetscScalar  u, uxx, uyy, *x,*f;
-  Vec     localX = user->fine.localX, localF = user->fine.localF; 
+  AppCtx         *user = (AppCtx *) ptr;
+  PetscInt       i, j, row, mx, my, xs, ys, xm, ym, Xs, Ys, Xm, Ym;
+  PetscErrorCode ierr;
+  double         two = 2.0, one = 1.0, lambda,hx, hy, hxdhy, hydhx,sc;
+  PetscScalar    u, uxx, uyy, *x,*f;
+  Vec            localX = user->fine.localX, localF = user->fine.localF; 
 
   mx = user->fine.mx;       my = user->fine.my;       lambda = user->param;
   hx = one/(double)(mx-1);  hy = one/(double)(my-1);
@@ -316,7 +316,7 @@ int FormFunction(SNES snes,Vec X,Vec F,void *ptr)
 
   /* Insert values into global vector */
   ierr = DALocalToGlobal(user->fine.da,localF,INSERT_VALUES,F);CHKERRQ(ierr);
-  PetscLogFlops(11*ym*xm);
+  ierr = PetscLogFlops(11*ym*xm);CHKERRQ(ierr);
   return 0; 
 } 
 
@@ -325,13 +325,13 @@ int FormFunction(SNES snes,Vec X,Vec F,void *ptr)
 */
 #undef __FUNC__
 #define __FUNC__ "FormJacobian_Grid"
-int FormJacobian_Grid(AppCtx *user,GridCtx *grid,Vec X, Mat *J,Mat *B)
+PetscErrorCode FormJacobian_Grid(AppCtx *user,GridCtx *grid,Vec X, Mat *J,Mat *B)
 {
-  Mat     jac = *J;
-  int     ierr, i, j, row, mx, my, xs, ys, xm, ym, Xs, Ys, Xm, Ym, col[5];
-  int     nloc, *ltog, grow;
-  PetscScalar  two = 2.0, one = 1.0, lambda, v[5], hx, hy, hxdhy, hydhx, sc, *x, value;
-  Vec     localX = grid->localX;
+  Mat            jac = *J;
+  PetscErrorCode ierr;
+  PetscInt       i, j, row, mx, my, xs, ys, xm, ym, Xs, Ys, Xm, Ym, col[5], nloc, *ltog, grow;
+  PetscScalar    two = 2.0, one = 1.0, lambda, v[5], hx, hy, hxdhy, hydhx, sc, *x, value;
+  Vec            localX = grid->localX;
 
   mx = grid->mx;            my = grid->my;            lambda = user->param;
   hx = one/(double)(mx-1);  hy = one/(double)(my-1);
@@ -385,11 +385,12 @@ int FormJacobian_Grid(AppCtx *user,GridCtx *grid,Vec X, Mat *J,Mat *B)
 */
 #undef __FUNC__
 #define __FUNC__ "FormJacobian_Coarse"
-int FormJacobian_Coarse(AppCtx *user,GridCtx *grid,Vec X, Mat *J,Mat *B)
+PetscErrorCode FormJacobian_Coarse(AppCtx *user,GridCtx *grid,Vec X, Mat *J,Mat *B)
 {
-  Mat     jac = *J;
-  int     ierr, i, j, row, mx, my, col[5];
-  PetscScalar  two = 2.0, one = 1.0, lambda, v[5], hx, hy, hxdhy, hydhx, sc, *x, value;
+  Mat            jac = *J;
+  PetscErrorCode ierr;
+  PetscInt       i, j, row, mx, my, col[5];
+  PetscScalar    two = 2.0, one = 1.0, lambda, v[5], hx, hy, hxdhy, hydhx, sc, *x, value;
 
   mx = grid->mx;            my = grid->my;            lambda = user->param;
   hx = one/(double)(mx-1);  hy = one/(double)(my-1);
@@ -428,14 +429,13 @@ int FormJacobian_Coarse(AppCtx *user,GridCtx *grid,Vec X, Mat *J,Mat *B)
 /* --------------------  Evaluate Jacobian F'(x) --------------------- */
 #undef __FUNC__
 #define __FUNC__ "FormJacobian"
-int FormJacobian(SNES snes,Vec X,Mat *J,Mat *B,MatStructure *flag,void *ptr)
+PetscErrorCode FormJacobian(SNES snes,Vec X,Mat *J,Mat *B,MatStructure *flag,void *ptr)
 {
-  AppCtx     *user = (AppCtx *) ptr;
-  int        ierr;
-  KSP       ksp;
-  PC         pc;
-  PetscTruth ismg;
-  KSP        ksp;
+  AppCtx         *user = (AppCtx *) ptr;
+  PetscErrorCode ierr;
+  KSP            ksp;
+  PC             pc;
+  PetscTruth     ismg;
 
   *flag = SAME_NONZERO_PATTERN;
   ierr = FormJacobian_Grid(user,&user->fine,X,J,B);CHKERRQ(ierr);
@@ -451,7 +451,7 @@ int FormJacobian(SNES snes,Vec X,Mat *J,Mat *B,MatStructure *flag,void *ptr)
 
     /* restrict X to coarse grid */
     ierr = MatMult(user->R,X,user->coarse.x);CHKERRQ(ierr);
-    ierr = VecPointwiseMult(user->Rscale,user->coarse.x,user->coarse.x);CHKERRQ(ierr);
+    ierr = VecPointwiseMult(user->coarse.x,user->coarse.x,user->Rscale);CHKERRQ(ierr);
 
     /* form Jacobian on coarse grid */
     if (user->redundant_build) {
@@ -477,16 +477,17 @@ int FormJacobian(SNES snes,Vec X,Mat *J,Mat *B,MatStructure *flag,void *ptr)
       Forms the interpolation (and restriction) operator from 
 coarse grid to fine.
 */
-int FormInterpolation(AppCtx *user)
+PetscErrorCode FormInterpolation(AppCtx *user)
 {
-  int      ierr,i,j,i_start,m_fine,j_start,m,n,M,Mx = user->coarse.mx,My = user->coarse.my,*idx;
-  int      m_ghost,n_ghost,*idx_c,m_ghost_c,n_ghost_c,m_coarse;
-  int      row,i_start_ghost,j_start_ghost,cols[4],mx = user->fine.mx, m_c,my = user->fine.my;
-  int      c0,c1,c2,c3,nc,ratio = user->ratio,i_end,i_end_ghost,m_c_local,m_fine_local;
-  int      i_c,j_c,i_start_c,j_start_c,n_c,i_start_ghost_c,j_start_ghost_c,col;
-  PetscScalar   v[4],x,y, one = 1.0;
-  Mat      mat;
-  Vec      Rscale;
+  PetscErrorCode ierr;
+  PetscInt       i,j,i_start,m_fine,j_start,m,n,*idx;
+  PetscInt       m_ghost,n_ghost,*idx_c,m_ghost_c,n_ghost_c,m_coarse;
+  PetscInt       row,i_start_ghost,j_start_ghost,cols[4], m_c;
+  PetscInt       nc,ratio = user->ratio,m_c_local,m_fine_locaol;
+  PetscInt       i_c,j_c,i_start_c,j_start_c,n_c,i_start_ghost_c,j_start_ghost_c,col;
+  PetscScalar    v[4],x,y, one = 1.0;
+  Mat            mat;
+  Vec            Rscale;
   
   ierr = DAGetCorners(user->fine.da,&i_start,&j_start,0,&m,&n,0);CHKERRQ(ierr);
   ierr = DAGetGhostCorners(user->fine.da,&i_start_ghost,&j_start_ghost,0,&m_ghost,&n_ghost,0);CHKERRQ(ierr);
@@ -520,14 +521,13 @@ int FormInterpolation(AppCtx *user)
       */
       x  = ((double)(i - i_c*ratio))/((double)ratio);
       y  = ((double)(j - j_c*ratio))/((double)ratio);
-      /* printf("i j %d %d %g %g\n",i,j,x,y); */
       nc = 0;
       /* one left and below; or we are right on it */
       if (j_c < j_start_ghost_c || j_c > j_start_ghost_c+n_ghost_c) {
-        SETERRQ3(1,"Sorry j %d %d %d",j_c,j_start_ghost_c,j_start_ghost_c+n_ghost_c);
+        SETERRQ3(1,"Sorry j %D %D %D",j_c,j_start_ghost_c,j_start_ghost_c+n_ghost_c);
       }
       if (i_c < i_start_ghost_c || i_c > i_start_ghost_c+m_ghost_c) {
-        SETERRQ3(1,"Sorry i %d %d %d",i_c,i_start_ghost_c,i_start_ghost_c+m_ghost_c);
+        SETERRQ3(1,"Sorry i %D %D %D",i_c,i_start_ghost_c,i_start_ghost_c+m_ghost_c);
       }
       col      = m_ghost_c*(j_c-j_start_ghost_c) + (i_c-i_start_ghost_c);
       cols[nc] = idx_c[col];
@@ -554,7 +554,7 @@ int FormInterpolation(AppCtx *user)
   ierr = MatAssemblyEnd(mat,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
 
   ierr = VecDuplicate(user->coarse.x,&Rscale);CHKERRQ(ierr);
-  ierr = VecSet(&one,user->fine.x);CHKERRQ(ierr);
+  ierr = VecSet(user->fine.x,one);CHKERRQ(ierr);
   ierr = MatMultTranspose(mat,user->fine.x,Rscale);CHKERRQ(ierr);
   ierr = VecReciprocal(Rscale);CHKERRQ(ierr);
   user->Rscale = Rscale;
