@@ -1,4 +1,3 @@
-/*$Id: ex13.c,v 1.33 2001/08/07 21:31:12 bsmith Exp $*/
 
 static char help[] = "This program is a replica of ex6.c except that it does 2 solves to avoid paging.\n\
 This program demonstrates use of the SNES package to solve systems of\n\
@@ -34,26 +33,27 @@ options are:\n\
 /* User-defined application context */
 typedef struct {
    PetscReal   param;         /* test problem parameter */
-   int         mx,my;         /* discretization in x, y directions */
+   PetscInt    mx,my;         /* discretization in x, y directions */
    Vec         localX,localF; /* ghosted local vector */
    DA          da;            /* distributed array data structure */
 } AppCtx;
 
-extern int FormFunction1(SNES,Vec,Vec,void*),FormInitialGuess1(AppCtx*,Vec);
-extern int FormJacobian1(SNES,Vec,Mat*,Mat*,MatStructure*,void*);
+extern PetscErrorCode FormFunction1(SNES,Vec,Vec,void*),FormInitialGuess1(AppCtx*,Vec);
+extern PetscErrorCode FormJacobian1(SNES,Vec,Mat*,Mat*,MatStructure*,void*);
 
 #undef __FUNCT__
 #define __FUNCT__ "main"
 int main(int argc,char **argv)
 {
   SNES           snes;                      /* nonlinear solver */
-  const SNESType type = SNESLS;             /* nonlinear solution method */
+  SNESType       type = SNESLS;             /* nonlinear solution method */
   Vec            x,r;                       /* solution, residual vectors */
   Mat            J;                         /* Jacobian matrix */
   AppCtx         user;                      /* user-defined work context */
-  int            i,ierr,its,N,Nx = PETSC_DECIDE,Ny = PETSC_DECIDE;
+  PetscInt       i,its,N,Nx = PETSC_DECIDE,Ny = PETSC_DECIDE;
+  PetscErrorCode ierr;
   PetscTruth     matrix_free;
-  int            size; 
+  PetscMPIInt    size; 
   PetscReal      bratu_lambda_max = 6.81,bratu_lambda_min = 0.;
 
   PetscInitialize(&argc,&argv,(char *)0,help);
@@ -98,7 +98,8 @@ int main(int argc,char **argv)
        */
     ierr = PetscOptionsHasName(PETSC_NULL,"-snes_mf",&matrix_free);CHKERRQ(ierr);
     if (!matrix_free) {
-      ierr = MatCreate(PETSC_COMM_WORLD,PETSC_DECIDE,PETSC_DECIDE,N,N,&J);CHKERRQ(ierr);
+      ierr = MatCreate(PETSC_COMM_WORLD,&J);CHKERRQ(ierr);
+      ierr = MatSetSizes(J,PETSC_DECIDE,PETSC_DECIDE,N,N);CHKERRQ(ierr);
       ierr = MatSetFromOptions(J);CHKERRQ(ierr);
       ierr = SNESSetJacobian(snes,J,J,FormJacobian1,&user);CHKERRQ(ierr);
     }
@@ -106,9 +107,9 @@ int main(int argc,char **argv)
     /* Set PetscOptions, then solve nonlinear system */
     ierr = SNESSetFromOptions(snes);CHKERRQ(ierr);
     ierr = FormInitialGuess1(&user,x);CHKERRQ(ierr);
-    ierr = SNESSolve(snes,x);CHKERRQ(ierr);
+    ierr = SNESSolve(snes,PETSC_NULL,x);CHKERRQ(ierr);
     ierr = SNESGetIterationNumber(snes,&its);CHKERRQ(ierr);
-    ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Newton iterations = %d\n",its);CHKERRQ(ierr);
+    ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Newton iterations = %D\n",its);CHKERRQ(ierr);
 
   /* Free data structures */
     if (!matrix_free) {
@@ -127,12 +128,13 @@ int main(int argc,char **argv)
 }/* --------------------  Form initial approximation ----------------- */
 #undef __FUNCT__
 #define __FUNCT__ "FormInitialGuess1"
-int FormInitialGuess1(AppCtx *user,Vec X)
+PetscErrorCode FormInitialGuess1(AppCtx *user,Vec X)
 {
-  int          i,j,row,mx,my,ierr,xs,ys,xm,ym,Xm,Ym,Xs,Ys;
-  PetscReal    one = 1.0,lambda,temp1,temp,hx,hy;
-  PetscScalar  *x;
-  Vec          localX = user->localX;
+  PetscInt       i,j,row,mx,my,xs,ys,xm,ym,Xm,Ym,Xs,Ys;
+  PetscErrorCode ierr;
+  PetscReal      one = 1.0,lambda,temp1,temp,hx,hy;
+  PetscScalar    *x;
+  Vec            localX = user->localX;
 
   mx = user->mx;            my = user->my;            lambda = user->param;
   hx = one/(PetscReal)(mx-1);  hy = one/(PetscReal)(my-1);
@@ -163,13 +165,14 @@ int FormInitialGuess1(AppCtx *user,Vec X)
 } /* --------------------  Evaluate Function F(x) --------------------- */
 #undef __FUNCT__
 #define __FUNCT__ "FormFunction1"
-int FormFunction1(SNES snes,Vec X,Vec F,void *ptr)
+PetscErrorCode FormFunction1(SNES snes,Vec X,Vec F,void *ptr)
 {
-  AppCtx       *user = (AppCtx*)ptr;
-  int          ierr,i,j,row,mx,my,xs,ys,xm,ym,Xs,Ys,Xm,Ym;
-  PetscReal    two = 2.0,one = 1.0,lambda,hx,hy,hxdhy,hydhx,sc;
-  PetscScalar  u,uxx,uyy,*x,*f;
-  Vec          localX = user->localX,localF = user->localF; 
+  AppCtx         *user = (AppCtx*)ptr;
+  PetscErrorCode ierr;
+  PetscInt       i,j,row,mx,my,xs,ys,xm,ym,Xs,Ys,Xm,Ym;
+  PetscReal      two = 2.0,one = 1.0,lambda,hx,hy,hxdhy,hydhx,sc;
+  PetscScalar    u,uxx,uyy,*x,*f;
+  Vec            localX = user->localX,localF = user->localF; 
 
   mx = user->mx;            my = user->my;            lambda = user->param;
   hx = one/(PetscReal)(mx-1);  hy = one/(PetscReal)(my-1);
@@ -208,14 +211,15 @@ int FormFunction1(SNES snes,Vec X,Vec F,void *ptr)
 } /* --------------------  Evaluate Jacobian F'(x) --------------------- */
 #undef __FUNCT__
 #define __FUNCT__ "FormJacobian1"
-int FormJacobian1(SNES snes,Vec X,Mat *J,Mat *B,MatStructure *flag,void *ptr)
+PetscErrorCode FormJacobian1(SNES snes,Vec X,Mat *J,Mat *B,MatStructure *flag,void *ptr)
 {
-  AppCtx  *user = (AppCtx*)ptr;
-  Mat     jac = *J;
-  int     ierr,i,j,row,mx,my,xs,ys,xm,ym,Xs,Ys,Xm,Ym,col[5];
-  int     nloc,*ltog,grow;
-  PetscScalar  two = 2.0,one = 1.0,lambda,v[5],hx,hy,hxdhy,hydhx,sc,*x;
-  Vec     localX = user->localX;
+  AppCtx         *user = (AppCtx*)ptr;
+  Mat            jac = *J;
+  PetscErrorCode ierr;
+  PetscInt       i,j,row,mx,my,xs,ys,xm,ym,Xs,Ys,Xm,Ym,col[5];
+  PetscInt       nloc,*ltog,grow;
+  PetscScalar    two = 2.0,one = 1.0,lambda,v[5],hx,hy,hxdhy,hydhx,sc,*x;
+  Vec            localX = user->localX;
 
   mx = user->mx;            my = user->my;            lambda = user->param;
   hx = one/(PetscReal)(mx-1);  hy = one/(PetscReal)(my-1);
