@@ -1,4 +1,3 @@
-/*$Id: ex9.c,v 1.52 2001/08/07 21:31:12 bsmith Exp $*/
 
 static char help[] = "This program demonstrates use of the SNES package. Solve systems of\n\
 nonlinear equations in parallel.  This example uses matrix-free Krylov\n\
@@ -30,28 +29,28 @@ ignition) test problem. The command line options are:\n\
 
 typedef struct {
     PetscReal param;           /* test problem nonlinearity parameter */
-    int       mx,my,mz;      /* discretization in x,y,z-directions */
+    PetscInt  mx,my,mz;      /* discretization in x,y,z-directions */
     Vec       localX,localF;  /* ghosted local vectors */
     DA        da;              /* distributed array datastructure */
 } AppCtx;
 
-extern int FormFunction1(SNES,Vec,Vec,void*),FormInitialGuess1(AppCtx*,Vec);
+extern PetscErrorCode  FormFunction1(SNES,Vec,Vec,void*),FormInitialGuess1(AppCtx*,Vec);
 
 #undef __FUNCT__
 #define __FUNCT__ "main"
 int main(int argc,char **argv)
 {
-  SNES          snes;                 /* nonlinear solver */
-  KSP           ksp;                 /* linear solver */
-  PC            pc;                   /* preconditioner */
-  Mat           J;                    /* Jacobian matrix */
-  AppCtx        user;                 /* user-defined application context */
-  Vec           x,r;                  /* vectors */
-  DAStencilType stencil = DA_STENCIL_BOX;
-  int           ierr,its;
-  PetscTruth    flg;
-  int           Nx = PETSC_DECIDE,Ny = PETSC_DECIDE,Nz = PETSC_DECIDE; 
-  PetscReal     bratu_lambda_max = 6.81,bratu_lambda_min = 0.;
+  SNES           snes;                 /* nonlinear solver */
+  KSP            ksp;                 /* linear solver */
+  PC             pc;                   /* preconditioner */
+  Mat            J;                    /* Jacobian matrix */
+  AppCtx         user;                 /* user-defined application context */
+  Vec            x,r;                  /* vectors */
+  DAStencilType  stencil = DA_STENCIL_BOX;
+  PetscErrorCode ierr;
+  PetscTruth     flg;
+  PetscInt       Nx = PETSC_DECIDE,Ny = PETSC_DECIDE,Nz = PETSC_DECIDE,its;
+  PetscReal      bratu_lambda_max = 6.81,bratu_lambda_min = 0.;
 
   PetscInitialize(&argc,&argv,(char *)0,help);
   ierr = PetscOptionsHasName(PETSC_NULL,"-star",&flg);CHKERRQ(ierr);
@@ -83,7 +82,7 @@ int main(int argc,char **argv)
   /* Create nonlinear solver */
   ierr = SNESCreate(PETSC_COMM_WORLD,&snes);CHKERRQ(ierr);
   /* Set various routines and options */
-  ierr = SNESSetFunction(snes,r,FormFunction1,(void *)&user);CHKERRQ(ierr);
+  ierr = SNESSetFunction(snes,r,FormFunction1,(void*)&user);CHKERRQ(ierr);
   ierr = MatCreateSNESMF(snes,x,&J);CHKERRQ(ierr);
   ierr = SNESSetJacobian(snes,J,J,MatSNESMFComputeJacobian,&user);CHKERRQ(ierr);
   ierr = SNESSetFromOptions(snes);CHKERRQ(ierr);
@@ -96,9 +95,9 @@ int main(int argc,char **argv)
 
   /* Solve nonlinear system */
   ierr = FormInitialGuess1(&user,x);CHKERRQ(ierr);
-  ierr = SNESSolve(snes,x);CHKERRQ(ierr);
+  ierr = SNESSolve(snes,PETSC_NULL,x);CHKERRQ(ierr);
   ierr = SNESGetIterationNumber(snes,&its);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Newton iterations = %d\n",its);CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Newton iterations = %D\n",its);CHKERRQ(ierr);
 
   /* Free data structures */
   ierr = VecDestroy(user.localX);CHKERRQ(ierr);
@@ -112,12 +111,13 @@ int main(int argc,char **argv)
 }/* --------------------  Form initial approximation ----------------- */
 #undef __FUNCT__
 #define __FUNCT__ "FormInitialGuess1"
-int FormInitialGuess1(AppCtx *user,Vec X)
+PetscErrorCode  FormInitialGuess1(AppCtx *user,Vec X)
 {
-  int          i,j,k,loc,mx,my,mz,ierr,xs,ys,zs,xm,ym,zm,Xm,Ym,Zm,Xs,Ys,Zs,base1;
-  PetscReal    one = 1.0,lambda,temp1,temp,Hx,Hy;
-  PetscScalar  *x;
-  Vec          localX = user->localX;
+  PetscInt       i,j,k,loc,mx,my,mz,xs,ys,zs,xm,ym,zm,Xm,Ym,Zm,Xs,Ys,Zs,base1;
+  PetscErrorCode ierr;
+  PetscReal      one = 1.0,lambda,temp1,temp,Hx,Hy;
+  PetscScalar    *x;
+  Vec            localX = user->localX;
 
   mx	 = user->mx; my	 = user->my; mz = user->mz; lambda = user->param;
   Hx     = one / (PetscReal)(mx-1);     Hy     = one / (PetscReal)(my-1);
@@ -149,14 +149,14 @@ int FormInitialGuess1(AppCtx *user,Vec X)
 }/* --------------------  Evaluate Function F(x) --------------------- */
 #undef __FUNCT__
 #define __FUNCT__ "FormFunction1"
-int FormFunction1(SNES snes,Vec X,Vec F,void *ptr)
+PetscErrorCode  FormFunction1(SNES snes,Vec X,Vec F,void *ptr)
 {
-  AppCtx       *user = (AppCtx*)ptr;
-  int          ierr,i,j,k,loc,mx,my,mz,xs,ys,zs,xm,ym,zm,Xs,Ys,Zs,Xm,Ym,Zm;
-  int          base1,base2;
-  PetscReal    two = 2.0,one = 1.0,lambda,Hx,Hy,Hz,HxHzdHy,HyHzdHx,HxHydHz;
-  PetscScalar  u,uxx,uyy,sc,*x,*f,uzz;
-  Vec          localX = user->localX,localF = user->localF; 
+  AppCtx         *user = (AppCtx*)ptr;
+  PetscErrorCode ierr;
+  PetscInt       i,j,k,loc,mx,my,mz,xs,ys,zs,xm,ym,zm,Xs,Ys,Zs,Xm,Ym,Zm,base1,base2;
+  PetscReal      two = 2.0,one = 1.0,lambda,Hx,Hy,Hz,HxHzdHy,HyHzdHx,HxHydHz;
+  PetscScalar    u,uxx,uyy,sc,*x,*f,uzz;
+  Vec            localX = user->localX,localF = user->localF; 
 
   mx      = user->mx; my = user->my; mz = user->mz; lambda = user->param;
   Hx      = one / (PetscReal)(mx-1);
