@@ -259,8 +259,11 @@ PetscErrorCode FormFunctionLocal(DALocalInfo *info,Field **x,Field **f,void *ptr
 
   /* 
      Define mesh intervals ratios for uniform grid.
-     [Note: FD formulae below are normalized by multiplying through by
-     local volume element to obtain coefficients O(1) in two dimensions.]
+
+     Note: FD formulae below are normalized by multiplying through by
+     local volume element (i.e. hx*hy) to obtain coefficients O(1) in two dimensions.
+
+     
   */
   dhx = (PetscReal)(info->mx-1);  dhy = (PetscReal)(info->my-1);
   hx = 1.0/dhx;                   hy = 1.0/dhy;
