@@ -1,5 +1,3 @@
-/* $Id: ex20.c,v 1.20 2001/08/07 21:31:17 bsmith Exp $ */
-
 
 static char help[] ="Nonlinear Radiative Transport PDE with multigrid in 3d.\n\
 Uses 3-dimensional distributed arrays.\n\
@@ -44,6 +42,7 @@ T*/
 #include "petscsnes.h"
 #include "petscda.h"
 #include "petscmg.h"
+#include "petscdmmg.h"
 
 /* User-defined application context */
 
@@ -54,20 +53,21 @@ typedef struct {
 
 #define POWFLOP 5 /* assume a pow() takes five flops */
 
-extern int FormInitialGuess(SNES,Vec,void*);
-extern int FormFunction(SNES,Vec,Vec,void*);
-extern int FormJacobian(SNES,Vec,Mat*,Mat*,MatStructure*,void*);
+extern PetscErrorCode FormInitialGuess(DMMG,Vec);
+extern PetscErrorCode FormFunction(SNES,Vec,Vec,void*);
+extern PetscErrorCode FormJacobian(SNES,Vec,Mat*,Mat*,MatStructure*,void*);
 
 #undef __FUNCT__
 #define __FUNCT__ "main"
 int main(int argc,char **argv)
 {
-  DMMG      *dmmg;
-  SNES      snes;                      
-  AppCtx    user;
-  int       ierr,its,lits;
-  PetscReal litspit;
-  DA        da;
+  DMMG           *dmmg;
+  SNES           snes;                      
+  AppCtx         user;
+  PetscErrorCode ierr;
+  PetscInt       its,lits;
+  PetscReal      litspit;
+  DA             da;
 
   PetscInitialize(&argc,&argv,PETSC_NULL,help);
 
@@ -114,8 +114,8 @@ int main(int argc,char **argv)
   ierr = SNESGetIterationNumber(snes,&its);CHKERRQ(ierr);
   ierr = SNESGetNumberLinearIterations(snes,&lits);CHKERRQ(ierr);
   litspit = ((PetscReal)lits)/((PetscReal)its);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Newton iterations = %d\n",its);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Linear iterations = %d\n",lits);CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Newton iterations = %D\n",its);CHKERRQ(ierr);
+  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of Linear iterations = %D\n",lits);CHKERRQ(ierr);
   ierr = PetscPrintf(PETSC_COMM_WORLD,"Average Linear its / Newton = %e\n",litspit);CHKERRQ(ierr);
 
   ierr = DMMGDestroy(dmmg);CHKERRQ(ierr);
@@ -126,13 +126,13 @@ int main(int argc,char **argv)
 /* --------------------  Form initial approximation ----------------- */
 #undef __FUNCT__
 #define __FUNCT__ "FormInitialGuess"
-int FormInitialGuess(SNES snes,Vec X,void *ptr)
+PetscErrorCode FormInitialGuess(DMMG dmmg,Vec X)
 {
-  DMMG        dmmg = (DMMG)ptr;
-  AppCtx      *user = (AppCtx*)dmmg->user;
-  int         i,j,k,ierr,xs,ys,xm,ym,zs,zm;
-  PetscReal   tleft = user->tleft;
-  PetscScalar ***x;
+  AppCtx         *user = (AppCtx*)dmmg->user;
+  PetscInt       i,j,k,xs,ys,xm,ym,zs,zm;
+  PetscErrorCode ierr;
+  PetscReal      tleft = user->tleft;
+  PetscScalar    ***x;
 
   PetscFunctionBegin;
 
@@ -154,17 +154,18 @@ int FormInitialGuess(SNES snes,Vec X,void *ptr)
 /* --------------------  Evaluate Function F(x) --------------------- */
 #undef __FUNCT__
 #define __FUNCT__ "FormFunction"
-int FormFunction(SNES snes,Vec X,Vec F,void* ptr)
+PetscErrorCode FormFunction(SNES snes,Vec X,Vec F,void* ptr)
 {
-  DMMG         dmmg = (DMMG)ptr;
-  AppCtx       *user = (AppCtx*)dmmg->user;
-  int          ierr,i,j,k,mx,my,mz,xs,ys,zs,xm,ym,zm;
-  PetscScalar  zero = 0.0,one = 1.0;
-  PetscScalar  hx,hy,hz,hxhydhz,hyhzdhx,hzhxdhy;
-  PetscScalar  t0,tn,ts,te,tw,an,as,ae,aw,dn,ds,de,dw,fn = 0.0,fs = 0.0,fe =0.0,fw = 0.0;
-  PetscScalar  tleft,tright,beta,td,ad,dd,fd,tu,au,du,fu;
-  PetscScalar  ***x,***f;
-  Vec          localX;
+  DMMG           dmmg = (DMMG)ptr;
+  AppCtx         *user = (AppCtx*)dmmg->user;
+  PetscErrorCode ierr;
+  PetscInt       i,j,k,mx,my,mz,xs,ys,zs,xm,ym,zm;
+  PetscScalar    zero = 0.0,one = 1.0;
+  PetscScalar    hx,hy,hz,hxhydhz,hyhzdhx,hzhxdhy;
+  PetscScalar    t0,tn,ts,te,tw,an,as,ae,aw,dn,ds,de,dw,fn = 0.0,fs = 0.0,fe =0.0,fw = 0.0;
+  PetscScalar    tleft,tright,beta,td,ad,dd,fd,tu,au,du,fu;
+  PetscScalar    ***x,***f;
+  Vec            localX;
 
   PetscFunctionBegin;
   ierr = DAGetLocalVector((DA)dmmg->dm,&localX);CHKERRQ(ierr);
@@ -469,19 +470,20 @@ int FormFunction(SNES snes,Vec X,Vec F,void* ptr)
 /* --------------------  Evaluate Jacobian F(x) --------------------- */
 #undef __FUNCT__
 #define __FUNCT__ "FormJacobian"
-int FormJacobian(SNES snes,Vec X,Mat *J,Mat *B,MatStructure *flg,void *ptr)
+PetscErrorCode FormJacobian(SNES snes,Vec X,Mat *J,Mat *B,MatStructure *flg,void *ptr)
 {
-  DMMG         dmmg = (DMMG)ptr;
-  AppCtx       *user = (AppCtx*)dmmg->user;
-  int          ierr,i,j,k,mx,my,mz,xs,ys,zs,xm,ym,zm;
-  PetscScalar  zero = 0.0,one = 1.0;
-  PetscScalar  hx,hy,hz,hxhydhz,hyhzdhx,hzhxdhy;
-  PetscScalar  t0,tn,ts,te,tw,an,as,ae,aw,dn,ds,de,dw,fn = 0.0,fs = 0.0,fe =0.0,fw = 0.0;
-  PetscScalar  tleft,tright,beta,td,ad,dd,fd,tu,au,du,fu,v[7],bm1,coef;
-  PetscScalar  ***x,bn,bs,be,bw,bu,bd,gn,gs,ge,gw,gu,gd;
-  Vec          localX;
-  MatStencil   c[7],row;
-  Mat          jac = *B;
+  DMMG           dmmg = (DMMG)ptr;
+  AppCtx         *user = (AppCtx*)dmmg->user;
+  PetscErrorCode ierr;
+  PetscInt       i,j,k,mx,my,mz,xs,ys,zs,xm,ym,zm;
+  PetscScalar    one = 1.0;
+  PetscScalar    hx,hy,hz,hxhydhz,hyhzdhx,hzhxdhy;
+  PetscScalar    t0,tn,ts,te,tw,an,as,ae,aw,dn,ds,de,dw;
+  PetscScalar    tleft,tright,beta,td,ad,dd,tu,au,du,v[7],bm1,coef;
+  PetscScalar    ***x,bn,bs,be,bw,bu,bd,gn,gs,ge,gw,gu,gd;
+  Vec            localX;
+  MatStencil     c[7],row;
+  Mat            jac = *B;
 
   PetscFunctionBegin;
   ierr = DAGetLocalVector((DA)dmmg->dm,&localX);CHKERRQ(ierr);
