@@ -58,8 +58,8 @@ PetscInt DAVecHDFOutput(DA,Vec,char*);
 #define D_xx(x,m,i,j) ((x[(j)][(i)+1].m - two*x[(j)][(i)].m + x[(j)][(i)-1].m) * hydhx * dhxdhy)
 #define D_yy(x,m,i,j) ((x[(j)+1][(i)].m - two*x[(j)][(i)].m + x[(j)-1][(i)].m) * hxdhy * dhxdhy)
 #define Lapl(x,m,i,j) (D_xx(x,m,i,j) + D_yy(x,m,i,j))
-#define lx            (2.*PETSC_PI)
-#define ly            (4.*PETSC_PI)
+#define lx            (2.*3.1415926)
+#define ly            (4.*3.1415926)
 #define sqr(a)        ((a)*(a))
 
 /* 
@@ -97,12 +97,12 @@ typedef struct {
   PetscTruth   draw_contours;    /* flag - 1 indicates drawing contours */
   PetscTruth   second_order;
   PetscTruth   PreLoading;
-} Parameter;
+} Parameters;
 
 typedef struct {
   Vec          Xoldold,Xold;
   TstepCtx     *tsCtx;
-  Parameter    *param;
+  Parameters    *param;
 } AppCtx;
 
 extern PetscErrorCode FormFunctionLocal(DALocalInfo*,Field**,Field**,void*);
@@ -112,6 +112,7 @@ extern PetscErrorCode AddTSTermLocal(DALocalInfo*,Field **,Field **,AppCtx *);
 extern PetscErrorCode AddTSTermLocal2(DALocalInfo*,Field **,Field **,AppCtx *);
 extern PetscErrorCode Gnuplot(DA, Vec, double);
 extern PetscErrorCode FormFunctionLocali(DALocalInfo*,MatStencil*,Field**,PetscScalar*,void*);
+extern PetscErrorCode FormFunctionLocali4(DALocalInfo*,MatStencil*,Field**,PetscScalar*,void*);
 extern PetscErrorCode CreateNullSpace(DMMG,Vec*);
 
 #undef __FUNCT__
@@ -122,7 +123,7 @@ int main(int argc,char **argv)
   DMMG           *dmmg;       /* multilevel grid structure */
   AppCtx         *user;       /* user-defined work context (one for each level) */
   TstepCtx       tsCtx;       /* time-step parameters (one total) */
-  Parameter      param;       /* physical parameters (one total) */
+  Parameters      param;       /* physical parameters (one total) */
   PetscInt       i,m,n,mx,my;
   DA             da;
   PetscReal      dt_ratio;
@@ -164,6 +165,7 @@ int main(int argc,char **argv)
     param.eta   = 1e-3;
     param.d_e   = 0.2;
     param.rho_s = 0;
+    param.second_order = PETSC_FALSE;
 
     ierr = PetscOptionsGetReal(PETSC_NULL, "-viscosity", &param.nu,PETSC_NULL);CHKERRQ(ierr);
 
@@ -247,20 +249,24 @@ int main(int argc,char **argv)
        Create nonlinear solver context
        
        Process adiC(20):  AddTSTermLocal AddTSTermLocal2 FormFunctionLocal FormFunctionLocali
+       Process blockadiC(4):  FormFunctionLocali4
        - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
     ierr = DMMGSetSNESLocal(dmmg, FormFunctionLocal, 0,ad_FormFunctionLocal, admf_FormFunctionLocal);CHKERRQ(ierr);
-    ierr = DMMGSetSNESLocali(dmmg,FormFunctionLocali,ad_FormFunctionLocali,admf_FormFunctionLocali);CHKERRQ(ierr);
-
-    /* attach nullspace to each level of the preconditioner */
+    ierr = DMMGSetSNESLocali(dmmg,FormFunctionLocali,0,admf_FormFunctionLocali);CHKERRQ(ierr);
+    ierr = DMMGSetSNESLocalib(dmmg,FormFunctionLocali4,0,admfb_FormFunctionLocali4);CHKERRQ(ierr);
+  
+   /* attach nullspace to each level of the preconditioner */
     ierr = DMMGSetNullSpace(dmmg,PETSC_FALSE,1,CreateNullSpace);CHKERRQ(ierr);
+    
+    ierr = PetscPrintf(PETSC_COMM_WORLD, "finish setupNull!");
 
     if (PreLoading) {
-      ierr = PetscPrintf(PETSC_COMM_WORLD, "# viscosity = %g, resistivity = %g, "
-			 "skin_depth # = %g, larmor_radius # = %g\n",
+      ierr = PetscPrintf(PETSC_COMM_WORLD, "# viscosity = %G, resistivity = %G, "
+			 "skin_depth # = %G, larmor_radius # = %G\n",
 			 param.nu, param.eta, param.d_e, param.rho_s);CHKERRQ(ierr);
       ierr = DAGetInfo(DMMGGetDA(dmmg),0,&m,&n,0,0,0,0,0,0,0,0);CHKERRQ(ierr);
       ierr = PetscPrintf(PETSC_COMM_WORLD,"Problem size %D by %D\n",m,n);CHKERRQ(ierr);
-      ierr = PetscPrintf(PETSC_COMM_WORLD,"dx %g dy %g dt %g ratio dt/min(dx,dy) %g\n",lx/mx,ly/my,tsCtx.dt,dt_ratio);CHKERRQ(ierr);
+      ierr = PetscPrintf(PETSC_COMM_WORLD,"dx %G dy %G dt %G ratio dt/min(dx,dy) %G\n",lx/mx,ly/my,tsCtx.dt,dt_ratio);CHKERRQ(ierr);
     }
 
     
@@ -324,7 +330,7 @@ PetscErrorCode Gnuplot(DA da, Vec X, double mtime)
   for (j=yints; j<yinte; j++) {
     for (i=xints; i<xinte; i++) {
       ierr = PetscFPrintf(PETSC_COMM_WORLD, f,
-                          "%D %D %g %g %g %g %g %g\n",
+                          "%D %D %G %G %G %G %G %G\n",
                           i, j, 0.0, 0.0,
                           PetscAbsScalar(x[j][i].U), PetscAbsScalar(x[j][i].F), 
                           PetscAbsScalar(x[j][i].phi), PetscAbsScalar(x[j][i].psi));CHKERRQ(ierr);
@@ -343,7 +349,7 @@ PetscErrorCode Gnuplot(DA da, Vec X, double mtime)
 PetscErrorCode Initialize(DMMG *dmmg)
 {
   AppCtx         *appCtx = (AppCtx*)DMMGGetUser(dmmg,0);
-  Parameter      *param = appCtx->param;
+  Parameters      *param = appCtx->param;
   DA             da;
   PetscErrorCode ierr;
   PetscInt       i,j,mx,my,xs,ys,xm,ym;
@@ -358,7 +364,7 @@ PetscErrorCode Initialize(DMMG *dmmg)
   ierr = PetscOptionsHasName(0,"-restart",&flg);CHKERRQ(ierr);
   if (flg) {
     PetscViewer viewer;
-    ierr = PetscViewerBinaryOpen(PETSC_COMM_WORLD,"binaryoutput",PETSC_FILE_RDONLY,&viewer);CHKERRQ(ierr);
+    ierr = PetscViewerBinaryOpen(PETSC_COMM_WORLD,"binaryoutput",FILE_MODE_READ,&viewer);CHKERRQ(ierr);
     ierr = VecLoadIntoVector(viewer,dmmg[param->mglevels-1]->x);CHKERRQ(ierr);
     ierr = PetscViewerDestroy(viewer);CHKERRQ(ierr);
     PetscFunctionReturn(0);
@@ -397,32 +403,28 @@ PetscErrorCode Initialize(DMMG *dmmg)
   /*
      Compute initial solution over the locally owned part of the grid
   */
+#if defined (PETSC_HAVE_ERF)
   {
     PetscReal eps = lx/ly;
-#if defined(PETSC_HAVE_ERF)
     PetscReal pert = 1e-4;
-#endif
     PetscReal k = 1.*eps;
     PetscReal gam; 
 
     if (d_e < rho_s) d_e = rho_s;
     gam = k * d_e;
-
     for (j=ys-1; j<ys+ym+1; j++) {
       yy = j * hy;
       for (i=xs-1; i<xs+xm+1; i++) {
 	xx = i * hx;
-#if defined(PETSC_HAVE_ERF)
-	if (xx < -PETSC_PI/2) {
-	  localx[j][i].phi = pert * gam / k * erf((xx + PETSC_PI) / (sqrt(2.0) * d_e)) * (-sin(k*yy));
-	} else if (xx < PETSC_PI/2) {
+	if (xx < -3.1416926/2) {
+	  localx[j][i].phi = pert * gam / k * erf((xx + 3.1415926) / (sqrt(2.0) * d_e)) * (-sin(k*yy));
+	} else if (xx < 3.1415926/2) {
 	  localx[j][i].phi = - pert * gam / k * erf(xx / (sqrt(2.0) * d_e)) * (-sin(k*yy));
-	} else if (xx < 3*PETSC_PI/2){
-	  localx[j][i].phi = pert * gam / k * erf((xx - PETSC_PI) / (sqrt(2.0) * d_e)) * (-sin(k*yy));
+	} else if (xx < 3*3.1415926/2){
+	  localx[j][i].phi = pert * gam / k * erf((xx - 3.1415926) / (sqrt(2.0) * d_e)) * (-sin(k*yy));
 	} else {
-	  localx[j][i].phi = - pert * gam / k * erf((xx - 2.*PETSC_PI) / (sqrt(2.0) * d_e)) * (-sin(k*yy));
+	  localx[j][i].phi = - pert * gam / k * erf((xx - 2.*3.1415926) / (sqrt(2.0) * d_e)) * (-sin(k*yy));
 	}
-#endif
 #ifdef EQ
 	localx[j][i].psi = 0.;
 #else
@@ -430,6 +432,7 @@ PetscErrorCode Initialize(DMMG *dmmg)
 #endif
       }
     }
+
     for (j=ys; j<ys+ym; j++) {
       for (i=xs; i<xs+xm; i++) {
 	x[j][i].U   = Lapl(localx,phi,i,j);
@@ -439,6 +442,10 @@ PetscErrorCode Initialize(DMMG *dmmg)
       }
     }
   }
+#else
+  SETERRQ(1,"erf() not available on this machine");
+#endif
+
   /*
      Restore vector
   */
@@ -489,7 +496,7 @@ PetscErrorCode ComputeMaxima(DA da, Vec X, PetscReal t)
   ierr = PetscObjectGetComm((PetscObject)da, &comm);CHKERRQ(ierr);
   ierr = MPI_Allreduce(norm, gnorm, 4, MPI_DOUBLE, MPI_MAX, comm);CHKERRQ(ierr);
 
-  ierr = PetscFPrintf(PETSC_COMM_WORLD, stderr,"%g\t%g\t%g\t%g\t%g\n",t, gnorm[0], gnorm[1], gnorm[2], gnorm[3]);CHKERRQ(ierr);
+  ierr = PetscFPrintf(PETSC_COMM_WORLD, stderr,"%G\t%G\t%G\t%G\t%G\n",t, gnorm[0], gnorm[1], gnorm[2], gnorm[3]);CHKERRQ(ierr);
 
   PetscFunctionReturn(0);
 }
@@ -500,7 +507,7 @@ PetscErrorCode FormFunctionLocal(DALocalInfo *info,Field **x,Field **f,void *ptr
 {
   AppCtx         *user = (AppCtx*)ptr;
   TstepCtx       *tsCtx = user->tsCtx;
-  Parameter      *param = user->param;
+  Parameters      *param = user->param;
   PetscErrorCode ierr;
   PetscInt       xints,xinte,yints,yinte,i,j;
   PassiveReal    hx,hy,dhx,dhy,hxdhy,hydhx,hxhy,dhxdhy;
@@ -615,7 +622,7 @@ PetscErrorCode Update(DMMG *dmmg)
 {
   AppCtx          *user = (AppCtx *) DMMGGetUser(dmmg,0);
   TstepCtx        *tsCtx = user->tsCtx;
-  Parameter       *param = user->param;
+  Parameters       *param = user->param;
   SNES            snes;
   PetscErrorCode  ierr;
   PetscInt        its,lits,i;
@@ -636,7 +643,8 @@ PetscErrorCode Update(DMMG *dmmg)
   snes = DMMGGetSNES(dmmg);
 
   for (tsCtx->itstep = 0; tsCtx->itstep < max_steps; tsCtx->itstep++) {
-
+    
+    ierr = PetscPrintf(PETSC_COMM_WORLD, "time step=%d!\n",tsCtx->itstep);
     if ((param->second_order) && (tsCtx->itstep > 0))
     {
       for (i=param->mglevels-1; i>=0 ;i--)
@@ -667,7 +675,7 @@ PetscErrorCode Update(DMMG *dmmg)
 
       ierr = PetscStrcpy(file, "matrix");CHKERRQ(ierr);
 
-      ierr = PetscViewerBinaryOpen(PETSC_COMM_WORLD, file, PETSC_FILE_CREATE, &viewer);CHKERRQ(ierr);
+      ierr = PetscViewerBinaryOpen(PETSC_COMM_WORLD, file, FILE_MODE_WRITE, &viewer);CHKERRQ(ierr);
 
       ierr = SNESGetKSP(snes, &ksp);CHKERRQ(ierr);
 
@@ -688,7 +696,7 @@ PetscErrorCode Update(DMMG *dmmg)
     if (tsCtx->dump_time > 0.0 && tsCtx->t >= tsCtx->dump_time) {
       Vec v = DMMGGetx(dmmg);
       ierr = VecView(v,PETSC_VIEWER_BINARY_WORLD);CHKERRQ(ierr);
-      SETERRQ1(1,"Saved solution at time %g",tsCtx->t);
+      SETERRQ1(1,"Saved solution at time %G",tsCtx->t);
     }
 
     if (ts_monitor)
@@ -703,8 +711,8 @@ PetscErrorCode Update(DMMG *dmmg)
         SETERRQ(1, "unable to find a newton step");
 
       ierr = PetscPrintf(PETSC_COMM_WORLD,
-                         "time step = %D, time = %g, number of nonlinear steps = %D, "
-                         "number of linear steps = %D, norm of the function = %g\n",
+                         "time step = %D, time = %G, number of nonlinear steps = %D, "
+                         "number of linear steps = %D, norm of the function = %G\n",
 			 tsCtx->itstep + 1, tsCtx->t, its, lits, PetscAbsScalar(tsCtx->fnorm));CHKERRQ(ierr);
 
       /* send solution over to Matlab, to be visualized (using ex29.m) */
@@ -731,7 +739,7 @@ PetscErrorCode Update(DMMG *dmmg)
 #ifdef HAVE_DA_HDF
           char fname[PETSC_MAX_PATH_LEN];
 
-          sprintf(fname, "out-%g.hdf", tsCtx->t);
+          sprintf(fname, "out-%G.hdf", tsCtx->t);
           ierr = DAVecHDFOutput(DMMGGetDA(dmmg), DMMGGetx(dmmg), fname);CHKERRQ(ierr);
 #else
 /*
@@ -747,7 +755,7 @@ PetscErrorCode Update(DMMG *dmmg)
  
   if (!param->PreLoading){ 
     ierr = SNESGetFunctionNorm(snes,&tsCtx->fnorm);CHKERRQ(ierr);
-    ierr = PetscPrintf(PETSC_COMM_WORLD, "timesteps %D fnorm = %g\n",
+    ierr = PetscPrintf(PETSC_COMM_WORLD, "timesteps %D fnorm = %G\n",
 		       tsCtx->itstep, PetscAbsScalar(tsCtx->fnorm));CHKERRQ(ierr);
   }
 
@@ -868,7 +876,7 @@ PetscErrorCode FormFunctionLocali(DALocalInfo *info,MatStencil *st,Field **x,Pet
 {
   AppCtx         *user = (AppCtx*)ptr;
   TstepCtx       *tsCtx = user->tsCtx;
-  Parameter      *param = user->param;
+  Parameters      *param = user->param;
   PetscErrorCode ierr;
   PetscInt       i,j,c;
   PetscInt       xints,xinte,yints,yinte;
@@ -976,6 +984,128 @@ PetscErrorCode FormFunctionLocali(DALocalInfo *info,MatStencil *st,Field **x,Pet
       ierr = DAVecRestoreArray(info->da,user->Xold,&xold);CHKERRQ(ierr);
 
 
+  /*
+     Flop count (multiply-adds are counted as 2 operations)
+  */
+  /*  ierr = PetscLogFlops(84*info->ym*info->xm);CHKERRQ(ierr); FIXME */
+  PetscFunctionReturn(0);
+} 
+/*
+    This is an experimental function and can be safely ignored.
+*/
+PetscErrorCode FormFunctionLocali4(DALocalInfo *info,MatStencil *st,Field **x,PetscScalar *ff,void *ptr)
+{
+  Field          *f  = (Field *)ff;
+  AppCtx         *user = (AppCtx*)ptr;
+  TstepCtx       *tsCtx = user->tsCtx;
+  Parameters     *param = user->param;
+  PetscErrorCode ierr;
+  PetscInt       i,j;
+  PetscInt       xints,xinte,yints,yinte;
+  PassiveReal    hx,hy,dhx,dhy,hxdhy,hydhx,hxhy,dhxdhy;
+  PassiveReal    de2,rhos2,nu,eta,dde2;
+  PassiveReal    two = 2.0,one = 1.0,p5 = 0.5;
+  PassiveReal    F_eq_x,By_eq,dtinv;
+  PetscScalar    xx;
+  PetscScalar    vx,vy,avx,avy,vxp,vxm,vyp,vym;
+  PetscScalar    Bx,By,aBx,aBy,Bxp,Bxm,Byp,Bym;
+  PassiveField   **xold;
+
+  PetscFunctionBegin;
+  de2     = sqr(param->d_e);
+  rhos2   = sqr(param->rho_s);
+  nu      = param->nu;
+  eta     = param->eta;
+  dde2    = one/de2;
+
+  /* 
+     Define mesh intervals ratios for uniform grid.
+     [Note: FD formulae below are normalized by multiplying through by
+     local volume element to obtain coefficients O(1) in two dimensions.]
+  */
+  dhx   = info->mx/lx;        dhy   = info->my/ly;
+  hx    = one/dhx;             hy   = one/dhy;
+  hxdhy = hx*dhy;           hydhx   = hy*dhx;
+  hxhy  = hx*hy;             dhxdhy = dhx*dhy;
+
+  xints = info->xs; xinte = info->xs+info->xm;
+  yints = info->ys; yinte = info->ys+info->ym;
+
+
+  i = st->i; j = st->j; 
+
+#ifdef EQ
+      xx = i * hx;
+      F_eq_x = - (1. + de2) * sin(PetscAbsScalar(xx));
+      By_eq = sin(PetscAbsScalar(xx));
+#else
+      F_eq_x = 0.;
+      By_eq = 0.;
+#endif
+
+      /*
+       * convective coefficients for upwinding
+       */
+
+      vx  = - D_y(x,phi,i,j);
+      vy  =   D_x(x,phi,i,j);
+      avx = PetscAbsScalar(vx); vxp = p5*(vx+avx); vxm = p5*(vx-avx);
+      avy = PetscAbsScalar(vy); vyp = p5*(vy+avy); vym = p5*(vy-avy);
+#ifndef UPWINDING
+      vxp = vxm = p5*vx;
+      vyp = vym = p5*vy;
+#endif
+
+      Bx  =   D_y(x,psi,i,j);
+      By  = - D_x(x,psi,i,j) + By_eq;
+      aBx = PetscAbsScalar(Bx); Bxp = p5*(Bx+aBx); Bxm = p5*(Bx-aBx);
+      aBy = PetscAbsScalar(By); Byp = p5*(By+aBy); Bym = p5*(By-aBy);
+#ifndef UPWINDING
+      Bxp = Bxm = p5*Bx;
+      Byp = Bym = p5*By;
+#endif
+
+      ierr  = DAVecGetArray(info->da,user->Xold,&xold);CHKERRQ(ierr);
+      dtinv = hxhy/(tsCtx->dt);
+      
+
+        
+          /* Lap(phi) - U */
+          f->phi = (Lapl(x,phi,i,j) - x[j][i].U) * hxhy;
+          
+
+          
+	  /* psi - d_e^2 * Lap(psi) - F */
+	  f->psi = (x[j][i].psi - de2 * Lapl(x,psi,i,j) - x[j][i].F) * hxhy;
+          
+
+        
+          /* vx * U_x + vy * U_y - (B_x * F_x + B_y * F_y) / d_e^2
+            - nu Lap(U) */
+	  f->U  =
+	    ((vxp * (D_xm(x,U,i,j)) + vxm * (D_xp(x,U,i,j)) +
+	      vyp * (D_ym(x,U,i,j)) + vym * (D_yp(x,U,i,j))) -
+	     (Bxp * (D_xm(x,F,i,j) + F_eq_x) + Bxm * (D_xp(x,F,i,j) + F_eq_x) +
+	      Byp * (D_ym(x,F,i,j)) + Bym * (D_yp(x,F,i,j))) * dde2 -
+	     nu * Lapl(x,U,i,j)) * hxhy;
+          f->U += dtinv*(x[j][i].U-xold[j][i].U);
+	  
+
+        
+          /* vx * F_x + vy * F_y - rho_s^2 * (B_x * U_x + B_y * U_y)
+           - eta * Lap(psi) */
+          f->F  =
+            ((vxp * (D_xm(x,F,i,j) + F_eq_x) + vxm * (D_xp(x,F,i,j) + F_eq_x) +
+             vyp * (D_ym(x,F,i,j)) + vym * (D_yp(x,F,i,j))) -
+            (Bxp * (D_xm(x,U,i,j)) + Bxm * (D_xp(x,U,i,j)) +
+             Byp * (D_ym(x,U,i,j)) + Bym * (D_yp(x,U,i,j))) * rhos2 -
+            eta * Lapl(x,psi,i,j)) * hxhy;
+          f->F += dtinv*(x[j][i].F-xold[j][i].F);
+         
+      
+      ierr = DAVecRestoreArray(info->da,user->Xold,&xold);CHKERRQ(ierr);
+
+
   /*
      Flop count (multiply-adds are counted as 2 operations)
   */
