@@ -182,12 +182,12 @@ int main(int argc,char **argv)
   for (i=rstart; i<rend; i++) {
     colors[i - rstart] = 3*((i/user.mx) % 3) + (i % 3);
   }
-  ierr   = ISColoringCreate(PETSC_COMM_WORLD,rend-rstart,colors,&iscoloring);CHKERRQ(ierr);
+  ierr   = ISColoringCreate(PETSC_COMM_WORLD,3*2+2,rend-rstart,colors,&iscoloring);CHKERRQ(ierr);
   ierr = PetscFree(colors);CHKERRQ(ierr);
 
   /*
      Create and set the nonzero pattern for the Jacobian: This is not done 
-     particularly efficiently. One should process the boundary nodes seperately and 
+     particularly efficiently. One should process the boundary nodes separately and 
      then use a simple loop for the interior nodes.
        Note that for this code we use the "natural" number of the nodes on the 
      grid (since that is what is good for the user provided function). In the 
