@@ -131,18 +131,19 @@ PetscErrorCode SNESLSCheckResidual_Private(Mat A,Vec F,Vec X,Vec W1,Vec W2)
 #define __FUNCT__ "SNESSolve_LS"
 PetscErrorCode SNESSolve_LS(SNES snes)
 { 
-  SNES_LS        *neP = (SNES_LS*)snes->data;
-  PetscErrorCode ierr;
-  PetscInt       maxits,i,lits;
-  PetscTruth     lssucceed;
-  MatStructure   flg = DIFFERENT_NONZERO_PATTERN;
-  PetscReal      fnorm,gnorm,xnorm,ynorm;
-  Vec            Y,X,F,G,W,TMP;
-  KSP            ksp;
+  SNES_LS            *neP = (SNES_LS*)snes->data;
+  PetscErrorCode     ierr;
+  PetscInt           maxits,i,lits;
+  PetscTruth         lssucceed;
+  MatStructure       flg = DIFFERENT_NONZERO_PATTERN;
+  PetscReal          fnorm,gnorm,xnorm,ynorm;
+  Vec                Y,X,F,G,W,TMP;
+  KSPConvergedReason kspreason;
 
   PetscFunctionBegin;
-  ierr = SNESGetKSP(snes,&ksp);CHKERRQ(ierr);
-  snes->reason  = SNES_CONVERGED_ITERATING;
+  snes->numFailures            = 0;
+  snes->numLinearSolveFailures = 0;
+  snes->reason                 = SNES_CONVERGED_ITERATING;
 
   maxits	= snes->max_its;	/* maximum number of iterations */
   X		= snes->vec_sol;	/* solution vector */
@@ -162,24 +163,28 @@ PetscErrorCode SNESSolve_LS(SNES snes)
   ierr = PetscObjectGrantAccess(snes);CHKERRQ(ierr);
   SNESLogConvHistory(snes,fnorm,0);
   SNESMonitor(snes,0,fnorm);
-
-  if (fnorm < snes->abstol) {snes->reason = SNES_CONVERGED_FNORM_ABS; PetscFunctionReturn(0);}
-
-  /* set parameter for default relative tolerance convergence test */
-  snes->ttol = fnorm*snes->rtol;
+  ierr = (*snes->ops->converged)(snes,snes->iter,0.0,0.0,fnorm,&snes->reason,snes->cnvP);CHKERRQ(ierr);
+  if (snes->reason) PetscFunctionReturn(0);
 
   for (i=0; i<maxits; i++) {
 
     /* Call general purpose update function */
-    if (snes->update) {
-      ierr = (*snes->update)(snes, snes->iter);CHKERRQ(ierr);
+    if (snes->ops->update) {
+      ierr = (*snes->ops->update)(snes, snes->iter);CHKERRQ(ierr);
     }
 
     /* Solve J Y = F, where J is Jacobian matrix */
     ierr = SNESComputeJacobian(snes,X,&snes->jacobian,&snes->jacobian_pre,&flg);CHKERRQ(ierr);
     ierr = KSPSetOperators(snes->ksp,snes->jacobian,snes->jacobian_pre,flg);CHKERRQ(ierr);
     ierr = KSPSolve(snes->ksp,F,Y);CHKERRQ(ierr);
-    ierr = KSPGetIterationNumber(ksp,&lits);CHKERRQ(ierr);
+    ierr = KSPGetConvergedReason(snes->ksp,&kspreason);CHKERRQ(ierr);
+    if (kspreason < 0) {
+      if (++snes->numLinearSolveFailures >= snes->maxLinearSolveFailures) {
+        snes->reason = SNES_DIVERGED_LINEAR_SOLVE;
+        PetscFunctionReturn(0);
+      }
+    }
+    ierr = KSPGetIterationNumber(snes->ksp,&lits);CHKERRQ(ierr);
 
     if (neP->precheckstep) {
       PetscTruth changed_y = PETSC_FALSE;
@@ -225,9 +230,9 @@ PetscErrorCode SNESSolve_LS(SNES snes)
     } 
 
     /* Test for convergence */
-    if (snes->converged) {
+    if (snes->ops->converged) {
       ierr = VecNorm(X,NORM_2,&xnorm);CHKERRQ(ierr);	/* xnorm = || X || */
-      ierr = (*snes->converged)(snes,xnorm,ynorm,fnorm,&snes->reason,snes->cnvP);CHKERRQ(ierr);
+      ierr = (*snes->ops->converged)(snes,snes->iter,xnorm,ynorm,fnorm,&snes->reason,snes->cnvP);CHKERRQ(ierr);
       if (snes->reason) {
         break;
       }
@@ -1007,7 +1012,7 @@ PetscErrorCode PETSCSNES_DLLEXPORT SNESLineSearchSetPostCheck(SNES snes,PetscErr
 
    Calling sequence of func:
 .vb
-   int func (SNES snes, Vec x,Vec y,,void *checkctx, PetscTruth *changed_y)
+   int func (SNES snes, Vec x,Vec y,void *checkctx, PetscTruth *changed_y)
 .ve
    where func returns an error code of 0 on success and a nonzero
    on failure.
@@ -1068,29 +1073,6 @@ PetscErrorCode PETSCSNES_DLLEXPORT SNESLineSearchSetPreCheck_LS(SNES snes,FCN3 f
   PetscFunctionReturn(0);
 }
 EXTERN_C_END
-/* -------------------------------------------------------------------------- */
-/*
-   SNESPrintHelp_LS - Prints all options for the SNES_LS method.
-
-   Input Parameter:
-.  snes - the SNES context
-
-   Application Interface Routine: SNESPrintHelp()
-*/
-#undef __FUNCT__  
-#define __FUNCT__ "SNESPrintHelp_LS"
-static PetscErrorCode SNESPrintHelp_LS(SNES snes,char *p)
-{
-  SNES_LS *ls = (SNES_LS *)snes->data;
-
-  PetscFunctionBegin;
-  (*PetscHelpPrintf)(snes->comm," method SNES_LS (ls) for systems of nonlinear equations:\n");
-  (*PetscHelpPrintf)(snes->comm,"   %ssnes_ls [cubic,quadratic,basic,basicnonorms,...]\n",p);
-  (*PetscHelpPrintf)(snes->comm,"   %ssnes_ls_alpha <alpha> (default %G)\n",p,ls->alpha);
-  (*PetscHelpPrintf)(snes->comm,"   %ssnes_ls_maxstep <max> (default %G)\n",p,ls->maxstep);
-  (*PetscHelpPrintf)(snes->comm,"   %ssnes_ls_steptol <tol> (default %G)\n",p,ls->steptol);
-  PetscFunctionReturn(0);
-}
 
 /*
    SNESView_LS - Prints info from the SNESLS data structure.
@@ -1199,14 +1181,13 @@ PetscErrorCode PETSCSNES_DLLEXPORT SNESCreate_LS(SNES snes)
   SNES_LS        *neP;
 
   PetscFunctionBegin;
-  snes->setup		= SNESSetUp_LS;
-  snes->solve		= SNESSolve_LS;
-  snes->destroy		= SNESDestroy_LS;
-  snes->converged	= SNESConverged_LS;
-  snes->printhelp       = SNESPrintHelp_LS;
-  snes->setfromoptions  = SNESSetFromOptions_LS;
-  snes->view            = SNESView_LS;
-  snes->nwork           = 0;
+  snes->ops->setup	     = SNESSetUp_LS;
+  snes->ops->solve	     = SNESSolve_LS;
+  snes->ops->destroy	     = SNESDestroy_LS;
+  snes->ops->converged	     = SNESConverged_LS;
+  snes->ops->setfromoptions  = SNESSetFromOptions_LS;
+  snes->ops->view            = SNESView_LS;
+  snes->nwork                = 0;
 
   ierr                  = PetscNew(SNES_LS,&neP);CHKERRQ(ierr);
   ierr = PetscLogObjectMemory(snes,sizeof(SNES_LS));CHKERRQ(ierr);
