@@ -7,6 +7,7 @@
 #endif
 
 #if defined(PETSC_HAVE_FORTRAN_CAPS)
+#define snessolve_                       SNESSOLVE
 #define snesdefaultcomputejacobian_      SNESDEFAULTCOMPUTEJACOBIAN
 #define snesdefaultcomputejacobiancolor_ SNESDEFAULTCOMPUTEJACOBIANCOLOR
 #define snesdacomputejacobian_           SNESDACOMPUTEJACOBIAN
@@ -32,6 +33,7 @@
 #define snesvecviewupdatemonitor_        SNESVECVIEWUPDATEMONITOR
 #define snessetmonitor_                  SNESSETMONITOR
 #elif !defined(PETSC_HAVE_FORTRAN_UNDERSCORE)
+#define snessolve_                       snessolve
 #define snesdefaultcomputejacobian_      snesdefaultcomputejacobian
 #define snesdefaultcomputejacobiancolor_ snesdefaultcomputejacobiancolor
 #define snesdacomputejacobian_           snesdacomputejacobian
@@ -61,7 +63,7 @@
 EXTERN_C_BEGIN
 static void (PETSC_STDCALL *f3)(SNES*,Vec*,Mat*,Mat*,MatStructure*,void*,PetscErrorCode*);
 static void (PETSC_STDCALL *f2)(SNES*,Vec*,Vec*,void*,PetscErrorCode*);
-static void (PETSC_STDCALL *f8)(SNES*,PetscReal*,PetscReal*,PetscReal*,SNESConvergedReason*,void*,PetscErrorCode*);
+static void (PETSC_STDCALL *f8)(SNES*,PetscInt *,PetscReal*,PetscReal*,PetscReal*,SNESConvergedReason*,void*,PetscErrorCode*);
 static void (PETSC_STDCALL *f7)(SNES*,PetscInt*,PetscReal*,void*,PetscErrorCode*);
 static void (PETSC_STDCALL *f71)(void*,PetscErrorCode*);
 EXTERN_C_END
@@ -72,11 +74,11 @@ static PetscErrorCode oursnesfunction(SNES snes,Vec x,Vec f,void *ctx)
   (*f2)(&snes,&x,&f,ctx,&ierr);CHKERRQ(ierr);
   return 0;
 }
-static PetscErrorCode oursnestest(SNES snes,PetscReal a,PetscReal d,PetscReal c,SNESConvergedReason*reason,void*ctx)
+static PetscErrorCode oursnestest(SNES snes,PetscInt it,PetscReal a,PetscReal d,PetscReal c,SNESConvergedReason*reason,void*ctx)
 {
   PetscErrorCode ierr = 0;
 
-  (*f8)(&snes,&a,&d,&c,reason,ctx,&ierr);CHKERRQ(ierr);
+  (*f8)(&snes,&it,&a,&d,&c,reason,ctx,&ierr);CHKERRQ(ierr);
   return 0;
 }
 
@@ -150,6 +152,13 @@ void PETSC_STDCALL snessetjacobian_(SNES *snes,Mat *A,Mat *B,void (PETSC_STDCALL
 }
 /* -------------------------------------------------------------*/
 
+void PETSC_STDCALL   snessolve_(SNES *snes,Vec *b,Vec *x, int *__ierr )
+{
+  Vec B = *b;
+  if (*b == PETSC_NULL_OBJECT_Fortran) B = PETSC_NULL;
+  *__ierr = SNESSolve(*snes,B,*x);
+}
+
 void PETSC_STDCALL snesgetoptionsprefix_(SNES *snes,CHAR prefix PETSC_MIXED_LEN(len),
                                          PetscErrorCode *ierr PETSC_END_LEN(len))
 {
@@ -217,21 +226,21 @@ void PETSC_STDCALL snesgetfunction_(SNES *snes,Vec *r,void *func,void **ctx,Pets
 }
 /*----------------------------------------------------------------------*/
 
-void snesconverged_tr_(SNES *snes,PetscReal *a,PetscReal *b,PetscReal *c,SNESConvergedReason *r,
+void snesconverged_tr_(SNES *snes,PetscInt *it,PetscReal *a,PetscReal *b,PetscReal *c,SNESConvergedReason *r,
                                        void *ct,PetscErrorCode *ierr)
 {
-  *ierr = SNESConverged_TR(*snes,*a,*b,*c,r,ct);
+  *ierr = SNESConverged_TR(*snes,*it,*a,*b,*c,r,ct);
 }
 
-void snesconverged_ls_(SNES *snes,PetscReal *a,PetscReal *b,PetscReal *c,SNESConvergedReason *r,
+void snesconverged_ls_(SNES *snes,PetscInt *it, PetscReal *a,PetscReal *b,PetscReal *c,SNESConvergedReason *r,
                                        void *ct,PetscErrorCode *ierr)
 {
-  *ierr = SNESConverged_LS(*snes,*a,*b,*c,r,ct);
+  *ierr = SNESConverged_LS(*snes,*it,*a,*b,*c,r,ct);
 }
 
 
 void PETSC_STDCALL snessetconvergencetest_(SNES *snes,
-       void (PETSC_STDCALL *func)(SNES*,PetscReal*,PetscReal*,PetscReal*,SNESConvergedReason*,void*,PetscErrorCode*),
+       void (PETSC_STDCALL *func)(SNES*,PetscInt*,PetscReal*,PetscReal*,PetscReal*,SNESConvergedReason*,void*,PetscErrorCode*),
        void *cctx,PetscErrorCode *ierr)
 {
   CHKFORTRANNULLOBJECT(cctx);
