@@ -286,6 +286,7 @@ PetscErrorCode PETSCSNES_DLLEXPORT SNESDefaultSMonitor(SNES snes,PetscInt its,Pe
 
    Input Parameters:
 +  snes - the SNES context
+.  it - the iteration (0 indicates before any Newton steps)
 .  xnorm - 2-norm of current iterate
 .  pnorm - 2-norm of current step 
 .  fnorm - 2-norm of function at current iterate
@@ -314,28 +315,36 @@ $  SNES_CONVERGED_ITERATING       - (otherwise),
 
 .seealso: SNESSetConvergenceTest(), SNESEisenstatWalkerConverged()
 @*/
-PetscErrorCode PETSCSNES_DLLEXPORT SNESConverged_LS(SNES snes,PetscReal xnorm,PetscReal pnorm,PetscReal fnorm,SNESConvergedReason *reason,void *dummy)
+PetscErrorCode PETSCSNES_DLLEXPORT SNESConverged_LS(SNES snes,PetscInt it,PetscReal xnorm,PetscReal pnorm,PetscReal fnorm,SNESConvergedReason *reason,void *dummy)
 {
   PetscErrorCode ierr;
 
   PetscFunctionBegin;
+  *reason = SNES_CONVERGED_ITERATING;
+
+  if (!it) {
+    /* set parameter for default relative tolerance convergence test */
+    snes->ttol = fnorm*snes->rtol;
+  }
   if (fnorm != fnorm) {
     ierr = PetscInfo(snes,"Failed to converged, function norm is NaN\n");CHKERRQ(ierr);
     *reason = SNES_DIVERGED_FNORM_NAN;
-  } else if (fnorm <= snes->ttol) {
-    ierr = PetscInfo2(snes,"Converged due to function norm %G < %G (relative tolerance)\n",fnorm,snes->ttol);CHKERRQ(ierr);
-    *reason = SNES_CONVERGED_FNORM_RELATIVE;
   } else if (fnorm < snes->abstol) {
     ierr = PetscInfo2(snes,"Converged due to function norm %G < %G\n",fnorm,snes->abstol);CHKERRQ(ierr);
     *reason = SNES_CONVERGED_FNORM_ABS;
-  } else if (pnorm < snes->xtol*xnorm) {
-    ierr = PetscInfo3(snes,"Converged due to small update length: %G < %G * %G\n",pnorm,snes->xtol,xnorm);CHKERRQ(ierr);
-    *reason = SNES_CONVERGED_PNORM_RELATIVE;
   } else if (snes->nfuncs >= snes->max_funcs) {
     ierr = PetscInfo2(snes,"Exceeded maximum number of function evaluations: %D > %D\n",snes->nfuncs,snes->max_funcs);CHKERRQ(ierr);
-    *reason = SNES_DIVERGED_FUNCTION_COUNT ;
-  } else {
-    *reason = SNES_CONVERGED_ITERATING;
+    *reason = SNES_DIVERGED_FUNCTION_COUNT;
+  }
+
+  if (it && !*reason) {
+    if (fnorm <= snes->ttol) {
+      ierr = PetscInfo2(snes,"Converged due to function norm %G < %G (relative tolerance)\n",fnorm,snes->ttol);CHKERRQ(ierr);
+      *reason = SNES_CONVERGED_FNORM_RELATIVE;
+    } else if (pnorm < snes->xtol*xnorm) {
+      ierr = PetscInfo3(snes,"Converged due to small update length: %G < %G * %G\n",pnorm,snes->xtol,xnorm);CHKERRQ(ierr);
+      *reason = SNES_CONVERGED_PNORM_RELATIVE;
+    }
   }
   PetscFunctionReturn(0);
 }
@@ -384,7 +393,7 @@ PetscErrorCode PETSCSNES_DLLEXPORT SNES_KSP_SetConvergenceTestEW(SNES snes)
  
    Input Parameters:
 +    snes - SNES context
-.    version - version 1 or 2 (default is 2)
+.    version - version 1, 2 (default is 2) or 3
 .    rtol_0 - initial relative tolerance (0 <= rtol_0 < 1)
 .    rtol_max - maximum relative tolerance (0 <= rtol_max < 1)
 .    alpha - power for version 2 rtol computation (1 < alpha <= 2)
@@ -394,6 +403,8 @@ PetscErrorCode PETSCSNES_DLLEXPORT SNES_KSP_SetConvergenceTestEW(SNES snes)
 -    threshold - threshold for imposing safeguard (0 < threshold < 1)
 
    Note:
+   Version 3 was contributed by Luis Chacon, June 2006.
+
    Use PETSC_DEFAULT to retain the default for any of the parameters.
 
    Level: advanced
@@ -436,8 +447,8 @@ PetscErrorCode PETSCSNES_DLLEXPORT SNES_KSP_SetParametersEW(SNES snes,PetscInt v
   if (kctx->alpha <= 1.0 || kctx->alpha > 2.0) {
     SETERRQ1(PETSC_ERR_ARG_OUTOFRANGE,"1.0 < alpha (%G) <= 2.0\n",kctx->alpha);
   }
-  if (kctx->version != 1 && kctx->version !=2) {
-    SETERRQ1(PETSC_ERR_ARG_OUTOFRANGE,"Only versions 1 and 2 are supported: %D",kctx->version);
+  if (kctx->version < 1 || kctx->version > 3) {
+    SETERRQ1(PETSC_ERR_ARG_OUTOFRANGE,"Only versions 1, 2 and 3 are supported: %D",kctx->version);
   }
   PetscFunctionReturn(0);
 }
@@ -464,7 +475,14 @@ PetscErrorCode SNES_KSP_EW_ComputeRelativeTolerance_Private(SNES snes,KSP ksp)
       rtol = kctx->gamma * pow(snes->norm/kctx->norm_last,kctx->alpha);
       stol = kctx->gamma * pow(kctx->rtol_last,kctx->alpha);
       if (stol > kctx->threshold) rtol = PetscMax(rtol,stol);
-    } else SETERRQ1(PETSC_ERR_ARG_OUTOFRANGE,"Only versions 1 or 2 are supported: %D",kctx->version);
+    } else if (kctx->version == 3) {
+      rtol = kctx->gamma * pow(snes->norm/kctx->norm_last,kctx->alpha);
+      /* safeguard: avoid sharp decrease of rtol */
+      rtol = PetscMin(kctx->rtol_0,PetscMax(rtol,kctx->gamma*pow(kctx->rtol_last,kctx->alpha)));
+      /* safeguard: avoid oversolving */
+      rtol = PetscMin(kctx->rtol_0,PetscMax(rtol,kctx->gamma*(snes->ttol)/snes->norm));
+
+    } else SETERRQ1(PETSC_ERR_ARG_OUTOFRANGE,"Only versions 1, 2 or 3 are supported: %D",kctx->version);
   }
   rtol = PetscMin(rtol,kctx->rtol_max);
   kctx->rtol_last = rtol;
