@@ -1,7 +1,7 @@
 #define PETSC_DLL
 
-#include "petsc.h"           /*I "petsc.h" I*/
-
+#include "petscsys.h"        /*I "petscsys.h" I*/
+#include "petscconfiginfo.h"
 
 #undef __FUNCT__  
 #define __FUNCT__ "PetscIgnoreErrorHandler" 
@@ -45,6 +45,34 @@ PetscErrorCode PETSC_DLLEXPORT PetscIgnoreErrorHandler(int line,const char *fun,
   PetscFunctionReturn(n);
 }
 
+/* ---------------------------------------------------------------------------------------*/
+
+static char  arch[10],hostname[64],username[16],pname[PETSC_MAX_PATH_LEN],date[64];
+static PetscTruth PetscErrorPrintfInitializeCalled = PETSC_FALSE;
+static char version[256];
+
+#undef __FUNCT__  
+#define __FUNCT__ "PetscErrorPrintfInitialize"
+/*
+   Initializes arch, hostname, username,date so that system calls do NOT need
+   to be made during the error handler.
+*/
+PetscErrorCode PETSC_DLLEXPORT PetscErrorPrintfInitialize()
+{
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  ierr = PetscGetArchType(arch,10);CHKERRQ(ierr);
+  ierr = PetscGetHostName(hostname,64);CHKERRQ(ierr);
+  ierr = PetscGetUserName(username,16);CHKERRQ(ierr);
+  ierr = PetscGetProgramName(pname,PETSC_MAX_PATH_LEN);CHKERRQ(ierr);
+  ierr = PetscGetDate(date,64);CHKERRQ(ierr);
+  ierr = PetscGetVersion(&version,256);CHKERRQ(ierr);
+  PetscErrorPrintfInitializeCalled = PETSC_TRUE;
+  PetscFunctionReturn(0);
+}
+
+
 
 #undef __FUNCT__  
 #define __FUNCT__ "PetscTraceBackErrorHandler" 
@@ -91,8 +119,8 @@ PetscErrorCode PETSC_DLLEXPORT PetscTraceBackErrorHandler(int line,const char *f
 
   PetscFunctionBegin;
 
-  (*PetscErrorPrintf)("%s() line %d in %s%s\n",fun,line,dir,file);
   if (p == 1) {
+    (*PetscErrorPrintf)("--------------------- Error Message ------------------------------------\n");
     if (n == PETSC_ERR_MEM) {
       (*PetscErrorPrintf)("Out of memory. This could be due to allocating\n");
       (*PetscErrorPrintf)("too large an object or bleeding by not properly\n");
@@ -119,7 +147,26 @@ PetscErrorCode PETSC_DLLEXPORT PetscTraceBackErrorHandler(int line,const char *f
     if (mess) {
       (*PetscErrorPrintf)("%s!\n",mess);
     }
+    (*PetscErrorPrintf)("------------------------------------------------------------------------\n");
+    (*PetscErrorPrintf)("%s\n",version);
+    (*PetscErrorPrintf)("See docs/changes/index.html for recent updates.\n");
+    (*PetscErrorPrintf)("See docs/faq.html for hints about trouble shooting.\n");
+    (*PetscErrorPrintf)("See docs/index.html for manual pages.\n");
+    (*PetscErrorPrintf)("------------------------------------------------------------------------\n");
+    if (PetscErrorPrintfInitializeCalled) {
+      (*PetscErrorPrintf)("%s on a %s named %s by %s %s\n",pname,arch,hostname,username,date);
+    }
+    (*PetscErrorPrintf)("Libraries linked from %s\n",PETSC_LIB_DIR);
+    (*PetscErrorPrintf)("Configure run at %s\n",petscconfigureruntime);
+    (*PetscErrorPrintf)("Configure options %s\n",petscconfigureoptions);
+    (*PetscErrorPrintf)("------------------------------------------------------------------------\n");
   }
+
+
+  /* first line in stack trace? */
+  (*PetscErrorPrintf)("%s() line %d in %s%s\n",fun,line,dir,file);
+
+
   PetscFunctionReturn(n);
 }
 
