@@ -11,6 +11,9 @@
 #define petscerror_                PETSCERROR
 #define petscrealview_             PETSCREALVIEW
 #define petscintview_              PETSCINTVIEW
+#define petscerroriscatchable_  PETSCERRORISCATCHABLE
+#define petscexceptionvalue_        PETSCEXCEPTIONVALUE
+#define petscexceptioncaught        PETSCEXCEPTIONCAUGHT
 #elif !defined(PETSC_HAVE_FORTRAN_UNDERSCORE)
 #define petscpusherrorhandler_   petscpusherrorhandler
 #define petsctracebackerrorhandler_   petsctracebackerrorhandler
@@ -21,6 +24,9 @@
 #define petscerror_                petscerror
 #define petscrealview_             petscrealview
 #define petscintview_              petscintview
+#define petscerroriscatchable_ petscerroriscatchable
+#define petscexceptionvalue_       petscexceptionvalue
+#define petscexceptioncaught_      petscexceptioncaught
 #endif
 
 EXTERN_C_BEGIN
@@ -124,6 +130,21 @@ void PETSC_STDCALL petscintview_(PetscInt *n,PetscInt *d,PetscViewer *viwer,Pets
   *ierr = PetscIntView(*n,d,v);
 }
 
+void PETSC_STDCALL petscerroriscatchable_(PetscErrorCode *ierr,PetscTruth *is)
+{
+  *is = PetscErrorIsCatchable(*ierr);
+}
+
+void PETSC_STDCALL petscexceptionvalue_(PetscErrorCode *ierr,PetscTruth *is)
+{
+  *is = PetscExceptionValue(*ierr);
+}
+
+void PETSC_STDCALL petscexceptioncaught_(PetscErrorCode *ierr,PetscErrorCode *zierr,PetscTruth *is)
+{
+  *is = PetscExceptionCaught(*ierr,*zierr);
+}
+
 #if defined(PETSC_HAVE_FORTRAN_CAPS)
 #define petscscalarview_             PETSCSCALARVIEW
 #elif !defined(PETSC_HAVE_FORTRAN_UNDERSCORE)
