@@ -1,5 +1,3 @@
-/*$Id: ex1.c,v 1.23 2001/03/23 23:20:59 balay Exp $*/
-
 /* 
    Demonstrates PETSc error handlers.
  */
@@ -10,7 +8,7 @@
 #define __FUNCT__ "CreateError"
 int CreateError(int n)
 {
-  int ierr;
+  PetscErrorCode ierr;
   if (!n) SETERRQ(1,"Error Created");
   ierr = CreateError(n-1);CHKERRQ(ierr);
   return 0;
@@ -20,7 +18,7 @@ int CreateError(int n)
 #define __FUNCT__ "main"
 int main(int argc,char **argv)
 {
-  int ierr;
+  PetscErrorCode ierr;
   PetscInitialize(&argc,&argv,(char *)0,0);
   ierr = PetscFPrintf(PETSC_COMM_WORLD,stdout,"Demonstrates PETSc Error Handlers\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(PETSC_COMM_WORLD,stdout,"The error is a contrived error to test error handling\n");CHKERRQ(ierr);
