@@ -60,6 +60,9 @@ extern PETSC_DLL_IMPORT PetscTruth PetscBeganMPI;
 #if defined(PETSC_HAVE_GFORTRAN_IARGC) /* gfortran from gcc4 */
 #define iargc_  _gfortran_iargc
 #define getarg_ _gfortran_getarg_i4
+#elif defined(PETSC_HAVE_BGL_IARGC) /* bgl g77 has different external & internal name mangling */
+#define iargc  iargc_
+#define getarg getarg_
 #endif
 
 /*
@@ -305,8 +308,14 @@ void PETSC_STDCALL petscinitialize_(CHAR filename PETSC_MIXED_LEN(len),PetscErro
      are not called; at least on IRIX.
   */
   {
+#if defined(PETSC_CLANGUAGE_CXX)
     PetscScalar ic(0.0,1.0);
     PETSC_i = ic;
+#else
+    PetscScalar ic;
+    ic = 1.I;
+    PETSC_i = ic;
+#endif
   }
   *ierr = MPI_Type_contiguous(2,MPIU_REAL,&MPIU_COMPLEX);
   if (*ierr) {(*PetscErrorPrintf)("PetscInitialize:Creating MPI types");return;}
