@@ -340,8 +340,9 @@ PetscErrorCode PETSC_DLLEXPORT PetscGetArgs(int *argc,char ***args)
 .  -debugger_pause [sleeptime] (in seconds) - Pauses debugger
 .  -stop_for_debugger - Print message on how to attach debugger manually to 
                         process and wait (-debugger_pause) seconds for attachment
-.  -malloc - Indicates use of PETSc error-checking malloc
+.  -malloc - Indicates use of PETSc error-checking malloc (on by default for debug version of libraries)
 .  -malloc no - Indicates not to use error-checking malloc
+.  -malloc_debug - check for memory corruption at EVERY malloc or free
 .  -fp_trap - Stops on floating point exceptions (Note that on the
               IBM RS6000 this slows code by at least a factor of 10.)
 .  -no_signal_handler - Indicates not to trap error signals
@@ -448,9 +449,16 @@ PetscErrorCode PETSC_DLLEXPORT PetscInitialize(int *argc,char ***args,const char
      are not called; at least on IRIX.
   */
   {
+#if defined(PETSC_CLANGUAGE_CXX)
     PetscScalar ic(0.0,1.0);
     PETSC_i = ic; 
+#else
+    PetscScalar ic;
+    ic = 1.I;
+    PETSC_i = ic;
+#endif
   }
+
   ierr = MPI_Type_contiguous(2,MPIU_REAL,&MPIU_COMPLEX);CHKERRQ(ierr);
   ierr = MPI_Type_commit(&MPIU_COMPLEX);CHKERRQ(ierr);
   ierr = MPI_Op_create(PetscSum_Local,1,&PetscSum_Op);CHKERRQ(ierr);
@@ -504,6 +512,9 @@ PetscErrorCode PETSC_DLLEXPORT PetscInitialize(int *argc,char ***args,const char
   ierr = PetscInfo1(0,"Running on machine: %s\n",hostname);CHKERRQ(ierr);
 
   ierr = PetscOptionsCheckInitial_Components();CHKERRQ(ierr);
+  /* Check the options database for options related to the options database itself */
+  ierr = PetscOptionsSetFromOptions(); CHKERRQ(ierr);
+
 
   PetscFunctionReturn(ierr);
 }
@@ -525,7 +536,6 @@ PetscErrorCode PETSC_DLLEXPORT PetscInitialize(int *argc,char ***args,const char
 .  -mpidump - Calls PetscMPIDump()
 .  -malloc_dump - Calls PetscMallocDump()
 .  -malloc_info - Prints total memory usage
-.  -malloc_debug - Calls PetscMallocDebug(), checks allocated memory for corruption while running
 -  -malloc_log - Prints summary of memory usage
 
    Options Database Keys for Profiling:
@@ -648,8 +658,8 @@ PetscErrorCode PETSC_DLLEXPORT PetscFinalize(void)
   ierr = PetscOptionsHasName(PETSC_NULL,"-nox_warning",&flg1);CHKERRQ(ierr)
   ierr = PetscOptionsHasName(PETSC_NULL,"-error_output_stderr",&flg1);CHKERRQ(ierr);
 
-  flg3 = PETSC_FALSE;
-  ierr = PetscOptionsGetTruth(PETSC_NULL,"-options_left",&flg3,PETSC_NULL);CHKERRQ(ierr);
+  flg3 = PETSC_FALSE; /* default value is required */
+  ierr = PetscOptionsGetTruth(PETSC_NULL,"-options_left",&flg3,&flg1);CHKERRQ(ierr);
   ierr = PetscOptionsAllUsed(&nopt);CHKERRQ(ierr);
   if (flg3) {
     if (!flg2) { /* have not yet printed the options */
@@ -664,7 +674,7 @@ PetscErrorCode PETSC_DLLEXPORT PetscFinalize(void)
     }
   } 
 #if defined(PETSC_USE_DEBUG)
-  if (nopt && !flg3) {
+  if (nopt && !flg3 && !flg1) {
     ierr = PetscPrintf(PETSC_COMM_WORLD,"WARNING! There are options you set that were not used!\n");CHKERRQ(ierr);
     ierr = PetscPrintf(PETSC_COMM_WORLD,"WARNING! could be spelling mistake, etc!\n");CHKERRQ(ierr);
     ierr = PetscOptionsLeft();CHKERRQ(ierr);
