@@ -1093,25 +1093,29 @@ PetscErrorCode PETSC_DLLEXPORT PetscLogDump(const char sname[])
   ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Total Flops %14e %16.8e\n", _TotalFlops, _TotalTime);
   ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Clock Resolution %g\n", 0.0);
   /* Output actions */
-  ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Actions accomplished %d\n", numActions);
-  for(action = 0; action < numActions; action++) {
-    ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "%g %d %d %d %d %d %d %g %g %g\n",
-                        actions[action].time, actions[action].action, (int)actions[action].event, (int)actions[action].cookie, actions[action].id1,
-                        actions[action].id2, actions[action].id3, actions[action].flops, actions[action].mem, actions[action].maxmem);
+  if (logActions) {
+    ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Actions accomplished %d\n", numActions);
+    for(action = 0; action < numActions; action++) {
+      ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "%g %d %d %d %d %d %d %g %g %g\n",
+                          actions[action].time, actions[action].action, (int)actions[action].event, (int)actions[action].cookie, actions[action].id1,
+                          actions[action].id2, actions[action].id3, actions[action].flops, actions[action].mem, actions[action].maxmem);
+    }
   }
   /* Output objects */
-  ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Objects created %d destroyed %d\n", numObjects, numObjectsDestroyed);
-  for(object = 0; object < numObjects; object++) {
-    ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Parent ID: %d Memory: %d\n", objects[object].parent, (int) objects[object].mem);
-    if (!objects[object].name[0]) {
-      ierr = PetscFPrintf(PETSC_COMM_WORLD, fd,"No Name\n");
-    } else {
-      ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Name: %s\n", objects[object].name);
-    }
-    if (objects[object].info[0] != 0) {
-      ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "No Info\n");
-    } else {
-      ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Info: %s\n", objects[object].info);
+  if (logObjects) {
+    ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Objects created %d destroyed %d\n", numObjects, numObjectsDestroyed);
+    for(object = 0; object < numObjects; object++) {
+      ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Parent ID: %d Memory: %d\n", objects[object].parent, (int) objects[object].mem);
+      if (!objects[object].name[0]) {
+        ierr = PetscFPrintf(PETSC_COMM_WORLD, fd,"No Name\n");
+      } else {
+        ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Name: %s\n", objects[object].name);
+      }
+      if (objects[object].info[0] != 0) {
+        ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "No Info\n");
+      } else {
+        ierr = PetscFPrintf(PETSC_COMM_WORLD, fd, "Info: %s\n", objects[object].info);
+      }
     }
   }
   /* Output events */
@@ -1219,7 +1223,7 @@ PetscErrorCode PETSC_DLLEXPORT PetscLogPrintSummary(MPI_Comm comm, const char fi
   ierr = PetscGetUserName(username, 16);CHKERRQ(ierr);
   ierr = PetscGetProgramName(pname, PETSC_MAX_PATH_LEN);CHKERRQ(ierr);
   ierr = PetscGetDate(date, 64);CHKERRQ(ierr);
-  ierr = PetscGetVersion(&version);CHKERRQ(ierr);
+  ierr = PetscGetVersion(&version,256);CHKERRQ(ierr);
   if (size == 1) {
     ierr = PetscFPrintf(comm,fd,"%s on a %s named %s with %d processor, by %s %s\n", pname, arch, hostname, size, username, date); CHKERRQ(ierr);
   } else {
@@ -1393,7 +1397,7 @@ PetscErrorCode PETSC_DLLEXPORT PetscLogPrintSummary(MPI_Comm comm, const char fi
   ierr = PetscFPrintf(comm, fd, "      #                                                        #\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(comm, fd, "      #   This code was compiled with a debugging option,      #\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(comm, fd, "      #   To get timing results run config/configure.py        #\n");CHKERRQ(ierr);
-  ierr = PetscFPrintf(comm, fd, "      #   without --with-debugging=no, the performance will    #\n");CHKERRQ(ierr);
+  ierr = PetscFPrintf(comm, fd, "      #   using --with-debugging=no, the performance will      #\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(comm, fd, "      #   be generally two or three times faster.              #\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(comm, fd, "      #                                                        #\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(comm, fd, "      ##########################################################\n\n\n");CHKERRQ(ierr);
@@ -1407,8 +1411,8 @@ PetscErrorCode PETSC_DLLEXPORT PetscLogPrintSummary(MPI_Comm comm, const char fi
   ierr = PetscFPrintf(comm, fd, "      #   The code for various complex numbers numerical       #\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(comm, fd, "      #   kernels uses C++, which generally is not well        #\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(comm, fd, "      #   optimized.  For performance that is about 4-5 times  #\n");CHKERRQ(ierr);
-  ierr = PetscFPrintf(comm, fd, "      #   faster, specify the flag -DPETSC_USE_FORTRAN_KERNELS #\n");CHKERRQ(ierr);
-  ierr = PetscFPrintf(comm, fd, "      #   in base_variables and recompile the PETSc libraries. #\n");CHKERRQ(ierr);
+  ierr = PetscFPrintf(comm, fd, "      #   faster, specify --with-fortran-kernels=generic       #\n");CHKERRQ(ierr);
+  ierr = PetscFPrintf(comm, fd, "      #   when running config/configure.py.                    #\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(comm, fd, "      #                                                        #\n");CHKERRQ(ierr);
   ierr = PetscFPrintf(comm, fd, "      ##########################################################\n\n\n");CHKERRQ(ierr);
 #endif
@@ -1506,6 +1510,8 @@ PetscErrorCode PETSC_DLLEXPORT PetscLogPrintSummary(MPI_Comm comm, const char fi
         ierr = MPI_Allreduce(&ierr,                           &maxCt, 1, MPI_INT,             MPI_MAX, comm);CHKERRQ(ierr);
         name = "";
       }
+      if (mint < 0.0) SETERRQ2(PETSC_ERR_PLIB,"Minimum time %g over all processors for %s is negative! Not possible!",mint,name);
+      if (minf < 0.0) SETERRQ2(PETSC_ERR_PLIB,"Minimum flops %g over all processors for %s is negative! Not possible!",minf,name);
       totm *= 0.5; totml *= 0.5; totr /= size;
      
       if (maxCt != 0) {
@@ -1604,6 +1610,9 @@ PetscErrorCode PETSC_DLLEXPORT PetscLogPrintSummary(MPI_Comm comm, const char fi
     }
     ierr = PetscCommDestroy(&newcomm);CHKERRQ(ierr);
   }
+  if (!rank) {
+    ierr = PetscOptionsPrint(fd);CHKERRQ(ierr);
+  }
   /* Machine and compile information */
 #if defined(PETSC_USE_FORTRAN_KERNELS)
   ierr = PetscFPrintf(comm, fd, "Compiled with FORTRAN kernels\n");CHKERRQ(ierr);
