@@ -1,4 +1,5 @@
-/*$Id: euler.c,v 1.30 2001/08/07 03:04:22 balay Exp $*/
+#define PETSCTS_DLL
+
 /*
        Code for Timestepping with explicit Euler.
 */
@@ -10,10 +11,10 @@ typedef struct {
 
 #undef __FUNCT__  
 #define __FUNCT__ "TSSetUp_Euler"
-static int TSSetUp_Euler(TS ts)
+static PetscErrorCode TSSetUp_Euler(TS ts)
 {
-  TS_Euler *euler = (TS_Euler*)ts->data;
-  int      ierr;
+  TS_Euler       *euler = (TS_Euler*)ts->data;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   ierr = VecDuplicate(ts->vec_sol,&euler->update);CHKERRQ(ierr);  
@@ -22,12 +23,13 @@ static int TSSetUp_Euler(TS ts)
 
 #undef __FUNCT__  
 #define __FUNCT__ "TSStep_Euler"
-static int TSStep_Euler(TS ts,int *steps,PetscReal *ptime)
+static PetscErrorCode TSStep_Euler(TS ts,PetscInt *steps,PetscReal *ptime)
 {
-  TS_Euler *euler = (TS_Euler*)ts->data;
-  Vec      sol = ts->vec_sol,update = euler->update;
-  int      ierr,i,max_steps = ts->max_steps;
-  PetscScalar   dt = ts->time_step;
+  TS_Euler       *euler = (TS_Euler*)ts->data;
+  Vec            sol = ts->vec_sol,update = euler->update;
+  PetscErrorCode ierr;
+  PetscInt       i,max_steps = ts->max_steps;
+  PetscScalar    dt = ts->time_step;
   
   PetscFunctionBegin;
   *steps = -ts->steps;
@@ -36,7 +38,7 @@ static int TSStep_Euler(TS ts,int *steps,PetscReal *ptime)
   for (i=0; i<max_steps; i++) {
     ts->ptime += ts->time_step;
     ierr = TSComputeRHSFunction(ts,ts->ptime,sol,update);CHKERRQ(ierr);
-    ierr = VecAXPY(&dt,update,sol);CHKERRQ(ierr);
+    ierr = VecAXPY(sol,dt,update);CHKERRQ(ierr);
     ts->steps++;
     ierr = TSMonitor(ts,ts->steps,ts->ptime,sol);CHKERRQ(ierr);
     if (ts->ptime > ts->max_time) break;
@@ -49,10 +51,10 @@ static int TSStep_Euler(TS ts,int *steps,PetscReal *ptime)
 /*------------------------------------------------------------*/
 #undef __FUNCT__  
 #define __FUNCT__ "TSDestroy_Euler"
-static int TSDestroy_Euler(TS ts)
+static PetscErrorCode TSDestroy_Euler(TS ts)
 {
-  TS_Euler *euler = (TS_Euler*)ts->data;
-  int      ierr;
+  TS_Euler       *euler = (TS_Euler*)ts->data;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   if (euler->update) {ierr = VecDestroy(euler->update);CHKERRQ(ierr);}
@@ -63,7 +65,7 @@ static int TSDestroy_Euler(TS ts)
 
 #undef __FUNCT__  
 #define __FUNCT__ "TSSetFromOptions_Euler"
-static int TSSetFromOptions_Euler(TS ts)
+static PetscErrorCode TSSetFromOptions_Euler(TS ts)
 {
   PetscFunctionBegin;
   PetscFunctionReturn(0);
@@ -71,7 +73,7 @@ static int TSSetFromOptions_Euler(TS ts)
 
 #undef __FUNCT__  
 #define __FUNCT__ "TSView_Euler"
-static int TSView_Euler(TS ts,PetscViewer viewer)
+static PetscErrorCode TSView_Euler(TS ts,PetscViewer viewer)
 {
   PetscFunctionBegin;
   PetscFunctionReturn(0);
@@ -82,16 +84,18 @@ static int TSView_Euler(TS ts,PetscViewer viewer)
 /*MC
       TS_EULER - ODE solver using the explicit forward Euler method
 
+  Level: beginner
+
 .seealso:  TSCreate(), TS, TSSetType(), TS_BEULER
 
 M*/
 EXTERN_C_BEGIN
 #undef __FUNCT__  
 #define __FUNCT__ "TSCreate_Euler"
-int TSCreate_Euler(TS ts)
+PetscErrorCode PETSCTS_DLLEXPORT TSCreate_Euler(TS ts)
 {
-  TS_Euler *euler;
-  int      ierr;
+  TS_Euler       *euler;
+  PetscErrorCode ierr;
 
   PetscFunctionBegin;
   ts->ops->setup           = TSSetUp_Euler;
@@ -101,7 +105,6 @@ int TSCreate_Euler(TS ts)
   ts->ops->view            = TSView_Euler;
 
   ierr = PetscNew(TS_Euler,&euler);CHKERRQ(ierr);
-  PetscLogObjectMemory(ts,sizeof(TS_Euler));
   ts->data = (void*)euler;
 
   PetscFunctionReturn(0);
