@@ -286,8 +286,6 @@ PetscErrorCode TSComputeRHSFunction(TS ts,PetscReal t,Vec x,Vec y)
     ierr = MatMult(ts->A,x,y);CHKERRQ(ierr);
   }
 
-  /* apply user-provided boundary conditions (only needed if these are time dependent) */
-  ierr = TSComputeRHSBoundaryConditions(ts,t,y);CHKERRQ(ierr);
   ierr = PetscLogEventEnd(TS_FunctionEval,ts,x,y,0);CHKERRQ(ierr);
 
   PetscFunctionReturn(0);
@@ -403,6 +401,79 @@ PetscErrorCode PETSCTS_DLLEXPORT TSSetRHSMatrix(TS ts,Mat A,Mat B,PetscErrorCode
   PetscFunctionReturn(0);
 }
 
+#undef __FUNCT__  
+#define __FUNCT__ "TSSetLHSMatrix"
+/*@C
+   TSSetLHSMatrix - Sets the function to compute the matrix A, where A U_t = F(U).
+   Also sets the location to store A.
+
+   Collective on TS
+
+   Input Parameters:
++  ts  - the TS context obtained from TSCreate()
+.  A   - matrix
+.  B   - preconditioner matrix (usually same as A)
+.  f   - the matrix evaluation routine; use PETSC_NULL (PETSC_NULL_FUNCTION in fortran)
+         if A is not a function of t.
+-  ctx - [optional] user-defined context for private data for the 
+          matrix evaluation routine (may be PETSC_NULL)
+
+   Calling sequence of func:
+$     func (TS ts,PetscReal t,Mat *A,Mat *B,PetscInt *flag,void *ctx);
+
++  t - current timestep
+.  A - matrix A, where A U_t = F(U)
+.  B - preconditioner matrix, usually the same as A
+.  flag - flag indicating information about the preconditioner matrix
+          structure (same as flag in KSPSetOperators())
+-  ctx - [optional] user-defined context for matrix evaluation routine
+
+   Notes: 
+   See KSPSetOperators() for important information about setting the flag
+   output parameter in the routine func().  Be sure to read this information!
+
+   The routine func() takes Mat * as the matrix arguments rather than Mat.  
+   This allows the matrix evaluation routine to replace A and/or B with a 
+   completely new new matrix structure (not just different matrix elements)
+   when appropriate, for instance, if the nonzero structure is changing
+   throughout the global iterations.
+
+   Notes: 
+   Currently, TSSetLHSMatrix() only supports the TS_BEULER type.
+
+   Level: beginner
+
+.keywords: TS, timestep, set, left-hand-side, matrix
+
+.seealso: TSSetRHSMatrix()
+@*/
+PetscErrorCode PETSCTS_DLLEXPORT TSSetLHSMatrix(TS ts,Mat A,Mat B,PetscErrorCode (*f)(TS,PetscReal,Mat*,Mat*,MatStructure*,void*),void *ctx)
+{
+  PetscTruth     sametype;
+  PetscErrorCode ierr;
+
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(ts,TS_COOKIE,1);
+  PetscValidHeaderSpecific(A,MAT_COOKIE,2);
+  PetscValidHeaderSpecific(B,MAT_COOKIE,3);
+  PetscCheckSameComm(ts,1,A,2);
+  PetscCheckSameComm(ts,1,B,3);
+  
+  if (!ts->type_name) SETERRQ(PETSC_ERR_ARG_NULL,"TS type must be set before calling TSSetLHSMatrix()");
+  ierr = PetscTypeCompare((PetscObject)ts,"beuler",&sametype);CHKERRQ(ierr);
+  if (!sametype)
+    SETERRQ1(PETSC_ERR_SUP,"TS type %s not supported for LHSMatrix",ts->type_name);
+  if (ts->problem_type == TS_NONLINEAR) {
+    SETERRQ(PETSC_ERR_ARG_WRONG,"Not for nonlinear problems yet");
+  }
+
+  ts->ops->lhsmatrix = f;
+  ts->jacPlhs        = ctx; 
+  ts->Alhs           = A;
+  ts->Blhs           = B;
+  PetscFunctionReturn(0);
+}
+
 #undef __FUNCT__  
 #define __FUNCT__ "TSSetRHSJacobian"
 /*@C
@@ -468,71 +539,6 @@ PetscErrorCode PETSCTS_DLLEXPORT TSSetRHSJacobian(TS ts,Mat A,Mat B,PetscErrorCo
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__  
-#define __FUNCT__ "TSComputeRHSBoundaryConditions"
-/*
-   TSComputeRHSBoundaryConditions - Evaluates the boundary condition function. 
-
-   Note: If the user did not provide a function but merely a matrix,
-   this routine applies the matrix.
-*/
-PetscErrorCode TSComputeRHSBoundaryConditions(TS ts,PetscReal t,Vec x)
-{
-  PetscErrorCode ierr;
-
-  PetscFunctionBegin;
-  PetscValidHeaderSpecific(ts,TS_COOKIE,1);
-  PetscValidHeaderSpecific(x,VEC_COOKIE,3);
-  PetscCheckSameComm(ts,1,x,3);
-
-  if (ts->ops->rhsbc) {
-    PetscStackPush("TS user boundary condition function");
-    ierr = (*ts->ops->rhsbc)(ts,t,x,ts->bcP);CHKERRQ(ierr);
-    PetscStackPop;
-    PetscFunctionReturn(0);
-  }
-
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__  
-#define __FUNCT__ "TSSetRHSBoundaryConditions"
-/*@C
-    TSSetRHSBoundaryConditions - Sets the routine for evaluating the function,
-    boundary conditions for the function F.
-
-    Collective on TS
-
-    Input Parameters:
-+   ts - the TS context obtained from TSCreate()
-.   f - routine for evaluating the boundary condition function
--   ctx - [optional] user-defined context for private data for the 
-          function evaluation routine (may be PETSC_NULL)
-
-    Calling sequence of func:
-$     func (TS ts,PetscReal t,Vec F,void *ctx);
-
-+   t - current timestep
-.   F - function vector
--   ctx - [optional] user-defined function context 
-
-    Level: intermediate
-
-.keywords: TS, timestep, set, boundary conditions, function
-@*/
-PetscErrorCode PETSCTS_DLLEXPORT TSSetRHSBoundaryConditions(TS ts,PetscErrorCode (*f)(TS,PetscReal,Vec,void*),void *ctx)
-{
-  PetscFunctionBegin;
-
-  PetscValidHeaderSpecific(ts,TS_COOKIE,1);
-  if (ts->problem_type != TS_LINEAR) {
-    SETERRQ(PETSC_ERR_ARG_WRONG,"For linear problems only");
-  }
-  ts->ops->rhsbc = f;
-  ts->bcP        = ctx;
-  PetscFunctionReturn(0);
-}
-
 #undef __FUNCT__  
 #define __FUNCT__ "TSView"
 /*@C
@@ -934,7 +940,7 @@ PetscErrorCode PETSCTS_DLLEXPORT TSDestroy(TS ts)
 
   if (ts->ksp) {ierr = KSPDestroy(ts->ksp);CHKERRQ(ierr);}
   if (ts->snes) {ierr = SNESDestroy(ts->snes);CHKERRQ(ierr);}
-  ierr = (*(ts)->ops->destroy)(ts);CHKERRQ(ierr);
+  if (ts->ops->destroy) {ierr = (*(ts)->ops->destroy)(ts);CHKERRQ(ierr);}
   ierr = TSClearMonitor(ts);CHKERRQ(ierr);
   ierr = PetscHeaderDestroy(ts);CHKERRQ(ierr);
   PetscFunctionReturn(0);
@@ -1104,137 +1110,6 @@ PetscErrorCode PETSCTS_DLLEXPORT TSSetSolution(TS ts,Vec x)
   PetscFunctionReturn(0);
 }
 
-#undef __FUNCT__  
-#define __FUNCT__ "TSDefaultRhsBC"
-/*@
-  TSDefaultRhsBC - The default boundary condition function which does nothing.
-
-  Collective on TS
-
-  Input Parameters:
-+ ts  - The TS context obtained from TSCreate()
-. rhs - The Rhs
-- ctx - The user-context
-
-  Level: developer
-
-.keywords: TS, Rhs, boundary conditions
-@*/
-PetscErrorCode PETSCTS_DLLEXPORT TSDefaultRhsBC(TS ts,  Vec rhs, void *ctx)
-{
-  PetscFunctionBegin;
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__  
-#define __FUNCT__ "TSSetSystemMatrixBC"
-/*@C
-  TSSetSystemMatrixBC - Sets the function which applies boundary conditions
-  to the system matrix and preconditioner of each system.
-
-  Collective on TS
-
-  Input Parameters:
-+ ts   - The TS context obtained from TSCreate()
-- func - The function
-
-  Calling sequence of func:
-. func (TS ts, Mat A, Mat B, void *ctx);
-
-+ A   - The current system matrix
-. B   - The current preconditioner
-- ctx - The user-context
-
-  Level: intermediate
-
-.keywords: TS, System matrix, boundary conditions
-@*/
-PetscErrorCode PETSCTS_DLLEXPORT TSSetSystemMatrixBC(TS ts, PetscErrorCode (*func)(TS, Mat, Mat, void *))
-{
-  PetscFunctionBegin;
-  PetscValidHeaderSpecific(ts, TS_COOKIE,1);
-  ts->ops->applymatrixbc = func;
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__  
-#define __FUNCT__ "TSDefaultSystemMatrixBC"
-/*@
-  TSDefaultSystemMatrixBC - The default boundary condition function which
-  does nothing.
-
-  Collective on TS
-
-  Input Parameters:
-+ ts  - The TS context obtained from TSCreate()
-. A   - The system matrix
-. B   - The preconditioner
-- ctx - The user-context
-
-  Level: developer
-
-.keywords: TS, System matrix, boundary conditions
-@*/
-PetscErrorCode PETSCTS_DLLEXPORT TSDefaultSystemMatrixBC(TS ts, Mat A, Mat B, void *ctx)
-{
-  PetscFunctionBegin;
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__  
-#define __FUNCT__ "TSSetSolutionBC"
-/*@C
-  TSSetSolutionBC - Sets the function which applies boundary conditions
-  to the solution of each system. This is necessary in nonlinear systems
-  which time dependent boundary conditions.
-
-  Collective on TS
-
-  Input Parameters:
-+ ts   - The TS context obtained from TSCreate()
-- func - The function
-
-  Calling sequence of func:
-. func (TS ts, Vec rsol, void *ctx);
-
-+ sol - The current solution vector
-- ctx - The user-context
-
-  Level: intermediate
-
-.keywords: TS, solution, boundary conditions
-@*/
-PetscErrorCode PETSCTS_DLLEXPORT TSSetSolutionBC(TS ts, PetscErrorCode (*func)(TS, Vec, void *))
-{
-  PetscFunctionBegin;
-  PetscValidHeaderSpecific(ts, TS_COOKIE,1);
-  ts->ops->applysolbc = func;
-  PetscFunctionReturn(0);
-}
-
-#undef __FUNCT__  
-#define __FUNCT__ "TSDefaultSolutionBC"
-/*@
-  TSDefaultSolutionBC - The default boundary condition function which
-  does nothing.
-
-  Collective on TS
-
-  Input Parameters:
-+ ts  - The TS context obtained from TSCreate()
-. sol - The solution
-- ctx - The user-context
-
-  Level: developer
-
-.keywords: TS, solution, boundary conditions
-@*/
-PetscErrorCode PETSCTS_DLLEXPORT TSDefaultSolutionBC(TS ts, Vec sol, void *ctx)
-{
-  PetscFunctionBegin;
-  PetscFunctionReturn(0);
-}
-
 #undef __FUNCT__  
 #define __FUNCT__ "TSSetPreStep"
 /*@C
