@@ -46,9 +46,6 @@ PetscErrorCode PETSCTS_DLLEXPORT TSCreate(MPI_Comm comm, TS *ts) {
   t->bops->publish    = TSPublish_Petsc;
   t->type_name        = PETSC_NULL;
 
-  t->ops->applymatrixbc = TSDefaultSystemMatrixBC;
-  t->ops->applyrhsbc    = TSDefaultRhsBC;
-  t->ops->applysolbc    = TSDefaultSolutionBC;
   t->ops->prestep       = TSDefaultPreStep;
   t->ops->update        = TSDefaultUpdate;
   t->ops->poststep      = TSDefaultPostStep;
@@ -58,12 +55,13 @@ PetscErrorCode PETSCTS_DLLEXPORT TSCreate(MPI_Comm comm, TS *ts) {
   t->vec_sol            = PETSC_NULL;
   t->vec_sol_always     = PETSC_NULL;
   t->numbermonitors     = 0;
-  t->isGTS              = PETSC_FALSE;
   t->isExplicit         = PETSC_NULL;
   t->Iindex             = PETSC_NULL;
-  t->ksp               = PETSC_NULL;
+  t->ksp                = PETSC_NULL;
   t->A                  = PETSC_NULL;
   t->B                  = PETSC_NULL;
+  t->Alhs               = PETSC_NULL;
+  t->Blhs               = PETSC_NULL;
   t->snes               = PETSC_NULL;
   t->funP               = PETSC_NULL;
   t->jacP               = PETSC_NULL;
@@ -86,6 +84,7 @@ PetscErrorCode PETSCTS_DLLEXPORT TSCreate(MPI_Comm comm, TS *ts) {
   PetscFunctionReturn(0);
 }
 
+/* Set A = 1/dt*Alhs - A, B = 1/dt*Blhs - B */
 #undef __FUNCT__  
 #define __FUNCT__ "TSScaleShiftMatrices"
 PetscErrorCode TSScaleShiftMatrices(TS ts,Mat A,Mat B,MatStructure str)
@@ -98,11 +97,19 @@ PetscErrorCode TSScaleShiftMatrices(TS ts,Mat A,Mat B,MatStructure str)
   ierr = PetscTypeCompare((PetscObject)ts->A,MATMFFD,&flg);CHKERRQ(ierr);
   if (!flg) {
     ierr = MatScale(ts->A,-1.0);CHKERRQ(ierr);
-    ierr = MatShift(ts->A,mdt);CHKERRQ(ierr);
+    if (ts->Alhs){
+      ierr = MatAXPY(ts->A,mdt,ts->Alhs,DIFFERENT_NONZERO_PATTERN);CHKERRQ(ierr);
+    } else {
+      ierr = MatShift(ts->A,mdt);CHKERRQ(ierr);
+    }
   }
   if (ts->B != ts->A && str != SAME_PRECONDITIONER) {
     ierr = MatScale(ts->B,-1.0);CHKERRQ(ierr);
-    ierr = MatShift(ts->B,mdt);CHKERRQ(ierr);
+    if (ts->Blhs){
+      ierr = MatAXPY(ts->B,mdt,ts->Blhs,DIFFERENT_NONZERO_PATTERN);CHKERRQ(ierr);
+    } else {
+      ierr = MatShift(ts->B,mdt);CHKERRQ(ierr);
+    }
   }
   PetscFunctionReturn(0);
 }
