@@ -1,4 +1,3 @@
-/*$Id: ex5.c,v 1.7 2001/04/10 19:34:49 bsmith Exp $*/
 
 static char help[] = "Tests ISLocalToGlobalMappingGetInfo.()\n\n";
 
@@ -8,7 +7,9 @@ static char help[] = "Tests ISLocalToGlobalMappingGetInfo.()\n\n";
 #define __FUNCT__ "main"
 int main(int argc,char **argv)
 {
-  int                    ierr,size,nlocal,local[5],rank,nneigh,*neigh,**ineigh,*numneigh;
+  PetscErrorCode         ierr;
+  PetscMPIInt            size,rank;
+  PetscInt               nlocal,local[5],nneigh,*neigh,**ineigh,*numneigh;
   ISLocalToGlobalMapping mapping;
 
 
@@ -16,7 +17,7 @@ int main(int argc,char **argv)
   ierr = MPI_Comm_size(PETSC_COMM_WORLD,&size);CHKERRQ(ierr);
   if (size != 3) SETERRQ(1,"Must run with three processors");
   ierr = MPI_Comm_rank(PETSC_COMM_WORLD,&rank);CHKERRQ(ierr);
-  if (rank == 0) {
+  if (!rank) {
     nlocal = 4; local[0] = 0; local[1] = 3; local[2] = 2; local[3] = 1;
   } else if (rank == 1) {
     nlocal = 4; local[0] = 3; local[1] = 5; local[2] = 4; local[3] = 2;
