@@ -81,7 +81,7 @@ PetscErrorCode VecPlaceArray_MPI(Vec vin,const PetscScalar *a)
 EXTERN PetscErrorCode VecLoad_Binary(PetscViewer, VecType, Vec*);
 EXTERN PetscErrorCode VecGetValues_MPI(Vec,PetscInt,const PetscInt [],PetscScalar []);
 
-static struct _VecOps DvOps = { VecDuplicate_MPI,
+static struct _VecOps DvOps = { VecDuplicate_MPI, /* 1 */
             VecDuplicateVecs_Default,
             VecDestroyVecs_Default,
             VecDot_MPI,
@@ -90,7 +90,7 @@ static struct _VecOps DvOps = { VecDuplicate_MPI,
             VecTDot_MPI,
             VecMTDot_MPI,
             VecScale_Seq,
-            VecCopy_Seq,
+            VecCopy_Seq, /* 10 */
             VecSet_Seq,
             VecSwap_Seq,
             VecAXPY_Seq,
@@ -100,7 +100,7 @@ static struct _VecOps DvOps = { VecDuplicate_MPI,
             VecWAXPY_Seq,
             VecPointwiseMult_Seq,
             VecPointwiseDivide_Seq,
-            VecSetValues_MPI,
+            VecSetValues_MPI, /* 20 */
             VecAssemblyBegin_MPI,
             VecAssemblyEnd_MPI,
             VecGetArray_Seq,
@@ -495,6 +495,8 @@ PetscErrorCode PETSCVEC_DLLEXPORT VecGhostUpdateEnd(Vec g,InsertMode insertmode,
    Use VecGhostGetLocalForm() to access the local, ghosted representation 
    of the vector.
 
+   This also automatically sets the ISLocalToGlobalMapping() for this vector.
+
    Level: advanced
 
    Concepts: vectors^creating with array
@@ -507,10 +509,12 @@ PetscErrorCode PETSCVEC_DLLEXPORT VecGhostUpdateEnd(Vec g,InsertMode insertmode,
 @*/ 
 PetscErrorCode PETSCVEC_DLLEXPORT VecCreateGhostWithArray(MPI_Comm comm,PetscInt n,PetscInt N,PetscInt nghost,const PetscInt ghosts[],const PetscScalar array[],Vec *vv)
 {
-  PetscErrorCode ierr;
-  Vec_MPI        *w;
-  PetscScalar    *larray;
-  IS             from,to;
+  PetscErrorCode         ierr;
+  Vec_MPI                *w;
+  PetscScalar            *larray;
+  IS                     from,to;
+  ISLocalToGlobalMapping ltog;
+  PetscInt               rstart,i,*indices;
 
   PetscFunctionBegin;
   *vv = 0;
@@ -540,6 +544,20 @@ PetscErrorCode PETSCVEC_DLLEXPORT VecCreateGhostWithArray(MPI_Comm comm,PetscInt
   ierr = ISDestroy(to);CHKERRQ(ierr);
   ierr = ISDestroy(from);CHKERRQ(ierr);
 
+  /* set local to global mapping for ghosted vector */
+  ierr = PetscMalloc((n+nghost)*sizeof(PetscInt),&indices);CHKERRQ(ierr);
+  ierr = VecGetOwnershipRange(*vv,&rstart,PETSC_NULL);CHKERRQ(ierr);
+  for (i=0; i<n; i++) {
+    indices[i] = rstart + i;
+  }
+  for (i=0; i<nghost; i++) {
+    indices[n+i] = ghosts[i];
+  }
+  ierr = ISLocalToGlobalMappingCreate(comm,n+nghost,indices,&ltog);CHKERRQ(ierr);
+  ierr = PetscFree(indices);CHKERRQ(ierr);
+  ierr = VecSetLocalToGlobalMapping(*vv,ltog);CHKERRQ(ierr);
+  ierr = ISLocalToGlobalMappingDestroy(ltog);CHKERRQ(ierr);
+  ierr = PetscFree(indices);CHKERRQ(ierr);
   PetscFunctionReturn(0);
 }
 
@@ -564,6 +582,8 @@ PetscErrorCode PETSCVEC_DLLEXPORT VecCreateGhostWithArray(MPI_Comm comm,PetscInt
    Use VecGhostGetLocalForm() to access the local, ghosted representation 
    of the vector.
 
+   This also automatically sets the ISLocalToGlobalMapping() for this vector.
+
    Level: advanced
 
    Concepts: vectors^ghosted
