@@ -60,7 +60,9 @@ PetscErrorCode VecNorm_Seq(Vec xin,NormType type,PetscReal* z)
     *z = BLASnrm2_(&bn,xx,&one);
 #endif
     ierr = VecRestoreArray(xin,&xx);CHKERRQ(ierr);
-    ierr = PetscLogFlops(2*n-1);CHKERRQ(ierr);
+    if (n > 0) {
+      ierr = PetscLogFlops(2*n-1);CHKERRQ(ierr);
+    }
   } else if (type == NORM_INFINITY) {
     PetscInt          i;
     PetscReal    max = 0.0,tmp;
@@ -78,7 +80,9 @@ PetscErrorCode VecNorm_Seq(Vec xin,NormType type,PetscReal* z)
     ierr = VecGetArray(xin,&xx);CHKERRQ(ierr);
     *z = BLASasum_(&bn,xx,&one);
     ierr = VecRestoreArray(xin,&xx);CHKERRQ(ierr);
-    ierr = PetscLogFlops(n-1);CHKERRQ(ierr);
+    if (n > 0) {
+      ierr = PetscLogFlops(n-1);CHKERRQ(ierr);
+    }
   } else if (type == NORM_1_AND_2) {
     ierr = VecNorm_Seq(xin,NORM_1,z);CHKERRQ(ierr);
     ierr = VecNorm_Seq(xin,NORM_2,z+1);CHKERRQ(ierr);
@@ -124,18 +128,72 @@ PetscErrorCode VecView_Seq_File(Vec xin,PetscViewer viewer)
 #endif
     }
   } else if (format == PETSC_VIEWER_ASCII_VTK || format == PETSC_VIEWER_ASCII_VTK_CELL) {
+    /* 
+       state 0: No header has been output
+       state 1: Only POINT_DATA has been output
+       state 2: Only CELL_DATA has been output
+       state 3: Output both, POINT_DATA last
+       state 4: Output both, CELL_DATA last 
+    */
+    static PetscInt stateId = -1;
+    int outputState = 0;
+    PetscTruth hasState;
+    int doOutput = 0;
     PetscInt bs, b;
 
+    if (stateId < 0) {
+      ierr = PetscObjectComposedDataRegister(&stateId);CHKERRQ(ierr);
+    }
+    ierr = PetscObjectComposedDataGetInt((PetscObject) viewer, stateId, outputState, hasState);CHKERRQ(ierr);
+    if (!hasState) {
+      outputState = 0;
+    }
+    ierr = PetscObjectGetName((PetscObject) xin, &name);CHKERRQ(ierr);
     ierr = VecGetBlockSize(xin, &bs);CHKERRQ(ierr);
     if ((bs < 1) || (bs > 3)) {
       SETERRQ1(PETSC_ERR_ARG_WRONGSTATE, "VTK can only handle 3D objects, but vector dimension is %d", bs);
     }
     if (format == PETSC_VIEWER_ASCII_VTK) {
-      ierr = PetscViewerASCIIPrintf(viewer, "POINT_DATA %d\n", n);CHKERRQ(ierr);
+      if (outputState == 0) {
+        outputState = 1;
+        doOutput = 1;
+      } else if (outputState == 1) {
+        doOutput = 0;
+      } else if (outputState == 2) {
+        outputState = 3;
+        doOutput = 1;
+      } else if (outputState == 3) {
+        doOutput = 0;
+      } else if (outputState == 4) {
+        SETERRQ(PETSC_ERR_ARG_WRONGSTATE, "Tried to output POINT_DATA again after intervening CELL_DATA");
+      }
+      if (doOutput) {
+        ierr = PetscViewerASCIIPrintf(viewer, "POINT_DATA %d\n", n);CHKERRQ(ierr);
+      }
     } else {
-      ierr = PetscViewerASCIIPrintf(viewer, "CELL_DATA %d\n", n);CHKERRQ(ierr);
+      if (outputState == 0) {
+        outputState = 2;
+        doOutput = 1;
+      } else if (outputState == 1) {
+        outputState = 4;
+        doOutput = 1;
+      } else if (outputState == 2) {
+        doOutput = 0;
+      } else if (outputState == 3) {
+        SETERRQ(PETSC_ERR_ARG_WRONGSTATE, "Tried to output CELL_DATA again after intervening POINT_DATA");
+      } else if (outputState == 4) {
+        doOutput = 0;
+      }
+      if (doOutput) {
+        ierr = PetscViewerASCIIPrintf(viewer, "CELL_DATA %d\n", n);CHKERRQ(ierr);
+      }
+    }
+    ierr = PetscObjectComposedDataSetInt((PetscObject) viewer, stateId, outputState);CHKERRQ(ierr);
+    if (name) {
+      ierr = PetscViewerASCIIPrintf(viewer, "SCALARS %s double %d\n", name, bs);CHKERRQ(ierr);
+    } else {
+      ierr = PetscViewerASCIIPrintf(viewer, "SCALARS scalars double %d\n", bs);CHKERRQ(ierr);
     }
-    ierr = PetscViewerASCIIPrintf(viewer, "SCALARS scalars double %d\n", bs);CHKERRQ(ierr);
     ierr = PetscViewerASCIIPrintf(viewer, "LOOKUP_TABLE default\n");CHKERRQ(ierr);
     for (i=0; i<n/bs; i++) {
       for (b=0; b<bs; b++) {
@@ -561,7 +619,7 @@ static PetscErrorCode VecPublish_Seq(PetscObject obj)
 
 EXTERN PetscErrorCode VecLoad_Binary(PetscViewer, VecType, Vec*);
 
-static struct _VecOps DvOps = {VecDuplicate_Seq,
+static struct _VecOps DvOps = {VecDuplicate_Seq, /* 1 */
             VecDuplicateVecs_Default,
             VecDestroyVecs_Default,
             VecDot_Seq,
@@ -570,7 +628,7 @@ static struct _VecOps DvOps = {VecDuplicate_Seq,
             VecTDot_Seq,
             VecMTDot_Seq,
             VecScale_Seq,
-            VecCopy_Seq,
+            VecCopy_Seq, /* 10 */
             VecSet_Seq,
             VecSwap_Seq,
             VecAXPY_Seq,
@@ -580,14 +638,15 @@ static struct _VecOps DvOps = {VecDuplicate_Seq,
             VecWAXPY_Seq,
             VecPointwiseMult_Seq,
             VecPointwiseDivide_Seq, 
-            VecSetValues_Seq,0,0,
+            VecSetValues_Seq, /* 20 */
+            0,0,
             VecGetArray_Seq,
             VecGetSize_Seq,
             VecGetSize_Seq,
             VecRestoreArray_Seq,
             VecMax_Seq,
             VecMin_Seq,
-            VecSetRandom_Seq,0,
+            VecSetRandom_Seq,0, /* 30 */
             VecSetValuesBlocked_Seq,
             VecDestroy_Seq,
             VecView_Seq,
@@ -597,7 +656,7 @@ static struct _VecOps DvOps = {VecDuplicate_Seq,
             VecTDot_Seq,
             VecNorm_Seq,
             VecMDot_Seq,
-            VecMTDot_Seq,
+            VecMTDot_Seq, /* 40 */
             VecLoadIntoVector_Default,
             VecReciprocal_Default,
             0, /* VecViewNative */
@@ -607,7 +666,7 @@ static struct _VecOps DvOps = {VecDuplicate_Seq,
             VecResetArray_Seq,
             0,
             VecMaxPointwiseDivide_Seq,
-            VecLoad_Binary,
+            VecLoad_Binary, /* 50 */
             VecPointwiseMax_Seq,
             VecPointwiseMaxAbs_Seq,
             VecPointwiseMin_Seq,
